@Override
	public Void call() throws Exception
	{
		final PdpEngineConfiguration configuration = PdpEngineConfiguration.getInstance(confFile, catalogLocation, extensionXsdLocation);
		System.out.println();
		switch (requestType)
		{

			case XACML_JSON:
				final JSONObject jsonRequest;
				try (InputStream inputStream = new FileInputStream(reqFile))
				{
					jsonRequest = new JSONObject(new JSONTokener(inputStream));
					if (!jsonRequest.has("Request"))
					{
						throw new IllegalArgumentException("Invalid XACML JSON Request file: " + reqFile + ". Expected root key: \"Request\"");
					}

					XacmlJsonUtils.REQUEST_SCHEMA.validate(jsonRequest);
				}

				final DecisionResultPostprocessor<IndividualXacmlJsonRequest, JSONObject> defaultResultPostproc = new BaseXacmlJsonResultPostprocessor(
				        configuration.getClientRequestErrorVerbosityLevel());
				final DecisionRequestPreprocessor<JSONObject, IndividualXacmlJsonRequest> defaultReqPreproc = SingleDecisionXacmlJsonRequestPreprocessor.LaxVariantFactory.INSTANCE.getInstance(
				        configuration.getAttributeValueFactoryRegistry(), configuration.isStrictAttributeIssuerMatchEnabled(), configuration.isXpathEnabled(), XmlUtils.SAXON_PROCESSOR,
				        defaultResultPostproc.getFeatures());

				final PdpEngineInoutAdapter<JSONObject, JSONObject> jsonPdpEngineAdapter = PdpEngineAdapters.newInoutAdapter(JSONObject.class, JSONObject.class, configuration, defaultReqPreproc,
				        defaultResultPostproc);
				final JSONObject jsonResponse = jsonPdpEngineAdapter.evaluate(jsonRequest);
				System.out.println(jsonResponse.toString(formattedOutput ? 4 : 0));
				break;

			default:
				final XmlnsFilteringParser parser = XacmlJaxbParsingUtils.getXacmlParserFactory(true).getInstance();
				final Object request = parser.parse(reqFile.toURI().toURL());
				if (!(request instanceof Request))
				{
					throw new IllegalArgumentException("Invalid XACML/XML Request file (according to XACML 3.0 schema): " + reqFile);
				}

				final PdpEngineInoutAdapter<Request, Response> xmlPdpEngineAdapter = PdpEngineAdapters.newXacmlJaxbInoutAdapter(configuration);
				final Response xmlResponse = xmlPdpEngineAdapter.evaluate((Request) request, parser.getNamespacePrefixUriMap());
				final Marshaller marshaller = Xacml3JaxbHelper.createXacml3Marshaller();
				marshaller.setProperty(Marshaller.JAXB_FORMATTED_OUTPUT, formattedOutput);
				marshaller.marshal(xmlResponse, System.out);
				break;
		}

		System.out.println();
		return null;
	}
