public boolean match(final EvaluationContext context) throws IndeterminateEvaluationException
	{
		// atLeastOneIndeterminate = true iff lastIndeterminate != null
		IndeterminateEvaluationException lastIndeterminate = null;

		// index of the current Match in this AllOf
		int childIndex = 0;

		// index of last Indeterminate for enhanced error message
		int lastIndeterminateChildIndex = -1;

		/*
		 * By construction, there must be at least one Match
		 */
		for (final MatchEvaluator matchEvaluator : evaluatableMatchList)
		{
			final boolean isMatched;
			try
			{
				isMatched = matchEvaluator.match(context);
				if (LOGGER.isDebugEnabled())
				{
					// Beware of autoboxing which causes call to
					// Boolean.valueOf(...), Integer.valueOf(...)
					LOGGER.debug("AllOf/Match#{} -> {}", childIndex, isMatched);
				}
			}
			catch (final IndeterminateEvaluationException e)
			{
				if (LOGGER.isDebugEnabled())
				{
					// Beware of autoboxing which causes call to
					// Integer.valueOf(...)
					LOGGER.debug("AllOf/Match#{} -> Indeterminate", childIndex, e);
				}
				lastIndeterminate = e;
				lastIndeterminateChildIndex = childIndex;
				continue;
			}

			/*
			 * At least one False -> No match
			 */
			if (!isMatched)
			{
				return false;
			}

			// True (Match) -> continue, all must be true to match
			childIndex += 1;
		}

		// No False (=NO_MATCH) occurred
		// lastIndeterminate == null iff no Indeterminate occurred
		if (lastIndeterminate == null)
		{
			// No False/Indeterminate, i.e. all True -> Match
			return true;
		}

		// No False but at least one Indeterminate (lastIndeterminate != null)
		throw new IndeterminateEvaluationException("Error evaluating <AllOf>'s <Match>#" + lastIndeterminateChildIndex,
				lastIndeterminate.getStatusCode(), lastIndeterminate);
	}
