public boolean match(final EvaluationContext context) throws IndeterminateEvaluationException
	{
		// atLeastOneIndeterminate = true iff lastIndeterminate != null
		IndeterminateEvaluationException lastIndeterminate = null;

		// index of the current AllOf in this AnyOf
		int childIndex = 0;

		// index of last Indeterminate for enhanced error message
		int lastIndeterminateChildIndex = -1;

		/*
		 * By construction, there must be at least one AllOf
		 */
		for (final AllOfEvaluator allOfEvaluator : evaluatableAllOfList)
		{
			final boolean isMatched;
			try
			{
				isMatched = allOfEvaluator.match(context);
				if (LOGGER.isDebugEnabled())
				{
					// Beware of autoboxing which causes call to
					// Boolean.valueOf(...), Integer.valueOf(...)
					LOGGER.debug("AnyOf/AllOf#{} -> {}", childIndex, isMatched);
				}
			}
			catch (final IndeterminateEvaluationException e)
			{
				if (LOGGER.isDebugEnabled())
				{
					// Beware of autoboxing which causes call to
					// Integer.valueOf(...)
					LOGGER.debug("AnyOf/AllOf#{} -> Indeterminate", childIndex, e);
				}
				lastIndeterminate = e;
				lastIndeterminateChildIndex = childIndex;
				continue;
			}

			/*
			 * At least one Match -> Match
			 */
			if (isMatched)
			{
				return true;
			}

			// No Match -> continue, all must be true to match
			childIndex += 1;
		}

		// No True (Match) occurred
		// lastIndeterminate == null iff no Indeterminate occurred
		if (lastIndeterminate == null)
		{
			// No True/Indeterminate, i.e. all "No match" -> No match
			return false;
		}

		// No Match and at least one Indeterminate (lastIndeterminate != null)
		// -> Indeterminate
		throw new IndeterminateEvaluationException("Error evaluating <AnyOf>'s <AllOf>#" + lastIndeterminateChildIndex,
				lastIndeterminate.getStatusCode(), lastIndeterminate);
	}
