public static CloseableAttributeProvider getInstance(final List<CloseableNamedAttributeProvider.DependencyAwareFactory> attributeProviderFactories,
	        final AttributeValueFactoryRegistry attributeFactory, final boolean strictAttributeIssuerMatch) throws IOException
	{
		if (attributeProviderFactories == null || attributeProviderFactories.isEmpty())
		{
			return EVALUATION_CONTEXT_ONLY_SCOPED_CLOSEABLE_ATTRIBUTE_PROVIDER;
		}

		final ListMultimap<AttributeFqn, NamedAttributeProvider> modulesByAttributeId = ArrayListMultimap.create();
		final int moduleCount = attributeProviderFactories.size();
		final Set<ModuleAdapter> mutableModuleCloserSet = HashCollections.newUpdatableSet(moduleCount);
		for (final CloseableNamedAttributeProvider.DependencyAwareFactory attProviderFactory : attributeProviderFactories)
		{
			try
			{
				final Set<AttributeDesignatorType> requiredAttrs = attProviderFactory.getDependencies();
				/*
				 * Each AttributeProviderModule is given a read-only AttributeProvider - aka "dependency attribute Provider" - to find any attribute they require (dependency), based on the attribute
				 * Provider modules that provide these required attributes (set above); read-only so that modules use this attribute Provider only to get required attributes, nothing else. Create this
				 * dependency attribute Provider.
				 */
				final AttributeProvider depAttrProvider;
				if (requiredAttrs == null)
				{
					depAttrProvider = ModularAttributeProvider.EVALUATION_CONTEXT_ONLY_SCOPED_ATTRIBUTE_PROVIDER;
				} else
				{
					final ImmutableListMultimap<AttributeFqn, NamedAttributeProvider> immutableCopyOfAttrProviderModsByAttrId = ImmutableListMultimap.copyOf(modulesByAttributeId);
					depAttrProvider = new ModularAttributeProvider(immutableCopyOfAttrProviderModsByAttrId, requiredAttrs, strictAttributeIssuerMatch);
				}

				/*
				 * attrProviderMod closing isn't done in this method but handled in close() method when closing all modules
				 */
				final ModuleAdapter moduleAdapter = new ModuleAdapter(attProviderFactory.getInstance(attributeFactory, depAttrProvider));
				mutableModuleCloserSet.add(moduleAdapter);

				for (final AttributeDesignatorType attrDesignator : moduleAdapter.getProvidedAttributes())
				{
					final AttributeFqn attrGUID = AttributeFqns.newInstance(attrDesignator);
					/*
					 * We allow multiple modules supporting the same attribute designator (as fall-back: if one does not find any value, the next one comes in)
					 */
					modulesByAttributeId.put(attrGUID, moduleAdapter.getAdaptedModule());
				}
			} catch (final IllegalArgumentException e)
			{
				close(mutableModuleCloserSet);
				throw e;
			}
		}

		if (modulesByAttributeId.isEmpty())
		{
			return EVALUATION_CONTEXT_ONLY_SCOPED_CLOSEABLE_ATTRIBUTE_PROVIDER;
		}

		return new CloseableAttributeProvider(ImmutableListMultimap.copyOf(modulesByAttributeId), HashCollections.newImmutableSet(mutableModuleCloserSet), strictAttributeIssuerMatch);
	}
