public static PdpEngineConfiguration getInstance(final String confLocation, final PdpModelHandler modelHandler) throws IOException, IllegalArgumentException
	{

		if (modelHandler == null)
		{
			throw NULL_PDP_MODEL_HANDLER_ARGUMENT_EXCEPTION;
		}

		try
		{
			final File confFile = ResourceUtils.getFile(confLocation);
			return getInstance(confFile, modelHandler);
		}
		catch (final FileNotFoundException e)
		{
			if (LOGGER.isInfoEnabled())
			{
				LOGGER.info(
				        "Could not resolve input PDP configuration location to a file in the file system ({}). Trying to resolve as generic URL instead (but PARENT_DIR property will remain undefined).",
				        e.getMessage());
			}
		}

		/*
		 * Not a file in the file system, e.g. maybe a file resource inside a JAR/ZIP
		 */
		final URL confUrl;
		try
		{
			confUrl = ResourceUtils.getURL(confLocation);
		}
		catch (final FileNotFoundException e)
		{
			throw new IllegalArgumentException("Invalid PDP configuration location (neither a file in the file system nor a valid URL): " + confLocation, e);
		}

		/*
		 * Leave PARENT_DIR environment property undefined since we cannot get the file's parent directory
		 */
		LOGGER.debug("Property {} = <undefined>", EnvironmentPropertyName.PARENT_DIR);
		final EnvironmentProperties envProps = new DefaultEnvironmentProperties();
		return getInstance(new StreamSource(confUrl.toExternalForm()), modelHandler, envProps);
	}
