@Override
	public CombiningAlg.Evaluator getInstance(final Iterable<CombiningAlgParameter<? extends T>> params, final Iterable<? extends T> combinedElements)
	        throws UnsupportedOperationException, IllegalArgumentException
	{
		// if no element combined -> decision is overridden Effect
		if (combinedElements == null)
		{
			LOGGER.warn("{}: no element to combine -> optimization: replacing with equivalent evaluator returning constant decision NotApplicable", this);
			return CombiningAlgEvaluators.NOT_APPLICABLE_CONSTANT_EVALUATOR;
		}

		final Iterator<? extends Decidable> combinedEltIterator = combinedElements.iterator();
		if (!combinedEltIterator.hasNext())
		{
			// empty (no element to combine)
			LOGGER.warn("{}: no element to combine -> optimization: replacing with equivalent evaluator returning constant decision NotApplicable", this);
			return CombiningAlgEvaluators.NOT_APPLICABLE_CONSTANT_EVALUATOR;
		}

		if (!RuleEvaluator.class.isAssignableFrom(getCombinedElementType()))
		{
			// combined elements are not rules but policies
			return new Evaluator(combinedElements);
		}

		// combined elements are Rules, we can optimize
		/*
		 * There is at least one Rule. Prepare to iterate over Rules.
		 */
		/*
		 * If we found any empty rule
		 */
		final Deque<RuleEvaluator> finalRules = new ArrayDeque<>();
		while (combinedEltIterator.hasNext())
		{
			final RuleEvaluator rule = (RuleEvaluator) combinedEltIterator.next();
			finalRules.add(rule);
			if (rule.isAlwaysApplicable())
			{
				/*
				 * The algorithm won't go further than that
				 */
				break;
			}
		}

		/*
		 * if(combinedEltIterator.hasNext()), combinedElements has more elements than finalRules, so finalRules is a subset of combinedElements; else they have the same elements
		 */
		return new Evaluator(combinedEltIterator.hasNext() ? finalRules : combinedElements);
	}
