public static Expression<?> newInstance(final ApplyType xacmlApply, final XPathCompiler xPathCompiler, final ExpressionFactory expFactory, final Deque<String> longestVarRefChain)
	        throws IllegalArgumentException
	{
		if (xacmlApply == null)
		{
			throw NULL_XACML_APPLY_ELEMENT_EXCEPTION;
		}

		if (expFactory == null)
		{
			throw NULL_EXPRESSION_FACTORY_EXCEPTION;
		}

		final String applyDesc = xacmlApply.getDescription();
		// function args
		final List<JAXBElement<? extends ExpressionType>> applyArgExpressions = xacmlApply.getExpressions();
		final List<Expression<?>> funcInputs = new ArrayList<>(applyArgExpressions.size());
		for (final JAXBElement<? extends ExpressionType> exprElt : applyArgExpressions)
		{
			final Expression<?> exprHandler;
			try
			{
				exprHandler = expFactory.getInstance(exprElt.getValue(), xPathCompiler, longestVarRefChain);
			} catch (final IllegalArgumentException e)
			{
				throw new IllegalArgumentException("Error parsing one of Apply [description=" + applyDesc + "]'s function arguments (Expressions)", e);
			}

			funcInputs.add(exprHandler);
		}

		final String functionId = xacmlApply.getFunctionId();

		// get the function instance
		// Determine whether this is a higher-order function, i.e. first parameter is a sub-function
		final Datatype<? extends AttributeValue> subFuncPrimReturnType;
		if (funcInputs.isEmpty())
		{
			subFuncPrimReturnType = null;
		} else
		{
			final Expression<?> xpr0 = funcInputs.get(0);
			if (xpr0 instanceof FunctionExpression)
			{
				final Datatype<?> subFuncReturnType = ((FunctionExpression) xpr0).getValue().get().getReturnType();
				if (subFuncReturnType.getTypeParameter().isPresent() || subFuncReturnType == StandardDatatypes.FUNCTION)
				{
					throw new IllegalArgumentException("Error parsing Apply[description=" + applyDesc + "]: Invalid return type (" + subFuncReturnType
					        + ") of sub-function (first-parameter) of Apply Function '" + functionId + "'. Expected: AttributeValue datatype.");
				}

				/*
				 * FIXME: is there a cleaner way to cast?
				 */
				subFuncPrimReturnType = (Datatype<? extends AttributeValue>) subFuncReturnType;
			} else
			{
				subFuncPrimReturnType = null;
			}
		}

		final FunctionExpression functionExp;
		try
		{
			functionExp = expFactory.getFunction(functionId, subFuncPrimReturnType);
		} catch (final IllegalArgumentException e)
		{
			throw new IllegalArgumentException(
			        "Invalid Apply[description=" + applyDesc + "]: Invalid return type (" + subFuncPrimReturnType + ") of sub-function (first-parameter) of Apply Function '" + functionId + "'", e);
		}

		if (functionExp == null)
		{
			throw new IllegalArgumentException("Invalid Apply[description=" + applyDesc + "]: Invalid Function: function ID '" + functionId + "' not supported");
		}

		final Function<?> function = functionExp.getValue().get();

		// check that the given inputs work for the function and get the optimized functionCall
		final FunctionCall<?> funcCall;
		try
		{
			funcCall = function.newCall(Collections.unmodifiableList(funcInputs));
		} catch (final IllegalArgumentException e)
		{
			throw new IllegalArgumentException("Invalid Apply[Description = " + applyDesc + "]: Invalid args for function " + function, e);
		}

		return newInstance(funcCall, applyDesc);
	}
