private static <V extends Value> Expression<V> newInstance(final FunctionCall<V> functionCall, final String description)
	{
		/*
		 * Check whether the Apply Expression is constant -> try to pre-evaluate the result statically (out of context, i.e. in null context), to prevent useless re-evaluation of the same thing
		 */
		V staticEvalResult = null;
		try
		{
			staticEvalResult = functionCall.evaluate(null);
			LOGGER.debug("Apply[Description = " + description + "]: static evaluation OK -> expression is constant -> optimizing: using constant result as evaluation result");
		} catch (final IndeterminateEvaluationException e)
		{
			LOGGER.debug("Apply[Description = " + description + "]: static evaluation failed -> expression is not constant -> not optimizing");
		}

		return staticEvalResult == null ? new VariableApplyExpression<>(functionCall) : new ConstantApplyExpression<>(functionCall.getReturnType(), staticEvalResult);
	}
