private BaseVariableReference<?> getVariable(final VariableReferenceType jaxbVarRef, final Deque<String> inoutLongestVarRefChain) throws IllegalArgumentException
	{
		assert jaxbVarRef != null;

		final String varId = jaxbVarRef.getVariableId();
		final BaseVariableReference<?> var = idToVariableMap.get(varId);
		if (var == null)
		{
			throw new IllegalArgumentException("VariableReference's VariableId=" + varId + " unknown in the current context, i.e. does not match any prior VariableDefinition's VariableId");
		}

		/*
		 * inoutLongestVarRefChain == null means that the longest VarRef chain will not be computed nor checked
		 */
		if (inoutLongestVarRefChain != null)
		{
			/*
			 * Check whether the chain formed by [the Variable's Expression's longest VariableReference chain, and the VariableReference that we currently resolving in this method] is not too big
			 */
			final Deque<String> referencedVarLongestRefChain = var.getLongestVariableReferenceChain();
			/*
			 * Make sure longestVarRefChain is set to the biggest one
			 */
			if (referencedVarLongestRefChain != null && referencedVarLongestRefChain.size() + 1 > inoutLongestVarRefChain.size())
			{
				// current longest is no longer the longest, so replace with new
				// longest's content
				inoutLongestVarRefChain.clear();
				inoutLongestVarRefChain.add(varId);
				inoutLongestVarRefChain.addAll(referencedVarLongestRefChain);
			}

			if (maxVariableReferenceDepth != UNLIMITED_MAX_VARIABLE_REF_DEPTH && inoutLongestVarRefChain.size() > this.maxVariableReferenceDepth)
			{
				throw new IllegalArgumentException("Max allowed VariableReference depth (" + this.maxVariableReferenceDepth + ") exceeded by length (" + inoutLongestVarRefChain.size()
				        + ") of VariableReference Reference chain: " + inoutLongestVarRefChain);
			}
		}

		return var;
	}
