public static FunctionRegistry getRegistry(final boolean enableXPath, final StringParseableValue.Factory<IntegerValue> stdIntValueFactory)
	{
		if (stdIntValueFactory == null)
		{
			throw NULL_INT_VALUE_FACTORY_ARGUMENT_EXCEPTION;
		}

		final Set<Function<?>> nonGenericFunctions;
		if (enableXPath)
		{
			nonGenericFunctions = HashCollections.newUpdatableSet(250);
			/*
			 * A.3.15. Optional XPath-based functions: only xpath-node-count supported
			 */
			nonGenericFunctions.add(new XPathNodeCountFunction(StandardFunction.XPATH_NODE_COUNT.id));
		} else
		{
			nonGenericFunctions = HashCollections.newUpdatableSet(249);
		}

		/*
		 * Add standard functions in an order as close as possible to the order of declaration in the XACML spec (A.3).
		 */

		/*
		 * Match functions taking only one type of parameter: Equality predicates (A.3.1) + special match function 'x500Name-match' (A.3.14)
		 */
		nonGenericFunctions.add(new EqualTypeMatchFunction<>(StandardFunction.STRING_EQUAL.id, StandardDatatypes.STRING, new EqualMatcher<StringValue>()));
		nonGenericFunctions.add(new EqualTypeMatchFunction<>(StandardFunction.BOOLEAN_EQUAL.id, StandardDatatypes.BOOLEAN, new EqualMatcher<BooleanValue>()));
		nonGenericFunctions.add(new EqualTypeMatchFunction<>(StandardFunction.INTEGER_EQUAL.id, StandardDatatypes.INTEGER, new EqualMatcher<IntegerValue>()));
		nonGenericFunctions.add(new EqualTypeMatchFunction<>(StandardFunction.DOUBLE_EQUAL.id, StandardDatatypes.DOUBLE, new EqualMatcher<DoubleValue>()));
		nonGenericFunctions.add(new EqualTypeMatchFunction<>(StandardFunction.DATE_EQUAL.id, StandardDatatypes.DATE, new EqualMatcher<DateValue>()));
		nonGenericFunctions.add(new EqualTypeMatchFunction<>(StandardFunction.TIME_EQUAL.id, StandardDatatypes.TIME, new EqualMatcher<TimeValue>()));
		nonGenericFunctions.add(new EqualTypeMatchFunction<>(StandardFunction.DATETIME_EQUAL.id, StandardDatatypes.DATETIME, new EqualMatcher<DateTimeValue>()));
		nonGenericFunctions.add(new EqualTypeMatchFunction<>(StandardFunction.DAYTIME_DURATION_EQUAL.id, StandardDatatypes.DAYTIMEDURATION, new EqualMatcher<DayTimeDurationValue>()));
		nonGenericFunctions.add(new EqualTypeMatchFunction<>(StandardFunction.YEARMONTH_DURATION_EQUAL.id, StandardDatatypes.YEARMONTHDURATION, new EqualMatcher<YearMonthDurationValue>()));
		nonGenericFunctions.add(new EqualTypeMatchFunction<>(StandardFunction.ANYURI_EQUAL.id, StandardDatatypes.ANYURI, new EqualMatcher<AnyUriValue>()));
		nonGenericFunctions.add(new EqualTypeMatchFunction<>(StandardFunction.X500NAME_EQUAL.id, StandardDatatypes.X500NAME, new EqualMatcher<X500NameValue>()));
		nonGenericFunctions.add(new EqualTypeMatchFunction<>(StandardFunction.RFC822NAME_EQUAL.id, StandardDatatypes.RFC822NAME, new EqualMatcher<Rfc822NameValue>()));
		nonGenericFunctions.add(new EqualTypeMatchFunction<>(StandardFunction.HEXBINARY_EQUAL.id, StandardDatatypes.HEXBINARY, new EqualMatcher<HexBinaryValue>()));
		nonGenericFunctions.add(new EqualTypeMatchFunction<>(StandardFunction.BASE64BINARY_EQUAL.id, StandardDatatypes.BASE64BINARY, new EqualMatcher<Base64BinaryValue>()));
		nonGenericFunctions.add(new EqualTypeMatchFunction<>(StandardFunction.STRING_EQUAL_IGNORE_CASE.id, StandardDatatypes.STRING, new EqualIgnoreCaseMatcher<StringValue>()));
		nonGenericFunctions.add(new EqualTypeMatchFunction<>(StandardFunction.X500NAME_MATCH.id, StandardDatatypes.X500NAME, StandardEqualTypeMatchers.X500NAME_MATCHER));
		nonGenericFunctions.add(new EqualTypeMatchFunction<>(StandardFunction.STRING_STARTS_WITH.id, StandardDatatypes.STRING, StandardEqualTypeMatchers.STRING_STARTS_WITH_MATCHER));
		nonGenericFunctions.add(new EqualTypeMatchFunction<>(StandardFunction.STRING_ENDS_WITH.id, StandardDatatypes.STRING, StandardEqualTypeMatchers.STRING_ENDS_WITH_MATCHER));
		nonGenericFunctions.add(new EqualTypeMatchFunction<>(StandardFunction.STRING_CONTAINS.id, StandardDatatypes.STRING, StandardEqualTypeMatchers.STRING_CONTAINS_MATCHER));
		nonGenericFunctions.add(new EqualTypeMatchFunction<>(StandardFunction.STRING_REGEXP_MATCH.id, StandardDatatypes.STRING, StandardEqualTypeMatchers.STRING_REGEXP_MATCH_CALL_FACTORY_BUILDER));

		/*
		 * Numeric Arithmetic functions (A.3.2)
		 */
		nonGenericFunctions.add(new NumericArithmeticFunction<>(StandardFunction.INTEGER_ABS.id, false, Arrays.asList(StandardDatatypes.INTEGER), new AbsOperator<IntegerValue>()));
		nonGenericFunctions.add(new NumericArithmeticFunction<>(StandardFunction.DOUBLE_ABS.id, false, Arrays.asList(StandardDatatypes.DOUBLE), new AbsOperator<DoubleValue>()));
		nonGenericFunctions.add(new NumericArithmeticFunction<>(StandardFunction.INTEGER_ADD.id, true, Arrays.asList(StandardDatatypes.INTEGER, StandardDatatypes.INTEGER, StandardDatatypes.INTEGER),
		        new AddOperator<IntegerValue>()));
		nonGenericFunctions.add(new NumericArithmeticFunction<>(StandardFunction.DOUBLE_ADD.id, true, Arrays.asList(StandardDatatypes.DOUBLE, StandardDatatypes.DOUBLE, StandardDatatypes.DOUBLE),
		        new AddOperator<DoubleValue>()));
		nonGenericFunctions.add(new NumericArithmeticFunction<>(StandardFunction.INTEGER_MULTIPLY.id, true,
		        Arrays.asList(StandardDatatypes.INTEGER, StandardDatatypes.INTEGER, StandardDatatypes.INTEGER), new MultiplyOperator<IntegerValue>()));
		nonGenericFunctions.add(new NumericArithmeticFunction<>(StandardFunction.DOUBLE_MULTIPLY.id, true, Arrays.asList(StandardDatatypes.DOUBLE, StandardDatatypes.DOUBLE, StandardDatatypes.DOUBLE),
		        new MultiplyOperator<DoubleValue>()));
		nonGenericFunctions.add(new NumericArithmeticFunction<>(StandardFunction.INTEGER_SUBTRACT.id, false, Arrays.asList(StandardDatatypes.INTEGER, StandardDatatypes.INTEGER),
		        new SubtractOperator<IntegerValue>()));
		nonGenericFunctions.add(
		        new NumericArithmeticFunction<>(StandardFunction.DOUBLE_SUBTRACT.id, false, Arrays.asList(StandardDatatypes.DOUBLE, StandardDatatypes.DOUBLE), new SubtractOperator<DoubleValue>()));
		nonGenericFunctions.add(
		        new NumericArithmeticFunction<>(StandardFunction.INTEGER_DIVIDE.id, false, Arrays.asList(StandardDatatypes.INTEGER, StandardDatatypes.INTEGER), new DivideOperator<IntegerValue>()));
		nonGenericFunctions
		        .add(new NumericArithmeticFunction<>(StandardFunction.DOUBLE_DIVIDE.id, false, Arrays.asList(StandardDatatypes.DOUBLE, StandardDatatypes.DOUBLE), new DivideOperator<DoubleValue>()));
		nonGenericFunctions.add(new NumericArithmeticFunction<>(StandardFunction.INTEGER_MOD.id, false, Arrays.asList(StandardDatatypes.INTEGER, StandardDatatypes.INTEGER),
		        NumericArithmeticOperators.INTEGER_MOD_OPERATOR));
		nonGenericFunctions.add(new NumericArithmeticFunction<>(StandardFunction.FLOOR.id, false, Arrays.asList(StandardDatatypes.DOUBLE), NumericArithmeticOperators.FLOOR_OPERATOR));
		nonGenericFunctions.add(new NumericArithmeticFunction<>(StandardFunction.ROUND.id, false, Arrays.asList(StandardDatatypes.DOUBLE), NumericArithmeticOperators.ROUND_OPERATOR));

		/*
		 * String-normalize functions (= A.3.3 String conversion functions in the spec)
		 */
		nonGenericFunctions.add(new StringN11nFunction(StandardFunction.STRING_NORMALIZE_SPACE.id, StringN11nFunction.STRING_NORMALIZE_SPACE_FUNCTION_CALL_FACTORY));
		nonGenericFunctions.add(new StringN11nFunction(StandardFunction.STRING_NORMALIZE_TO_LOWER_CASE.id, StringN11nFunction.STRING_NORMALIZE_TO_LOWER_CASE_FUNCTION_CALL_FACTORY));

		/*
		 * Primitive data-type conversion functions: A.3.4 Numeric data-type conversion functions, and all {type}-from-string / string-from-{type} functions from A.3.9 (other parts of A.3.9 addressed
		 * below by StringConcatenateFunction, NonEqualTypeMatchFunction, SubstringFunction)
		 */
		nonGenericFunctions
		        .add(new DatatypeConversionFunction<>(StandardFunction.DOUBLE_TO_INTEGER.id, StandardDatatypes.DOUBLE, StandardDatatypes.INTEGER, StandardDatatypeConverters.DOUBLE_TO_INTEGER));
		nonGenericFunctions
		        .add(new DatatypeConversionFunction<>(StandardFunction.INTEGER_TO_DOUBLE.id, StandardDatatypes.INTEGER, StandardDatatypes.DOUBLE, StandardDatatypeConverters.INTEGER_TO_DOUBLE));
		nonGenericFunctions.add(new DatatypeConversionFunction<>(StandardFunction.BOOLEAN_FROM_STRING.id, StandardDatatypes.STRING, StandardDatatypes.BOOLEAN,
		        new FromStringConverter<>(StandardAttributeValueFactories.BOOLEAN)));
		nonGenericFunctions
		        .add(new DatatypeConversionFunction<>(StandardFunction.STRING_FROM_BOOLEAN.id, StandardDatatypes.BOOLEAN, StandardDatatypes.STRING, StandardDatatypeConverters.BOOLEAN_TO_STRING));
		nonGenericFunctions
		        .add(new DatatypeConversionFunction<>(StandardFunction.INTEGER_FROM_STRING.id, StandardDatatypes.STRING, StandardDatatypes.INTEGER, new FromStringConverter<>(stdIntValueFactory)));
		nonGenericFunctions.add(new DatatypeConversionFunction<>(StandardFunction.STRING_FROM_INTEGER.id, StandardDatatypes.INTEGER, StandardDatatypes.STRING, new ToStringConverter<IntegerValue>()));
		nonGenericFunctions.add(new DatatypeConversionFunction<>(StandardFunction.DOUBLE_FROM_STRING.id, StandardDatatypes.STRING, StandardDatatypes.DOUBLE,
		        new FromStringConverter<>(StandardAttributeValueFactories.DOUBLE)));
		nonGenericFunctions.add(new DatatypeConversionFunction<>(StandardFunction.STRING_FROM_DOUBLE.id, StandardDatatypes.DOUBLE, StandardDatatypes.STRING, new ToStringConverter<DoubleValue>()));
		nonGenericFunctions.add(new DatatypeConversionFunction<>(StandardFunction.TIME_FROM_STRING.id, StandardDatatypes.STRING, StandardDatatypes.TIME,
		        new FromStringConverter<>(StandardAttributeValueFactories.TIME)));
		nonGenericFunctions.add(new DatatypeConversionFunction<>(StandardFunction.STRING_FROM_TIME.id, StandardDatatypes.TIME, StandardDatatypes.STRING, new ToStringConverter<TimeValue>()));
		nonGenericFunctions.add(new DatatypeConversionFunction<>(StandardFunction.DATE_FROM_STRING.id, StandardDatatypes.STRING, StandardDatatypes.DATE,
		        new FromStringConverter<>(StandardAttributeValueFactories.DATE)));
		nonGenericFunctions.add(new DatatypeConversionFunction<>(StandardFunction.STRING_FROM_DATE.id, StandardDatatypes.DATE, StandardDatatypes.STRING, new ToStringConverter<DateValue>()));
		nonGenericFunctions.add(new DatatypeConversionFunction<>(StandardFunction.DATETIME_FROM_STRING.id, StandardDatatypes.STRING, StandardDatatypes.DATETIME,
		        new FromStringConverter<>(StandardAttributeValueFactories.DATETIME)));
		nonGenericFunctions
		        .add(new DatatypeConversionFunction<>(StandardFunction.STRING_FROM_DATETIME.id, StandardDatatypes.DATETIME, StandardDatatypes.STRING, new ToStringConverter<DateTimeValue>()));
		nonGenericFunctions.add(new DatatypeConversionFunction<>(StandardFunction.ANYURI_FROM_STRING.id, StandardDatatypes.STRING, StandardDatatypes.ANYURI,
		        new FromStringConverter<>(StandardAttributeValueFactories.ANYURI)));
		nonGenericFunctions.add(new DatatypeConversionFunction<>(StandardFunction.STRING_FROM_ANYURI.id, StandardDatatypes.ANYURI, StandardDatatypes.STRING, new ToStringConverter<AnyUriValue>()));
		nonGenericFunctions.add(new DatatypeConversionFunction<>(StandardFunction.DAYTIMEDURATION_FROM_STRING.id, StandardDatatypes.STRING, StandardDatatypes.DAYTIMEDURATION,
		        new FromStringConverter<>(StandardAttributeValueFactories.DAYTIMEDURATION)));
		nonGenericFunctions.add(new DatatypeConversionFunction<>(StandardFunction.STRING_FROM_DAYTIMEDURATION.id, StandardDatatypes.DAYTIMEDURATION, StandardDatatypes.STRING,
		        new ToStringConverter<DayTimeDurationValue>()));
		nonGenericFunctions.add(new DatatypeConversionFunction<>(StandardFunction.YEARMONTHDURATION_FROM_STRING.id, StandardDatatypes.STRING, StandardDatatypes.YEARMONTHDURATION,
		        new FromStringConverter<>(StandardAttributeValueFactories.YEARMONTHDURATION)));
		nonGenericFunctions.add(new DatatypeConversionFunction<>(StandardFunction.STRING_FROM_YEARMONTHDURATION.id, StandardDatatypes.YEARMONTHDURATION, StandardDatatypes.STRING,
		        new ToStringConverter<YearMonthDurationValue>()));
		nonGenericFunctions.add(new DatatypeConversionFunction<>(StandardFunction.X500NAME_FROM_STRING.id, StandardDatatypes.STRING, StandardDatatypes.X500NAME,
		        new FromStringConverter<>(StandardAttributeValueFactories.X500NAME)));
		nonGenericFunctions
		        .add(new DatatypeConversionFunction<>(StandardFunction.STRING_FROM_X500NAME.id, StandardDatatypes.X500NAME, StandardDatatypes.STRING, new ToStringConverter<X500NameValue>()));
		nonGenericFunctions.add(new DatatypeConversionFunction<>(StandardFunction.RFC822NAME_FROM_STRING.id, StandardDatatypes.STRING, StandardDatatypes.RFC822NAME,
		        new FromStringConverter<>(StandardAttributeValueFactories.RFC822NAME)));
		nonGenericFunctions
		        .add(new DatatypeConversionFunction<>(StandardFunction.STRING_FROM_RFC822NAME.id, StandardDatatypes.RFC822NAME, StandardDatatypes.STRING, new ToStringConverter<Rfc822NameValue>()));
		nonGenericFunctions.add(new DatatypeConversionFunction<>(StandardFunction.IPADDRESS_FROM_STRING.id, StandardDatatypes.STRING, StandardDatatypes.IPADDRESS,
		        new FromStringConverter<>(StandardAttributeValueFactories.IPADDRESS)));
		nonGenericFunctions
		        .add(new DatatypeConversionFunction<>(StandardFunction.STRING_FROM_IPADDRESS.id, StandardDatatypes.IPADDRESS, StandardDatatypes.STRING, new ToStringConverter<IpAddressValue>()));
		nonGenericFunctions.add(new DatatypeConversionFunction<>(StandardFunction.DNSNAME_FROM_STRING.id, StandardDatatypes.STRING, StandardDatatypes.DNSNAME,
		        new FromStringConverter<>(StandardAttributeValueFactories.DNSNAME)));
		nonGenericFunctions.add(
		        new DatatypeConversionFunction<>(StandardFunction.STRING_FROM_DNSNAME.id, StandardDatatypes.DNSNAME, StandardDatatypes.STRING, new ToStringConverter<DnsNameWithPortRangeValue>()));

		/*
		 * Logical functions (A.3.5)
		 */
		nonGenericFunctions.add(new LogicalOrFunction(StandardFunction.OR.id));
		nonGenericFunctions.add(new LogicalAndFunction(StandardFunction.AND.id));
		nonGenericFunctions.add(new LogicalNOfFunction(StandardFunction.N_OF.id));
		nonGenericFunctions.add(new LogicalNotFunction(StandardFunction.NOT.id));

		/*
		 * Total-ordering comparison functions (all elements of a given type can be compared to each other), i.e. numeric (A.3.6) and string comparison functions (first part of A.3.8)
		 */
		for (final PostCondition condition : PostCondition.values())
		{
			nonGenericFunctions.add(new ComparisonFunction<>(StandardDatatypes.INTEGER, condition));
			nonGenericFunctions.add(new ComparisonFunction<>(StandardDatatypes.DOUBLE, condition));
			nonGenericFunctions.add(new ComparisonFunction<>(StandardDatatypes.STRING, condition));
		}

		/*
		 * Date and time arithmetic functions (A.3.7)
		 */
		nonGenericFunctions.add(new TemporalArithmeticFunction<>(StandardFunction.DATETIME_ADD_DAYTIMEDURATION.id, StandardDatatypes.DATETIME, StandardDatatypes.DAYTIMEDURATION,
		        new TimeAddDurationOperator<DateTimeValue, DayTimeDurationValue>()));
		nonGenericFunctions.add(new TemporalArithmeticFunction<>(StandardFunction.DATETIME_SUBTRACT_DAYTIMEDURATION.id, StandardDatatypes.DATETIME, StandardDatatypes.DAYTIMEDURATION,
		        new TimeSubtractDurationOperator<DateTimeValue, DayTimeDurationValue>()));
		nonGenericFunctions.add(new TemporalArithmeticFunction<>(StandardFunction.DATETIME_ADD_YEARMONTHDURATION.id, StandardDatatypes.DATETIME, StandardDatatypes.YEARMONTHDURATION,
		        new TimeAddDurationOperator<DateTimeValue, YearMonthDurationValue>()));
		nonGenericFunctions.add(new TemporalArithmeticFunction<>(StandardFunction.DATETIME_SUBTRACT_YEARMONTHDURATION.id, StandardDatatypes.DATETIME, StandardDatatypes.YEARMONTHDURATION,
		        new TimeSubtractDurationOperator<DateTimeValue, YearMonthDurationValue>()));
		nonGenericFunctions.add(new TemporalArithmeticFunction<>(StandardFunction.DATE_ADD_YEARMONTHDURATION.id, StandardDatatypes.DATE, StandardDatatypes.YEARMONTHDURATION,
		        new TimeAddDurationOperator<DateValue, YearMonthDurationValue>()));
		nonGenericFunctions.add(new TemporalArithmeticFunction<>(StandardFunction.DATE_SUBTRACT_YEARMONTHDURATION.id, StandardDatatypes.DATE, StandardDatatypes.YEARMONTHDURATION,
		        new TimeSubtractDurationOperator<DateValue, YearMonthDurationValue>()));

		/*
		 * Date and time comparison functions (second part of A.3.8, first part already addressed previously), i.e. not imposing total ordering of compared objects, as opposed to total-ordering
		 * comparison functions above, since such date/times may have indeterminate relationship to each other
		 */
		for (final PostCondition condition : PostCondition.values())
		{
			nonGenericFunctions.add(new ComparisonFunction<>(StandardDatatypes.TIME, condition));
			nonGenericFunctions.add(new ComparisonFunction<>(StandardDatatypes.DATE, condition));
			nonGenericFunctions.add(new ComparisonFunction<>(StandardDatatypes.DATETIME, condition));
		}

		nonGenericFunctions.add(new TimeRangeComparisonFunction(StandardFunction.TIME_IN_RANGE.id));

		/*
		 * String-concatenate function (start of A.3.9, other parts addressed above by DatatypeConversionFunction, and below by NonEqualTypeMatchFunction and SubstringFunction)
		 */
		nonGenericFunctions.add(new StringConcatenateFunction(StandardFunction.STRING_CONCATENATE.id));

		/*
		 * Match functions taking parameters of possibly different types, i.e. *-contains / *-starts-with / *-ends-with (second before last part of A.3.9, other parts addressed above by
		 * DatatypeConversionFunction, StringConcatenateFunction, and below by SubstringFunction), regexp-match (A.3.13) and special match 'rfc822Name-match' (part of A.3.14, other part addressed
		 * above by EqualTypeMatchFunction)
		 */
		nonGenericFunctions
		        .add(new NonEqualTypeMatchFunction<>(StandardFunction.RFC822NAME_MATCH.id, StandardDatatypes.STRING, StandardDatatypes.RFC822NAME, StandardNonEqualTypeMatchers.RFC822NAME_MATCHER));
		nonGenericFunctions.add(
		        new NonEqualTypeMatchFunction<>(StandardFunction.ANYURI_STARTS_WITH.id, StandardDatatypes.STRING, StandardDatatypes.ANYURI, StandardNonEqualTypeMatchers.ANYURI_STARTS_WITH_MATCHER));
		nonGenericFunctions
		        .add(new NonEqualTypeMatchFunction<>(StandardFunction.ANYURI_ENDS_WITH.id, StandardDatatypes.STRING, StandardDatatypes.ANYURI, StandardNonEqualTypeMatchers.ANYURI_ENDS_WITH_MATCHER));
		nonGenericFunctions
		        .add(new NonEqualTypeMatchFunction<>(StandardFunction.ANYURI_CONTAINS.id, StandardDatatypes.STRING, StandardDatatypes.ANYURI, StandardNonEqualTypeMatchers.ANYURI_CONTAINS_MATCHER));
		nonGenericFunctions
		        .add(new NonEqualTypeMatchFunction<>(StandardFunction.ANYURI_REGEXP_MATCH.id, StandardDatatypes.STRING, StandardDatatypes.ANYURI, new RegexpMatchCallFactoryBuilder<AnyUriValue>()));
		nonGenericFunctions.add(new NonEqualTypeMatchFunction<>(StandardFunction.IPADDRESS_REGEXP_MATCH.id, StandardDatatypes.STRING, StandardDatatypes.IPADDRESS,
		        new RegexpMatchCallFactoryBuilder<IpAddressValue>()));
		nonGenericFunctions.add(new NonEqualTypeMatchFunction<>(StandardFunction.DNSNAME_REGEXP_MATCH.id, StandardDatatypes.STRING, StandardDatatypes.DNSNAME,
		        new RegexpMatchCallFactoryBuilder<DnsNameWithPortRangeValue>()));
		nonGenericFunctions.add(new NonEqualTypeMatchFunction<>(StandardFunction.RFC822NAME_REGEXP_MATCH.id, StandardDatatypes.STRING, StandardDatatypes.RFC822NAME,
		        new RegexpMatchCallFactoryBuilder<Rfc822NameValue>()));
		nonGenericFunctions.add(
		        new NonEqualTypeMatchFunction<>(StandardFunction.X500NAME_REGEXP_MATCH.id, StandardDatatypes.STRING, StandardDatatypes.X500NAME, new RegexpMatchCallFactoryBuilder<X500NameValue>()));

		/*
		 * Substring functions (last part of A.3.9, other parts addressed above by DatatypeConversionFunction, StringConcatenateFunction, NonEqualTypeMatchFunction)
		 */
		nonGenericFunctions.add(new SubstringFunction<>(StandardFunction.STRING_SUBSTRING.id, StandardDatatypes.STRING));
		nonGenericFunctions.add(new SubstringFunction<>(StandardFunction.ANYURI_SUBSTRING.id, StandardDatatypes.ANYURI));

		/*
		 * First-order bag functions (A.3.10, A.3.11)
		 */
		for (final AttributeDatatype<?> datatype : StandardDatatypes.MANDATORY_SET)
		{
			nonGenericFunctions.addAll(FirstOrderBagFunctions.getFunctions(datatype));
		}

		/*
		 * Higher-order bag functions (A.3.12)
		 */
		nonGenericFunctions.add(new BooleanOneBagOnlyFunction(StandardFunction.ANY_OF.id, new AnyOfCallFactory(StandardFunction.ANY_OF.id)));
		nonGenericFunctions.add(new BooleanOneBagOnlyFunction(StandardFunction.ALL_OF.id, new AllOfCallFactory(StandardFunction.ALL_OF.id)));
		nonGenericFunctions.add(new AnyOfAny(StandardFunction.ANY_OF_ANY.id));
		nonGenericFunctions.add(new AllOfAny(StandardFunction.ALL_OF_ANY.id));
		nonGenericFunctions.add(new AnyOfAll(StandardFunction.ANY_OF_ALL.id));
		nonGenericFunctions.add(new AllOfAll(StandardFunction.ALL_OF_ALL.id));

		/*
		 * A.3.13 already addressed above by NonEqualTypeMatchFunction
		 */
		/*
		 * A.3.14 already addressed above by EqualTypeMatchFunction and NonEqualTypeMatchFunction
		 */

		// Generic functions, e.g. map function
		final Set<GenericHigherOrderFunctionFactory> genericFuncFactories = Collections.<GenericHigherOrderFunctionFactory>singleton(new MapFunctionFactory(StandardFunction.MAP.id));

		/*
		 * A.3.16. Optional function(s) not supported
		 */

		if (LOGGER.isDebugEnabled())
		{
			// TreeSet for sorting functions, easier to read
			final TreeSet<Function<?>> sortedFunctions = new TreeSet<>(FUNCTION_COMPARATOR);
			sortedFunctions.addAll(nonGenericFunctions);
			LOGGER.debug("Loaded XACML standard non-generic functions: {}", sortedFunctions);

			final TreeSet<GenericHigherOrderFunctionFactory> sortedFunctionFactories = new TreeSet<>(FUNCTION_FACTORY_COMPARATOR);
			sortedFunctionFactories.addAll(genericFuncFactories);
			LOGGER.debug("Loaded XACML standard generic functions: {}", sortedFunctionFactories);
		}

		return new ImmutableFunctionRegistry(nonGenericFunctions, genericFuncFactories);
	}
