public static <ADAPTER_INPUT, ADAPTER_OUTPUT> PdpEngineInoutAdapter<ADAPTER_INPUT, ADAPTER_OUTPUT> newInoutAdapter(final Class<ADAPTER_INPUT> adapterInputClass,
			final Class<ADAPTER_OUTPUT> adapterOutputClass, final CloseablePdpEngine adaptee, final DecisionRequestPreprocessor<?, ?> rawReqPreproc,
			final DecisionResultPostprocessor<?, ?> rawResultPostproc) throws IllegalArgumentException
	{
		/*
		 * Decision result processor
		 */
		if (rawResultPostproc == null)
		{
			throw NULL_RESPOSTPROC_ARGUMENT_EXCEPTION;
		}

		if (rawResultPostproc.getResponseType() != adapterOutputClass)
		{
			throw new IllegalArgumentException("Invalid response type for " + DecisionResultPostprocessor.class.getCanonicalName() + " extension: " + rawResultPostproc.getResponseType()
					+ ". Expected: " + adapterOutputClass);
		}

		/*
		 * Decision request processor
		 */
		if (rawReqPreproc == null)
		{
			throw NULL_REQPREPROC_ARGUMENT_EXCEPTION;
		}

		if (rawReqPreproc.getInputRequestType() != adapterInputClass)
		{
			throw new IllegalArgumentException("Invalid request type for " + DecisionRequestPreprocessor.class.getCanonicalName() + " extension: " + rawReqPreproc.getInputRequestType()
					+ ". Expected: " + adapterInputClass);
		}

		if (rawReqPreproc.getOutputRequestType() != rawResultPostproc.getRequestType())
		{
			throw new IllegalArgumentException("Decision request preprocessor is not compatible with decision result postprocessor: output request type of preprocessor ("
					+ rawReqPreproc.getOutputRequestType() + ") != input request type of postprocessor (" + rawResultPostproc.getRequestType() + ")");
		}

		return newInoutAdapter(adaptee, (DecisionRequestPreprocessor<ADAPTER_INPUT, ?>) rawReqPreproc, (DecisionResultPostprocessor<?, ADAPTER_OUTPUT>) rawResultPostproc);
	}
