public Entry<PolicyVersion, P> getLatest(final Optional<PolicyVersionPatterns> PolicyVersionPatterns) {
		assert PolicyVersionPatterns != null;

		// policiesByVersion is not empty -> at least one value
		final Iterator<Entry<PolicyVersion, P>> versionPolicyPairsIterator = policiesByVersion.entrySet().iterator();
		if (!PolicyVersionPatterns.isPresent())
		{
			/*
			 * Return the latest version which is the first element by design (TreeMap initialized with reverse order on version keys). See §5.10 of XACML core spec:
			 * "In the case that more than one matching version can be obtained, then the most recent one SHOULD be used."
			 */
			return versionPolicyPairsIterator.next();
		}

		final PolicyVersionPatterns nonNullPolicyVersionPatterns = PolicyVersionPatterns.get();

		// constraints not null
		// in the loop, go on until LatestVersion matched, then go on as long as
		// EarliestVersion
		// matched, if Version matched, return the result
		boolean latestVersionMatched = false;
		boolean earliestVersionMatched = false;
		while (versionPolicyPairsIterator.hasNext())
		{
			final Entry<PolicyVersion, P> versionPolicyPair = versionPolicyPairsIterator.next();
			final PolicyVersion version = versionPolicyPair.getKey();
			/*
			 * Versions ordered by latest first, so check against constraints' LatestVersion pattern first. If LatestVersion is matched by this version, no need to check again for the next versions,
			 * as they are already sorted from latest to earliest. If LatestVersion not matched yet, we check now.
			 */
			if (!latestVersionMatched)
			{
				latestVersionMatched = nonNullPolicyVersionPatterns.matchLatestVersion(version);
			}

			// If LatestVersion matched, check other constraints, else do
			// nothing (check next
			// version)
			if (latestVersionMatched)
			{
				/*
				 * If EarliestVersion already checked and not matched before, we would have returned null (see below). So at this point, EarliestVersion is either not checked yet or already matched.
				 * So EarliestVersion no checked iff not already matched.
				 */
				if (!earliestVersionMatched)
				{
					// EarliestVersion not checked yet
					// check against EarliestVersion pattern
					earliestVersionMatched = nonNullPolicyVersionPatterns.matchEarliestVersion(version);
					/*
					 * If still not matched, version cannot be in the [EarliestVersion, LatestVersion] interval. All next versions are earlier, so they cannot be either -> no match
					 */
					if (!earliestVersionMatched)
					{
						return null;
					}
				}

				// EarliestVersion and LatestVersion matched.
				// Check against Version pattern
				if (nonNullPolicyVersionPatterns.matchVersion(version))
				{
					// all constraints matched, return the associated policy
					return versionPolicyPair;
				}

				// constraints not met, so try next version
			}
		}

		// no match found
		return null;
	}
