public static BooleanEvaluator getInstance(final Condition condition, final XPathCompiler xPathCompiler, final ExpressionFactory expressionFactory) throws IllegalArgumentException
	{
		if (condition == null)
		{
			return TRUE_CONDITION;
		}

		/*
		 * condition != null -> condition's Expression is not null (by definition of XACML schema), therefore expressionFactory is needed
		 */
		final ExpressionType exprElt = condition.getExpression().getValue();
		if (expressionFactory == null)
		{
			throw NULL_EXPR_FACTORY_ARGUMENT_EXCEPTION;
		}

		final Expression<?> expr = expressionFactory.getInstance(exprElt, xPathCompiler, null);

		// make sure it's a boolean expression...
		if (!(expr.getReturnType().equals(StandardDatatypes.BOOLEAN)))
		{
			throw new IllegalArgumentException("Invalid return datatype (" + expr.getReturnType() + ") for Expression (" + expr.getClass().getSimpleName() + ") in Condition. Expected: Boolean.");
		}

		// WARNING: unchecked cast
		final Expression<BooleanValue> evaluatableExpression = (Expression<BooleanValue>) expr;

		/*
		 * Check whether the expression is constant
		 */
		final Optional<BooleanValue> constant = evaluatableExpression.getValue();
		if (constant.isPresent())
		{
			if (constant.get().getUnderlyingValue())
			{
				// constant TRUE
				LOGGER.warn("Condition's expression is equivalent to constant True -> optimization: replacing with constant True condition");
				return TRUE_CONDITION;
			}

			// constant False -> unacceptable
			throw INVALID_CONSTANT_FALSE_EXPRESSION_EXCEPTION;
		}

		// constant == null
		LOGGER.debug("Condition's Expression is not constant (evaluation without context failed)");
		return new BooleanExpressionEvaluator(evaluatableExpression);
	}
