@Override
	public DecisionResult evaluate(final EvaluationContext context)
	{
		try
		{
			if (!targetEvaluator.evaluate(context))
			{
				LOGGER.debug("{}/Target -> No-match", this);
				final DecisionResult result = DecisionResults.SIMPLE_NOT_APPLICABLE;
				LOGGER.debug("{} -> {}", this, result);
				return result;
			}

			LOGGER.debug("{}/Target -> Match", this);
		} catch (final IndeterminateEvaluationException e)
		{
			// Target is Indeterminate
			/*
			 * Before we lose the exception information, log it at a higher level because it is an evaluation error (but no critical application error, therefore lower level than error)
			 */
			LOGGER.info("{}/Target -> Indeterminate", this, e);

			/*
			 * Condition is Indeterminate, determine Extended Indeterminate (section 7.11) which is the value of the Rule's Effect
			 */
			final DecisionResult result = decisionResultFactory.newIndeterminate(e);
			LOGGER.debug("{} -> {}", this, result);
			return result;
		}

		/*
		 * Target matches -> check Rule's condition. See section 7.9 of XACML core spec, so result is the Rule's Effect, unless condition evaluates to False or throws Indeterminate exception.
		 */
		final boolean isConditionTrue;
		try
		{
			isConditionTrue = conditionEvaluator.evaluate(context);
		} catch (final IndeterminateEvaluationException e)
		{
			/*
			 * Condition is Indeterminate, determine Extended Indeterminate (section 7.11) which is the value of the Rule's Effect
			 */
			/*
			 * Before we lose the exception information, log it at a higher level because it is an evaluation error (but not a critical application error, therefore lower level than Error level)
			 */
			LOGGER.info("{}/Condition -> Indeterminate", this, e);
			final DecisionResult result = decisionResultFactory.newIndeterminate(e);
			LOGGER.debug("{} -> {}", this, result);
			return result;
		}

		if (!isConditionTrue)
		{
			LOGGER.debug("{}/Condition -> False", this);
			final DecisionResult result = DecisionResults.SIMPLE_NOT_APPLICABLE;
			LOGGER.debug("{} -> {}", this, result);
			return result;
		}

		LOGGER.debug("{}/Condition -> True", this);

		/*
		 * Target match and condition true
		 */
		final DecisionResult result = this.decisionResultFactory.getInstance(context);
		LOGGER.debug("{} -> {}", this, result);
		return result;
	}
