private static final List<Expression<?>> toExpressions(final String subFunctionName, final List<Value> values)
	{
		final List<Expression<?>> inputExpressions = new ArrayList<>();
		if (subFunctionName != null)
		{
			// sub-function of higher-order function
			final FunctionExpression subFuncExp = STD_EXPRESSION_FACTORY.getFunction(subFunctionName);
			if (subFuncExp == null)
			{
				throw new UnsupportedOperationException("Function " + subFunctionName + " not valid/supported (as first-order function)");
			}

			inputExpressions.add(subFuncExp);
		}

		final AttributeValueFactoryRegistry stdDatatypeFactoryRegistry = StandardAttributeValueFactories.getRegistry(true, Optional.empty());
		for (final Value val : values)
		{
			final Expression<?> valExpr;
			if (val instanceof NullValue)
			{
				/*
				 * Undefined arg -> wrap in a special expression that always return Indeterminate (useful for testing functions that do not need all arguments to return a result, such as logical
				 * or/and/n-o
				 */
				final NullValue nullVal = (NullValue) val;
				final AttributeValueFactory<?> datatypeFactory = stdDatatypeFactoryRegistry.getExtension(nullVal.getDatatypeId());
				if (datatypeFactory == null)
				{
					throw new UnsupportedOperationException("Unsupported attribute datatype: '" + nullVal.getDatatypeId() + "'");
				}

				valExpr = nullVal.isBag() ? new IndeterminateExpression<>(datatypeFactory.getDatatype().getBagDatatype()) : new IndeterminateExpression<>(datatypeFactory.getDatatype());
			} else if (val instanceof AttributeValue)
			{
				final AttributeValue primVal = (AttributeValue) val;
				final AttributeValueFactory<?> datatypeFactory = stdDatatypeFactoryRegistry.getExtension(JAVA_CLASS_TO_DATATYPE_MAP.get(primVal.getClass()).getId());
				valExpr = createValueExpression(datatypeFactory.getDatatype(), primVal);
			} else if (val instanceof Bag)
			{
				final Bag<?> bagVal = (Bag<?>) val;
				final AttributeValueFactory<?> datatypeFactory = stdDatatypeFactoryRegistry.getExtension(bagVal.getElementDatatype().getId());
				valExpr = createValueExpression(datatypeFactory.getDatatype().getBagDatatype(), bagVal);
			} else
			{
				throw new UnsupportedOperationException("Unsupported type of Value: " + val.getClass());
			}

			inputExpressions.add(valExpr);
		}

		return inputExpressions;
	}
