@Parameters(name = "{index}: {1} -> {2}")
	public static Collection<Object[]> data()
	{
		final Object[][] data = new Object[][] {
		        /*
		         * each test input is: attributeValueFactories (standard if null), raw values, expected (XACML) datatype of attribute values created from them, exception iff error expected (null if
		         * none)
		         */
		        /* empty collection */
		        { null, Collections.emptyList(), StandardDatatypes.STRING.getId(), IllegalArgumentException.class },

		        /* string type */
		        { null, Arrays.asList("string"), StandardDatatypes.STRING.getId(), null },
		        /* multiple values (strings) */
		        { null, Arrays.asList("string1", "string2"), StandardDatatypes.STRING.getId(), null },

		        /* boolean type */
		        /* invalid */
		        /* invalid */
		        { null, Arrays.asList((Boolean) null), StandardDatatypes.BOOLEAN.getId(), IllegalArgumentException.class },

		        /*
		         * singleton
		         */
		        { null, Arrays.asList(true), StandardDatatypes.BOOLEAN.getId(), null },
		        /* multiple values of type boolean */
		        { null, Arrays.asList(true, false), StandardDatatypes.BOOLEAN.getId(), null },

		        /*
		         * integer
		         */
		        /* invalid */
		        { null, Arrays.asList((Integer) null), StandardDatatypes.INTEGER.getId(), IllegalArgumentException.class },

		        /* Short */
		        { ATT_VALUE_FACTORIES_WITH_MEDIUM_INT_SUPPORT, Arrays.asList(Short.MIN_VALUE), StandardDatatypes.INTEGER.getId(), null },
		        /* Integer */
		        { ATT_VALUE_FACTORIES_WITH_MEDIUM_INT_SUPPORT, Arrays.asList(Integer.MIN_VALUE), StandardDatatypes.INTEGER.getId(), null },

		        /* Long */
		        /* Using medium integer support (Long converted to Integer) */
		        { ATT_VALUE_FACTORIES_WITH_MEDIUM_INT_SUPPORT, Arrays.asList(Long.valueOf(0)), StandardDatatypes.INTEGER.getId(), null },
		        /* Max long unsupported by attribute value factory for small/medium integers */
		        { ATT_VALUE_FACTORIES_WITH_MEDIUM_INT_SUPPORT, Arrays.asList(Long.MAX_VALUE), StandardDatatypes.INTEGER.getId(), IllegalArgumentException.class },
		        /* Max long supported by attribute value factory for long integers */
		        { ATT_VALUE_FACTORIES_WITH_LONG_INT_SUPPORT, Arrays.asList(Long.MAX_VALUE), StandardDatatypes.INTEGER.getId(), null },

		        /* BigInteger (non-final!) */
		        /* Using medium integer support (BigInteger converted to Integer) */
		        { ATT_VALUE_FACTORIES_WITH_MEDIUM_INT_SUPPORT, Arrays.asList(BigInteger.ZERO), StandardDatatypes.INTEGER.getId(), null },
		        /*
		         * Using long integer support (BigInteger converted to Long)
		         */
		        { ATT_VALUE_FACTORIES_WITH_LONG_INT_SUPPORT, Arrays.asList(BigInteger.ZERO), StandardDatatypes.INTEGER.getId(), null },
		        /* subtype of BigInteger */
		        { ATT_VALUE_FACTORIES_WITH_MEDIUM_INT_SUPPORT, Arrays.asList(MyBigInteger.valueOf(0)), StandardDatatypes.INTEGER.getId(), null },
		        /* BigInteger too big to be supported by attribute value factory for small/medium integers */
		        { ATT_VALUE_FACTORIES_WITH_MEDIUM_INT_SUPPORT, Arrays.asList(INTEGER_GREATER_THAN_MAX_LONG), StandardDatatypes.INTEGER.getId(), IllegalArgumentException.class },
		        /* BigInteger too big to be supported by attribute value factory for long integers */
		        { ATT_VALUE_FACTORIES_WITH_LONG_INT_SUPPORT, Arrays.asList(INTEGER_GREATER_THAN_MAX_LONG), StandardDatatypes.INTEGER.getId(), IllegalArgumentException.class },
		        /* BigInteger bigger than max long, supported by attribute value factory for big integers */
		        { ATT_VALUE_FACTORIES_WITH_BIG_INT_SUPPORT, Arrays.asList(INTEGER_GREATER_THAN_MAX_LONG), StandardDatatypes.INTEGER.getId(), null },

		        /* Mix of different integer types */
		        { ATT_VALUE_FACTORIES_WITH_MEDIUM_INT_SUPPORT, Arrays.asList(Short.MAX_VALUE, Integer.MAX_VALUE, Long.valueOf(0), BigInteger.ZERO), StandardDatatypes.INTEGER.getId(), null },

		        { ATT_VALUE_FACTORIES_WITH_LONG_INT_SUPPORT, Arrays.asList(Short.MAX_VALUE, Integer.MAX_VALUE, Long.MAX_VALUE, BigInteger.ZERO), StandardDatatypes.INTEGER.getId(), null },

		        { ATT_VALUE_FACTORIES_WITH_BIG_INT_SUPPORT, Arrays.asList(Short.MAX_VALUE, Integer.MAX_VALUE, Long.MAX_VALUE, INTEGER_GREATER_THAN_MAX_LONG), StandardDatatypes.INTEGER.getId(), null },

		        /*
		         * double
		         */
		        /* invalid */
		        { null, Arrays.asList((Double) null), StandardDatatypes.DOUBLE.getId(), IllegalArgumentException.class },
		        /* from Double */
		        { null, Arrays.asList(Double.MIN_NORMAL), StandardDatatypes.DOUBLE.getId(), null },
		        /* from Float */
		        { null, Arrays.asList(Float.MIN_NORMAL), StandardDatatypes.DOUBLE.getId(), null },
		        /* Mix of float and double */
		        { null, Arrays.asList(Float.MIN_NORMAL, Double.MIN_NORMAL), StandardDatatypes.DOUBLE.getId(), null },

		        /*
		         * time
		         */
		        /* invalid */
		        { null, Arrays.asList((LocalTime) null), StandardDatatypes.TIME.getId(), IllegalArgumentException.class },
		        /* from LocalTime */
		        { null, Arrays.asList(LocalTime.now()), StandardDatatypes.TIME.getId(), null },
		        /* from OffsetTime */
		        { null, Arrays.asList(OffsetTime.now()), StandardDatatypes.TIME.getId(), null },
		        /* Mix of LocalTime and OffsetTime */
		        { null, Arrays.asList(LocalTime.now(), OffsetTime.now()), StandardDatatypes.TIME.getId(), null },

		        /*
		         * date
		         */
		        /* invalid */
		        { null, Arrays.asList((LocalDate) null), StandardDatatypes.DATE.getId(), IllegalArgumentException.class },
		        /*
		         * From LocalDate
		         */
		        { null, Arrays.asList(LocalDate.now()), StandardDatatypes.DATE.getId(), null },

		        /*
		         * date-time
		         */
		        /* invalid */
		        { null, Arrays.asList((LocalDateTime) null), StandardDatatypes.DATETIME.getId(), IllegalArgumentException.class },
		        /* from LocalDateTime */
		        { null, Arrays.asList(LocalDateTime.now()), StandardDatatypes.DATETIME.getId(), null },
		        /* from OffsetDateTime */
		        { null, Arrays.asList(OffsetDateTime.now()), StandardDatatypes.DATETIME.getId(), null },
		        /* from ZonedDateTime */
		        { null, Arrays.asList(ZonedDateTime.now()), StandardDatatypes.DATETIME.getId(), null },
		        /* from ZonedDateTime */
		        { null, Arrays.asList(Instant.now()), StandardDatatypes.DATETIME.getId(), null },
		        /* Mix of LocalDateTime, OffsetDateTime... */
		        { null, Arrays.asList(LocalDateTime.now(), OffsetDateTime.now(), ZonedDateTime.now(), Instant.now()), StandardDatatypes.DATETIME.getId(), null },
		        /* from LocalDateTime */
		        { null, Arrays.asList(LocalDateTime.now()), StandardDatatypes.DATETIME.getId(), null },

		        /*
		         * anyURI
		         */
		        /* from URI */
		        { null, Arrays.asList(URI.create("")), StandardDatatypes.ANYURI.getId(), null },

		        /*
		         * hexBinary
		         */
		        /* invalid: null */
		        { null, Arrays.asList((byte[]) null), StandardDatatypes.HEXBINARY.getId(), IllegalArgumentException.class },
		        /* Empty byte array is considered like empty XML value which is valid xs:hexBinary */
		        { null, Arrays.asList(new byte[] {}), StandardDatatypes.HEXBINARY.getId(), null },
		        /* singleton byte */
		        { null, Arrays.asList(new byte[] { 0x01 }), StandardDatatypes.HEXBINARY.getId(), null },
		        /* from bytes */
		        { null, Arrays.asList(new byte[] { 0x01, 0x23 }), StandardDatatypes.HEXBINARY.getId(), null },

		        /*
		         * x500Name
		         */
		        /* invalid */
		        { null, Arrays.asList((X500Principal) null), StandardDatatypes.X500NAME.getId(), IllegalArgumentException.class },
		        /* from bytes */
		        { null, Arrays.asList(new X500Principal("CN=someCN")), StandardDatatypes.X500NAME.getId(), null },

		        /* invalid mix of different datatypes */
		        { null, Arrays.asList(new Integer(0), LocalDate.now()), StandardDatatypes.INTEGER.getId(), IllegalArgumentException.class },

		        /*
		         * Unsupported java type
		         */
		        /*
		         * GregorianCalendar and Date classes not supported here because considered legacy code since Java 8. More info: https://docs.oracle.com/javase/tutorial/datetime/iso/legacy.html
		         */
		        { null, Arrays.asList(new Date()), StandardDatatypes.DATETIME.getId(), UnsupportedOperationException.class }
				/*
				 * 
				 */
		};

		return Arrays.asList(data);
	}
