@Test
	public void test()
	{
		if (rawValues == null || rawValues.isEmpty())
		{
			try
			{
				attValFactories.newAttributeBag(rawValues);
				Assert.fail("Should have raised IllegalArgumentException because of invalid rawValues");
			} catch (final Exception e)
			{
				Assert.assertTrue("Unexpected error: " + e, expectedExceptionClass != null && expectedExceptionClass.isInstance(e));
			}
			return;
		}

		// rawValues has at least one value
		if (rawValues.size() == 1)
		{
			final Serializable rawVal = rawValues.iterator().next();
			if (rawVal == null)
			{
				/*
				 * Instantiate using expected datatype to check if null is spotted as invalid value
				 */
				try
				{
					attValFactories.newExpression(expectedAttributeDatatypeId, Collections.singletonList(rawVal), null, null);
					Assert.assertTrue("Parsing raw value into AttributeValue did not throw exception as expected", expectedExceptionClass == null);
				} catch (final Exception e)
				{
					Assert.assertTrue("Unexpected error: " + e, expectedExceptionClass != null && expectedExceptionClass.isInstance(e));
				}
			} else
			{
				try
				{
					final AttributeValueFactory<?> attValFactory = attValFactories.getCompatibleFactory(rawVal.getClass());
					final String actualDatatypeId = attValFactory.getDatatype().getId();
					Assert.assertEquals("Invalid datatype for created attribute value", actualDatatypeId, expectedAttributeDatatypeId);
					attValFactories.newAttributeValue(rawVal);
					Assert.assertTrue("Parsing raw value into AttributeValue did not throw exception as expected", expectedExceptionClass == null);
				} catch (final Exception e)
				{
					Assert.assertTrue("Unexpected error: " + e, expectedExceptionClass != null && expectedExceptionClass.isInstance(e));
				}
			}
		}

		try
		{
			final AttributeBag<?> attBag = attValFactories.newAttributeBag(rawValues);
			Assert.assertEquals("Invalid datatype for created attribute values", attBag.getElementDatatype().getId(), expectedAttributeDatatypeId);

			/*
			 * Marshall to XACML and try to unmarshall to original Java value to make sure marshalling is OK
			 */
			final List<AttributeValueType> outXacmlAttVals = attBag.elements().stream()
			        .map(attVal -> new AttributeValueType(attVal.getContent(), attBag.getElementDatatype().getId(), attVal.getXmlAttributes())).collect(Collectors.toList());
			final Attribute outXacmlAtt = new Attribute(outXacmlAttVals, testId.toString(), null, false);
			final Marshaller marshaller = Xacml3JaxbHelper.createXacml3Marshaller();
			final StringWriter strWriter = new StringWriter();
			marshaller.marshal(outXacmlAtt, strWriter);
			final String outStr = strWriter.toString();

			final Unmarshaller unmarshaller = Xacml3JaxbHelper.createXacml3Unmarshaller();
			final Attribute inXacmlAtt = (Attribute) unmarshaller.unmarshal(new StringReader(outStr));
			final List<AttributeValueType> inXacmlAttVals = inXacmlAtt.getAttributeValues();
			if (inXacmlAttVals.isEmpty())
			{
				Assert.fail("Marshalling/unmarshalling failed: no AttributeValue after unmarshalling: " + outStr);
				return;
			}

			final AttributeValueType inXacmlAttVal0 = inXacmlAttVals.get(0);
			final AttributeValueFactory<?> attValFactory = this.attValFactories.getExtension(inXacmlAttVal0.getDataType());
			final List<AttributeValue> inAttVals = inXacmlAttVals.stream()
			        .map(inputXacmlAttValue -> attValFactory.getInstance(inputXacmlAttValue.getContent(), inputXacmlAttValue.getOtherAttributes(), null)).collect(Collectors.toList());

			Assert.assertEquals("AttributeValues after unmarshalling do not match original AttributeValues before marshalling: " + outStr, attBag.elements(), ImmutableMultiset.copyOf(inAttVals));
			Assert.assertTrue("Parsing raw value into AttributeValue did not throw exception as expected", expectedExceptionClass == null);
		} catch (final Exception e)
		{
			Assert.assertTrue("Unexpected error: " + e, expectedExceptionClass != null && expectedExceptionClass.isInstance(e));
		}
	}
