@Override
	public final List<IndividualXacmlJsonRequest> process(final JSONObject request, final Map<String, String> namespaceURIsByPrefix) throws IndeterminateEvaluationException
	{
		if (request == null)
		{
			throw NULL_REQUEST_ARGUMENT_EXCEPTION;
		}

		try
		{
			XacmlJsonUtils.REQUEST_SCHEMA.validate(request);
		}
		catch (final ValidationException e)
		{
			LOGGER.debug(e.toJSON().toString(4));
			throw new IndeterminateEvaluationException("Invalid Request", XacmlStatusCode.SYNTAX_ERROR.value(), e);
		}

		final JSONObject requestJsonObj = request.optJSONObject("Request");
		if (requestJsonObj == null)
		{
			throw MISSING_REQUEST_OBJECT_EXCEPTION;
		}

		/*
		 * No support for MultiRequests (§2.4 of Multiple Decision Profile).
		 */
		if (requestJsonObj.has("MultiRequests"))
		{
			/*
			 * According to 7.19.1 Unsupported functionality, return Indeterminate with syntax-error code for unsupported element
			 */
			throw UNSUPPORTED_MULTI_REQUESTS_EXCEPTION;
		}

		/*
		 * No support for CombinedDecision = true if result processor does not support it. (The use of the CombinedDecision attribute is specified in Multiple Decision Profile.)
		 */
		final boolean combinedDecisionRequested;
		if (requestJsonObj.optBoolean("CombinedDecision", false))
		{
			if (!this.isCombinedDecisionSupported)
			{
				/*
				 * According to XACML core spec, 5.42, "If the PDP does not implement the relevant functionality in [Multiple Decision Profile], then the PDP must return an Indeterminate with a status
				 * code of urn:oasis:names:tc:xacml:1.0:status:processing-error if it receives a request with this attribute set to "true".
				 */
				throw UNSUPPORTED_COMBINED_DECISION_EXCEPTION;
			}

			combinedDecisionRequested = true;
		}
		else
		{
			combinedDecisionRequested = false;
		}

		final boolean returnPolicyIdList = requestJsonObj.optBoolean("ReturnPolicyIdList", false);
		final XPathCompiler xPathCompiler = requestJsonObj.has("XPathVersion") ? XmlUtils.newXPathCompiler(requestJsonObj.getString("XPathVersion"), namespaceURIsByPrefix) : null;
		final SingleCategoryXacmlAttributesParser<JSONObject> xacmlAttrsParser = xacmlAttrsParserFactory.getInstance();
		return process(requestJsonObj.optJSONArray("Category"), xacmlAttrsParser, returnPolicyIdList, combinedDecisionRequested, xPathCompiler, namespaceURIsByPrefix);
	}
