private static JSONObject convert(final IndividualXacmlJsonRequest request, final DecisionResult result)
	{
		assert request != null && result != null;

		final Map<String, Object> jsonPropertyMap = HashCollections.newUpdatableMap(6);
		// Decision
		jsonPropertyMap.put("Decision", result.getDecision().value());

		// Status
		final Status status = result.getStatus();
		if (status != null)
		{
			jsonPropertyMap.put("Status", toJson(status));
		}

		// Obligations/Advice
		final ImmutableList<PepAction> pepActions = result.getPepActions();
		assert pepActions != null;
		if (!pepActions.isEmpty())
		{
			final int numOfPepActions = pepActions.size();
			final List<JSONObject> jsonObligations = new ArrayList<>(numOfPepActions);
			final List<JSONObject> jsonAdvices = new ArrayList<>(numOfPepActions);
			pepActions.forEach(pepAction -> {
				final JSONObject pepActionJsonObject = toJson(pepAction.getId(), pepAction.getAttributeAssignments());
				final List<JSONObject> pepActionJsonObjects = pepAction.isMandatory() ? jsonObligations : jsonAdvices;
				pepActionJsonObjects.add(pepActionJsonObject);
			});

			if (!jsonObligations.isEmpty())
			{
				jsonPropertyMap.put("Obligations", new JSONArray(jsonObligations));
			}

			if (!jsonAdvices.isEmpty())
			{
				jsonPropertyMap.put("AssociatedAdvice", new JSONArray(jsonAdvices));
			}
		}

		// IncludeInResult categories
		final List<JSONObject> attributesByCategoryToBeReturned = request.getAttributesByCategoryToBeReturned();
		if (!attributesByCategoryToBeReturned.isEmpty())
		{
			jsonPropertyMap.put("Category", new JSONArray(attributesByCategoryToBeReturned));
		}

		// PolicyIdentifierList
		final ImmutableList<PrimaryPolicyMetadata> applicablePolicies = result.getApplicablePolicies();
		if (applicablePolicies != null && !applicablePolicies.isEmpty())
		{
			final List<JSONObject> policyRefs = new ArrayList<>(applicablePolicies.size());
			final List<JSONObject> policySetRefs = new ArrayList<>(applicablePolicies.size());
			for (final PrimaryPolicyMetadata applicablePolicy : applicablePolicies)
			{
				final JSONObject ref = new JSONObject(HashCollections.newImmutableMap("Id", applicablePolicy.getId(), "Version", applicablePolicy.getVersion().toString()));
				final List<JSONObject> refs = applicablePolicy.getType() == TopLevelPolicyElementType.POLICY ? policyRefs : policySetRefs;
				refs.add(ref);
			}

			final Map<String, Object> policyListJsonObjMap = HashCollections.newUpdatableMap(2);
			if (!policyRefs.isEmpty())
			{
				policyListJsonObjMap.put("PolicyIdReference", new JSONArray(policyRefs));
			}

			if (!policySetRefs.isEmpty())
			{
				policyListJsonObjMap.put("PolicySetIdReference", new JSONArray(policySetRefs));
			}

			jsonPropertyMap.put("PolicyIdentifierList", new JSONObject(policyListJsonObjMap));
		}

		// final Result
		return new JSONObject(jsonPropertyMap);
	}
