@Override
	public List<IndividualXacmlJsonRequest> process(final JSONArray jsonArrayOfRequestAttributeCategoryObjects, final SingleCategoryXacmlAttributesParser<JSONObject> xacmlAttrsParser,
	        final boolean isApplicablePolicyIdListReturned, final boolean combinedDecision, final XPathCompiler xPathCompiler, final Map<String, String> namespaceURIsByPrefix)
	        throws IndeterminateEvaluationException
	{
		final Map<AttributeFqn, AttributeBag<?>> namedAttributes = HashCollections.newUpdatableMap(jsonArrayOfRequestAttributeCategoryObjects.length());
		/*
		 * TODO: Content object not supported yet (optional in XACML)
		 */
		final Map<String, XdmNode> extraContentsByCategory = Collections.emptyMap() /* HashCollections.newUpdatableMap(requestAttributeCategoryObjects.length()) */;

		/*
		 * requestAttributeCategoryObjectsIncludedInResult.size() <= jsonArrayOfRequestAttributeCategoryObjects.size()
		 */
		final List<JSONObject> requestAttributeCategoryObjectsIncludedInResult = new ArrayList<>(jsonArrayOfRequestAttributeCategoryObjects.length());

		for (final Object requestAttributeCategoryObject : jsonArrayOfRequestAttributeCategoryObjects)
		{
			if (!(requestAttributeCategoryObject instanceof JSONObject))
			{
				throw INVALID_REQUEST_CATEGORY_ARRAY_ELEMENT_TYPE_EXCEPTION;
			}

			final JSONObject requestAttCatJsonObj = (JSONObject) requestAttributeCategoryObject;
			final SingleCategoryAttributes<?, JSONObject> categorySpecificAttributes = xacmlAttrsParser.parseAttributes(requestAttCatJsonObj, xPathCompiler);
			if (categorySpecificAttributes == null)
			{
				// skip this empty Attributes
				continue;
			}

			/*
			 * TODO: Content object not supported yet (optional in XACML)
			 */
			// final XdmNode newContentNode = categorySpecificAttributes.getExtraContent();
			// if (newContentNode != null)
			// {
			// final XdmNode duplicate = extraContentsByCategory.putIfAbsent(categoryName, newContentNode);
			// /*
			// * No support for Multiple Decision Profile -> no support for repeated categories as specified in Multiple Decision Profile. So we must check duplicate attribute categories.
			// */
			// if (duplicate != null)
			// {
			// throw new IndeterminateEvaluationException("Unsupported repetition of Attributes[@Category='" + categoryName
			// + "'] (feature 'urn:oasis:names:tc:xacml:3.0:profile:multiple:repeated-attribute-categories' is not supported)", StatusHelper.STATUS_SYNTAX_ERROR);
			// }
			// }

			/*
			 * Convert growable (therefore mutable) bag of attribute values to immutable ones. Indeed, we must guarantee that attribute values remain constant during the evaluation of the request, as
			 * mandated by the XACML spec, section 7.3.5: <p> <i>
			 * "Regardless of any dynamic modifications of the request context during policy evaluation, the PDP SHALL behave as if each bag of attribute values is fully populated in the context before it is first tested, and is thereafter immutable during evaluation. (That is, every subsequent test of that attribute shall use the same bag of values that was initially tested.)"
			 * </i></p>
			 */
			for (final Entry<AttributeFqn, AttributeBag<?>> attrEntry : categorySpecificAttributes)
			{
				namedAttributes.put(attrEntry.getKey(), attrEntry.getValue());
			}

			final JSONObject catSpecificAttrsToIncludeInResult = categorySpecificAttributes.getAttributesToIncludeInResult();
			if (catSpecificAttrsToIncludeInResult != null)
			{
				requestAttributeCategoryObjectsIncludedInResult.add(catSpecificAttrsToIncludeInResult);
			}
		}

		final ImmutableDecisionRequest pdpEngineReq = reqFactory.getInstance(namedAttributes, extraContentsByCategory, isApplicablePolicyIdListReturned);
		return Collections.singletonList(new IndividualXacmlJsonRequest(pdpEngineReq, ImmutableList.copyOf(requestAttributeCategoryObjectsIncludedInResult)));
	}
