@Test(dataProvider = "getTestDirectories")
	public void test(final Path testDirectoryPath, final String requestFilterId) throws Exception
	{
		LOGGER.debug("******************************");
		LOGGER.debug("Starting PDP test of directory '{}'", testDirectoryPath);

		// Response file
		final Path expectedRespFile = testDirectoryPath.resolve(EXPECTED_RESPONSE_FILENAME_SUFFIX);
		final JSONObject expectedResponse;
		try (final BufferedReader reader = Files.newBufferedReader(expectedRespFile, StandardCharsets.UTF_8))
		{
			expectedResponse = new LimitsCheckingJSONObject(reader, MAX_JSON_STRING_LENGTH, MAX_JSON_CHILDREN_COUNT, MAX_JSON_DEPTH);
			if (!expectedResponse.has("Response"))
			{
				throw new IllegalArgumentException("Invalid XACML JSON Response file: " + expectedRespFile + ". Expected root key: \"Response\"");
			}

			XacmlJsonUtils.RESPONSE_SCHEMA.validate(expectedResponse);
		}

		// Request file
		final JSONObject jsonRequest;
		final Path reqFile = testDirectoryPath.resolve(REQUEST_FILENAME_SUFFIX);
		try (InputStream inputStream = new FileInputStream(reqFile.toFile()))
		{
			jsonRequest = new JSONObject(new JSONTokener(inputStream));
			if (!jsonRequest.has("Request"))
			{
				throw new IllegalArgumentException("Invalid XACML JSON Request file: " + reqFile + ". Expected root key: \"Request\"");
			}

			XacmlJsonUtils.REQUEST_SCHEMA.validate(jsonRequest);
		}

		final Path rootPolicyFile = testDirectoryPath.resolve(ROOT_POLICY_FILENAME_SUFFIX);
		final Path policiesDir = testDirectoryPath.resolve(POLICIES_DIRNAME_SUFFIX);

		final Path attributeProviderConfFile = testDirectoryPath.resolve(ATTRIBUTE_PROVIDER_FILENAME_SUFFIX);
		final Optional<Path> optAttProviderConfFile = Files.exists(attributeProviderConfFile) ? Optional.of(attributeProviderConfFile) : Optional.empty();

		/*
		 * So far we assume the PDP engine configuration files are valid, because for the moment we only test Request/Response in JSON Profile since JSON Profile only applies to these elements (not to
		 * policies) at the moment. If some day, JSON Profile addresses policy format too, then we should do like in ConformanceV3fromV2 class from pdp-testutils package (policy syntax validation).
		 */
		final PdpEngineConfiguration pdpEngineConf = Files.exists(policiesDir)
		        ? TestUtils.newPdpEngineConfiguration(TestUtils.getPolicyRef(rootPolicyFile), policiesDir, ENABLE_XPATH, optAttProviderConfFile, requestFilterId,
		                BaseXacmlJsonResultPostprocessor.DefaultFactory.ID)
		        : TestUtils.newPdpEngineConfiguration(rootPolicyFile, ENABLE_XPATH, optAttProviderConfFile, requestFilterId, BaseXacmlJsonResultPostprocessor.DefaultFactory.ID);

		try (final PdpEngineInoutAdapter<JSONObject, JSONObject> pdp = PdpEngineXacmlJsonAdapters.newXacmlJsonInoutAdapter(pdpEngineConf))
		{
			// this is an evaluation test with request/response (not a policy syntax check)
			LOGGER.debug("Request that is sent to the PDP: {}", jsonRequest);
			final JSONObject actualResponse = pdp.evaluate(jsonRequest);
			if (LOGGER.isDebugEnabled())
			{
				LOGGER.debug("Response that is received from the PDP :  {}", actualResponse);
			}

			assertNormalizedEquals(testDirectoryPath.toString(), expectedResponse, actualResponse);
		}
	}
