private static PdpEngineConfiguration newPdpEngineConfiguration(final TopLevelPolicyElementRef rootPolicyRef, final List<String> policyLocations, final boolean enableXPath,
	        final Optional<Path> attributeProviderConfFile, final String requestPreprocId, final String resultPostprocId) throws JAXBException, IllegalArgumentException, IOException
	{
		Preconditions.checkNotNull(rootPolicyRef, "Root policy reference (ID, version) undefined");
		Preconditions.checkNotNull(policyLocations, "Policy location(s) undefined");

		final Pdp jaxbPDP = new Pdp();
		jaxbPDP.setEnableXPath(enableXPath);

		final StaticPolicyProvider jaxbPolicyProvider = new StaticPolicyProvider();
		jaxbPolicyProvider.setId("policyProvider");
		jaxbPolicyProvider.getPolicyLocations().addAll(policyLocations);
		jaxbPDP.setPolicyProvider(jaxbPolicyProvider);

		// set max PolicySet reference depth to max possible depth automatically
		jaxbPDP.setMaxPolicyRefDepth(BigInteger.valueOf(jaxbPolicyProvider.getPolicyLocations().size()));
		jaxbPDP.setRootPolicyRef(rootPolicyRef);

		// test attribute provider
		if (attributeProviderConfFile.isPresent())
		{
			final Unmarshaller unmarshaller = TEST_ATTRIBUTE_PROVIDER_JAXB_CONTEXT.createUnmarshaller();
			@SuppressWarnings("unchecked")
			final JAXBElement<TestAttributeProviderDescriptor> testAttributeProviderElt = (JAXBElement<TestAttributeProviderDescriptor>) unmarshaller
			        .unmarshal(attributeProviderConfFile.get().toFile());
			jaxbPDP.getAttributeProviders().add(testAttributeProviderElt.getValue());
		}

		if (requestPreprocId != null)
		{
			final InOutProcChain ioProcChain = new InOutProcChain(requestPreprocId, resultPostprocId);
			jaxbPDP.getIoProcChains().add(ioProcChain);
		}

		return new PdpEngineConfiguration(jaxbPDP, new DefaultEnvironmentProperties());

	}
