public static Response normalizeForComparison(final Response response)
	{
		final List<Result> results = new ArrayList<>();
		/*
		 * We iterate over all results, because for each results, we don't compare everything. In particular, we choose to ignore the Status. Indeed, a PDP implementation might return a perfectly
		 * XACML-compliant response but with extra StatusCode/Message/Detail that we would not expect.
		 */
		for (final Result result : response.getResults())
		{
			// We ignore the status, so set it to null in both expected and tested response to avoid
			// StatusMessage/StatusDetail/nested StatusCode comparison
			// conserve root status code if any
			final Status oldStatus = result.getStatus();
			final Status newStatus;
			if (oldStatus == null)
			{
				newStatus = null;
			}
			else
			{
				final StatusCode oldStatusCode = oldStatus.getStatusCode();
				// status OK is useless, equivalent to no status (no error)
				if (oldStatusCode.getValue().equals(XacmlStatusCode.OK.value()))
				{
					newStatus = null;
				}
				else if (oldStatus.getStatusMessage() == null && oldStatus.getStatusDetail() == null && oldStatusCode.getStatusCode() == null)
				{
					// if there is only a StatusCode (no nested one), keep it as is
					newStatus = oldStatus;
				}
				else
				{
					// keep only the statusCode
					newStatus = new Status(oldStatusCode, null, null);
				}
			}

			results.add(new Result(result.getDecision(), newStatus, result.getObligations(), result.getAssociatedAdvice(), normalizeAttributeCategories(result.getAttributes()),
			        result.getPolicyIdentifierList()));
		}

		return new Response(results);
	}
