@Override
	public StaticTopLevelPolicyElementEvaluator getPolicySet(final String policyId, final Optional<PolicyVersionPatterns> policyPolicyVersionPatterns, final Deque<String> policySetRefChain)
	        throws IndeterminateEvaluationException
	{
		/*
		 * TODO: use a policy cache and check it before requesting the database. If we found a matching policy in cache, and it is a policyset, we would check the depth of policy references as well:
		 * <p>
		 * Utils.appendAndCheckPolicyRefChain(newPolicySetRefChain, cachedPolicy.getExtraPolicyMetadata().getLongestPolicyRefChain(), maxPolicySetRefDepth);
		 */
		final PolicyQueryResult xmlParsingResult = getJaxbPolicyElement(XACML3_POLICYSET_TYPE_ID, policyId, policyPolicyVersionPatterns);
		if (xmlParsingResult == null)
		{
			return null;
		}

		final PolicyPojo policyPOJO = xmlParsingResult.policyPojo;
		final Object jaxbPolicyOrPolicySetObj = xmlParsingResult.resultJaxbObj;
		final Map<String, String> nsPrefixUriMap = xmlParsingResult.xmlnsToPrefixMap;
		if (!(jaxbPolicyOrPolicySetObj instanceof PolicySet))
		{
			throw new IndeterminateEvaluationException("PolicyProvider " + id + ": 'content' of the policy document " + policyPOJO
			        + " retrieved from database is not consistent with 'type' (expected: PolicySet). Actual content type: " + jaxbPolicyOrPolicySetObj.getClass() + " (corrupted database?).",
			        XacmlStatusCode.PROCESSING_ERROR.value());
		}

		final PolicySet jaxbPolicySet = (PolicySet) jaxbPolicyOrPolicySetObj;
		final String contentPolicyId = jaxbPolicySet.getPolicySetId();
		if (!contentPolicyId.equals(policyPOJO.getId()))
		{
			throw new IndeterminateEvaluationException("PolicyProvider " + id + ": PolicyId in 'content' of the policy document " + policyPOJO
			        + " retrieved from database is not consistent with 'id'. Actual PolicyId: " + contentPolicyId + " (corrupted database?).", XacmlStatusCode.PROCESSING_ERROR.value());
		}

		final String contentPolicyVersion = jaxbPolicySet.getVersion();
		if (!contentPolicyVersion.equals(policyPOJO.getVersion()))
		{
			throw new IndeterminateEvaluationException("PolicyProvider " + id + ": Version in 'content' of the policy document " + policyPOJO
			        + " retrieved from database is not consistent with 'version'. Actual Version: " + contentPolicyVersion + " (corrupted database?).", XacmlStatusCode.PROCESSING_ERROR.value());
		}

		try
		{
			return PolicyEvaluators.getInstanceStatic(jaxbPolicySet, null, nsPrefixUriMap, expressionFactory, combiningAlgRegistry, this, policySetRefChain);
		}
		catch (final IllegalArgumentException e)
		{
			throw new IndeterminateEvaluationException("Invalid PolicySet in 'content' of the policy document " + policyPOJO + " retrieved from database", XacmlStatusCode.PROCESSING_ERROR.value(), e);
		}
	}
