@Override
	public StaticTopLevelPolicyElementEvaluator getPolicy(final String policyId, final Optional<PolicyVersionPatterns> policyPolicyVersionPatterns) throws IndeterminateEvaluationException
	{
		/*
		 * TODO: use a policy cache and check it before requesting the database.
		 */
		final PolicyQueryResult xmlParsingResult = getJaxbPolicyElement(XACML3_POLICY_TYPE_ID, policyId, policyPolicyVersionPatterns);
		if (xmlParsingResult == null)
		{
			return null;
		}

		final PolicyPojo policyPOJO = xmlParsingResult.policyPojo;
		final Object jaxbPolicyOrPolicySetObj = xmlParsingResult.resultJaxbObj;
		final Map<String, String> nsPrefixUriMap = xmlParsingResult.xmlnsToPrefixMap;
		if (!(jaxbPolicyOrPolicySetObj instanceof Policy))
		{
			throw new IndeterminateEvaluationException("PolicyProvider " + id + ": 'content' of the policy document " + policyPOJO
			        + " retrieved from database is not consistent with its 'type' (expected: Policy). Actual content type: " + jaxbPolicyOrPolicySetObj.getClass() + " (corrupted database?).",
			        XacmlStatusCode.PROCESSING_ERROR.value());
		}

		final Policy jaxbPolicy = (Policy) jaxbPolicyOrPolicySetObj;
		final String contentPolicyId = jaxbPolicy.getPolicyId();
		if (!contentPolicyId.equals(policyPOJO.getId()))
		{
			throw new IndeterminateEvaluationException("PolicyProvider " + id + ": PolicyId in 'content' of the policy document " + policyPOJO
			        + " retrieved from database is not consistent with 'id'. Actual PolicyId: " + contentPolicyId + " (corrupted database?).", XacmlStatusCode.PROCESSING_ERROR.value());
		}

		final String contentPolicyVersion = jaxbPolicy.getVersion();
		if (!contentPolicyVersion.equals(policyPOJO.getVersion()))
		{
			throw new IndeterminateEvaluationException("PolicyProvider " + id + ": Version in 'content' of the policy document " + policyPOJO
			        + " retrieved from database is not consistent with 'version'. Actual Version: " + contentPolicyVersion + " (corrupted database?).", XacmlStatusCode.PROCESSING_ERROR.value());
		}

		try
		{
			return PolicyEvaluators.getInstance(jaxbPolicy, null, nsPrefixUriMap, expressionFactory, combiningAlgRegistry);
		}
		catch (final IllegalArgumentException e)
		{
			throw new IllegalArgumentException("Invalid Policy in 'content' of the policy document " + policyPOJO + " retrieved from database", e);
		}
	}
