@Override
	public Response process(final Collection<Entry<IndividualXacmlJaxbRequest, ? extends DecisionResult>> resultsByRequest)
	{
		DecisionType combinedDecision = DecisionType.INDETERMINATE;
		for (final Entry<? extends IndividualXacmlJaxbRequest, ? extends DecisionResult> resultEntry : resultsByRequest)
		{
			final DecisionResult result = resultEntry.getValue();
			if (result.getDecision() == DecisionType.INDETERMINATE)
			{
				// either all result must be indeterminate or we return Indeterminate as final result anyway
				return SIMPLE_INDETERMINATE_RESPONSE;
			}

			final ImmutableList<PepAction> pepActions = result.getPepActions();
			assert pepActions != null;

			if (!pepActions.isEmpty())
			{
				return SIMPLE_INDETERMINATE_RESPONSE;
			}

			final DecisionType individualDecision = result.getDecision();
			// if combinedDecision not initialized yet (indeterminate), set it to the result's decision
			if (combinedDecision == DecisionType.INDETERMINATE)
			{
				combinedDecision = individualDecision;
			} else
			// combinedDecision != Indeterminate
			if (individualDecision != combinedDecision)
			{
				return SIMPLE_INDETERMINATE_RESPONSE;
			}
		}

		switch (combinedDecision)
		{
			case PERMIT:
				return SIMPLE_PERMIT_RESPONSE;
			case DENY:
				return SIMPLE_DENY_RESPONSE;
			case NOT_APPLICABLE:
				return SIMPLE_NOT_APPLICABLE_RESPONSE;
			default:
				return SIMPLE_INDETERMINATE_RESPONSE;
		}
	}
