@BeforeClass
	public static void setUpBeforeClass() throws Exception
	{
		final PdpModelHandler pdpModelHandler = new PdpModelHandler("classpath:catalog.xml", "classpath:pdp-ext.xsd");
		final Pdp pdpConf;
		try (final InputStream is = MongoDBRefPolicyProviderTest.class.getResourceAsStream(PdpTest.PDP_CONF_FILENAME))
		{
			pdpConf = pdpModelHandler.unmarshal(new StreamSource(is), Pdp.class);
		}

		final AbstractPolicyProvider policyProviderConf = pdpConf.getPolicyProvider();
		if (!(policyProviderConf instanceof MongoDBBasedPolicyProviderDescriptor))
		{
			throw new RuntimeException("Invalid type of refPolicyProvider in pdp.xml. Expected: " + MongoDBBasedPolicyProviderDescriptor.class);
		}

		final MongoDBBasedPolicyProviderDescriptor mongodbBasedPolicyProviderConf = (MongoDBBasedPolicyProviderDescriptor) policyProviderConf;
		final BigInteger maxAllowedIntVal = BigInteger.valueOf(Integer.MAX_VALUE);

		final AttributeValueFactoryRegistry valFactoryReg = StandardAttributeValueFactories.getRegistry(false, Optional.of(maxAllowedIntVal));
		final AttributeValueFactory<?> intValFactory = valFactoryReg.getExtension(StandardDatatypes.INTEGER.getId());
		final FunctionRegistry funcReg = StandardFunction.getRegistry(false, (StringParseableValue.Factory<IntegerValue>) intValFactory);
		try (final ExpressionFactory expressionFactory = new DepthLimitingExpressionFactory(valFactoryReg, funcReg, null, 0, false, false))
		{
			POLICY_PROVIDER_MODULE = new MongoDbPolicyProvider.Factory().getInstance(mongodbBasedPolicyProviderConf, XacmlJaxbParsingUtils.getXacmlParserFactory(false), 10, expressionFactory,
			        StandardCombiningAlgorithm.REGISTRY, null);
		}

		/*
		 * Use in-memory MongoDB server from https://github.com/bwaldvogel/mongo-java-server
		 */
		/*
		 * 
		 * Discarded alternatives for embedded MongoDB server:
		 * 
		 * - fakemongo/fongo: does not implement the wire protocol so not an actual server listening on the network, therefore useless to test the RESTfulRefPolicyProviderModule;
		 * 
		 * - de.flapdoodle.embed.mongo: overkill for unit tests (requires to download and run the actual MongoDB executable).
		 */
		DB_SERVER = new MongoServer(new MemoryBackend());
		final InetSocketAddress socketAddress = new InetSocketAddress(mongodbBasedPolicyProviderConf.getServerHost(), mongodbBasedPolicyProviderConf.getServerPort());
		DB_SERVER.bind(socketAddress);

		final MongoClient dbClient = new MongoClient(new ServerAddress(socketAddress));
		final Jongo testDbWrapper = new Jongo(dbClient.getDB(mongodbBasedPolicyProviderConf.getDbName()));
		POLICY_COLLECTION = testDbWrapper.getCollection(mongodbBasedPolicyProviderConf.getCollectionName());
		// populate database with sample policies
		final Unmarshaller unmarshaller = Xacml3JaxbHelper.createXacml3Unmarshaller();
		for (final String policyFilename : SAMPLE_POLICY_FILENAMES)
		{
			final String policyContent;
			try (final InputStream is = MongoDBRefPolicyProviderTest.class.getResourceAsStream(policyFilename))
			{
				policyContent = IOUtils.toString(is, Charsets.UTF_8.name());
			}
			final Object jaxbObj = unmarshaller.unmarshal(new StringReader(policyContent));
			final String policyTypeId;
			final String policyId;
			final String policyVersion;
			if (jaxbObj instanceof Policy)
			{
				final Policy policy = (Policy) jaxbObj;
				policyTypeId = MongoDbPolicyProvider.XACML3_POLICY_TYPE_ID;
				policyId = policy.getPolicyId();
				policyVersion = policy.getVersion();
			}
			else
			{
				// PolicySet
				policyTypeId = MongoDbPolicyProvider.XACML3_POLICYSET_TYPE_ID;
				final PolicySet policySet = (PolicySet) jaxbObj;
				policyId = policySet.getPolicySetId();
				policyVersion = policySet.getVersion();
			}

			POLICY_COLLECTION.insert(new PolicyPojo(policyId, policyVersion, policyTypeId, policyContent));
		}

	}
