@Test
	public void test() throws IllegalArgumentException, IOException, URISyntaxException, JAXBException
	{
		final String testResourceLocationPrefix = TEST_RESOURCES_DIRECTORY_LOCATION + "/";

		/*
		 * Policies
		 * 
		 * If there is a "$TEST_DIR/$POLICIES_DIR_NAME" directory, then load all policies from there, including root policy from "$TEST_DIR/$POLICIES_DIR_NAME/$ROOT_POLICY_FILENAME" Else load only the
		 * root policy from "$TEST_DIR/$ROOT_POLICY_FILENAME"
		 */
		final Path policiesDir = Paths.get(testResourceLocationPrefix + PdpTest.POLICIES_DIR_NAME);
		final Optional<Path> optPoliciesDir;
		final Path rootPolicyFile;
		if (Files.isDirectory(policiesDir))
		{
			optPoliciesDir = Optional.of(policiesDir);
			rootPolicyFile = policiesDir.resolve(PdpTest.ROOT_POLICY_FILENAME);
		}
		else
		{
			optPoliciesDir = Optional.empty();
			rootPolicyFile = Paths.get(testResourceLocationPrefix + PdpTest.ROOT_POLICY_FILENAME);
		}

		/*
		 * Create PDP
		 */
		final PdpEngineConfiguration pdpEngineConf = optPoliciesDir.isPresent()
		        ? TestUtils.newPdpEngineConfiguration(TestUtils.getPolicyRef(rootPolicyFile), optPoliciesDir.get(), false, Optional.empty(), null, null)
		        : TestUtils.newPdpEngineConfiguration(rootPolicyFile, false, Optional.empty(), null, null);
		try (final PdpEngineInoutAdapter<Request, Response> pdp = PdpEngineAdapters.newXacmlJaxbInoutAdapter(pdpEngineConf))
		{
			final Iterator<PrimaryPolicyMetadata> staticApplicablePolicies = pdp.getApplicablePolicies().iterator();
			assertTrue("No root policy in PDP's applicable policies (statically resolved)", staticApplicablePolicies != null && staticApplicablePolicies.hasNext());
			assertEquals("Invalid root policy in PDP's applicable policies (statically resolved)", ROOT_POLICYSET_METADATA, staticApplicablePolicies.next());

			for (final PrimaryPolicyMetadata expectedRefPolicyMeta : REF_POLICYSET_METADATA_SET)
			{
				assertTrue("No (more) referenced policy in PDP's applicable policies (statically resolved) although expected", staticApplicablePolicies.hasNext());
				assertEquals("Invalid referenced policy in PDP's applicable policies (statically resolved)", expectedRefPolicyMeta, staticApplicablePolicies.next());
			}

		}
	}
