public static void setDefaultConfig(int sid,
                                      String host,
                                      String adminuid, String adminpwd,
                                      int joram, int jndi, Properties props) {
    StringBuffer strbuf = new StringBuffer();

    if (host == null) {
      try {
        host = InetAddress.getLocalHost().getHostName();
      } catch (UnknownHostException e) {
        host = "localhost";
      }
    }
    if (adminuid == null) {
      adminuid = System.getProperty(AgentServer.CFG_ADMINUID_PROPERTY, "root");
    }
    if (adminpwd == null) {
      adminpwd = System.getProperty(AgentServer.CFG_ADMINPWD_PROPERTY, adminuid);
    }
    if (joram == 0) {
      joram = Integer.getInteger(AgentServer.CFG_JMS_PORT_PROPERTY, CFG_JMS_PORT_DFLT);
    }
    if (jndi == 0) {
      jndi = Integer.getInteger(AgentServer.CFG_JNDI_PORT_PROPERTY, CFG_JNDI_PORT_DFLT);
    }

    strbuf.append(
        "<config>\n");
    if (props != null) {
      // Fixes the Transaction property if needed.
      if (props.getProperty("Transaction") == null)
        props.setProperty("Transaction", "fr.dyade.aaa.ext.NGTransaction");
      for (Enumeration e = props.keys(); e.hasMoreElements();) {
        String key = (String) e.nextElement();
        strbuf.append("<property name=\"").append(key).append("\" value=\"").append(props.getProperty(key)).append("\"/>\n");
      }
    } else {
      // There is no property defined, set the Transaction property.
      strbuf.append(
                    "<property name=\"Transaction\" value=\"fr.dyade.aaa.ext.NGTransaction\"/>\n" +
          "<server id=\"").append(sid).append("\" name=\"S").append(sid).append("\" hostname=\"").append(host).append("\">\n");
    }
    if (joram > 0) { // Joram/JMS service and TCP connector
      strbuf.append(
          "<service class=\"org.objectweb.joram.mom.proxies.ConnectionManager\" args=\"").append(adminuid).append(' ').append(adminpwd).append("\"/>\n" +
          "<service class=\"org.objectweb.joram.mom.proxies.tcp.TcpProxyService\" args=\"").append(joram).append("\"/>\n");
    } else if (joram == -1) { // No Joram/JMS service
      strbuf.append(
          "<!-- No Joram/JMS service -->\n");
    } else if (joram == -2) { // Joram/JMS service without TCP connector
      strbuf.append(
          "<service class=\"org.objectweb.joram.mom.proxies.ConnectionManager\" args=\"").append(adminuid).append(' ').append(adminpwd).append("\"/>\n");
    } else if (joram == -2) { // Joram/JMS service without TCP connector
      int min = Integer.getInteger(AgentServer.CFG_MIN_JORAM_PORT_PROPERTY, CFG_MIN_JORAM_PORT_DFLT);
      int max = Integer.getInteger(AgentServer.CFG_MAX_JORAM_PORT_PROPERTY, CFG_MAX_JORAM_PORT_DFLT);
      joram = min + new Random().nextInt(max-min);
      // TODO (AF): We should try if this listening port is free.
      strbuf.append(
          "<service class=\"org.objectweb.joram.mom.proxies.ConnectionManager\" args=\"").append(adminuid).append(' ').append(adminpwd).append("\"/>\n" +
          "<service class=\"org.objectweb.joram.mom.proxies.tcp.TcpProxyService\" args=\"").append(joram).append("\"/>\n");
    }
    if (jndi > 0) {
      strbuf.append(
          "<service class=\"fr.dyade.aaa.jndi2.server.JndiServer\" args=\"").append(jndi).append("\"/>\n");
    }
    strbuf.append(
        "</server>\n" +
        "</config>\n");
    
    defaultConfig = strbuf.toString();
  }
