void commit() throws Exception {
    if (logmon.isLoggable(BasicLevel.DEBUG))
      logmon.log(BasicLevel.DEBUG, getName() + ": commit()");
    
    if (agent != null) {
      agent.save();
    }
    
    if (noTxIfTransient && msg.not.persistent == false
        && !persistentPush
        && !AgentServer.getTransaction().containsOperations()) {
      // Suppress the processed notification from message queue ..
      qin.pop();
      // .. then deletes it ..
      msg.delete();
      // .. and frees it.
      msg.free();
      // Post all notifications temporary kept in mq to the right consumers,
      // then saves changes.
      Message msgToDispatch = null;
      while (!mq.isEmpty()) {
        try {
          msgToDispatch = (Message) mq.get();
        } catch (InterruptedException exc) {
          continue;
        }
        if (msgToDispatch.from == null)
          msgToDispatch.from = AgentId.localId;
        MessageConsumer cons = AgentServer.getConsumer(msgToDispatch.to.getTo());
        cons.postAndValidate(msgToDispatch);
        mq.pop();
      }
    } else {
      AgentServer.getTransaction().begin();
      // Suppress the processed notification from message queue ..
      qin.pop();
      // .. then deletes it ..
      msg.delete();
      // .. and frees it.
      msg.free();
      // Post all notifications temporary kept in mq to the right consumers,
      // then saves changes.
      dispatch();
      // Saves the agent state then commit the transaction.
      AgentServer.getTransaction().commit(false);
      // The transaction has committed, then validate all messages.
      Channel.validate();
      AgentServer.getTransaction().release();
    }
    
    persistentPush = false;
    
    if (logmon.isLoggable(BasicLevel.DEBUG))
      logmon.log(BasicLevel.DEBUG, getName() + ": commited");

  }
