public void run() {
    try {
      long start = 0L;
      long end = 0L;
      boolean profiling = false;
      
      averageCPUTask = new AverageCPUTask(Thread.currentThread().getId(), 12);
      averageCPUTask.start(AgentServer.getTimer());
      
      main_loop:
        while (isRunning) {
          agent = null;
          canStop = true;

          // Get a notification, then execute the right reaction.
          try {
            msg = qin.get(timeout);
            if (msg == null) {
              onTimeOut();
              continue;
            }
          } catch (InterruptedException exc) {
            continue;
          }

          canStop = false;
          if (! isRunning) break;

          // Increment workInProgress counter to indicate that the engine is working.
          incWorkInProgress();
          
          if ((msg.from == null) || (msg.to == null) || (msg.not == null)) {
            // The notification is malformed.
            logmon.log(BasicLevel.ERROR,
                       AgentServer.getName() + ": Bad message [" +
                       msg.from + ", " + msg.to + ", " + msg.not + ']');
            // Remove the failed notification ..
            qin.pop();
            // .. then deletes it ..
            msg.delete();
            // .. and frees it.
            msg.free();

            continue;
          }
          
          CallbackNotification callbackNotification;
          if (msg.getNot() instanceof CallbackNotification) {
            callbackNotification = (CallbackNotification) msg.getNot();
          } else {
            callbackNotification = null;
          }

          if ((msg.not.expiration <= 0L) ||
              (msg.not.expiration >= System.currentTimeMillis())) {
            // The message is valid, try to load the destination agent
            try {
              agent = load(msg.to);
            } catch (UnknownAgentException exc) {
              //  The destination agent don't exists, send an error
              // notification to sending agent.
              logmon.log(BasicLevel.ERROR,
                         getName() + ": Unknown agent, " + msg.to + ".react(" +
                         msg.from + ", " + msg.not + ")");
              agent = null;
              if (callbackNotification != null) {
                callbackNotification.failed(exc);
              }
              push(AgentId.localId, msg.from, new UnknownAgent(msg.to, msg.not));
            } catch (Exception exc) {
              //  Can't load agent then send an error notification
              // to sending agent.
              logmon.log(BasicLevel.ERROR,
                         getName() + ": Can't load agent, " + msg.to + ".react(" +
                         msg.from + ", " + msg.not + ")",
                         exc);
              agent = null;
              // Stop the AgentServer
              AgentServer.stop(false);
              break main_loop;
            }
          } else {
            if (msg.not.deadNotificationAgentId != null) {
              if (logmon.isLoggable(BasicLevel.DEBUG)) {
                logmon.log(BasicLevel.DEBUG,
                           getName() + ": forward expired notification " +
                           msg.from + ", " + msg.not + " to " +
                           msg.not.deadNotificationAgentId);
              }
              ExpiredNot expiredNot = new ExpiredNot(msg.not, msg.from, msg.to);
              push(AgentId.localId, msg.not.deadNotificationAgentId, expiredNot);
            } else {
              if (logmon.isLoggable(BasicLevel.DEBUG)) {
                logmon.log(BasicLevel.DEBUG,
                           getName() + ": removes expired notification " +
                           msg.from + ", " + msg.not);
              }
            }
          }

          if (agent != null) {
            if (logmon.isLoggable(BasicLevel.DEBUG))
              logmon.log(BasicLevel.DEBUG,
                         getName() + ": " + agent + ".react(" + msg.from + ", " + msg.getStamp() + ", " + msg.not + ")");

            profiling = agentProfiling || agent.agentProfiling;
            if (profiling) {
              start = System.nanoTime();
            }
            
//            if (AgentServer.sdf != null) {
//              // SDF generation
//              strbuf.append("<react agentName=\"").append(agent.getAgentId()).append("\" notification=\"").append(StringId.toStringId('N', '_', msg.getSource(), msg.getDest(), msg.getStamp())).append("\" logpointer=\"10\" timestamp=\"").append(System.currentTimeMillis()).append("\">\n");
//            }

            profiling = agentProfiling || agent.agentProfiling;
            if (profiling)
              start = System.nanoTime();
           
            try {
              agent.react(msg.from, msg.not);
              agent.reactNb += 1;
              if (profiling) {
                end  = System.nanoTime();
                agent.reactTime += (end - start);
                reactTime += (end - start);
                start = end;
              }
            } catch (Exception exc) {
              logmon.log(BasicLevel.ERROR,
                         getName() + ": Uncaught exception during react, " + agent + ".react(" + msg.from + ", " + msg.not + ")",
                         exc);
              switch (recoveryPolicy) {
              case RP_EXC_NOT:
              default:
                // In case of unrecoverable error during the reaction we have
                // to rollback.
                abort(exc);
                
                if (callbackNotification != null) {
                  callbackNotification.failed(exc);
                }
                
                // then continue.
                continue;
              case RP_EXIT:
                // Stop the AgentServer
                AgentServer.stop(false);
                break main_loop;
              }
            }
          }

          // Commit all changes then continue.
          commit();
          
          if (callbackNotification != null) {
            callbackNotification.done();
          }
          
//          // SDF generation
//          if (AgentServer.sdf != null) {
//            strbuf.append("</react>");
//            AgentServer.sdf.println(strbuf.toString());
//            strbuf.setLength(0);
//          }
//          
//          // TODO (AF): This code could throw a NPE if the agent doesn't exist!
//          if (AgentServer.logsdf.isLoggable(BasicLevel.INFO))
//            AgentServer.logsdf.log(BasicLevel.INFO,
//                                   "react " + agent.getAgentId() + ' ' + StringId.toStringId('N', '_', msg.getSource(), msg.getDest(), msg.getStamp()));

          // Agent profiling
          if (profiling && (agent != null)) {
            end  = System.nanoTime();
            agent.commitTime += (end - start);
            commitTime += (end - start);
          }
        }
    } catch (Throwable exc) {
      //  There is an unrecoverable exception during the transaction
      // we must exit from server.
      logmon.log(BasicLevel.FATAL, getName() + ": Transaction problem", exc);
      canStop = false;
      // Stop the AgentServer
      AgentServer.stop(false);
    } finally {
      terminate();
      logmon.log(BasicLevel.DEBUG, getName() + " stopped.");
    }
  }
