protected final void writeMessage(Message msg,
                                    long time) throws IOException {
    if (getLogger().isLoggable(BasicLevel.DEBUG))
      getLogger().log(BasicLevel.DEBUG, "writeMessage()");
    
    // Writes the protocol specific data.
    writeHeader();

    if (msg != null) {
      // Writes the message header data.
      writeMessageHeader(msg);

      if (msg.not == null) {
        if (getLogger().isLoggable(BasicLevel.DEBUG))
          getLogger().log(BasicLevel.DEBUG, "writeMessage - 1");
        
        buf[count++] = Message.NULL;
        flush();
      } else {
        if (getLogger().isLoggable(BasicLevel.DEBUG))
          getLogger().log(BasicLevel.DEBUG, "writeMessage - 2");
        
        // Writes notification attributes
        buf[count++] = msg.optToByte();

        try {
          if (msg.not.expiration > 0)
            msg.not.expiration -= time;

          // Writes a serializable object to this output stream.
          if (compressedFlows) {
            ByteArrayOutputStream baos = new ByteArrayOutputStream();
            GZIPOutputStream gzipos = new GZIPOutputStream(baos);
            
            oos = new ObjectOutputStream(gzipos);
            oos.writeObject(msg.not);

            // Be careful, the reset writes a TC_RESET byte
            oos.reset();
            // The OOS flush call the flush of this output stream.
            oos.flush();
            gzipos.finish();
            gzipos.flush();
            
            if (getLogger().isLoggable(BasicLevel.DEBUG))
              getLogger().log(BasicLevel.DEBUG, "writeNotification - size=" + baos.size());

            writeInt(baos.size());
            baos.writeTo(this);
            
            flush();
            
            oos = null;
          } else {
            // Write the STREAM_MAGIC constant
            buf[count++] = STREAM_MAGIC1;
            buf[count++] = STREAM_MAGIC2;
            // Write the STREAM_VERSION constant
            buf[count++] = STREAM_VERSION1;
            buf[count++] = STREAM_VERSION2;
            oos.writeObject(msg.not);

            // Be careful, the reset writes a TC_RESET byte
            oos.reset();
            // The OOS flush call the flush of this output stream.
            oos.flush();
          }
        } finally {
          if ((msg.not != null) && (msg.not.expiration > 0))
            msg.not.expiration += time;
        }
      }
    } else {
      flush();
    }
    
    if (getLogger().isLoggable(BasicLevel.DEBUG))
      getLogger().log(BasicLevel.DEBUG, "writeMessage returns");
  }
