public void decode(Decoder decoder) throws Exception {
    // Reads sender's AgentId
    from = new AgentId(decoder.decode16(), decoder.decode16(), decoder.decode32());
    // Reads adressee's AgentId
    to = new AgentId(decoder.decode16(), decoder.decode16(), decoder.decode32());
    // Reads source server id of message
    source = decoder.decode16();
    // Reads destination server id of message
    dest = decoder.decode16();
    // Reads stamp of message
    stamp = decoder.decode32();

    int opt = decoder.decodeByte();
    if (opt == NULL) {
      Debug.getLogger(getClass().getName()).log(BasicLevel.ERROR,
          "Message.readObject -> null notification.");
      not = null;
    } else {
      // Reads notification attributes
      boolean persistent = ((opt & PERSISTENT) != 0);
      boolean detachable = ((opt & DETACHABLE) != 0);

      if (! detachable) {
        // Reads notification object
        boolean isEncodable = decoder.decodeBoolean();
        if (isEncodable) {
          int classId = decoder.decodeUnsignedInt();
          EncodableFactory factory = EncodableFactoryRepository.getFactory(classId);
          if (factory == null) {
            Debug.getLogger(getClass().getName()).log(BasicLevel.ERROR,
                "from=" + from) ;
            Debug.getLogger(getClass().getName()).log(BasicLevel.ERROR,
                "to=" + to) ;
            Debug.getLogger(getClass().getName()).log(BasicLevel.ERROR,
                "dest=" + dest) ;
            Debug.getLogger(getClass().getName()).log(BasicLevel.ERROR,
                "stamp=" + stamp) ;
            throw new Exception("Notification factory not found: " + classId);
          }
          not = (Notification) factory.createEncodable();
          not.decode(decoder);
        } else {
          SerializableWrapper sw = new SerializableWrapper();
          sw.decode(decoder);
          not = (Notification) sw.getValue();
        }
        not.detachable = detachable;
        not.persistent = persistent;
        not.detached = false;
      } else {
        Debug.getLogger(getClass().getName()).log(BasicLevel.DEBUG,
            "Message.readObject -> " + opt);
      }
    }
  }
