protected void deliver(Message msg) throws Exception {
    // Get real from serverId.
    final short source = msg.getSource();

    // Test if the message is really for this node (final destination or
    // router).
    final short dest = msg.getDest();
    if (dest != AgentServer.getServerId()) {
      logmon.log(BasicLevel.ERROR,
                 getName() + ", recv bad msg#" + msg.getStamp() +
                 " really to " + dest +
                 " by " + source);
      throw new Exception("recv bad msg#" + msg.getStamp() + " really to " + dest + " by " + source);
    }

    if (logmon.isLoggable(BasicLevel.DEBUG))
      logmon.log(BasicLevel.DEBUG,
                 getName() + ", recv msg#" + msg.getStamp() +
                 " from " + msg.from +
                 " to " + msg.to +
                 " by " + source);

    ServerDesc desc = AgentServer.getServerDesc(source);
    if (! desc.active) {
      desc.active = true;
      desc.retry = 0;
    }

    // Start a transaction in order to ensure atomicity of clock updates
    // and queue changes.
    AgentServer.getTransaction().begin();

    // Test if the message can be delivered then deliver it
    // else put it in the waiting list
    int todo = testRecvUpdate(source, msg.getStamp());

    if (todo == DELIVER) {
      // Deliver the message and save it.
      
      
      Channel.post(msg); nbMessageIn += 1;

      if (logmon.isLoggable(BasicLevel.DEBUG))
        logmon.log(BasicLevel.DEBUG, getName() + ", deliver msg#" + msg.getStamp());

      Channel.save();
      AgentServer.getTransaction().commit(false);
      // then commit and validate the message.
      Channel.validate();
      AgentServer.getTransaction().release();
    } else {
//    it's an already delivered message, we have just to re-send an
//    acknowledge (see below).
      AgentServer.getTransaction().commit(true);
    }
  }
