public void restore() throws Exception {
    if (logmon.isLoggable(BasicLevel.DEBUG))
      logmon.log(BasicLevel.DEBUG, getName() + ".restore()");

    sid = AgentServer.getServerId();
    idxLS = index(sid);
    // Loads the logical clock.
    stampbuf = AgentServer.getTransaction().loadByteArray(name);
    if (stampbuf ==  null) {
      // Creates the new stamp array and the boot time stamp,
      stampbuf = new byte[4*servers.length];
      stamp = new int[servers.length];
      bootTS = new int[servers.length];
      // Then initializes them
      for (int i=0; i<servers.length; i++) {
        if (i != idxLS) {
          stamp[i] = -1;
          bootTS[i] = -1;
        } else {
          stamp[i] = 0;
          bootTS[i] = (int) (System.currentTimeMillis() /1000L);
        }
      }
      // Save the servers configuration and the logical time stamp.
      AgentServer.getTransaction().save(servers, serversFN);
      AgentServer.getTransaction().save(bootTS, bootTSFN);
      AgentServer.getTransaction().saveByteArray(stampbuf, name);
    } else {
      // Loads the domain configurations
      short[] s = (short[]) AgentServer.getTransaction().load(serversFN);
      bootTS = (int[]) AgentServer.getTransaction().load(bootTSFN);
      stamp = new int[s.length];
      for (int i=0; i<stamp.length; i++) {
        stamp[i] = ((stampbuf[(i*4)+0] & 0xFF) << 24) +
          ((stampbuf[(i*4)+1] & 0xFF) << 16) +
          ((stampbuf[(i*4)+2] & 0xFF) <<  8) +
          (stampbuf[(i*4)+3] & 0xFF);
      }
      // Joins with the new domain configuration:
      if ((servers != null) && !Arrays.equals(servers, s)) {
        StringBuffer strbuf = new StringBuffer();
        strbuf.append("Incoherent network configuration: ");
        Strings.toString(strbuf, servers, -1, 0);
        strbuf.append(" != ");
        Strings.toString(strbuf, s, -1, 0);

        logmon.log(BasicLevel.ERROR, strbuf.toString());

        throw new IOException("Network configuration changed");
      }
    }
  }
