public synchronized void addServer(short id) throws Exception {
    if (logmon.isLoggable(BasicLevel.DEBUG)) {
      StringBuffer strbuf = new StringBuffer();
      strbuf.append(getName()).append(" before addServer(").append(id).append("):");
      for (int i=0; i<servers.length; i++) {
        strbuf.append("\n\tserver#" + servers[i] + " -> " + sessions[i]);
      }
      logmon.log(BasicLevel.DEBUG, strbuf.toString());
    }

    // First we have to verify that the server is not already defined.
    // Be careful, this test is already done in superclass.
    if (index(id) >= 0) return;

    try {
      super.addServer(id);

      if (sessions.length == servers.length) return;

      NetSession[] newSessions = new NetSession[servers.length];

      // Copy the old array in the new one
      for (int i=0; i<sessions.length; i++) {
        if ((sessions[i] != null) && 
            (sessions[i].sid != AgentServer.getServerId())) {
          newSessions[index(sessions[i].sid)] = sessions[i];
          sessions[i] = null;
        }
      }
      sessions = newSessions;
      // Allocate the NetSession for the new server
      int idx = index(id);
      sessions[idx] = new NetSession(getName(), id);
      sessions[idx].init();

      try {
        MXWrapper.registerMBean(new NetSessionWrapper(this, id),
                                "AgentServer", getMBeanName(id));
      } catch (Exception exc) {
        logmon.log(BasicLevel.WARN, getName() + ".addServer - jmx failed: " + getMBeanName(id), exc);
      }

      if (logmon.isLoggable(BasicLevel.DEBUG)) {
        StringBuffer strbuf = new StringBuffer();
        strbuf.append(getName()).append(" after addServer:");
        for (int i=0; i<servers.length; i++) {
          strbuf.append("\n\tserver#" + servers[i] + " -> " + sessions[i]);
        }
        logmon.log(BasicLevel.DEBUG, strbuf.toString());
      }

    } catch (Exception exc) {
      logmon.log(BasicLevel.ERROR, getName() + ", addServer failed", exc);
    }
    
    if (logmon.isLoggable(BasicLevel.DEBUG))
      logmon.log(BasicLevel.DEBUG, getName() + ", addServer ok");
  }
