public void addServer(int sid, 
                        String hostName, 
                        String domainName,
                        int port,
                        String name) throws Exception {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, 
                 "ServerConfigHelper.addServer(" + sid + ',' + hostName + ',' + domainName + ',' + port + ',' + name + ')');
    
    // Adds the server in the ACML configuration graph
    
    A3CMLConfig a3cmlConfig = AgentServer.getConfig();
    if (a3cmlConfig.servers.get(new Integer(sid)) != null)
      throw new ServerIdAlreadyUsedException("Server id already used: " + sid);
    
    A3CMLDomain domain = a3cmlConfig.getDomain(domainName);
    
    A3CMLServer server = new A3CMLServer((short)sid, name, hostName);
    a3cmlConfig.addServer(server);

    A3CMLNetwork network = new A3CMLNetwork(domainName, port);
    server.addNetwork(network);
    domain.addServer(server);
    server.domain = domainName;

    A3CMLServer root = a3cmlConfig.getServer(AgentServer.getServerId());
    a3cmlConfig.configure(root);
    
    // Adds the server in the configuration structure
    
    ServerDesc desc = new ServerDesc((short)sid, name, hostName, -1);
    AgentServer.addServerDesc(desc);
    AgentServer.initServerDesc(desc, server);
    
    // TODO (AF): There is a problem with HttpNetwork.

//    if (desc.gateway == desc.sid) {
    if (server.hops == 1) {
      // The server is directly accessible, adds it to the corresponding Network component
      if (desc.getDomain() instanceof Network) {
        Network net = (Network) desc.getDomain();
        net.stop();
        net.addServer((short)sid);
        net.start();
      } else {
        throw new Error("Unknown gateway type: " + desc.getDomain());
      }
    } else {
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG, "ServerConfigHelper.addServer -> desc = " + desc);
    }


    if (autoCommit) commit();
  }
