public static A3CMLConfig getConfig(String path) throws IOException {
    if (Log.logger.isLoggable(BasicLevel.DEBUG))
      Log.logger.log(BasicLevel.DEBUG, "Config.load(" + path + ")");
    
    A3CMLConfig a3config = null;
    
    File cfgFile = new File(path);
    if (cfgFile.exists() && cfgFile.isFile()) {
      if ((cfgFile.length() == 0)) {
        Log.logger.log(BasicLevel.DEBUG, " \"" + cfgFile.getPath() + "\", is empty.");
      } else {
        FileInputStream fis = null;
        try {
          fis = new FileInputStream(cfgFile);
          ObjectInputStream ois = new ObjectInputStream(fis);
          a3config = (A3CMLConfig) ois.readObject();
        } catch (Exception exc) {
          Log.logger.log(BasicLevel.DEBUG, "Can't load configuration: " + path, exc);
        } finally {
          if (fis != null)
            try {
              fis.close();
            } catch (IOException exc) {}
        }
      }
    }
    
    if (a3config != null) {
      if (Log.logger.isLoggable(BasicLevel.DEBUG))
        Log.logger.log(BasicLevel.DEBUG, "Config.load: a3cmlconfig = " + a3config);

      return a3config;
    }

    //search a3config in path used to load classes.
    ClassLoader classLoader = null;
    try {
      classLoader = A3CMLConfig.class.getClassLoader();
    } catch (Exception exc) {
      Log.logger.log(BasicLevel.WARN, "Can't get classLoader", exc);
    }
    
    if (classLoader != null) {
      Log.logger.log(BasicLevel.DEBUG,
                     "Trying to find [" + path + "] using " + classLoader + " class loader.");

      InputStream is = classLoader.getResourceAsStream(path);
      
      if (is == null) {
        // Last ditch attempt: get the resource from the system class path.
        is = ClassLoader.getSystemResourceAsStream(path);
      }

      if (is != null) {
        ObjectInputStream ois = null;
        try {
          ois = new ObjectInputStream(is);
          a3config = (A3CMLConfig) ois.readObject();
        } catch (IOException | ClassNotFoundException exc) {
          Log.logger.log(BasicLevel.WARN,
                         "Can't load serialized config.", exc);
        } finally {
          if (ois != null)
            try {
              ois.close();
            } catch (IOException exc) {}
        }
      }
    }
    
    if (a3config == null) {
      Log.logger.log(BasicLevel.DEBUG,
                     "Unable to find configuration file: " + path);
      throw new IOException("Unable to find configuration file: " + path);
    }
    
    if (Log.logger.isLoggable(BasicLevel.DEBUG))
      Log.logger.log(BasicLevel.DEBUG, "Config.load : a3cmlconfig = " + a3config);
    
    return a3config;
  }
