public static A3CMLConfig getXMLConfig(String path) throws Exception {
    if (Log.logger.isLoggable(BasicLevel.DEBUG))
      Log.logger.log(BasicLevel.DEBUG,"Config.getXMLConfig(" + path + ")");
    
    A3CMLConfig a3cmlconfig = null;    
    Reader reader = null;

    // 1st, search XML configuration file in directory.    
    File cfgFile = new File(path);
    try {
      if (!cfgFile.exists() || !cfgFile.isFile() || (cfgFile.length() == 0)) {
        throw new IOException();
      }
      reader = new FileReader(cfgFile);
    } catch (IOException exc) {
      // configuration file seems not exist, search it from the
      // search path used to load classes.
      Log.logger.log(BasicLevel.DEBUG,
                     "Unable to find configuration file \"" + cfgFile.getPath() + "\".");
      reader = null;
    }
      
    // 2nd, search XML configuration file in path used to load classes.
    if (reader == null) {
      ClassLoader classLoader = null;
      InputStream is = null;
      try {
        classLoader = A3CMLConfig.class.getClassLoader();
        if (classLoader != null) {
          Log.logger.log(BasicLevel.DEBUG,
                         "Trying to find [" + path + "] using " + classLoader + " class loader.");
          is = classLoader.getResourceAsStream(path);
        }
      } catch (Throwable t) {
        Log.logger.log(BasicLevel.DEBUG,
                       "Can't find [" + path + "] using " + classLoader + " class loader.");
        is = null;
      }
      
      if (is == null) {
        // Last ditch attempt: get the resource from the class path.
        Log.logger.log(BasicLevel.DEBUG,
                       "Trying to find [" + path + "] using ClassLoader.getSystemResource().");
        is = ClassLoader.getSystemResourceAsStream(path);
      }
      if (is != null) {
        a3cmlconfig = getConfig(new InputStreamReader(is));
      }
    } else {
      a3cmlconfig = getConfig(reader);
    }
    
    if (Log.logger.isLoggable(BasicLevel.DEBUG))
      Log.logger.log(BasicLevel.DEBUG, "a3cmlconfig = " + a3cmlconfig);
    
    if (a3cmlconfig == null)
      throw new FileNotFoundException("xml configuration file not found.");

    return a3cmlconfig;
  }
