public synchronized void close() {
    if (logmon.isLoggable(BasicLevel.INFO))
      logmon.log(BasicLevel.INFO, "DBTransaction, close");

    if (phase == INIT) return;

    while (phase != FREE) {
      // Wait for the transaction subsystem to be free
      try {
        wait();
      } catch (InterruptedException exc) {
      }
    }

    setPhase(FINALIZE);
    Statement s = null;
    try {
      insertStmt.close();
      updateStmt.close();
      loadStmt.close();
      deleteStmt.close();
      
      if ((dbclose != null) && (dbclose.length() > 0)) {
        // Creating a statement lets us issue commands against the connection.
        s = conn.createStatement();
        s.executeUpdate(dbclose);
      }
      
      conn.commit();
    } catch (SQLException sqle) {
      logmon.log(BasicLevel.ERROR, "DBTransaction.close()", sqle);
    } catch (Throwable t) {
      logmon.log(BasicLevel.ERROR, "DBTransaction.close()", t);
    } finally {
      try {
        if (s != null) s.close();
      } catch (SQLException sqle) {
        logmon.log(BasicLevel.ERROR, "DBTransaction.stop()", sqle);
      }
      try {
        conn.close();
      } catch (SQLException sqle) {
        logmon.log(BasicLevel.ERROR, "DBTransaction.close(), closing driver", sqle);
      }
      logmon.log(BasicLevel.INFO, "DBTransaction.close(), stopped");
    }
    setPhase(INIT);

    if (logmon.isLoggable(BasicLevel.INFO)) {
      logmon.log(BasicLevel.INFO, "DBTransaction, closed");
    }
  }
