public final synchronized void commit(boolean release) throws IOException {
    if (phase != RUN)
      throw new IllegalStateException("Can not commit.");

    if (logmon.isLoggable(BasicLevel.DEBUG))
      logmon.log(BasicLevel.DEBUG, "DBTransaction, commit");
    
    Hashtable<String, DBOperation> log = perThreadContext.get().getLog();
    if (! log.isEmpty()) {
      boolean completed = false;
      int retry = 0;
      long startRetry = 0L;
      SQLException lastexc = null;
      do {
        try {
          dbLogCommit(log);
          lastexc = null; 
          completed = true;
        } catch (SQLException sqle) {
          if (logmon.isLoggable(BasicLevel.DEBUG))
            logmon.log(BasicLevel.WARN, "DBTransaction, commit: try to reconnect", sqle);
          else
            logmon.log(BasicLevel.WARN, "DBTransaction, commit: try to reconnect - " + sqle.getMessage());

          lastexc = sqle;
          retry += 1;
          if ((connectRetryCount > 0) && (retry > connectRetryCount)) break;
          
          if (startRetry == 0L) startRetry = System.currentTimeMillis();
          if ((connectRetryDelay > 0L) && ((System.currentTimeMillis() - startRetry) > connectRetryDelay)) break;

          try {
            connectDB();
            createPreparedStatement();
          } catch (IOException exc) {}
        }
      } while (!completed);

      if (lastexc != null)
        throw new IOException(lastexc.getMessage());
      
      // All operations are committed in database, frees them and clear the log.
      log.forEach((k, op) -> { op.free(); });
//      for (Enumeration<DBOperation> e = log.elements(); e.hasMoreElements(); ) {
//        e.nextElement().free();
//      }
//      for (DBOperation op : log.values()) {
//        op.free();
//      }
      log.clear();
    }

    if (logmon.isLoggable(BasicLevel.DEBUG))
      logmon.log(BasicLevel.DEBUG, "DBTransaction, committed");
    
    if (release) {
      // Change the transaction state and save it.
      setPhase(FREE);
      notify();
    } else {
      setPhase(COMMIT);
    }
  }
