protected void initDB() throws IOException {
    String configFile = AgentServer.getProperty("MySQLDBTransactionConfigFile", "MySQL.properties");
    Properties prop = new Properties();
    try {
      prop.load(new FileInputStream(configFile));
    } catch (FileNotFoundException e) {
      if (logmon.isLoggable(BasicLevel.INFO)) {
        logmon.log(BasicLevel.INFO, "File " + configFile + " not found, using default parameters");
      }
    }
    
    String dbHost = prop.getProperty("host", "localhost");
    String dbPort = prop.getProperty("port", "3306");
    String dbName = prop.getProperty("database", "joramdb");
    String dbUser = prop.getProperty("user", "joram");
    String dbPass = prop.getProperty("password", "joram");
    
    try {
      Class.forName(driver).newInstance();
      StringBuffer sb = new StringBuffer(connurl);
      sb.append("//");
      sb.append(dbHost);
      sb.append(':');
      sb.append(dbPort);
      sb.append('/');
      sb.append(dbName);
      sb.append("?user=");
      sb.append(dbUser);
      sb.append("&password=");
      sb.append(dbPass);
      Enumeration enu = prop.keys();
      while (enu.hasMoreElements()) {
        String key = (String)enu.nextElement();
        if (key.equals("host") || key.equals("port") || key.equals("database") || key.equals("user") || key.equals("password")) {
          continue;
        }
        sb.append('&');
        sb.append(key);
        sb.append('=');
        sb.append(prop.get(key));
      }
      conn = DriverManager.getConnection(sb.toString());
      conn.setAutoCommit(false);
    } catch (SQLException e) {
      throw new IOException(e.getMessage());
    } catch (InstantiationException e) {
      throw new IOException(e.getMessage());
    } catch (IllegalAccessException e) {
      throw new IOException(e.getMessage());
    } catch (ClassNotFoundException e) {
      throw new IOException(e.getMessage());
    }

    try {
      // Creating a statement lets us issue commands against the connection.
      Statement s = conn.createStatement();
      
      // We create the table.
      s.execute("CREATE TABLE " + dbtable + " (name VARCHAR(255), content LONGBLOB, PRIMARY KEY(name))");

      s.close();
      conn.commit();
    } catch (SQLException sqle) {
      if (logmon.isLoggable(BasicLevel.INFO))
        logmon.log(BasicLevel.INFO, "DBTransaction, init() DB already exists");
    }
  }
