public static void init(String args, boolean firstTime) throws Exception {
    if (Trace.logger.isLoggable(BasicLevel.DEBUG))
      Trace.logger.log(BasicLevel.DEBUG, "DistributedJndiServer.init(" + args + ',' + firstTime + ')');
    StringTokenizer st = new StringTokenizer(args);
    String portS = st.nextToken();
    int port = Integer.parseInt(portS);

    Vector list = new Vector();
    while (st.hasMoreTokens()) {
      String idS = st.nextToken();
      Short id = Short.valueOf(idS);
      list.addElement(id);
    }

    short[] serverIds = new short[list.size()];
    for (int i = 0; i < list.size(); i++) {
      serverIds[i] = 
        ((Short)list.elementAt(i)).shortValue();
    }

    // Create the socket here in order to throw an exception
    // if the socket can't be created (even if firstTime is false).
    ServerSocket serverSocket = new ServerSocket(port);

    int poolSize = AgentServer.getInteger(JndiServer.POOL_SIZE_PROP, JndiServer.DEFAULT_POOL_SIZE).intValue();

    // TODO (AF): To remove
    if (AgentServer.getInteger(JndiServer.SO_TIMEOUT_PROP, -1).intValue() != -1) {
      Trace.logger.log(BasicLevel.WARN,
                       "\n!! Be careful, property \"" + JndiServer.SO_TIMEOUT_PROP + "\" is no longer used." +
                       "\n!! Please use property \"" + IOControl.SO_TIMEOUT_PROP + "\" instead.");
    }

    tcpServer = new TcpServer(serverSocket, poolSize, getDefault());

    if (firstTime) {
      ReplicationManager manager = new ReplicationManager(serverIds);
      AgentEntryPoint agentEP = new AgentEntryPoint();    
      agentEP.setRequestManager(manager);
      TcpEntryPoint tcpEP = new TcpEntryPoint();
      tcpEP.setRequestManager(manager);
      ReplicationEntryPoint replicationEP = new ReplicationEntryPoint();    
      replicationEP.setRequestManager(manager);

      Container container = new Container();    
      container.addEntryPoint(agentEP);
      container.addEntryPoint(tcpEP);
      container.addEntryPoint(replicationEP);
      container.setLifeCycleListener(manager);
      manager.setContainer(container);
      container.deploy();
    }

    tcpServer.start();
  }
