public static void init(String args, boolean firstTime) throws Exception {
    if (Trace.logger.isLoggable(BasicLevel.DEBUG))
      Trace.logger.log(BasicLevel.DEBUG,
                       "JndiServer.init(" + args + ',' + firstTime + ')');
    
    int port = Integer.parseInt(args);

    // Create the socket here in order to throw an exception
    // if the socket can't be created (even if firstTime is false).
    ServerSocket serverSocket = new ServerSocket(port);

    int poolSize = AgentServer.getInteger(POOL_SIZE_PROP, DEFAULT_POOL_SIZE).intValue();

    // TODO (AF): To remove
    if (AgentServer.getInteger(SO_TIMEOUT_PROP, -1).intValue() != -1) {
      Trace.logger.log(BasicLevel.WARN,
                       "\n!! Be careful, property \"" + SO_TIMEOUT_PROP + "\" is no longer used." +
                       "\n!! Please use property \"" + IOControl.SO_TIMEOUT_PROP + "\" instead.");
    }
    

    tcpServer = new TcpServer(serverSocket, poolSize, getDefault());

    if (firstTime) {
      RequestManager manager = new RequestManager();
      AgentEntryPoint agentEP = new AgentEntryPoint();    
      agentEP.setRequestManager(manager);
      TcpEntryPoint tcpEP = new TcpEntryPoint();
      tcpEP.setRequestManager(manager);
      Container container = new Container();    
      container.addEntryPoint(agentEP);
      container.addEntryPoint(tcpEP);
      container.setLifeCycleListener(manager);
      manager.setContainer(container);
      container.deploy();
    }

    try {
      MXWrapper.registerMBean(tcpServer, "JNDI", "service=tcp");
    } catch (Exception exc) {
      Trace.logger.log(BasicLevel.WARN, " JNDI server jmx failed", exc);
    }

    tcpServer.start();
  }
