public synchronized void start() throws ResourceAdapterInternalException {
   super.start();
   status.value = Status.STARTING;
   
    if (logger.isLoggable(BasicLevel.INFO))
  		logger.log(BasicLevel.INFO, "JORAM adapter:: Start the Joram server : " + startJoramServer);

    String joramPort = null;
    if (startJoramServer) {
    	if (logger.isLoggable(BasicLevel.INFO))
    		logger.log(BasicLevel.INFO, "JORAM adapter starting deployment...");

    	if (isJoramServerRun()) {
    		throw new ResourceAdapterInternalException("Restriction: only one server can run in the VM"); 
    	}
    	
    	// Collocated mode: starting the JORAM server.
    	if (collocated) {
    		if (logger.isLoggable(BasicLevel.INFO))
    			logger.log(BasicLevel.INFO, " - Collocated JORAM server is starting...");

    		// TODO (AF): Setting system properties forbids the launching of multiples
    		// servers in an OSGi platform.
//    		if (persistentPlatform) {
//    			System.setProperty("Transaction", "fr.dyade.aaa.util.NTransaction");
//    			System.setProperty("NTNoLockFile", "true");
//    		} else {
//    			System.setProperty("Transaction", "fr.dyade.aaa.util.NullTransaction");
//    			System.setProperty("NbMaxAgents", "" + Integer.MAX_VALUE);
//    		}

    		if (platformConfigDir != null) {
    			System.setProperty(AgentServer.CFG_DIR_PROPERTY, platformConfigDir);
    			System.setProperty(Debug.DEBUG_DIR_PROPERTY, platformConfigDir);
    		}

    		try {
    			AgentServer.init(serverId, storage, null);
    			AgentServer.start();
    			joramPort = AgentServer.getServiceArgs(AgentServer.getServerId(), TcpProxyService.class.getName());
    			if (serverPort < 0 && joramPort != null && joramPort.length() > 0)
    			  serverPort = new Integer(joramPort).intValue();
    			//TODO
    			//String jndiPort = AgentServer.getServiceArgs(AgentServer.getServerId(), JndiServer.class.getName());
    			
    			if (logger.isLoggable(BasicLevel.INFO))
    				logger.log(BasicLevel.INFO, "JoramAdapter - Collocated JORAM server has successfully started.");
    		} catch (Exception exc) {
    			if (logger.isLoggable(BasicLevel.DEBUG))
      			logger.log(BasicLevel.DEBUG, "EXCEPTION:: AgentServer", exc);
    			AgentServer.stop();
    			AgentServer.reset(true);
    			throw new ResourceAdapterInternalException("Could not start collocated JORAM instance: " + exc);
    		}
    	}
    } else {
    	if (collocated) {
    		waitAgentServerStarted();
    		serverId = AgentServer.getServerId();
    		try {
	        hostName = AgentServer.getHostname(serverId);
	        joramPort = AgentServer.getServiceArgs(serverId, TcpProxyService.class.getName());
	        if (serverPort < 0 && joramPort != null && joramPort.length() > 0)
            serverPort = new Integer(joramPort).intValue();
        } catch (Exception e) { }
    	}
    }

    if (joramPort != null) {
    	if (logger.isLoggable(BasicLevel.INFO))
    		logger.log(BasicLevel.INFO, "JoramAdapter - JORAM server listen on port " + joramPort);
    }
    
    // Starting an admin session...
    try {
      adminConnect();
      serverId = (short) wrapper.getLocalServerId();
    } catch (Exception exc) {
      if (logger.isLoggable(BasicLevel.WARN))
        logger.log(BasicLevel.WARN, " - JORAM server not administerable: " + exc);
    }

    if (adminFileXML != null) {
    	// Execute the XML script of configuration.
    	try {
    		if (logger.isLoggable(BasicLevel.INFO))
    			logger.log(BasicLevel.INFO,
    					"JoramAdapter - Reading the provided admin file: " + adminFileXML);
    		AdminModule.executeXMLAdmin(platformConfigDir, adminFileXML);
    	} catch (FileNotFoundException exc) {
    		if (logger.isLoggable(BasicLevel.INFO))
    			logger.log(BasicLevel.INFO,
    					"JoramAdapter - problem during XML configuration: " + adminFileXML + " file not found.");
    	} catch (Exception exc) {
    		if (logger.isLoggable(BasicLevel.ERROR))
    			logger.log(BasicLevel.ERROR,
    					"JoramAdapter - problem during XML configuration: " + adminFileXML, exc);
    	}

    }
    
    if (adminFileExportXML != null) {
    	// Execute the XML script corresponding to the export of the configuration.
    	try {
    		if (logger.isLoggable(BasicLevel.INFO))
    			logger.log(BasicLevel.INFO,
    					"JoramAdapter - Reading the provided admin file: " + adminFileExportXML);
    		AdminModule.executeXMLAdmin(platformConfigDir, adminFileExportXML);
    	} catch (FileNotFoundException exc) {
    		if (logger.isLoggable(BasicLevel.INFO))
    			logger.log(BasicLevel.INFO,
    					"JoramAdapter - problem during XML configuration: " + adminFileExportXML + " file not found.");
    	} catch (Exception exc) {
    		if (logger.isLoggable(BasicLevel.ERROR))
    			logger.log(BasicLevel.ERROR,
    					"JoramAdapter - problem during XML configuration: " + adminFileExportXML, exc);
    	}
    }

    if (collocated) {
    	if (logger.isLoggable(BasicLevel.INFO))
    		logger.log(BasicLevel.INFO, "Collocated server.");
    } else {
    	if (logger.isLoggable(BasicLevel.INFO))
    		logger.log(BasicLevel.INFO, "Server port is " + serverPort);
    }

    status.value = Status.STARTED;

    if (logger.isLoggable(BasicLevel.INFO))
      logger.log(BasicLevel.INFO, "JORAM adapter " + ConnectionMetaData.providerVersion + " successfully deployed.");
  }
