public final ManagedConnection
  createManagedConnection(Subject subject, ConnectionRequestInfo cxRequest)
  throws ResourceException {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, this + " createManagedConnection(" + subject + ", " + cxRequest + ")");

    String userName;
    String password;
    String identityClass;

    String hostName = getHostName();
    int serverPort = getServerPort();

    // For XA recovery, connecting to the JORAM server with the default user
    // identity.
    if (cxRequest == null) {
      userName = getUserName();
      password = getPassword();
      identityClass = getIdentityClass();
    } else {
      if (! (cxRequest instanceof ConnectionRequest)) {
        if (out != null)
          out.print("Provided ConnectionRequestInfo instance is not a JORAM object.");
        throw new ResourceException("Provided ConnectionRequestInfo instance is not a JORAM object.");
      }

      userName = ((ConnectionRequest) cxRequest).getUserName();
      password = ((ConnectionRequest) cxRequest).getPassword();
      identityClass = ((ConnectionRequest) cxRequest).getIdentityClass();
    }

    XAConnectionFactory factory = createFactory(cxRequest);
    setParameters(factory);
    ((AbstractConnectionFactory) factory).setIdentityClassName(identityClass);
    
    XAConnection cnx = createXAConnection(factory, userName, password);

    if (ra == null) {
      setResourceAdapter(new JoramAdapter());
    }
    
    ManagedConnectionImpl managedCx = new ManagedConnectionImpl(ra,
    		                                                        this,
                                                                cnx,
                                                                hostName,
                                                                serverPort,
                                                                userName);
    managedCx.setLogWriter(out);
    // for reconnection 
    managedCx.subject = subject;
    managedCx.cxRequest = cxRequest;
    

    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, this + " createManagedConnection managedCx = " + managedCx);
    return managedCx;
  }
