public final ManagedConnection
  matchManagedConnections(Set connectionSet,
                          Subject subject,
                          ConnectionRequestInfo cxRequest) throws ResourceException {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, this + " matchManagedConnections(" + connectionSet + ", " + subject + ", " + cxRequest + ")");

    String userName;

    // No user identification provided, using the default one.
    String mode = ManagedConnectionFactoryConfig.MODE_UNIFIED;

    if (cxRequest == null)
      userName = getUserName();
    else {
      if (! (cxRequest instanceof ConnectionRequest)) {
        out.print("Provided ConnectionRequestInfo instance is not a JORAM object.");
        throw new ResourceException("Provided ConnectionRequestInfo instance is not a JORAM object.");
      }

      if (cxRequest instanceof QueueConnectionRequest)
        mode = ManagedConnectionFactoryConfig.MODE_PTP;
      else if (cxRequest instanceof TopicConnectionRequest)
        mode = ManagedConnectionFactoryConfig.MODE_PUBSUB;

      userName = ((ConnectionRequest) cxRequest).getUserName();
    }

    ManagedConnectionImpl managedCx = null;
    boolean matching = false;

    Iterator it = connectionSet.iterator();

    String hostName = getHostName();
    int serverPort = getServerPort();

    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG,
                 this + " hostName = " +  hostName + ", serverPort = " + serverPort);
    if (isCollocated()) {
      hostName = "localhost";
      serverPort = -1;
    }

    while (! matching && it.hasNext()) {
      try {
        managedCx = (ManagedConnectionImpl) it.next();
        matching = managedCx.matches(hostName, serverPort, userName, mode);
      } catch (ClassCastException exc) {
        logger.log(BasicLevel.WARN,
                   this + " matchManagedConnections managedCx = " + managedCx, exc);
      }
    }

    if (matching) {
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG,
                   this + " matchManagedConnections managedCx = " + managedCx);
      managedCx.setLogWriter(out);
      return managedCx;
    }

    return null;
  }
