public XAResource getXAResource() throws ResourceException {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, this + " getXAResource()");

    if (! isValid()) {
        if (out != null)
            out.print("Physical connection to the underlying JORAM server has been lost.");
      throw new CommException("Physical connection to the underlying JORAM server has been lost.");
    }

    try {
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG, this + " getXAResource session = " + session);

      if (session == null) {
        OutboundConnection outboundCnx = null;
        if (logger.isLoggable(BasicLevel.DEBUG))
          logger.log(BasicLevel.DEBUG, this + " getXAResource handles = " + handles);
        for (java.util.Enumeration e = handles.elements(); e.hasMoreElements(); ) {
          outboundCnx = (OutboundConnection) e.nextElement();
          if (outboundCnx.cnxEquals(cnx)) {
            if (logger.isLoggable(BasicLevel.DEBUG))
              logger.log(BasicLevel.DEBUG, this + " getXAResource : outboundCnx found in handles table.");
            break;
          }
        }

        if (outboundCnx == null)
          outboundCnx = (OutboundConnection) getConnection(null,null);

        if (outboundCnx != null) {
          if (logger.isLoggable(BasicLevel.DEBUG))
            logger.log(BasicLevel.DEBUG,
                       this + " getXAResource  outboundCnx = " + outboundCnx + "\n  outboundCnx.sess = " + outboundCnx.sessions);

          OutboundSession outboundSession = null;
          if (outboundCnx.sessions.size() > 0) {
            outboundSession = (OutboundSession) outboundCnx.sessions.get(0);
            
            if (!(outboundSession.sess instanceof XASession)) {
              if (logger.isLoggable(BasicLevel.DEBUG))
                logger.log(BasicLevel.DEBUG, 
                           this + " getXAResource  outboundSession.sess = " + outboundSession.sess);

              // getXARessourceManager (create by XAConnection)
              org.objectweb.joram.client.jms.XAResourceMngr xaResourceMngr = null;
              if (cnx instanceof org.objectweb.joram.client.jms.XAConnection) {
                xaResourceMngr = ((org.objectweb.joram.client.jms.XAConnection) cnx).getXAResourceMngr();
              } else if (cnx instanceof org.objectweb.joram.client.jms.XAQueueConnection) {
                xaResourceMngr = ((org.objectweb.joram.client.jms.XAQueueConnection) cnx).getXAResourceMngr();
              } else if (cnx instanceof org.objectweb.joram.client.jms.XATopicConnection) {
                xaResourceMngr = ((org.objectweb.joram.client.jms.XATopicConnection) cnx).getXAResourceMngr();
              }

              if (xaResourceMngr == null)
                xaResourceMngr = new org.objectweb.joram.client.jms.XAResourceMngr((org.objectweb.joram.client.jms.Connection) outboundCnx.xac);

              if (logger.isLoggable(BasicLevel.DEBUG))
                logger.log(BasicLevel.DEBUG, this + " getXAResource  xaResourceMngr = " + xaResourceMngr);

              org.objectweb.joram.client.jms.Session sess =
                  (org.objectweb.joram.client.jms.Session) outboundSession.sess;
              // set Session transacted = true
              sess.setTransacted(true);

              session = new org.objectweb.joram.client.jms.XASession(
                  (org.objectweb.joram.client.jms.Connection) outboundCnx.xac,
                  sess,
                  xaResourceMngr);

              if (logger.isLoggable(BasicLevel.DEBUG))
                logger.log(BasicLevel.DEBUG, this + " getXAResource  session = " + session +
                    "\noutboundSession.sess = " + outboundSession.sess + ", sess.class = " + outboundSession.sess.getClass().getName() + 
                    ", getAcknowledgeMode = " + outboundSession.getAcknowledgeMode() + ", getTransacted = " + outboundSession.getTransacted() + 
                    ", isStarted = " + outboundSession.isStarted());
            } else {
              // the outboundSession.sess is an instance of a XASession
              if (logger.isLoggable(BasicLevel.DEBUG))
                logger.log(BasicLevel.DEBUG, this + " getXAResource outboundSession.sess = " + outboundSession.sess + 
                    ", sess.class = " + outboundSession.sess.getClass().getName() + ", getAcknowledgeMode = " + outboundSession.getAcknowledgeMode() + 
                    ", getTransacted = " + outboundSession.getTransacted() + ", isStarted = " + outboundSession.isStarted());
            }
            
          } else {
            // No session available, create a new XASession.
            if (logger.isLoggable(BasicLevel.DEBUG))
              logger.log(BasicLevel.DEBUG, this + " getXAResource createXASession");
            
            session = cnx.createXASession();

            if (logger.isLoggable(BasicLevel.DEBUG))
              logger.log(BasicLevel.DEBUG,
                         this + " getXAResource session = " + session + ", session.class = " + session.getClass().getName() + 
                         ", getAcknowledgeMode = " + session.getAcknowledgeMode() + ", getTransacted = " + session.getTransacted());
          }
          
          if (logger.isLoggable(BasicLevel.DEBUG))
            logger.log(BasicLevel.DEBUG, this + " getXAResource xaresource = " + ((org.objectweb.joram.client.jms.XASession) session).getXAResource() + ", transacted = " + ((org.objectweb.joram.client.jms.XASession) session).getTransacted());

        } else {
          // never arrived.
          if (logger.isLoggable(BasicLevel.WARN))
            logger.log(BasicLevel.WARN, this + " getXAResource  outboundCnx = null.");
        }
      } else if (session instanceof org.objectweb.joram.client.jms.XASession) {
        if (logger.isLoggable(BasicLevel.DEBUG))
          logger.log(BasicLevel.DEBUG, this + " getXAResource session is XASession and not null");
        
        // set Session transacted = true
        ((org.objectweb.joram.client.jms.XASession)session).getDelegateSession().setTransacted(true);

        if (logger.isLoggable(BasicLevel.DEBUG))
          logger.log(BasicLevel.DEBUG,
                     this + " getXAResource session = " + session + ", session.class = " + session.getClass().getName() + 
                     ", getAcknowledgeMode = " + session.getAcknowledgeMode() + ", getTransacted = " + session.getTransacted());
        
        // TODO
        // cnx.sessions.add((org.objectweb.joram.client.jms.Session) session);
      } else if (! (session instanceof javax.jms.XASession)) {
          if (out != null)
              out.print("Managed connection not involved in a local transaction.");
        throw new IllegalStateException("Managed connection not involved in a local transaction.");
      }

      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG, this + " getXAResource  return = " + ((XASession) session).getXAResource());

      return ((XASession) session).getXAResource();
    } catch (JMSException exc) {
        if (out != null)
            out.print("Could not get XA resource: " + exc);
      throw new ResourceAdapterInternalException("Could not get XA resource: " + exc);
    }
  }
