public void onException(JMSException exc) {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, this + " onException(" + exc + ')');
    
    // Physical connection already invalid: doing nothing.
    if (! isValid())
      return;

    // Asynchronous JORAM exception does not notify of a connection loss:
    // doing nothing.
    if (! (exc instanceof javax.jms.IllegalStateException))
      return;

    ConnectionEvent event =
      new ConnectionEvent(this, ConnectionEvent.CONNECTION_ERROR_OCCURRED);

    synchronized(lockForExc) {
      ConnectionEventListener listener;
      for (int i = 0; i < listeners.size(); i++) {
        listener = (ConnectionEventListener) listeners.get(i);
        listener.connectionErrorOccurred(event);
      }


      try {
        cleanup();
      } catch (ResourceException e) {
        if (logger.isLoggable(BasicLevel.DEBUG))
          logger.log(BasicLevel.DEBUG, this + " onException.cleanup exception " + e);
      }

      try {
        if (logger.isLoggable(BasicLevel.DEBUG))
          logger.log(BasicLevel.DEBUG, this + " onException: call ra.reconnect()");
        ra.reconnect();
        reconnect();
      } catch (Exception e) {
      }
    }
  }
