public Session createSession(boolean transacted, int acknowledgeMode) throws JMSException {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, this + " createSession(" + transacted + ", " + acknowledgeMode + ")");

    if (! valid)
      throw new javax.jms.IllegalStateException("Invalid connection handle.");

    // TODO (AF): JORAM-335, if needed the creation of the effective session should be done by the ManagedConnection,
    // so the getSession should never return null (and it shall be synchronized).
    Session sess = managedCx.getSession();
    if (logger.isLoggable(BasicLevel.DEBUG))
    	logger.log(BasicLevel.DEBUG, this + " createSession managedCx.session = " + sess);

    if (sess == null) {
    	try {
    		sess = xac.createSession(false, acknowledgeMode);
    		// JORAM-327: managedCx.session should be set with the created session. May be, we should deal
    		// with potential synchronization issues.
    		managedCx.setSession(sess);
    	} catch (IllegalStateException e) {
    		if (logger.isLoggable(BasicLevel.DEBUG))
    			logger.log(BasicLevel.DEBUG, this + " createSession (IllegalStateException)" + e);
    		logger.log(BasicLevel.WARN, this + " createSession reconnection in progress...");
    		
    		try {
    			if (managedCx.isReconnected()) {
    				ManagedConnection mc = managedCx.mcf.createManagedConnection(managedCx.subject, managedCx.cxRequest);
    				OutboundConnection outboundConnection = (OutboundConnection) mc.getConnection(managedCx.subject, managedCx.cxRequest);
    				outboundConnection.managedCx.associateConnection(this);
    			} else {
    				if (logger.isLoggable(BasicLevel.DEBUG))
    					logger.log(BasicLevel.DEBUG, this + " createSession : managed connection is not reconnected.");
    				throw new JMSException(this + " createSession : managed connection is not reconnected.");
    			}
    			sess = xac.createSession(false, acknowledgeMode);
          // Joram-327: managedCx.session should be set with the created session. May be, we should deal
          // with potential synchronization issues.
    			managedCx.setSession(sess);
    		} catch (ResourceException exc) {
    			if (logger.isLoggable(BasicLevel.WARN))
    				logger.log(BasicLevel.WARN, this + " createSession (ResourceException)", exc);
    		}
    	}
    	if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG, this + " createSession new session = " + sess);
    } else {
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG, this + " createSession retrieve session = " + sess);
    }
    
    return new OutboundSession(sess, this, transacted);
  }
