public void open(FactoryParameters factoryParameters,
                    RequestChannel requestChannel) throws JMSException {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, 
                 "Connection.open(" + factoryParameters + ',' + requestChannel + ')');

    // We need to clone the FactoryParameter Object to avoid side-effect with
    // external modifications.
    this.factoryParameters = (FactoryParameters) factoryParameters.clone();
    mtpx = new RequestMultiplexer(this,
                                  requestChannel,
                                  factoryParameters.cnxPendingTimer);
    if (factoryParameters.multiThreadSync) {
      mtpx.setMultiThreadSync(factoryParameters.multiThreadSyncDelay,
                              factoryParameters.multiThreadSyncThreshold);
    }
    
    requestor = new Requestor(mtpx);
    sessions = new Vector();
    cconsumers = new Vector();
    
    closer = new Closer();
    
    setStatus(Status.STOP);

    // Requesting the connection key and proxy identifier:
    CnxConnectRequest req = new CnxConnectRequest();
    CnxConnectReply rep = (CnxConnectReply) requestor.request(req);
    proxyId = rep.getProxyId();
    key = rep.getCnxKey();

    sessionsC = new AtomicCounter("c" + key + 's');
    
    // Get an eventual MessageID prefix defined by a global property. If it is not defined checks
    // in the settings of the ConnectionFactory.
    String messageIdPrefix = Configuration.getProperty(MESSAGE_ID_PREFIX_PROPERTY);
    if (messageIdPrefix == null)
      messageIdPrefix = factoryParameters.messageIdPrefix;
    
    if (messageIdPrefix == null)
      messagesC = new AtomicCounter("ID:" + proxyId.substring(1) + 'c' + key + 'm');
    else
      messagesC = new AtomicCounter("ID:" + messageIdPrefix + '_' + proxyId.substring(1) + 'c' + key + 'm');
    
    subsC = new AtomicCounter("c"  + key + "sub");

    stringImage = getClass().getSimpleName() + ":c" + key + '[' + proxyId + ']';
    hashCode = (proxyId.hashCode() & 0xFFFF0000) + key;
    
    if (tracker.isLoggable(BasicLevel.DEBUG))
      tracker.log(BasicLevel.DEBUG, stringImage + " established.", new Exception());

    mtpx.setDemultiplexerDaemonName(toString());
    
    identity = requestChannel.getIdentity();
    
    if (factoryParameters.clientID != null) {
      clientID = factoryParameters.clientID;
      addClientIDToProxy(clientID);
      lockClientId();
    }
      
    registerMBean(JMXBeanBaseName);
  }
