public void stop() throws JMSException {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, stringImage + ".stop()");
    checkClosed();

    synchronized (this) {
      if (status == Status.STOP)
        return;
    }
    
    // At this point, the server won't deliver messages anymore,
    // the connection just waits for the sessions to have finished their
    // processings.
    // Must go out of the synchronized block in order to enable
    // the message listeners to use the connection.
    // As a csq, the connection stop is reentrant. Several 
    // threads can enter this method during the stopping stage.
    for (int i = 0; i < sessions.size(); i++) {
      Session session = (Session) sessions.get(i);
      session.stop();
    }

    synchronized (this) {
      if (status == Status.STOP)
        return;

      // Now send an asynchronous "stop" request to the server in order
      // to allow stop call from CompletionListener.
//      requestor.request(new CnxStopRequest());
      mtpx.sendRequest(new CnxStopRequest());
      
      // Set the status as STOP as the following operations
      // (Session.stop) can't fail.
      setStatus(Status.STOP);
    }
    lockClientId();
  }
