void doClose() throws JMSException {
    synchronized (this) {
      if (status == Status.CLOSE) 
        return;
      // The status must be changed before
      // the call to Session.closeConsumer
      // in order to enable Session.preReceive
      // to check if the consumer has been closed.
      setStatus(Status.CLOSE);
    }
    
    if (!queueMode) {
      // For a topic, remove the subscription.
      if (durableSubscriber) {
        try {
          sess.syncRequest(new ConsumerCloseSubRequest(targetName));
        } catch (JMSException exc) {
          if (logger.isLoggable(BasicLevel.DEBUG))
            logger.log(BasicLevel.DEBUG, "", exc);
        }
      } else {
        try {
          sess.syncRequest(new ConsumerUnsubRequest(targetName));
        } catch (JMSException exc) {
          if (logger.isLoggable(BasicLevel.DEBUG))
            logger.log(BasicLevel.DEBUG, "", exc);
        }
      }
    }
    
    sess.closeConsumer(this);
    
    MessageConsumerListener mcl = sess.getMessageConsumerListener(targetName);
    if (mcl != null) {
      // Stop the listener.
      sess.removeMessageListener(mcl, false);
      sess.removeMessageConsumerListener(targetName);
    }
  }
