public synchronized void commit() throws JMSException {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "Session.commit()");

    checkClosed();
    checkThreadOfControl();
    
    if (cnx.checkCLSession(this))
      throw new IllegalStateException("Cannot commit session");

    if (!transacted)
      throw new IllegalStateException("Can't commit a non transacted session.");

    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "--- " + this + ": committing...");

    // If the transaction was scheduled: canceling.
    if (scheduled) {
      closingTask.cancel();
      scheduled = false;
    }

    // Sending client messages:
    try {
      CommitRequest commitReq = new CommitRequest();

      Enumeration producerMessages = sendings.elements();
      while (producerMessages.hasMoreElements()) {
        ProducerMessages pM = (ProducerMessages) producerMessages.nextElement();
        commitReq.addProducerMessages(pM);
      }
      sendings.clear();
      
      // Acknowledging the received messages:
      Enumeration targets = deliveries.keys();
      while (targets.hasMoreElements()) {
        String target = (String) targets.nextElement();
        MessageAcks acks = (MessageAcks) deliveries.get(target);
        commitReq.addAckRequest(new SessAckRequest(target, acks.getIds(), acks.getQueueMode()));
      }
      deliveries.clear();
      
      if (asyncSend) {
        // Asynchronous sending
        commitReq.setAsyncSend(true);
        if (listener == null)
          mtpx.sendRequest(commitReq);
        else
          mtpx.sendRequest(commitReq, listener);
      } else {
        if (listener == null)
          requestor.request(commitReq);
        else
          requestor.request(commitReq, listener);
      }

      listener = null;
      
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG, this + ": committed.");
    }
    // Catching an exception if the sendings or acknowledgement went wrong:
    catch (JMSException jE) {
      if (logger.isLoggable(BasicLevel.ERROR))
        logger.log(BasicLevel.ERROR, "", jE);
      TransactionRolledBackException tE = new TransactionRolledBackException(
          "A JMSException was thrown during the commit.");
      tE.setLinkedException(jE);

      if (logger.isLoggable(BasicLevel.ERROR))
        logger.log(BasicLevel.ERROR, "Exception: " + tE);

      rollback();
      throw tE;
    }
  }
