void onMessage(org.objectweb.joram.shared.messages.Message momMsg,
                 MessageConsumerListener mcl) throws JMSException {
    String msgId = momMsg.id;

    if (!autoAck)
      prepareAck(mcl.getTargetName(), msgId, mcl.getQueueMode());

    Message msg = null;
    try {
      msg = Message.wrapMomMessage(this, momMsg);
    } catch (JMSException jE) {
      // Catching a JMSException means that the building of the Joram
      // message went wrong: denying the message:
      if (autoAck)
        denyMessage(mcl.getTargetName(), msgId, mcl.getQueueMode(), true);
      return;
    }
    msg.session = this;
    if (trace.isLoggable(BasicLevel.INFO))
      trace.log(BasicLevel.INFO,
                 this + " handling message=" + msg + ", from=" + mcl.getDestName() + '/' + mcl.getTargetName());
    // Executes IN interceptors
    if ((inInterceptors != null) && (!inInterceptors.isEmpty())) {
      for (Iterator it = inInterceptors.iterator(); it.hasNext();) {
        MessageInterceptor interceptor = (MessageInterceptor) it.next();
        if (logger.isLoggable(BasicLevel.DEBUG))
          logger.log(BasicLevel.DEBUG,
                     "Intercepting the message after receiving by " + interceptor.getClass().getName());

        try {
          interceptor.handle(msg, this);
        } catch (Throwable t) {
          if (logger.isLoggable(BasicLevel.WARN))
            logger.log(BasicLevel.WARN, "Error during interception (continue anyway...)", t);
        }
      }
    }

    try {
      if (messageListener == null) {
        // Standard JMS (MessageConsumer)
        mcl.onMessage(msg, acknowledgeMode);
      } else {
        // ASF (ConnectionConsumer)
        mcl.onMessage(msg, messageListener, acknowledgeMode);
      }
    } catch (JMSException exc) {
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG, "", exc);

      if (mcl.isClosed()) {
        denyMessage(mcl.getTargetName(), msgId, mcl.getQueueMode(), false);
      } else if (autoAck) {
        denyMessage(mcl.getTargetName(), msgId, mcl.getQueueMode(), true);
      }
      return;
    }
    
    if (recover) {
      recover = false;
      // The session has been recovered by the
      // listener thread.
      if (autoAck) {
        denyMessage(mcl.getTargetName(), msgId, mcl.getQueueMode(), true);
      } else {
        doRecover();
      }
    } else {
      if (autoAck) {
        mcl.ack(msgId, acknowledgeMode);
      }
    }
    
    if (toClose) {
      doClose();
      toClose = false;
    }
  }
