javax.jms.Message receive(long requestTimeToLive, long waitTimeOut, MessageConsumer mc, String targetName,
      String selector, boolean queueMode) throws JMSException {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG,
                 "Session.receive(" + requestTimeToLive + ',' + waitTimeOut + ',' + targetName + ',' + selector + ',' + queueMode + ')');
    preReceive(mc);
    try {
      ConsumerMessages reply = null;
      ConsumerReceiveRequest request = new ConsumerReceiveRequest(targetName, selector, requestTimeToLive, queueMode);
      if (implicitAck)
        request.setReceiveAck(true);
      reply = (ConsumerMessages) receiveRequestor.request(request, waitTimeOut, null);

      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG, " -> reply = " + reply);
        
      synchronized (this) {
        // The session may have been 
        // closed in between.
        if (status == Status.CLOSE) {
          if (reply != null) {
            mtpx.deny(reply);
          }
          return null;
        }
        
        if (reply != null) {
          Vector msgs = reply.getMessages();
          if (msgs != null && !msgs.isEmpty()) {
            Message msg = Message.wrapMomMessage(this, (org.objectweb.joram.shared.messages.Message) msgs.get(0));
            String msgId = msg.getJMSMessageID();
            
            // Auto ack: acknowledging the message:
            if (autoAck && !implicitAck) {
              ConsumerAckRequest req = new ConsumerAckRequest(targetName, queueMode);
              req.addId(msgId);
              mtpx.sendRequest(req);
            } else {
              prepareAck(targetName, msgId, queueMode);
            }
            msg.session = this;
            if (trace.isLoggable(BasicLevel.INFO))
              trace.log(BasicLevel.INFO,
                         this + " handling message=" + msg + ", from=" + mc.getDest().getAdminName() + '/' + mc.getTargetName());
            // Executes IN interceptors
            if ((inInterceptors != null) && (!inInterceptors.isEmpty())) {
              for (Iterator it = inInterceptors.iterator(); it.hasNext();) {
                MessageInterceptor interceptor = (MessageInterceptor) it.next();
                if (logger.isLoggable(BasicLevel.DEBUG))
                  logger.log(BasicLevel.DEBUG,
                             "Intercepting the message after receiving by " + interceptor.getClass().getName());

                try {
                  interceptor.handle(msg, this);
                } catch (Throwable t) {
                  if (logger.isLoggable(BasicLevel.WARN))
                    logger.log(BasicLevel.WARN, "Error during interception (continue anyway...)", t);
                }
              }
            }
            return msg;
          }
          
          return null;
        }
        
        return null;
      }
    } finally {
      postReceive();
    }
  }
