synchronized void end(Xid xid, int flag,
                        Session sess) throws XAException {
    boolean saveResourceState = true;

    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG,
                                 "--- " + this + ": end(" + xid + ", " + flag + ", " + sess + ")"); 
    
    if (flag == XAResource.TMSUSPEND) {
      if (getStatus(xid) != STARTED)
        throw new XAException("Can't suspend non started transaction.");

      setStatus(xid, SUSPENDED);
    } else {
      if (getStatus(xid) != STARTED && getStatus(xid) != SUSPENDED)
        throw new XAException("Can't end non active or non "
                              + "suspended transaction.");

      // No need to save the resource's state as it has already been done
      // when suspending it.
      if (getStatus(xid) == SUSPENDED)
        saveResourceState = false;

      if (flag == XAResource.TMSUCCESS)
        setStatus(xid, SUCCESS);
      else if (flag == XAResource.TMFAIL)
        setStatus(xid, ROLLBACK_ONLY);
      else
        throw new XAException("Invalid flag: " + flag);
    }

    if (saveResourceState) {
      XAContext xaC = (XAContext) transactions.get(xid);
      xaC.addSendings(sess.sendings);
      xaC.addDeliveries(sess.deliveries);
    }

    Session session = (Session) sessionTable.get(xid);
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG,
                                 "--- " + this + ": end(...) session="  + session);

    if (session != null) {
      session.setTransacted(false);
      sessionTable.remove(xid);
    }
  }
