synchronized void prepare(Xid xid) throws XAException {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG,
                                 "--- " + this  + ": prepare(" + xid + ")"); 
    
    try {
      if (getStatus(xid) == ROLLBACK_ONLY)
        throw new XAException("Can't prepare resource in ROLLBACK_ONLY state.");

      XAContext xaC = (XAContext) transactions.get(xid);

      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG,
                                   "--- "
                                   + this
                                   + ": prepares transaction "
                                   + xid.toString()); 

      Enumeration targets;    
      String target;
      Vector pMs = new Vector();
      MessageAcks acks;
      Vector sessAcks = new Vector();

      // Getting all the ProducerMessages to send:
      targets = xaC.sendings.keys();
      while (targets.hasMoreElements()) {
        target = (String) targets.nextElement();
        pMs.add(xaC.sendings.remove(target));
      }

      // Getting all the SessAckRequest to send:
      targets = xaC.deliveries.keys();
      while (targets.hasMoreElements()) {
        target = (String) targets.nextElement();
        acks = (MessageAcks) xaC.deliveries.remove(target);
        sessAcks.add(new SessAckRequest(target, acks.getIds(),
                                        acks.getQueueMode()));
      }

      // Sending to the proxy:
      cnx.syncRequest(new XACnxPrepare(xid.getBranchQualifier(),
                                        xid.getFormatId(),
                                        xid.getGlobalTransactionId(),
                                        pMs,
                                        sessAcks));

      setStatus(xid, PREPARED);
    } catch (JMSException exc) {
      setStatus(xid, ROLLBACK_ONLY);
      throw new XAException("Prepare request failed: " + exc);
    } catch (XAException exc) {
      setStatus(xid, ROLLBACK_ONLY);
      throw exc;
    }
  }
