synchronized void rollback(Xid xid) throws XAException {

    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG,
                                 "--- " + this + ": rollback(" + xid + ")");

    try {
      XAContext xaC = (XAContext) transactions.get(xid);

      if (xaC == null)
        throw new XAException("Unknown transaction.");

      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG,
                                   "--- " + this + ": rolls back transaction " + xid.toString()); 

      Enumeration targets; 
      String target;
      MessageAcks acks;

      XACnxRollback rollbackRequest;
  
      targets = xaC.deliveries.keys();
  
      rollbackRequest = new XACnxRollback(xid.getBranchQualifier(),
                                           xid.getFormatId(),
                                           xid.getGlobalTransactionId());

      while (targets.hasMoreElements()) {
        target = (String) targets.nextElement();
        acks = (MessageAcks) xaC.deliveries.remove(target);
        rollbackRequest.add(target, acks.getIds(), acks.getQueueMode());
      }

      // Sending to the proxy:
      cnx.syncRequest(rollbackRequest);

      transactions.remove(xid);
      Session session = (Session) sessionTable.get(xid);
      if (session != null) {
        session.setTransacted(false);
        sessionTable.remove(xid);
      }
    } catch (JMSException exc) {
      setStatus(xid, ROLLBACK_ONLY);
      throw new XAException("Rollback request failed: " + exc);
    } catch (XAException exc) {
      setStatus(xid, ROLLBACK_ONLY);
      throw exc;
    }
  }
