private static void doConnect(AbstractConnectionFactory cf,
                                String name,
                                String password,
                                String identityClass) throws ConnectException, AdminException {
    synchronized(lock) {
      if (wrapper != null) {
        // We should throw an exception, the asked connection may use a different CF in
        // order to connect to another server!
        logger.log(BasicLevel.DEBUG, "AdminModule.doConnect: Already connected.");
        throw new ConnectException("Already connected.");
      }

      //  set identity className
      cf.setIdentityClassName(identityClass);

      try {
        cnx = cf.createConnection(name, password);
        cnx.start();
        wrapper = new AdminWrapper(cnx);

        FactoryParameters params = cf.getParameters();
        localHost = params.getHost();
        localPort = params.getPort();
      } catch (JMSSecurityException exc) {
        if (logger.isLoggable(BasicLevel.DEBUG))
          logger.log(BasicLevel.DEBUG, "AdminModule.doConnect", exc);
        throw new AdminException(exc.getMessage());
      } catch (JMSException exc) {
        if (logger.isLoggable(BasicLevel.DEBUG))
          logger.log(BasicLevel.DEBUG, "AdminModule.doConnect", exc);
        throw new ConnectException("Connecting failed: " + exc);
      }
    }
  }
