public static void executeXMLAdmin(String path) throws Exception {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "AdminModule.executeXMLAdmin(" + path + ")");
    

    // 1st, search XML configuration file in directory.
    Reader reader = null;
    File cfgFile = new File(path);
    try {
      if (!cfgFile.exists() || !cfgFile.isFile() || (cfgFile.length() == 0)) {
        throw new IOException();
      }
      reader = new FileReader(cfgFile);
    } catch (IOException exc) {
      // configuration file seems not exist, search it from the
      // search path used to load classes.
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG,
                   "Unable to find Joram Admin configuration file \"" + cfgFile.getPath() + "\".");
      reader = null;
    }
    if (reader != null) {
      executeAdmin(reader);
      return;
    }

    // 2nd, search XML configuration file in path used to load classes.
    InputStream is = null;
    ClassLoader classLoader = null;
    try {
      classLoader = AdminModule.class.getClassLoader();
      if (classLoader != null) {
        if (logger.isLoggable(BasicLevel.DEBUG))
          logger.log(BasicLevel.DEBUG,
                     "Trying to find [" + path + "] using AdminModule class loader.");
        is = classLoader.getResourceAsStream(path);
      }
    } catch (Throwable t) {
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG,
                   "Can't find [" + path + "] using AdminModule class loader.", t);
      is = null;
    }

    if (is == null) {
      // Last ditch attempt: get the resource from the class path.
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG,
                   "Trying to find [" + path + "] using ClassLoader.getSystemResource().");
      is = ClassLoader.getSystemResourceAsStream(path);
    }
    
    if (is == null)
      throw new FileNotFoundException("XML Joram configuration file \"" + path + "\" not found.");

    executeAdmin(new InputStreamReader(is));
  }
