public static void exportRepositoryToFile(String exportDir,
                                            String exportFilename) throws AdminException {

    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "export repository to " + exportDir.toString());

    
    StringBuffer strbuf = new StringBuffer();
    int indent = 0;
    strbuf.append("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n" +
                  "<!--\n" +
                  " Exported JMS objects : \n" +
                  " - destinations : Topic/Queue \n" +
                  " The file can be reloaded through the admin interface (joramAdmin.executeXMLAdmin())\n" +
                  "-->\n" +
    "<JoramAdmin>\n");
    indent += 2;

    // Get the list of servers
    int[] servers;
    try {
      servers = wrapper.getServersIds();
    } catch (Exception exc) {
      throw new AdminException("exportRepositoryToFile() failed - " + exc);
    }

    if (servers != null) {
      // For each server
      for (int i=0; i<servers.length; i++) {
        try {
          // Export the JMS destinations
          Destination[] dest = wrapper.getDestinations(servers[i]);
          for (int j=0; j<dest.length; j++) {
            strbuf.append(dest[j].toXml(indent, servers[i]));
          }
        } catch (Exception exc) {
          throw new AdminException("exportRepositoryToFile() failed - " + exc);
        }
      }

      if (logger.isLoggable(BasicLevel.DEBUG)) {
        logger.log(BasicLevel.DEBUG, "exported objects : \n" + strbuf.toString());
      }
    }

    indent -= 2;
    strbuf.append("</JoramAdmin>");

    // Flush the file in the specified directory
    File exportFile = null;
    FileOutputStream fos = null;

    try {
      exportFile = new File(exportDir, exportFilename);
      fos = new FileOutputStream(exportFile);
      fos.write(strbuf.toString().getBytes());
    } catch(Exception ioe) {
      throw new AdminException("exportRepositoryToFile() failed - " + ioe);
    } finally {
      try {
        exportFile = null;
        fos.close();
      } catch (Exception e) {
        if (logger.isLoggable(BasicLevel.DEBUG)) {
          logger.log(BasicLevel.DEBUG, "Unable to close the file  : " + fos);
        }
      }
      if (logger.isLoggable(BasicLevel.DEBUG)) {
        logger.log(BasicLevel.DEBUG, "File : " + exportDir + "/" + exportFilename + " created");
      }
    }
  }
