public synchronized AdminReply request(AdminRequest request) throws AdminException, ConnectException {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "AdminRequestor.request(" + request + ')');

    AdminMessage requestMsg = new AdminMessage();
    if (session instanceof org.objectweb.joram.client.jms.Session)
      requestMsg.setCompressedMinSize(((org.objectweb.joram.client.jms.Session)session).getCompressedMinSize());
    javax.jms.Message replyMsg = null;
    AdminReply reply = null;
    
    try {
      // Sends the an AdminMessage containing the request to the administration topic.
      requestMsg.setAdminMessage(request);
      requestMsg.setJMSReplyTo(tmpTopic);
      producer.send(requestMsg, DeliveryMode.NON_PERSISTENT, Message.DEFAULT_PRIORITY, requestTimeout);

      // Selects the message containing the reply.
      String correlationId = requestMsg.getJMSMessageID();
      while (true) {
        replyMsg = consumer.receive(requestTimeout);
        if (replyMsg == null)
          throw new JMSException("Interrupted request");

        if (correlationId.equals(replyMsg.getJMSCorrelationID())) break;

        if (logger.isLoggable(BasicLevel.WARN))
          logger.log(BasicLevel.WARN, "AdminRequestor.request() bad correlation identifier.");
      }
    } catch (JMSException exc) {
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG,
                   "AdminRequestor.request() connection failed.", exc);
      throw new ConnectException("Connection failed: " + exc.getMessage());
    }
    
    try {
      reply = (AdminReply) ((AdminMessage) replyMsg).getAdminMessage();
    } catch (ClassCastException exc) {
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG,
                   "AdminRequestor.request() invalid server reply.", exc);
      throw new AdminException("Invalid server reply: " + exc.getMessage());
    } catch (MessageFormatException exc) {
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG,
                   "AdminRequestor.request() invalid server reply.", exc);
      throw new AdminException("Invalid server reply: " + exc.getMessage());
    }

    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "AdminRequestor.request(" + request + ") -> " + reply);

    if (reply != null) throwException(reply);
    return reply;
  }
