public void sendRequest(AbstractJmsRequest request, ReplyListener listener, CompletionListener completionListener) throws JMSException {
    synchronized (this) {
      if (status == Status.CLOSE)
        throw new IllegalStateException("Connection closed");

      if (requestCounter == Integer.MAX_VALUE) {
        requestCounter = 0;
      }

      request.setRequestId(requestCounter++);

      if (listener != null) {
        requestsTable.put(new Integer(request.getRequestId()), listener);
      }
      
      if (completionListener != null) {
        if (request instanceof ProducerMessages) {
          //TODO: used request.getClassId() == AbstractJmsMessage.PRODUCER_MESSAGES
          ProducerMessages pm = (ProducerMessages) request;
          completionListeners.put(request.getRequestId(), completionListener);
        } else if (request instanceof CommitRequest) {
          CommitRequest cr = (CommitRequest) request;
          completionListeners.put(cr.getRequestId(), completionListener);
        }
      }

      if (heartBeatTask != null) {
        lastRequestDate = System.currentTimeMillis();
      }
    }

    try {
      channel.send(request);
    } catch (Exception exc) {
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG, "", exc);
      JMSException jmsExc = new JMSException(exc.toString());
      jmsExc.setLinkedException(exc);
      throw jmsExc;
    }
  }
