public synchronized AbstractJmsReply request(AbstractJmsRequest request, long timeout, CompletionListener completionListener) throws JMSException {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "Requestor.request(" + request + ',' + timeout + ',' + completionListener + "), status = " + Status.toString(status));

    long sleep = timeout;
    
    if (status != Status.INIT) {
      if (status == Status.CLOSE) return null;

      // AF: It seems to be bad correction to the lack of reinitialisation of this
      // requestor from a previous use with a completion listener.
      if (completionListener == null && status != Status.STOP) 
        throw new javax.jms.IllegalStateException("Requestor already used");
    }
    
    if (status == Status.STOP) {
      long time = System.currentTimeMillis();
      try {
        if (logger.isLoggable(BasicLevel.DEBUG))
          logger.log(BasicLevel.DEBUG, " -> request STOP wait");
        wait(sleep);
        if (logger.isLoggable(BasicLevel.DEBUG))
          logger.log(BasicLevel.DEBUG, " -> request STOP awake");
      } catch (InterruptedException exc) {
        if (logger.isLoggable(BasicLevel.WARN))
          logger.log(BasicLevel.WARN, exc);
        return null;
      }
      
      if (sleep > 0) {
        time = System.currentTimeMillis() - time;
        if (time >= sleep)
          return null; 
        else 
          sleep = sleep - time;
        if (logger.isLoggable(BasicLevel.DEBUG))
          logger.log(BasicLevel.DEBUG, "new timeout = " + sleep);
      }
    }
    
    mtpx.sendRequest(request, this, completionListener);
    setStatus(Status.RUN);
    requestId = request.getRequestId();
    
    if (completionListener != null && request instanceof ProducerMessages) {
      //TODO: use request.getClassId() == AbstractJmsMessage.PRODUCER_MESSAGES
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG, " -> request #" + requestId + ", completionListener = " + completionListener);

      init(); // The requestor is no longer used.
      return null;
    }

    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, " -> request #" + requestId + " wait");
    
    try {
      wait(sleep);
    } catch (InterruptedException exc) {
      if (logger.isLoggable(BasicLevel.WARN))
        logger.log(BasicLevel.WARN, exc);
      setStatus(Status.DONE);
    }

    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, " -> request #" + requestId + " awake");
    
    try {
      if (status == Status.RUN) {
        // Means that the wait ended with a timeout.
        // Abort the request.
        mtpx.abortRequest(requestId);
        return null;
      } else if (status == Status.INIT) {
        // Means that the wait ended with a notify from start method.
        // Abort the request.
        mtpx.abortRequest(requestId);
        // re-send a synchronous request
        return request(request, sleep, completionListener);
      } else if (status == Status.CLOSE) {
        if (logger.isLoggable(BasicLevel.DEBUG))
          logger.log(BasicLevel.DEBUG, " -> deny " + reply);
        if (reply instanceof ConsumerMessages) {
          // The consumer is closed, denies the received messages
          mtpx.deny((ConsumerMessages)reply);
        } else if ((reply == null) &&
            (request instanceof ConsumerReceiveRequest)) {
          // The request is aborted, we shall try to deny the receive request (JORAM-281).
          ConsumerReceiveRequest crr = (ConsumerReceiveRequest) request;
          if ((crr.getTimeToLive() <= 0) && (crr.getQueueMode())) {
            // If the connection is alive we should try to deny the request
            logger.log(BasicLevel.DEBUG, " -> deny request " + request.getRequestId());
            mtpx.denyRequest(crr);
          }
        }
        return null;
      } else if (status == Status.DONE) {
        // Status
        if (logger.isLoggable(BasicLevel.DEBUG))
          logger.log(BasicLevel.DEBUG, " -> request #" + requestId + " done : " + reply);
        if (reply instanceof MomExceptionReply) {
          JMSException jmsExc = RequestMultiplexer.buildJmsException((MomExceptionReply) reply);
          throw jmsExc;
        } else if (reply instanceof AbstractJmsReply) {
          return (AbstractJmsReply) reply;
        } else {
          // Reply aborted or thread interrupted.
          return null;
        }
      } else throw new Error();
    } finally {
      init();
    }
  }
