public void connect() throws Exception {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "LocalConnection.connect()");

    final LocalConnections localConnections = LocalConnections.getCurrentInstance();
    if (!localConnections.isActivated()) {
      throw new IllegalStateException("Local connections have been deactivated.");
    }

    localConnections.increaseInitiatedConnectionCount();

    if (AgentServer.getStatus() != AgentServer.Status.STARTED) {
      if ((AgentServer.getStatus() != AgentServer.Status.INITIALIZED) &&
          (AgentServer.getStatus() != AgentServer.Status.STOPPED)) {
        if (logger.isLoggable(BasicLevel.ERROR))
          logger.log(BasicLevel.ERROR,
                     "LocalConnection.connect(), server is not initialized: " + AgentServer.getStatusInfo() + '.');
        throw new Exception("Server is not initialized.");
      }

      if (logger.isLoggable(BasicLevel.WARN))
        logger.log(BasicLevel.WARN,
                   "LocalConnection.connect(), server is not started: " + AgentServer.getStatusInfo() + '.');
      throw new Exception("Server is not started.");
    }
    
    GetProxyIdNot gpin = new GetProxyIdNot(identity, null);
    try {
      gpin.invoke(AdminTopic.getDefault(), params.connectingTimer *1000L);
      proxyId = gpin.getProxyId();
    } catch (Exception exc) {
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG, "LocalConnection.connect() failed", exc);
      localConnections.increaseFailedLoginCount();
      throw new JMSException(exc.getMessage());
    }
    if (proxyId == null) {
      String msg = "Could not connect to embedded JMS server after " + params.connectingTimer + " secs.";
      IllegalStateException jmsExc = new IllegalStateException(msg);
      
      if (logger.isLoggable(BasicLevel.WARN))
        logger.log(BasicLevel.WARN,
                   " -> Could not connect to JMS server " + identity, jmsExc);

      throw jmsExc;
    }

    // TODO (AF): We have to take in account the time spent during the first call.
    
    OpenConnectionNot ocn = new OpenConnectionNot(Type.STANDARD, 0, true);
    try {
      ocn.invoke(proxyId, params.connectingTimer *1000L);
      ctx = (StandardConnectionContext) ocn.getConnectionContext();
      creationDate = new Date();
    } catch (Exception exc) {
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG, "LocalConnection.connect() failed", exc);
      JMSException jmse = new JMSException(exc.getMessage());
      jmse.setLinkedException(exc);
      throw jmse;
    }
    if (ctx == null) {
      String msg = "Could not connect to embedded JMS server after " + params.connectingTimer + " secs.";
      IllegalStateException jmsExc = new IllegalStateException(msg);
      
      if (logger.isLoggable(BasicLevel.WARN))
        logger.log(BasicLevel.WARN,
                   " -> Could not connect to JMS server " + identity, jmsExc);
      
      // TODO (AF): We have to clean the pending connection if any.

      throw jmsExc;
    }

    localConnections.addLocalConnection(this);
    try {
      MXWrapper.registerMBean(this, "Joram#" + AgentServer.getServerId(), getMBeanName());
    } catch (Exception e) {
      logger.log(BasicLevel.DEBUG, "registerMBean", e);
    }
  }
