private static SocketFactory createSocketFactory() throws Exception {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "ReliableSSLTcpClient.createSocketFactory()");

    // AF: TODO these parameters should be in FactoryParameters
    char[] keyStorePass =  System.getProperty(KS_PASS,"jorampass").toCharArray();
    String keystoreFile = System.getProperty(KS,"./joram_ks");
    String sslContext = System.getProperty(SSLCONTEXT,"SSL");
    String ksType = System.getProperty(KS_TYPE,"JKS");

    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG,
                 "SSLTcpProxyService.createSocketFactory : keystoreFile=" + keystoreFile);
    
    KeyStore keystore = KeyStore.getInstance(ksType);
    keystore.load(new FileInputStream(keystoreFile),keyStorePass);
    
    KeyManagerFactory kmf = KeyManagerFactory.getInstance("SunX509");
    kmf.init(keystore,keyStorePass);
    
    TrustManagerFactory tmf = TrustManagerFactory.getInstance("SunX509");
    tmf.init(keystore);       
    TrustManager[] trustManagers = tmf.getTrustManagers();
    
    SSLContext ctx = SSLContext.getInstance(sslContext);
    SecureRandom securerandom = SecureRandom.getInstance("SHA1PRNG");
//    SecureRandom securerandom = null;
    ctx.init(kmf.getKeyManagers(),trustManagers,securerandom);
    
    return ctx.getSocketFactory();
  }
