public void init(Socket sock) throws IOException {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "ReliableTcpConnection.init()");
    synchronized (this) {
      if (getStatus() != INIT) 
        throw new IOException("Already connected");
      setStatus(CONNECTING);
    }

    try {
      this.sock = sock;

      synchronized (outputLock) {
        nos = new NetOutputStream(sock);
        
        if (!noAckedQueue) {
          synchronized (pendingMessages) {
            for (int i = 0; i < pendingMessages.size(); i++) {
              TcpMessage pendingMsg = (TcpMessage) pendingMessages.elementAt(i);
              doSend(pendingMsg.id, inputCounter, pendingMsg.object);
            }
          }
        }
      }

      synchronized (inputLock) {
        bis = new BufferedInputStream(sock.getInputStream());
      }
      
      reader = new Reader();
      reader.start();

      setStatus(CONNECT);
    } catch (IOException exc) {
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG, exc);
      close();
      throw exc;
    }
  }
