public AbstractJmsReply receive() throws Exception {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG,
                 "ReliableTcpConnection.receive()");
    if (getStatus() != CONNECT) 
      throw new IOException("Connection closed");

    while (true) {
      try {
        byte[] bytes = receiveQueue.take();
        if (bytes.length == 0) {
          if (logger.isLoggable(BasicLevel.DEBUG))
            logger.log(BasicLevel.DEBUG, "The reader offer a closing marker, so closed.");
          throw new IOException("Connection closed.");
        }
        ByteArrayInputStream bais = new ByteArrayInputStream(bytes);

        long messageId;
        long ackId;
        AbstractJmsReply obj;

        messageId = StreamUtil.readLongFrom(bais);
        ackId = StreamUtil.readLongFrom(bais);
        obj =  (AbstractJmsReply) AbstractJmsMessage.read(bais);

        if (logger.isLoggable(BasicLevel.DEBUG))
          logger.log(BasicLevel.DEBUG, " -> id = " + messageId);
        
        if (!noAckedQueue) {
          ackPendingMessages(ackId);
          if (obj != null) {
            if (unackCounter < windowSize) {
              if (logger.isLoggable(BasicLevel.DEBUG))
                logger.log(BasicLevel.DEBUG, " -> unackCounter++");
              unackCounter++;
            } else {
              if (logger.isLoggable(BasicLevel.DEBUG))
                logger.log(BasicLevel.DEBUG, " -> schedule");
              AckTimerTask ackTimertask = new AckTimerTask();
              timer.schedule(ackTimertask, 0);
            }
            if (messageId > inputCounter) {
              inputCounter = messageId;
              return obj;
            } else {
              logger.log(BasicLevel.WARN, " -> already received message: " + messageId + " " + obj);
              // This should never happened, close the connection.
              throw new IOException("Duplicate  message: " + messageId);
            }
          }
        } else {
          if (obj != null) {
            return obj;
          }
        }
      } catch (InterruptedException exc) {
        if (logger.isLoggable(BasicLevel.DEBUG))
          logger.log(BasicLevel.DEBUG, exc);
        close();
        throw new IllegalStateException("Interrupted receive: Connection closed.");
      } catch (IOException exc) {
        if (logger.isLoggable(BasicLevel.DEBUG))
          logger.log(BasicLevel.DEBUG, exc);
        close();
        throw exc;
      }
    }
  }
