public void updated(final String pid, final Dictionary properties)
      throws ConfigurationException {
		if (logmon.isLoggable(BasicLevel.DEBUG))
  		logmon.log(BasicLevel.DEBUG, "updated(" + pid + ", " + properties + ')');
		
		if (properties == null) {
			deleted(pid);
			return;
		}

		AbstractConnectionFactory cf = null;
		
		//TODO: name ?
		String name = (String) properties.get(NAME);
		
		String className = (String) properties.get(CLASSNAME);
		if (!isSet(className)) {
			throw new ConfigurationException(CLASSNAME, "this property is required.");
		}
		
		if (TcpConnectionFactory.class.getName().equals(className)) {
			// TcpConnectionFactory
			String host = (String) properties.get(HOST);
			if (!isSet(host))
				host = AbstractConnectionFactory.getDefaultServerHost();
			int port =-1;
			String portStr = (String) properties.get(PORT);
			if (!isSet(portStr))
				port = AbstractConnectionFactory.getDefaultServerPort();
			else	
				port = new Integer(portStr).intValue();
			String reliableClass = (String) properties.get(RELIABLECLASS);
			if (!isSet(reliableClass))
				reliableClass = "org.objectweb.joram.client.jms.tcp.ReliableTcpClient";
			cf  = TcpConnectionFactory.create(host, port, reliableClass);
			
		} else if (LocalConnectionFactory.class.getName().equals(className)) {
			// LocalConnectionFactory
			cf = LocalConnectionFactory.create();
			
		} else {
			throw new ConfigurationException(CLASSNAME, "Unknown class : " + className); 
		}
		
		// put cf in cnxFactories Map
		cnxFactories.put(pid, cf);
		
		String identityClassName = (String) properties.get(IDENTITYCLASS);
		if (!isSet(identityClassName)) {
			identityClassName = SimpleIdentity.class.getName();
		}
		
		String inInterceptorClassname = (String) properties.get(ININTERCEPTORCLASS);
		if (isSet(inInterceptorClassname))
			cf.getParameters().addInInterceptor(inInterceptorClassname);
		String outInterceptorClassname = (String) properties.get(OUTINTERCEPTORCLASS);
		if (isSet(outInterceptorClassname))
			cf.getParameters().addOutInterceptor(outInterceptorClassname);
		
		// remove the reserved word, and set factory parameters
		Properties prop = new Properties();
		Enumeration keys = properties.keys();
		while (keys.hasMoreElements()) {
      String key = (String) keys.nextElement();
      if (key.equals(CLASSNAME))
        continue;
      else if (key.equals(HOST))
        continue;
      else if (key.equals(PORT))
        continue;
      else if (key.equals(RELIABLECLASS))
        continue;
      else if (key.equals(TIMEOUT))
        continue;
      else if (key.equals(IDENTITYCLASS))
        continue;
      else if (key.equals(ININTERCEPTORCLASS))
        continue;
      else if (key.equals(OUTINTERCEPTORCLASS))
        continue;
      else if (key.equals(JNDINAME))
        continue;
      else if (key.equals(NAME))
        continue;
      else if (key.equals("service.pid"))
        continue;
      else if (key.equals("service.factoryPid"))
        continue;
      else if (key.startsWith("jonas"))
        continue;
      // add property
      Object value = properties.get(key);
      if (value != null && value instanceof String)
        prop.put(key, (String) value);
    }
		// set factory parameters
		cf.getParameters().setParameters(prop);
		   
		final String jndiName = (String) properties.get(JNDINAME);
		final AbstractConnectionFactory cff = cf;
		if (isSet(jndiName)) {
			new Thread(new Runnable() {
				public void run() {
					int i = 0;
					while (i < 10) {
						try {
							jndiHelper.rebind(jndiName, cff);
							jndiNames.put(pid, jndiName);
							break;
						} catch (NamingException e) {
							i++;
							try {
	              Thread.sleep(1000);
	              if (logmon.isLoggable(BasicLevel.DEBUG))
	      					logmon.log(BasicLevel.DEBUG, "retry to rebind: " + jndiName);
              } catch (InterruptedException e1) {
              	break;
              }
						}
					}
				}
			}).start();
		}
		
		if (logmon.isLoggable(BasicLevel.DEBUG))
  		logmon.log(BasicLevel.DEBUG, "updated cf created/updated : " + cf);
  }
