public void doUpdated(String pid, Dictionary properties) {
	  if (logmon.isLoggable(BasicLevel.DEBUG))
	    logmon.log(BasicLevel.DEBUG, "doUpdated(" + pid + ", " + properties + ')');

	  try {
	    AdminItf wrapper = wrappers.get(pid);

	    if (wrapper == null) {
	      String name = (String) properties.get(NAME);
	      if (!isSet(name)) 
	        name = "admin";

	      String hostName = (String) properties.get(ADMIN_HOST);
	      if (!isSet(hostName)) 
	        hostName = "localhost";

	      String serverPortValue = (String) properties.get(ADMIN_PORT);
	      if (!isSet(serverPortValue)) 
	        serverPortValue = "16010";
	      int serverPort = Integer.parseInt(serverPortValue);

	      String rootName = (String) properties.get(ADMIN_USERNAME);
	      if (!isSet(rootName)) 
	        rootName = "root";

	      String rootPasswd = (String) properties.get(ADMIN_USERPASS);
	      if (!isSet(rootPasswd)) 
	        rootPasswd = "root";

	      String collocatedValue = (String) properties.get(COLLOCATED);
	      if (!isSet(collocatedValue)) 
	        collocatedValue = "true";
	      boolean collocated = Boolean.parseBoolean(collocatedValue);

	      String identityClassName = (String) properties.get(IDENTITYCLASS);
	      if (!isSet(identityClassName)) {
	        identityClassName = SimpleIdentity.class.getName();
	      }

	      String connectingTimerValue = (String) properties.get(CONNECTING_TIMER);
	      if (!isSet(connectingTimerValue)) 
	        connectingTimerValue = "60";
	      int connectingTimer = Integer.parseInt(connectingTimerValue);

	      ConnectionFactory cf = null;

	      if (collocated)
	        cf = LocalConnectionFactory.create();
	      else
	        cf = TcpConnectionFactory.create(hostName, serverPort);

	      if (connectingTimer == 0)
	        cf.getParameters().connectingTimer = 60;
	      else
	        cf.getParameters().connectingTimer = connectingTimer;

	      cf.setIdentityClassName(identityClassName);

	      Connection cnx = null;
	      int nbRetry = 10;
	      while (nbRetry > 0) {
	        try {
	          cnx = cf.createConnection(rootName, rootPasswd);
	          cnx.start();
	          wrapper = new JoramAdmin(cnx);
	          break;
	        } catch (JMSException e) {
	          Thread.sleep(100);
	          nbRetry--;
	          if (logmon.isLoggable(BasicLevel.DEBUG))
	            logmon.log(BasicLevel.DEBUG, "doUpdated admin connect retry =  " + (10 - nbRetry));
	        }
	      }

	      if (wrapper == null) {
	        if (logmon.isLoggable(BasicLevel.ERROR))
	          logmon.log(BasicLevel.ERROR, "doUpdated admin wrapper not start !");
	        return;
	      }

	      // register wrapper as a service
	      Properties props = new Properties();
	      props.setProperty("name", name);
	      props.setProperty("host", hostName);
	      props.setProperty("port", ""+serverPort);
	      props.setProperty("user", rootName);

	      registration =  bundleContext.registerService(
	          AdminItf.class.getName(),
	          wrapper,
	          (Dictionary)props);

	      if (logmon.isLoggable(BasicLevel.DEBUG))
	        logmon.log(BasicLevel.DEBUG, "doUpdated registration =  " + registration);

	      wrappers.put(pid, wrapper);
	      connections.put(pid, cnx);
	    }

	  } catch (Exception e) {
	    if (logmon.isLoggable(BasicLevel.ERROR))
	      logmon.log(BasicLevel.ERROR, "doUpdated ", e);
	  }
	}
