public void updated(final String pid, final Dictionary properties)
      throws ConfigurationException {
		if (logmon.isLoggable(BasicLevel.DEBUG))
  		logmon.log(BasicLevel.DEBUG, "updated(" + pid + ", " + properties + ')');
		
		if (properties == null) {
			deleted(pid);
			return;
		}

		AbstractConnectionFactory cf = null;
    
		//TODO: name ?
		String name = (String) properties.get(NAME);
		
		String type = (String) properties.get(TYPE);
		if (isSet(type)) {
		  if (LocalConnectionFactory.class.getName().toUpperCase().indexOf(type.toUpperCase()) > 0) {
		    // create the local connection factory
	      cf = LocalConnectionFactory.create();
		    
		  } else if (TcpConnectionFactory.class.getName().toUpperCase().indexOf(type.toUpperCase()) > 0) {
		    // TcpConnectionFactory
        String host = (String) properties.get(HOST);
        if (!isSet(host))
          host = AbstractConnectionFactory.getDefaultServerHost();
        int port =-1;
        String portStr = (String) properties.get(PORT);
        if (!isSet(portStr))
          port = AbstractConnectionFactory.getDefaultServerPort();
        else  
          port = new Integer(portStr).intValue();
        // create the connection factory
        cf  = TcpConnectionFactory.create(host, port);
        
		  } else if (type.equalsIgnoreCase("ssl")) {
		    // TcpConnectionFactory with SSL
        String host = (String) properties.get(HOST);
        if (!isSet(host))
          host = AbstractConnectionFactory.getDefaultServerHost();
        int port =-1;
        String portStr = (String) properties.get(PORT);
        if (!isSet(portStr))
          port = AbstractConnectionFactory.getDefaultServerPort();
        else  
          port = new Integer(portStr).intValue();
        // create the ssl connection factory
        cf  = TcpConnectionFactory.create(host, port, ReliableSSLTcpClient.class.getName());
        
		  } else {
		    throw new ConfigurationException(TYPE, "Unknown type : " + type); 
		  }
		} else {
		  throw new ConfigurationException(TYPE, "this property is required.");
		}
			
		// put cf in cnxFactories Map
		cnxFactories.put(pid, cf);
		
		String identityClassName = (String) properties.get(IDENTITYCLASS);
		if (!isSet(identityClassName)) {
			identityClassName = SimpleIdentity.class.getName();
		}
		
		String inInterceptorClassname = (String) properties.get(ININTERCEPTORCLASS);
		if (isSet(inInterceptorClassname))
			cf.getParameters().addInInterceptor(inInterceptorClassname);
		String outInterceptorClassname = (String) properties.get(OUTINTERCEPTORCLASS);
		if (isSet(outInterceptorClassname))
			cf.getParameters().addOutInterceptor(outInterceptorClassname);
		
		// remove the reserved word, and set factory parameters
		Properties prop = new Properties();
		Enumeration keys = properties.keys();
		while (keys.hasMoreElements()) {
      String key = (String) keys.nextElement();
      if (key.equals(TYPE))
        continue;
      else if (key.equals(HOST))
        continue;
      else if (key.equals(PORT))
        continue;
      else if (key.equals(IDENTITYCLASS))
        continue;
      else if (key.equals(ININTERCEPTORCLASS))
        continue;
      else if (key.equals(OUTINTERCEPTORCLASS))
        continue;
      else if (key.equals(JNDINAME))
        continue;
      else if (key.equals(NAME))
        continue;
      else if (key.equals("service.pid"))
        continue;
      else if (key.equals("service.factoryPid"))
        continue;
      else if (key.startsWith("jonas"))
        continue;
      // add property
      Object value = properties.get(key);
      if (value != null && value instanceof String)
        prop.put(key, (String) value);
    }
		// set factory parameters
		cf.getParameters().setParameters(prop);
		
		// register the connection factory
    ServiceRegistration reg = bundleContext.registerService(
        javax.jms.ConnectionFactory.class.getName(),
        cf,
        properties);
    registrations.put(pid, reg);
		   
		final String jndiName = (String) properties.get(JNDINAME);
		final AbstractConnectionFactory cff = cf;
		if (isSet(jndiName)) {
			new Thread(new Runnable() {
				public void run() {
					int i = 0;
					while (i < 10) {
						try {
							jndiHelper.rebind(jndiName, cff);
							jndiNames.put(pid, jndiName);
							break;
						} catch (NamingException e) {
							i++;
							try {
	              Thread.sleep(1000);
	              if (logmon.isLoggable(BasicLevel.DEBUG))
	      					logmon.log(BasicLevel.DEBUG, "retry to rebind: " + jndiName);
              } catch (InterruptedException e1) {
              	break;
              }
						}
					}
				}
			}).start();
		}
		
		if (logmon.isLoggable(BasicLevel.DEBUG))
  		logmon.log(BasicLevel.DEBUG, "updated cf created/updated : " + cf);
  }
