public void doUpdated(String pid, Dictionary properties, String className, boolean isQueue) {
  	if (logmon.isLoggable(BasicLevel.DEBUG))
  		logmon.log(BasicLevel.DEBUG, "doUpdated(" + pid + ", " + properties + ')');
  	
  	try {
  		String wrapperName = (String) properties.get(ADMIN_WRAPPER);
  		String adminHost = (String) properties.get(ADMIN_HOST);
  		String adminPort = (String) properties.get(ADMIN_PORT);
  		String adminUser = (String) properties.get(ADMIN_USERNAME);
  		AdminItf wrapper = AdminWrapperHelper.getWrapper(bundleContext, new AdminStruct(wrapperName, adminHost, adminPort, adminUser));
  		
  		int sid = 0;
  		String name = (String) properties.get(NAME);
  		String serverId = (String) properties.get(SERVERID);
  		
  		Properties props = new Properties();
  		Enumeration keys = properties.keys();
  		while (keys.hasMoreElements()) {
  			String key = (String) keys.nextElement();
  			// TODO: remove unused properties
  			Object value = properties.get(key);
        if (value instanceof String)
          props.setProperty(key, (String) value);
  		}

  		if (isSet(serverId)) {
  			sid = new Integer(serverId).intValue();
  		} else {
  			if (logmon.isLoggable(BasicLevel.DEBUG))
  	  		logmon.log(BasicLevel.DEBUG, "doUpdated serverId not set used 0");
  		}

  		Destination dest = null;
  		if (!destinations.containsKey(pid)) {
  			// create destination
  			dest = createDestination(wrapper, sid, name, className, props, isQueue);
  		} else {
  			dest = destinations.get(pid);
  			dest.setProperties(props);
  		}

  		if (dest == null) {
  			if (logmon.isLoggable(BasicLevel.WARN))
  	  		logmon.log(BasicLevel.WARN, "updated destination is null.");
  			throw new ConfigurationException(null, "doUpdated: destination is null.");
  		}
  		
  		//set right
  		boolean freeReading = new Boolean((String) properties.get(FREEREADING)).booleanValue();
  		boolean freeWriting = new Boolean((String) properties.get(FREEWRITING)).booleanValue();
  		String readers = (String) properties.get(READERS);
  		String writers = (String) properties.get(WRITERS);
  		setRight(wrapper, dest, sid, freeReading, freeWriting, readers, writers);

  		if (dest instanceof Queue) {
  			String threshold = (String) properties.get(THRESHOLD);
  			String nbMaxMsg = (String) properties.get(NB_MAXMSG);
  			setQueueThreshold((Queue) dest, threshold, nbMaxMsg);
  		}

  		// bind the destination
  		String jndiName = (String) properties.get(JNDINAME);
  		if (isSet(jndiName)) {
  			jndiHelper.rebind(jndiName, dest);
  			jndiNames.put(pid, jndiName);
  		}

  		// set the DMQ
  		String dmq = (String) properties.get(DMQ);
  		if (isSet(dmq)) {
  			String dmqSid = (String) properties.get(DMQ_SID);
  			if (!isSet(dmqSid))
  				dmqSid = ""+wrapper.getLocalServerId();
  			setDestinationDMQ(wrapper, dest, dmq, new Integer(dmqSid).intValue());
  		}

  		destinations.put(pid, dest);
  		
         // register osgi service javax.jms.Queue/Topic
         props = new Properties();
         props.setProperty("adminName", dest.getAdminName());
         props.setProperty("name", dest.getName());
         if (dest.getDMQ() != null)
           props.setProperty("DMQ", dest.getDMQ().getAdminName());
         props.setProperty("interceptors", dest.getInterceptors());
         props.setProperty("isFreelyReadable", Boolean.toString(dest.isFreelyReadable()));
         props.setProperty("isFreelyWriteable", Boolean.toString(dest.isFreelyWriteable()));
         //  props.setProperty("writers", dest.getWriterList());
         //  props.setProperty("readers", dest.getReaderList());
         
         ServiceRegistration reg = null;
         if (dest.isQueue())
           reg = bundleContext.registerService(
               javax.jms.Queue.class.getName(),
               dest,
               (Dictionary)props);
         else
           reg = bundleContext.registerService(
               javax.jms.Topic.class.getName(),
               dest,
               (Dictionary)props);
         
         registrations.put(pid, reg);
  		 
  	} catch (Exception e) {
  		if (logmon.isLoggable(BasicLevel.ERROR))
	  		logmon.log(BasicLevel.ERROR, "doUpdated ", e);
  	}
  }
