protected void doParse(Element element, BeanDefinitionBuilder bean) {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "JoramQueueBeanDefinitionParser.doParse(" + element + ", " + bean + ')');
    
    // this however is an required property
    String name = element.getAttribute("name");
    
    // this however is an optional property
    String sid = element.getAttribute("sid");
    if (!StringUtils.hasText(sid)) {
      sid = "0";
    }
    
    // this however is an optional property
    String dmq = element.getAttribute("dmq");
    
    // this however is an optional property
    String dmqSid = element.getAttribute("dmqSid");
    if (!StringUtils.hasText(dmqSid)) {
      dmqSid = sid;
    }
    
    String deleteOnStop = element.getAttribute("deleteOnStop");
    if (!StringUtils.hasText(deleteOnStop)) {
      deleteOnStop = "false";
    }

    // joram admin: create the queue.
    try {
      AdminItf wrapper = JoramAdmin.getWrapper();
      if (wrapper == null) throw new Exception("JoramQueueBeanDefinitionParser:: the admin wrapper is null !");
      
      Destination queue = wrapper.createQueue(Short.valueOf(sid), name);
      queue.setFreeReading();
      queue.setFreeWriting();
      
      if (StringUtils.hasText(dmq)) {
        Queue deadMQ = (Queue) wrapper.createQueue(Short.valueOf(dmqSid), dmq);
        deadMQ.setFreeReading();
        deadMQ.setFreeWriting();
        // set dead message queue
        queue.setDMQ(deadMQ);
      }
      
      bean.addPropertyValue("destination", queue);
      bean.addPropertyValue("deleteOnStop", Boolean.parseBoolean(deleteOnStop));
      
    } catch (Exception e) {
      if (logger.isLoggable(BasicLevel.ERROR))
        logger.log(BasicLevel.ERROR, "JoramQueueBeanDefinitionParser.doParse", e);
    }
  }
