public void createAndStart(short sid, String port) throws Exception {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "JoramServerBeanDefinitionParser.createAndStart(" + sid + ')');
    
    File tempDir = File.createTempFile("joram", "");
    tempDir.delete();
    tempDir.deleteOnExit();
    if (tempDir.mkdir()) {
      File a3servers = new File(tempDir, "a3servers.xml");
      FileWriter writer = new FileWriter(a3servers, true);
      writer.write("<?xml version=\"1.0\"?>");
      writer.write("<config>");
      writer.write("<property name=\"Transaction\" value=\"fr.dyade.aaa.util.NullTransaction\" />");
      writer.write("<server id=\"" + sid + "\" name=\"S0\" hostname=\"localhost\">");
      writer.write("<service class=\"org.objectweb.joram.mom.proxies.ConnectionManager\" args=\"root root\"/>");
      writer.write("<service class=\"org.objectweb.joram.mom.proxies.tcp.TcpProxyService\" args=\"" + port + "\"/>");
      writer.write("</server>");
      writer.write("</config>");
      writer.flush();
      
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG, "JoramServerBeanDefinitionParser.createAndStart a3servers.xml : " + a3servers.getAbsolutePath());
    } else {
      throw new Exception("can't create the directory : " + tempDir);
    }
    
    System.setProperty(AgentServer.CFG_DIR_PROPERTY, tempDir.getAbsolutePath());
    System.setProperty(Debug.DEBUG_DIR_PROPERTY, tempDir.getAbsolutePath());

    if (AgentServer.getStatus() == AgentServer.Status.STARTED ||
        AgentServer.getStatus() == AgentServer.Status.STARTING)
      return;

    try {
      AgentServer.init(sid, tempDir+"/s0", null);
    } catch (Exception exc) {
      logger.log(BasicLevel.ERROR, AgentServer.getName() + " initialization failed", exc);
    }

    try {
      String errStr = AgentServer.start();
      if (errStr == null) {
        if (logger.isLoggable(BasicLevel.INFO))
          logger.log(BasicLevel.INFO, AgentServer.getName() + " started: " + AgentServer.OKSTRING);
        
        createAdminWrapper();
        createUser(sid);
      } else {
        if (logger.isLoggable(BasicLevel.INFO)) {
          logger.log(BasicLevel.INFO, AgentServer.getName() + " started: " + AgentServer.ERRORSTRING +
              "\n" + errStr + "\n" + AgentServer.ENDSTRING);
        }
      }
    } catch (Exception exc) {
      logger.log(BasicLevel.ERROR, AgentServer.getName() + " failed", exc);
    }
  }
