private void acceptConnection() throws AMQPException, IOException {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "AMQPConnectionListener.acceptConnection()");

    sock = serverSocket.accept();

    // create new connection listener for parallelism 
    AMQPService.createConnectionListener();

    if (logger.isLoggable(BasicLevel.DEBUG)) {
      logger.log(BasicLevel.DEBUG, " -> accept connection: " + sock.getInetAddress().getHostAddress());
    }

    sock.setTcpNoDelay(true);
    //If a peer detects no incoming traffic (i.e. received octets) for two heartbeat
    // intervals or longer, it should close the connection
    sock.setSoTimeout(sHeartbeat * 2000);

    try {
      readProtocolHeader(sock.getInputStream());
    } catch (FrameErrorException e) {
      if (logger.isLoggable(BasicLevel.WARN)) {
        logger.log(BasicLevel.WARN, "EXCEPTION :: ", e);
      }
      // If the server cannot support the protocol specified in the
      // protocol header, it MUST respond with a valid protocol header and
      // then close the socket connection.
      OutputStream bos = new BufferedOutputStream(sock.getOutputStream());
      bos.write('A');
      bos.write('M');
      bos.write('Q');
      bos.write('P');
      bos.write(0);
      bos.write(AMQP.PROTOCOL.MAJOR);
      bos.write(AMQP.PROTOCOL.MINOR);
      bos.write(AMQP.PROTOCOL.REVISION);
      bos.flush();
      closeSocket();
      return;
    }

    //queueOut.removeAllElements();
    netServerOut = new NetServerOut(this.getClass().getName());
    netServerOut.start();

    AMQP.Connection.Start startMethod = getConnectionStartMethod();
    queueOut.add(startMethod);

    InputStream cnxInputStream = sock.getInputStream();
    while (true) {
      process(Frame.readFrom(cnxInputStream));
    }

  }
