private void process(Frame frame) throws IOException, ConnectionException {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "proceed frame = " + frame);

    int channelNumber = frame.getChannel();
    if (channelMax != 0 && channelNumber > channelMax) {
      throw new ChannelErrorException("Non permitted channel number: " + channelNumber);
    }
    
    switch (frame.getType()) {
    case AMQP.FRAME_METHOD:
      if (isChannelOpen(channelNumber) && openChannel.get(Integer.valueOf(channelNumber)) != null) {
        throw new UnexpectedFrameException("Method frame was not expected.");
      }
      doProcessMethod(AbstractMarshallingMethod.read(frame.getPayload()), channelNumber);
      break;
    case AMQP.FRAME_HEADER:
      PublishRequest publishRequest = openChannel.get(Integer.valueOf(channelNumber));
      if (publishRequest == null || publishRequest.getHeader() != null) {
        throw new UnexpectedFrameException("Header frame was unexpected.");
      }
      if (channelNumber == NO_CHANNEL) {
        throw new ChannelErrorException("Content header channel can't be zero.");
      }
      doProcessHeader(MarshallingHeader.read(frame.getPayload()), publishRequest, channelNumber);
      break;
    case AMQP.FRAME_BODY:
      publishRequest = openChannel.get(Integer.valueOf(channelNumber));
      if (publishRequest == null || publishRequest.getHeader() == null) {
        throw new UnexpectedFrameException("Body frame was unexpected.");
      }
      doProcessBody(frame.getPayload(), publishRequest, channelNumber);
      break;
    case AMQP.FRAME_HEARTBEAT:
      if (logger.isLoggable(BasicLevel.DEBUG)) {
        logger.log(BasicLevel.DEBUG, "client FRAME_HEARTBEAT.");
      }
      if (channelNumber != NO_CHANNEL) {
        throw new CommandInvalidException("Non-zero channel number for heartbeat frame.");
      }
      break;

    default:
      if (logger.isLoggable(BasicLevel.WARN)) {
        logger.log(BasicLevel.WARN, "AMQPConnectionListener.process:: bad type " + frame);
      }
      throw new FrameErrorException("Bad frame type received: " + frame.getType());
    } 
  }
