public static void init(String args, boolean firstTime) throws Exception {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "AMQPService.init(" + args + ',' + firstTime + ')');

    port = DEFAULT_PORT;
    address = DEFAULT_BINDADDRESS;

    // Mix some method numbers to set up a server harshly supporting AMQP 0.8 if needed
    if (args != null) {
      StringTokenizer st = new StringTokenizer(args);

      String param = st.nextToken();
      if (param.equals("0-8")) {
        AMQP.PROTOCOL.MAJOR = 8;
        AMQP.PROTOCOL.MINOR = 0;
        AMQP.Connection.Close.INDEX = 60;
        AMQP.Connection.CloseOk.INDEX = 61;
        AMQP.Connection.mids = new int[] { 10, 11, 20, 21, 30, 31, 40, 41, 60, 61 };

        if (st.hasMoreTokens())
          port = Integer.parseInt(st.nextToken());

        if (st.hasMoreTokens()) {
          address = st.nextToken();
        }
      } else {
        port = Integer.parseInt(param);

        if (st.hasMoreTokens()) {
          address = st.nextToken();
        }
      }

    }
 
    int backlog = AgentServer.getInteger(BACKLOG_PROP, DEFAULT_BACKLOG).intValue();
    
    // Create the socket here in order to throw an exception
    // if the socket can't be created (even if firstTime is false).
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "AMQPService.init() - binding to " +
          address + ", port " + port);

    if (address.equals("0.0.0.0")) {
      serverSocket = new ServerSocket(port, backlog);
    } else {
      serverSocket = new ServerSocket(port, backlog, InetAddress.getByName(address));
    }

    heartbeat = AgentServer.getInteger(HEARTBEAT_PROP, DEFAULT_HEARTBEAT).intValue();
     
    // Initialization Naming 
    naming = new Naming();
    
    if (firstTime) {
      Naming.createDefaults();
    } else {
      // Load ....
      loads();
    }
     
    // Initialization transient Agent AMQP
    AMQPAgent agentAMQP = new AMQPAgent();
    agentAMQP.deploy();
    
    amqpService = new AMQPService();
    amqpService.start();
  }
