public void basicAck(AMQP.Basic.Ack ack) throws PreconditionFailedException {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "Proxy.basicAck(" + ack.deliveryTag + ", " + ack.channelNumber + ')');

    ChannelContext channelContext = getContext(ack.channelNumber);

    Iterator<Delivery> iter = channelContext.deliveriesToAck.iterator();
    if (!ack.multiple) {
      while (iter.hasNext()) {
        Delivery delivery = iter.next();
        if (delivery.deliveryTag == ack.deliveryTag) {
          if (channelContext.transacted) {
            if (delivery.waitingCommit) {
              break;
            } else {
              delivery.waitingCommit = true;
              return;
            }
          }
          List<Long> ackList = new ArrayList<Long>(1);
          ackList.add(new Long(delivery.queueMsgId));
          iter.remove();
          if (delivery.queue.islocal()) {
            delivery.queue.getReference().ackMessages(ackList);
          } else {
            StubAgentOut.asyncSend(new Ack(delivery.queue.getName(), ackList),
                Naming.resolveServerId(delivery.queue.getName()));
          }

          if (channelContext.prefetchCount != 0) {
            queueIn.push(new GetDeliveries(null, ack.channelNumber));
          }
          return;
        }
      }
      throw new PreconditionFailedException("Acknowledgement error: invalid tag '" + ack.deliveryTag + "'.");
    } else {
      Map<QueueShell, List<Long>> deliveryMap = new HashMap<QueueShell, List<Long>>();
      while (iter.hasNext()) {
        Delivery delivery = iter.next();
        if (delivery.deliveryTag <= ack.deliveryTag || ack.deliveryTag == 0) {
          if (channelContext.transacted) {
            if (delivery.waitingCommit) {
              continue;
            } else {
              delivery.waitingCommit = true;
            }
          }
          List<Long> ackList = deliveryMap.get(delivery.queue);
          if (ackList == null) {
            ackList = new ArrayList<Long>();
            deliveryMap.put(delivery.queue, ackList);
          }
          ackList.add(new Long(delivery.queueMsgId));
          if (!channelContext.transacted) {
            iter.remove();
          }
        } else if (delivery.deliveryTag > ack.deliveryTag) {
          break;
        }
      }
      if (deliveryMap.size() == 0) {
        throw new PreconditionFailedException("Acknowledgement error: invalid tag '" + ack.deliveryTag + "'.");
      }
      if (channelContext.transacted) {
        return;
      }
      Iterator<QueueShell> iterQueues = deliveryMap.keySet().iterator();
      while (iterQueues.hasNext()) {
        QueueShell queue = iterQueues.next();
        if (queue.islocal()) {
          queue.getReference().ackMessages(deliveryMap.get(queue));
        } else {
          StubAgentOut.asyncSend(new Ack(queue.getName(), deliveryMap.get(queue)),
              Naming.resolveServerId(queue.getName()));
        }
      }

      if (channelContext.prefetchCount != 0) {
        queueIn.push(new GetDeliveries(null, ack.channelNumber));
      }
    }
  }
