public void basicConsume(AMQP.Basic.Consume basicConsume) throws NotFoundException, NotAllowedException,
      AMQPException, AccessRefusedException, ResourceLockedException {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "Proxy.basicConsume(" + basicConsume + ')');

    String queueName = basicConsume.queue;
    if (queueName == null || queueName.equals("")) {
      throw new NotAllowedException("Consuming from unspecified queue.");
    }

    ChannelContext channelContext = getContext(basicConsume.channelNumber);
    // The consumer tag is local to a channel, so two clients can use the
    // same consumer tags. If this field is empty the server will generate a unique tag.
    String tag = basicConsume.consumerTag;
    if (tag.equals("")) {
      channelContext.consumerTagCounter++;
      tag = "genTag-" + channelContext.consumerTagCounter;
    }

    if (channelContext.consumerQueues.get(tag) != null) {
      throw new NotAllowedException("Consume request failed due to non-unique tag: '" + tag + "'.");
    }

    QueueShell queueShell;
    if (Naming.isLocal(queueName)) {
      StubLocal.basicConsume(this, basicConsume.queue, tag, basicConsume.exclusive, basicConsume.noAck,
          basicConsume.noLocal, basicConsume.channelNumber, name.serverId, name.proxyId);
      queueShell = new QueueShell(Naming.lookupQueue(queueName));
    } else {
      queueShell = new QueueShell(basicConsume.queue);
      basicConsume.consumerTag = tag;
      StubAgentOut.asyncSend(basicConsume, Naming.resolveServerId(basicConsume.queue), name.proxyId);
    }

    // Send the ok response
    if (basicConsume.noWait == false) {
      AMQP.Basic.ConsumeOk consumeOk = new AMQP.Basic.ConsumeOk(tag);
      consumeOk.channelNumber = basicConsume.channelNumber;
      send(consumeOk);
    }
    channelContext.consumerQueues.put(tag, queueShell);

    queueIn.push(new GetDeliveries(tag, basicConsume.channelNumber));

  }
