public GetResponse basicGet(AMQP.Basic.Get basicGet) throws NotFoundException, AMQPException,
      SyntaxErrorException, ResourceLockedException {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "Proxy.basicGet(" + basicGet + ')');

    String queueName = basicGet.queue;
    ChannelContext channelContext = getContext(basicGet.channelNumber);
    if (queueName.equals("")) {
      queueName = channelContext.lastQueueCreated;
      /* If the client did not declare a queue, and the method needs a queue
       * name, this will result in a 502 (syntax error) channel exception. */
      if (queueName == null) {
        throw new SyntaxErrorException("No queue previously declared on the channel.");
      }
    }
    
    Message msg;
    QueueShell queueShell;
    if (Naming.isLocal(queueName)) {
      msg = StubLocal.basicGet(queueName, basicGet.noAck, name.serverId, name.proxyId);
      queueShell = new QueueShell(Naming.lookupQueue(queueName));
    } else {
      basicGet.queue = queueName;
      msg = (Message) StubAgentOut.syncSend(basicGet, Naming.resolveServerId(basicGet.queue));
      queueShell = new QueueShell(basicGet.queue);
    }

    if (msg == null) {
      return null;
    }
    long deliveryTag = channelContext.nextDeliveryTag();
    AMQP.Basic.GetOk getOk = new AMQP.Basic.GetOk(deliveryTag, msg.redelivered, msg.exchange, msg.routingKey,
        msg.queueSize);
    if (!basicGet.noAck) {
      channelContext.deliveriesToAck.add(new Delivery(deliveryTag, msg.queueMsgId, queueShell));
    }
    return new GetResponse(getOk, msg.properties, msg.body);
  }
