public void basicPublish(PublishRequest publishRequest) throws NotFoundException, TransactionException {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "Proxy.basicPublish(" + publishRequest + ')');

    ChannelContext channelContext = getContext(publishRequest.channel);
    if (channelContext.transacted) {
      IExchange exchange = Naming.lookupExchange(publishRequest.getPublish().exchange);
      if (exchange == null) {
        throw new NotFoundException("Can't publish on an unknwon exchange: '"
            + publishRequest.getPublish().exchange + "'.");
      }
      channelContext.pubToCommit.add(publishRequest);
      return;
    }

    if (Naming.isLocal(publishRequest.getPublish().exchange)) {

      try {
        AgentServer.getTransaction().begin();
      } catch (IOException exc) {
        throw new TransactionException(exc.getMessage());
      }

      try {
        StubLocal.basicPublish(publishRequest, name.serverId, name.proxyId);
      } catch (AMQPException exc) {
        AMQP.Basic.Return returned = new AMQP.Basic.Return(exc.getCode(), exc.getMessage(), publishRequest.getPublish().exchange, publishRequest.getPublish().routingKey);
        returned.channelNumber = publishRequest.channel;
        send(new Returned(returned, publishRequest.getHeader(), publishRequest.getBody()));
      }

      try {
        AgentServer.getTransaction().commit(true);
      } catch (IOException exc) {
        throw new TransactionException(exc.getMessage());
      }
    } else {
      StubAgentOut.asyncSend(publishRequest, Naming.resolveServerId(publishRequest.getPublish().exchange),
          name.proxyId);
    }
  }
