protected void doProcessMethod(AbstractMarshallingMethod method) throws AMQPException {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "+ doProcess marshallingMethod = " + method);

    int channelNumber = method.channelNumber;

    switch (method.getClassId()) {

    case AMQP.Connection.INDEX:
      if (method.getMethodId() == AMQP.Connection.Close.INDEX) {
        connectionClose();
        try {
          send(new AMQP.Connection.CloseOk());
        } catch (StoppedQueueException sqe) {
          // Connection already closed.
        }
      } else {
        throw new IllegalStateException();
      }
      break;

    case AMQP.Channel.INDEX:
      if (method.getMethodId() == AMQP.Channel.Close.INDEX) {
        channelClose(channelNumber);
        AMQP.Channel.CloseOk closeOk = new AMQP.Channel.CloseOk();
        closeOk.channelNumber = channelNumber;
        send(closeOk);
      } else {
        throw new IllegalStateException();
      }
      break;

    case AMQP.Queue.INDEX:
      switch (method.getMethodId()) {
      case AMQP.Queue.Declare.INDEX:
        AMQP.Queue.Declare declare = (AMQP.Queue.Declare) method;
        AMQP.Queue.DeclareOk declareOk = queueDeclare(declare);
        if (declare.noWait == false) {
          declareOk.channelNumber = channelNumber;
          send(declareOk);
        }
        break;

      case AMQP.Queue.Delete.INDEX:
        AMQP.Queue.Delete delete = (AMQP.Queue.Delete) method;
        AMQP.Queue.DeleteOk deleteOk = queueDelete(delete);
        if (delete.noWait == false) {
          deleteOk.channelNumber = channelNumber;
          send(deleteOk);
        }
        break;

      case AMQP.Queue.Bind.INDEX:
        AMQP.Queue.Bind bind = (AMQP.Queue.Bind) method;
        queueBind(bind);
        if (bind.noWait == false) {
          AMQP.Queue.BindOk bindOk = new AMQP.Queue.BindOk();
          bindOk.channelNumber = channelNumber;
          send(bindOk);
        }
        break;

      case AMQP.Queue.Unbind.INDEX:
        AMQP.Queue.Unbind unbind = (AMQP.Queue.Unbind) method;
        queueUnbind(unbind);
        AMQP.Queue.UnbindOk unbindOk = new AMQP.Queue.UnbindOk();
        unbindOk.channelNumber = channelNumber;
        send(unbindOk);
        break;

      case AMQP.Queue.Purge.INDEX:
        AMQP.Queue.Purge purge = (AMQP.Queue.Purge) method;
        AMQP.Queue.PurgeOk purgeOk = queuePurge(purge);
        if (purge.noWait == false) {
          purgeOk.channelNumber = channelNumber;
          send(purgeOk);
        }
        break;

      default:
        break;
      }
      break;

    case AMQP.Basic.INDEX:

      switch (method.getMethodId()) {

      case AMQP.Basic.Get.INDEX:
        AMQP.Basic.Get get = (AMQP.Basic.Get) method;
        GetResponse response = basicGet(get);
        if (response == null) {
          AMQP.Basic.GetEmpty getEmpty = new AMQP.Basic.GetEmpty();
          getEmpty.channelNumber = channelNumber;
          send(getEmpty);
        } else {
          response.getOk.channelNumber = channelNumber;
          send(response);
        }
        break;

      case AMQP.Basic.Ack.INDEX:
        AMQP.Basic.Ack ack = (AMQP.Basic.Ack) method;
        if (logger.isLoggable(BasicLevel.DEBUG))
          logger.log(BasicLevel.DEBUG, "ACK = " + ack);
        basicAck(ack);
        break;

      case AMQP.Basic.Consume.INDEX:
        AMQP.Basic.Consume consume = (AMQP.Basic.Consume) method;
        if (logger.isLoggable(BasicLevel.DEBUG))
          logger.log(BasicLevel.DEBUG, "consume = " + consume);
        basicConsume(consume);
        break;

      case AMQP.Basic.Cancel.INDEX:
        AMQP.Basic.Cancel cancel = (AMQP.Basic.Cancel) method;
        if (logger.isLoggable(BasicLevel.DEBUG))
          logger.log(BasicLevel.DEBUG, "cancel consumerTag = " + cancel.consumerTag + " nowait = "
              + cancel.noWait);
        basicCancel(cancel.consumerTag, channelNumber);
        if (cancel.noWait == false) {
          AMQP.Basic.CancelOk cancelOk = new AMQP.Basic.CancelOk(cancel.consumerTag);
          cancelOk.channelNumber = channelNumber;
          send(cancelOk);
        }
        break;

      case AMQP.Basic.Reject.INDEX:
        AMQP.Basic.Reject reject = (AMQP.Basic.Reject) method;
        basicReject(reject);
        break;

      case AMQP.Basic.RecoverAsync.INDEX:
        // This method is deprecated in favor of the synchronous Recover/RecoverOk.
        AMQP.Basic.RecoverAsync recoverAsync = (AMQP.Basic.RecoverAsync) method;
        basicRecover(recoverAsync.requeue, channelNumber);
        break;

      case AMQP.Basic.Recover.INDEX:
        AMQP.Basic.Recover recover = (AMQP.Basic.Recover) method;
        basicRecover(recover.requeue, channelNumber);
        AMQP.Basic.RecoverOk recoverOk = new AMQP.Basic.RecoverOk();
        recoverOk.channelNumber = channelNumber;
        send(recoverOk);
        break;

      case AMQP.Basic.Qos.INDEX:
        AMQP.Basic.Qos qos = (AMQP.Basic.Qos) method;
        basicQoS(qos);
        AMQP.Basic.QosOk qosOk = new AMQP.Basic.QosOk();
        qosOk.channelNumber = channelNumber;
        send(qosOk);
        break;

      default:
        break;
      }
      break;

    case AMQP.Exchange.INDEX:

      switch (method.getMethodId()) {
      case AMQP.Exchange.Declare.INDEX:
        AMQP.Exchange.Declare declare = (AMQP.Exchange.Declare) method;
        exchangeDeclare(declare);
        if (declare.noWait == false) {
          AMQP.Exchange.DeclareOk declareOk = new AMQP.Exchange.DeclareOk();
          declareOk.channelNumber = channelNumber;
          send(declareOk);
        }
        break;

      case AMQP.Exchange.Delete.INDEX:
        AMQP.Exchange.Delete delete = (AMQP.Exchange.Delete) method;
        exchangeDelete(delete);
        if (delete.noWait == false) {
          AMQP.Exchange.DeleteOk deleteOk = new AMQP.Exchange.DeleteOk();
          deleteOk.channelNumber = channelNumber;
          send(deleteOk);
        }
        break;

      default:
        break;
      }
      break;

    case AMQP.Tx.INDEX:

      switch (method.getMethodId()) {
      case AMQP.Tx.Select.INDEX:
        getContext(channelNumber).transacted = true;
        AMQP.Tx.SelectOk selectOk = new AMQP.Tx.SelectOk();
        selectOk.channelNumber = channelNumber;
        send(selectOk);
        break;

      case AMQP.Tx.Commit.INDEX:
        txCommit(channelNumber);
        AMQP.Tx.CommitOk commitOk = new AMQP.Tx.CommitOk();
        commitOk.channelNumber = channelNumber;
        send(commitOk);
        break;

      case AMQP.Tx.Rollback.INDEX:
        txRollback(channelNumber);
        AMQP.Tx.RollbackOk rollbackOk = new AMQP.Tx.RollbackOk();
        rollbackOk.channelNumber = channelNumber;
        send(rollbackOk);
        break;
      }
      break;

    default:
      break;
    }
  }
