public void queueBind(AMQP.Queue.Bind queueBind) throws NotFoundException, SyntaxErrorException,
      ResourceLockedException, AMQPException {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "Proxy.queueBind(" + queueBind + ')');

    /* If the queue name is empty, the server uses the last queue declared on
     * the channel. If the routing key is also empty, the server uses this queue
     * name for the routing key as well. If the queue name is provided but the
     * routing key is empty, the server does the binding with that empty routing
     * key. */
    String queueName = queueBind.queue;
    if (queueName.equals("")) {
      queueName = getContext(queueBind.channelNumber).lastQueueCreated;
      /* If the client did not declare a queue, and the method needs a queue
       * name, this will result in a 502 (syntax error) channel exception. */
      if (queueName == null) {
        throw new SyntaxErrorException("No queue previously declared on the channel.");
      }
      if (queueBind.routingKey.equals("")) {
        queueBind.routingKey = queueName;
      }
    }

    if (Naming.isLocal(queueBind.exchange)) {
      StubLocal.queueBind(queueName, queueBind.exchange, queueBind.routingKey, queueBind.arguments,
          name.serverId, name.proxyId);
    } else {
      // Assign queue name in case we use lastQueueCreated field
      queueBind.queue = Naming.getGlobalName(queueName);
      StubAgentOut.syncSend(queueBind, Naming.resolveServerId(queueBind.exchange));
    }
  }
