public void txCommit(int channelNumber) throws PreconditionFailedException, TransactionException {

    ChannelContext channelContext = getContext(channelNumber);
    if (!channelContext.transacted) {
      throw new PreconditionFailedException("Can't commit a non-transacted channel.");
    }

    try {
      AgentServer.getTransaction().begin();
    } catch (IOException exc) {
      throw new TransactionException(exc.getMessage());
    }
    for (PublishRequest publish : channelContext.pubToCommit) {
      if (Naming.isLocal(publish.getPublish().exchange)) {
        try {
          StubLocal.basicPublish(publish, name.serverId, name.proxyId);
        } catch (AMQPException exc) {
          // the behaviour of transactions with respect to the immediate and mandatory
          // flags on Basic.Publish methods is not defined
          AMQP.Basic.Return returned = new AMQP.Basic.Return(exc.getCode(), exc.getMessage(),
              publish.getPublish().exchange, publish.getPublish().routingKey);
          returned.channelNumber = publish.channel;
          send(new Returned(returned, publish.getHeader(), publish.getBody()));
        }
      } else {
        StubAgentOut.asyncSend(publish, Naming.resolveServerId(publish.getPublish().exchange), name.proxyId);
      }
    }
    channelContext.pubToCommit.clear();

    Map<QueueShell, List<Long>> deliveryMap = new HashMap<QueueShell, List<Long>>();
    Iterator<Delivery> iter = channelContext.deliveriesToAck.iterator();
    while (iter.hasNext()) {
      Delivery delivery = iter.next();
      if (delivery.waitingCommit) {
        List<Long> ackList = deliveryMap.get(delivery.queue);
        if (ackList == null) {
          ackList = new ArrayList<Long>();
          deliveryMap.put(delivery.queue, ackList);
        }
        ackList.add(new Long(delivery.queueMsgId));
        iter.remove();
      }
    }
    Iterator<QueueShell> iterQueues = deliveryMap.keySet().iterator();
    while (iterQueues.hasNext()) {
      QueueShell queue = iterQueues.next();
      if (queue.islocal()) {
        queue.getReference().ackMessages(deliveryMap.get(queue));
      } else {
        StubAgentOut.asyncSend(new Ack(queue.getName(), deliveryMap.get(queue)),
            Naming.resolveServerId(queue.getName()));
      }
    }

    try {
      AgentServer.getTransaction().commit(true);
    } catch (IOException exc) {
      throw new TransactionException(exc.getMessage());
    }

    if (channelContext.prefetchCount != 0) {
      queueIn.push(new GetDeliveries(null, channelNumber));
    }
  }
