public synchronized void consume(DeliveryListener proxy, int channelId, String consumerTag,
      boolean exclusiveConsumer, boolean noAck, boolean noLocal, short serverId, long proxyId)
      throws AccessRefusedException, ResourceLockedException {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "Queue.consume()");

    if (exclusive && (this.serverId != serverId || this.proxyId != proxyId)) {
      throw new ResourceLockedException("Can't consume on the non-owned exclusive queue '" + name + "'.");
    }
    if (exclusiveConsumer && consumers.size() != 0) {
      throw new AccessRefusedException("Exclusive consume request failed due to previous consumer on queue '"
          + name + "'.");
    }
    if (consumers.size() == 1 && consumers.values().iterator().next().exclusive) {
      throw new AccessRefusedException("Consume request failed due to previous exclusive consumer on queue '"
          + name + "'.");
    }

    consumers.put(new SubscriptionKey(serverId, proxyId, channelId, consumerTag), new Subscription(proxy,
        channelId, consumerTag, exclusiveConsumer, noAck, noLocal, serverId, proxyId));

  }
