public synchronized void publish(Message msg, boolean immediate, short serverId, long proxyId)
      throws NoConsumersException, TransactionException {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "Queue.publish(" + msg.properties + ')');

    if (exclusive && serverId != -1 && this.serverId != serverId && this.proxyId != proxyId) {
      if (logger.isLoggable(BasicLevel.WARN))
        logger.log(BasicLevel.WARN, "Publishing to a non-owned exclusive queue '" + name + "'.");
      // TODO ?
      return;
    }
    boolean recover = false;
    if (msg.queueMsgId == FIRST_DELIVERY) {
      msg.queueMsgId = msgCounter++;
    } else {
      recover = true;
    }

    if (consumers.size() == 0 && immediate) {
      throw new NoConsumersException("No consumer available for immediate publication on queue '" + name + "'.");
    }
    
    if (durable) {
      if (recover) {
        toAck.remove(msg);
      } else {
        saveMessage(msg);
      }
    }

    toDeliver.add(msg);

    // If a consumer is present, try to deliver right now
    if (consumers.size() > 0) {
      Iterator<Entry<SubscriptionKey, Subscription>> iterEntries = consumers.entrySet().iterator();

      // Deliver to the first available (ie QoS buffer not full) consumer
      // this will achieve round-robin if no QoS is set.
      while (iterEntries.hasNext()) {
        Entry<SubscriptionKey, Subscription> entry = iterEntries.next();
        Subscription subscription = entry.getValue();
        if (subscription.deliveryListener.deliver(subscription.consumerTag, subscription.channelId, this,
            subscription.serverId, subscription.proxyId)) {
          consumers.get(entry.getKey());
          return;
        }
      }
    }
  }
