private static Object doProcessMethod(AbstractMarshallingMethod method, short serverId, long proxyId) throws AMQPException {
    Object response = null;
    
    if (method != null) {
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG, "doProcess marshallingMethod = " + method);

      int channelNumber = method.channelNumber;
      
      switch (method.getClassId()) {

      case AMQP.Connection.INDEX:
        throw new IllegalStateException();

      case AMQP.Channel.INDEX:
        throw new IllegalStateException();

      case AMQP.Queue.INDEX:
        switch (method.getMethodId()) {
        case AMQP.Queue.Declare.INDEX:
          AMQP.Queue.Declare declare = (AMQP.Queue.Declare) method;
          AMQP.Queue.DeclareOk declareOk = queueDeclare(declare, serverId, proxyId);
          if (declare.noWait == false) {
            declareOk.channelNumber = channelNumber;
            response = declareOk;
          }
          break;

        case AMQP.Queue.Delete.INDEX:
          AMQP.Queue.Delete delete = (AMQP.Queue.Delete) method;
          AMQP.Queue.DeleteOk deleteOk = queueDelete(delete, serverId, proxyId);
          if (delete.noWait == false) {
            deleteOk.channelNumber = channelNumber;
            response = deleteOk;
          }
          break;

        case AMQP.Queue.Bind.INDEX:
          AMQP.Queue.Bind bind = (AMQP.Queue.Bind) method;
          queueBind(bind, serverId, proxyId);
          if (bind.noWait == false) {
            AMQP.Queue.BindOk bindOk = new AMQP.Queue.BindOk();
            bindOk.channelNumber = channelNumber;
            response = bindOk;
          }
          break;
          
        case AMQP.Queue.Unbind.INDEX:
          AMQP.Queue.Unbind unbind = (AMQP.Queue.Unbind) method;
          queueUnbind(unbind, serverId, proxyId);
          AMQP.Queue.UnbindOk unbindOk = new AMQP.Queue.UnbindOk();
          unbindOk.channelNumber = channelNumber;
          response = unbindOk;
          break;
          
        case AMQP.Queue.Purge.INDEX:
            AMQP.Queue.Purge purge = (AMQP.Queue.Purge) method;
            AMQP.Queue.PurgeOk purgeOk = queuePurge(purge, serverId, proxyId);
            if (purge.noWait == false) {
              purgeOk.channelNumber = channelNumber;
              response = purgeOk;
            }
          break;

        default:
          break;
        }
        break;

      case AMQP.Basic.INDEX:

        switch (method.getMethodId()) {

        case AMQP.Basic.Get.INDEX:
          AMQP.Basic.Get get = (AMQP.Basic.Get) method;
          response = basicGet(get, serverId, proxyId);
          if (response == null) {
            return nullResponse;
          }
          break;

        case AMQP.Basic.Ack.INDEX:
          throw new IllegalStateException();

        case AMQP.Basic.Consume.INDEX:
          AMQP.Basic.Consume consume = (AMQP.Basic.Consume) method;
          if (logger.isLoggable(BasicLevel.DEBUG))
            logger.log(BasicLevel.DEBUG, "consume = " + consume);
          basicConsume(consume, serverId, proxyId);
          break;

        case AMQP.Basic.Cancel.INDEX:
          throw new IllegalStateException();
          
        case AMQP.Basic.Reject.INDEX:
          throw new IllegalStateException();

        case AMQP.Basic.RecoverAsync.INDEX:
          throw new IllegalStateException();

        case AMQP.Basic.Recover.INDEX:
          throw new IllegalStateException();

        case AMQP.Basic.Qos.INDEX:
          throw new NotImplementedException("Qos method currently not implemented.");

        default:
          break;
        }
        break;

      case AMQP.Exchange.INDEX:

        switch (method.getMethodId()) {
        case AMQP.Exchange.Declare.INDEX:
          AMQP.Exchange.Declare declare = (AMQP.Exchange.Declare) method;
          exchangeDeclare(declare);
          if (declare.noWait == false) {
            AMQP.Exchange.DeclareOk declareOk = new AMQP.Exchange.DeclareOk();
            declareOk.channelNumber = channelNumber;
            response = declareOk;
          }
          break;

        case AMQP.Exchange.Delete.INDEX:
          AMQP.Exchange.Delete delete = (AMQP.Exchange.Delete) method;
          exchangeDelete(delete);
          if (delete.noWait == false) {
            AMQP.Exchange.DeleteOk deleteOk = new AMQP.Exchange.DeleteOk();
            deleteOk.channelNumber = channelNumber;
            response = deleteOk;
          }
          break;

        default:
          break;
        }
        break;

      case AMQP.Tx.INDEX:
        break;

      default:
        break;
      }
    }
    return response;
  }
