public static void processRequest(AgentId from, long keyLock, long proxyId, Object request) {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "processRequest(" + from + ", " + keyLock + ", " + request + ')');

    Object response = null;
    try {
      if (request instanceof AbstractMarshallingMethod) {  
        response = doProcessMethod((AbstractMarshallingMethod) request, from.getFrom(), proxyId);
      } else if (request instanceof Ack) {
        basicAck(((Ack) request).getQueueName(), ((Ack) request).getIdsToAck());
      } else if(request instanceof Recover) {
        basicRecover(((Recover) request).getQueueName(), ((Recover) request).getIdsToRecover());
        response = new AMQP.Basic.RecoverOk();
      } else if(request instanceof Cancel) {
        Cancel cancel = (Cancel) request;
        response = basicCancel(cancel.getConsumerTag(), cancel.getQueueName(), cancel.getChannelNumber(),
            from.getFrom(), proxyId);
      } else if(request instanceof PublishRequest) {
        basicPublish((PublishRequest) request, from.getFrom(), proxyId);
      } else if (request instanceof PublishToQueue) {
        publishToQueue((PublishToQueue) request);
      } else if (request instanceof AddBoundExchange) {
        addBoundExchange((AddBoundExchange) request, from.getFrom(), proxyId);
      } else if (request instanceof RemoveQueueBindings) {
        removeQueueBindings((RemoveQueueBindings) request);
      } else if (request instanceof RemoveBoundExchange) {
        removeBoundExchange((RemoveBoundExchange) request, from.getFrom(), proxyId);
      }
    } catch (AMQPException exc) {
      if (logger.isLoggable(BasicLevel.DEBUG)) {
        logger.log(BasicLevel.DEBUG, "StubAgentIn: ERROR:: " + exc.getMessage());
      }
        response = exc;
    }
    
    if (response != null) {
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG, "processRequest response = " + response);
      AMQPResponseNot not = new AMQPResponseNot();
      not.keyLock = keyLock;
      if (response != nullResponse) {
        not.obj = response;
      }
      Channel.sendTo(AMQPAgent.getAMQPId(from.getFrom()), not);
    }
  }
