public static void exchangeDeclare(String exchangeName, String type, boolean durable, boolean passive)
      throws NotFoundException, CommandInvalidException, NotAllowedException, PreconditionFailedException,
      AccessRefusedException {
    IExchange exchange = Naming.lookupExchange(exchangeName);
    if (exchange == null) {
      if (passive) {
        throw new NotFoundException("Passive declaration of an unknown exchange: '" + exchangeName + "'.");
      }
      checkName(exchangeName);
      if (type.equalsIgnoreCase(DirectExchange.TYPE)) {
        exchange = new DirectExchange(exchangeName, durable);
      } else if (type.equalsIgnoreCase(TopicExchange.TYPE)) {
        exchange = new TopicExchange(exchangeName, durable);
      } else if (type.equalsIgnoreCase(FanoutExchange.TYPE)) {
        exchange = new FanoutExchange(exchangeName, durable);
      } else if (type.equalsIgnoreCase(HeadersExchange.TYPE)) {
        exchange = new HeadersExchange(exchangeName, durable);
      } else {
        try {
          Class exchangeClass = Class.forName(type);
          exchange = (IExchange) exchangeClass.newInstance();
        } catch (ClassNotFoundException exc) {
          throw new CommandInvalidException("Unknown exchange type: " + type);
        } catch (Exception exc) {
          throw new CommandInvalidException(exc.getMessage());
        }
      }
      //      exchange.setArguments(arguments);
      try {
        Naming.bindExchange(exchangeName, exchange);
      } catch (AlreadyBoundException exc) {
        // TODO
      }
    } else {
      if (passive) {
        return;
      }
      // Check if exchange type corresponds with existing exchange
      if (type.equalsIgnoreCase(DirectExchange.TYPE)) {
        if (!(exchange instanceof DirectExchange)) {
          throw new NotAllowedException("Exchange type do not match existing exchange '" + exchangeName + "'.");
        }
      } else if (type.equalsIgnoreCase(TopicExchange.TYPE)) {
        if (!(exchange instanceof TopicExchange)) {
          throw new NotAllowedException("Exchange type do not match existing exchange '" + exchangeName + "'.");
        }
      } else if (type.equalsIgnoreCase(FanoutExchange.TYPE)) {
        if (!(exchange instanceof FanoutExchange)) {
          throw new NotAllowedException("Exchange type do not match existing exchange '" + exchangeName + "'.");
        }
      } else if (type.equalsIgnoreCase(HeadersExchange.TYPE)) {
        if (!(exchange instanceof HeadersExchange)) {
          throw new NotAllowedException("Exchange type do not match existing exchange '" + exchangeName + "'.");
        }
      } else {
        if (!exchange.getClass().getName().equals(type)) {
          throw new NotAllowedException("Exchange type do not match existing exchange '" + exchangeName + "'.");
        }
      }

      if (durable != exchange.isDurable()) {
        throw new PreconditionFailedException("Exchange durable property do not match existing exchange '"
            + exchangeName + "'.");
      }
    }
  }
