public static void exchangeDelete(String exchangeName, boolean ifUnused) throws NotFoundException,
      PreconditionFailedException, AccessRefusedException {
    IExchange exchange = Naming.lookupExchange(exchangeName);
    if (exchange == null) {
      throw new NotFoundException("Exchange not found for deletion: '" + exchangeName + "'.");
    }
    if (ifUnused && !exchange.isUnused()) {
      throw new PreconditionFailedException("Deletion error: Exchange '" + exchangeName + "' is not unused.");
    }
    
    exchange.deleteExchange();
    Naming.unbindExchange(exchangeName);

    // Unbind queues bound to the exchange
    Set<String> boundQueues = exchange.getBoundQueues();
    Iterator<String> queuesIterator = boundQueues.iterator();
    while (queuesIterator.hasNext()) {
      String queueName = queuesIterator.next();
      if (Naming.isLocal(queueName)) {
        Queue queue = Naming.lookupQueue(queueName);
        queue.removeBoundExchange(exchangeName);
      } else {
        StubAgentOut.asyncSend(new RemoveBoundExchange(queueName, exchangeName), Naming.resolveServerId(queueName));
      }
    }
  }
