public static AMQP.Queue.DeclareOk queueDeclare(String queueName, boolean passive, boolean durable,
      boolean autoDelete, boolean exclusive, short serverId, long proxyId) throws NotFoundException,
      ResourceLockedException, PreconditionFailedException, AccessRefusedException, TransactionException {
    // Generate queue name if unspecified
    if (queueName.equals("")) {
      queueName = Naming.nextQueueName();
    }

    // Check if the queue already exists
    Queue queue = Naming.lookupQueue(queueName);

    if (queue == null) {
      if (passive) {
        throw new NotFoundException("Passive declaration of an unknown queue: '" + queueName + "'.");
      }
      checkName(queueName);
      queue = new Queue(queueName, durable, autoDelete, exclusive, serverId, proxyId);
      try {
        Naming.bindQueue(queueName, queue);
      } catch (AlreadyBoundException exc) {
        // TODO 
      }

      // All message queues MUST BE automatically bound to the nameless exchange using the
      // message queue's name as routing key.
      queueBind(queueName, IExchange.DEFAULT_EXCHANGE_NAME, queueName, null, serverId, proxyId);
      return new AMQP.Queue.DeclareOk(queueName, 0, 0);

    } else {
      if (!passive) {
        // If passive is not set and the queue exists, the server MUST check that the
        // existing queue has the same values for durable, exclusive, auto-delete,
        // and arguments fields.
        if (durable != queue.isDurable()) {
          throw new PreconditionFailedException("Queue durable property do not match existing queue '"
              + queueName + "'.");
        }
        if (exclusive != queue.isExclusive()) {
          throw new ResourceLockedException("Queue exclusive property do not match existing queue '"
              + queueName + "'.");
        }
        if (autoDelete != queue.isAutodelete()) {
          throw new PreconditionFailedException("Queue autodelete property do not match existing queue one '"
              + queueName + "'.");
        }
      }
      return queue.getInfo(serverId, proxyId);
    }
  }
