public static int queueDelete(String queueName, boolean ifUnused, boolean ifEmpty, short serverId,
      long proxyId) throws PreconditionFailedException, NotFoundException, ResourceLockedException,
      TransactionException {
    Queue queue = Naming.lookupQueue(queueName);
    if (queue == null) {
      throw new NotFoundException("Unknown queue for deletion: '" + queueName + "'.");
    }

    if (ifEmpty && queue.getToDeliverMessageCount() > 0) {
      throw new PreconditionFailedException("Deletion error: queue '" + queueName + "' is not empty.");
    }
    if (ifUnused && queue.getConsumerCount() > 0) {
      throw new PreconditionFailedException("Deletion error: queue '" + queueName + "' is not unused.");
    }
    queue.deleteQueue(queueName, serverId, proxyId);
    Naming.unbindQueue(queueName);

    // Unbind exchanges bound to the queue
    List<String> boundExchanges = queue.getBoundExchanges();
    Iterator<String> exchangesIterator = boundExchanges.iterator();
    while (exchangesIterator.hasNext()) {
      String exchangeName = exchangesIterator.next();
      if (Naming.isLocal(exchangeName)) {
        IExchange exchange = Naming.lookupExchange(exchangeName);
        if (exchange != null) {
          exchange.removeQueueBindings(queueName);
        }
      } else {
        StubAgentOut.asyncSend(new RemoveQueueBindings(exchangeName, queueName), Naming.resolveServerId(exchangeName));
      }
    }
    
    return queue.getToDeliverMessageCount();
  }
