private final Object readFieldValue() throws IOException, SyntaxErrorException {
    Object value = null;
    int type = StreamUtil.readUnsignedByteFrom(in);
    switch (type) {
    case 'S':
      value = readLongstr();
      break;
    case 'I':
      value = new Integer(StreamUtil.readIntFrom(in));
      break;
    case 'D':
      int scale = StreamUtil.readUnsignedByteFrom(in);
      byte[] unscaled = StreamUtil.readByteArrayFrom(in, 4);
      value = new BigDecimal(new BigInteger(unscaled), scale);
      break;
    case 'T':
      value = readTimestamp();
      break;
    case 'F':
      value = readTable();
      break;
    case 'B':
      value = new Byte(StreamUtil.readByteFrom(in));
      break;
    case 'U':
      value = new Short(StreamUtil.readShortFrom(in));
      break;
    case 'L':
      value = new Long(StreamUtil.readLongFrom(in));
      break;
    case 'A':
      value = readArray();
      break;
    case 'f':
      value = new Float(StreamUtil.readFloatFrom(in));
      break;
    case 'd':
      value = new Double(StreamUtil.readDoubleFrom(in));
      break;
    case 'b':
      value = new Byte(StreamUtil.readByteFrom(in));
      break;
    case 'l':
      value = new Long(StreamUtil.readLongFrom(in));
      break;
    case 't':
      value = new Boolean(readBoolean());
      break;
    case 'V':
      value = null;
      break;
    case 's':
      value = new Boolean(StreamUtil.readShortStringFrom(in));
      break;
    default:
      throw new SyntaxErrorException("Unrecognised object type in table: " + (char) type);
    }
    return value;
  }
