private void writeFieldValue(Object value) throws IOException {
    if (value == null) {
      writeOctet('V');
    } else if (value instanceof String) {
      writeOctet('s');
      writeShortstr((String) value);
    } else if (value instanceof LongString) {
      writeOctet('S');
      writeLongstr((LongString) value);
    } else if (value instanceof Integer) {
      writeOctet('I');
      writeLong(((Integer) value).intValue());
    } else if (value instanceof Short) {
      writeOctet('U');
      writeShort(((Short) value).shortValue());
    } else if (value instanceof Byte) {
      writeOctet('b');
      writeByte(((Byte) value).byteValue());
    } else if (value instanceof BigDecimal) {
      writeOctet('D');
      BigDecimal decimal = (BigDecimal) value;
      writeOctet(decimal.scale());
      BigInteger unscaled = decimal.unscaledValue();
      if (unscaled.bitLength() > 32) /* Integer.SIZE in Java 1.5 */
        throw new IllegalArgumentException("BigDecimal too large to be encoded");
      writeLong(decimal.unscaledValue().intValue());
    } else if (value instanceof Date) {
      writeOctet('T');
      writeTimestamp((Date) value);
    } else if (value instanceof Boolean) {
      writeOctet('t');
      writeBoolean(((Boolean) value).booleanValue());
    } else if (value instanceof Map) {
      writeOctet('F');
      writeTable((Map) value);
    } else if (value instanceof Long) {
      writeOctet('l');
      writeLonglong(((Long) value).longValue());
    } else if (value instanceof Double) {
      writeOctet('d');
      writeDouble(((Double) value).doubleValue());
    } else if (value instanceof Float) {
      writeOctet('f');
      writeFloat(((Float) value).floatValue());
    } else if (value instanceof Object[]) {
      writeOctet('A');
      writeArray((Object[]) value);
    } else {
      throw new IllegalArgumentException("Invalid value type: " + value.getClass().getName());
    }
  }
