private void checkItems() throws Exception {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "Scheduler.checkItems()");
    Date now = new Date();
    
    checkLoop:
      for (ScheduleItem item = items; item != null;) {
        if (item.date != null &&
            item.date.after(now))
          break checkLoop;

        ScheduleItem nextItem = item.next;
        
        // reschedules event
        item.date = item.event.nextDate(now);
        // this call must return a date later than now
        // for fear of an infinite loop
        if ((item.date != null) && ! item.date.after(now))
          item.date = null;

        if (item.date == null) {
          // removes event from list
          removeItem(item);
          item = nextItem;
          continue checkLoop;
        }

        // checks if event needs to be changed in the list
        if (nextItem == null || ! item.date.after(nextItem.date)) {
          continue checkLoop;
        }

        // removes event from list
        removeItem(item);
        // and inserts it at its new place
        insertItem(item);

        item = nextItem;
      }

    // sets next wake-up time, schedule in Timer.
    if (items != null) {
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG, "Scheduler.checkItems nextDate = " + items.date);
      schedule(items.event, items.date.getTime() - now.getTime());
    }
  }
