public static void checkAcquisitionClass(String className) throws Exception {
    if (className == null) {
      throw new Exception("AcquisitionHandler class not defined: use " + DestinationConstants.ACQUISITION_CLASS_NAME
          + " property to chose acquisition class.");
    }
    Class<?> clazz = Class.forName(className);
    boolean isDaemon = false;
    boolean isHandler = false;
    while (clazz != null) {
      Class<?>[] interfaces = clazz.getInterfaces();
      for (int i = 0; i < interfaces.length; i++) {
        if (interfaces[i].equals(AcquisitionDaemon.class)) {
          isDaemon = true;
        } else if (interfaces[i].equals(AcquisitionHandler.class)) {
          isHandler = true;
        }
      }
      clazz = clazz.getSuperclass();
    }
    if (isDaemon && isHandler) {
      throw new Exception("Acquisition class " + className
          + " can't implement both AcquisitionHandler and AcquisitionDaemon interfaces.");
    } else if (!isDaemon && !isHandler) {
      throw new Exception("Acquisition class " + className
          + " must implement either AcquisitionHandler or AcquisitionDaemon interface.");
    }
  }
