public void setProperties(Properties properties) {

    if (isDaemon && running) {
      ((AcquisitionDaemon) acquisitionHandler).stop();
      running = false;
    }

    if (acquisitionTask != null) {
      acquisitionTask.cancel();
    }

    // Reset to defaults
    period = 0;
    isExpirationSet = false;
    isPersistencySet = false;
    isPrioritySet = false;

    // Clone properties as it is modified before setting handler properties
    // and we want to keep all properties in destinations to persist them
    Properties props = (Properties) properties.clone();

    if (logger.isLoggable(BasicLevel.DEBUG)) {
      logger.log(BasicLevel.DEBUG, "AcquisitionModule.setProperties = " + props + " daemon = " + isDaemon);
    }

    if (props.containsKey(DestinationConstants.ACQUISITION_PERIOD)) {
      try {
        period = ConversionHelper.toLong(props.get(DestinationConstants.ACQUISITION_PERIOD));
      } catch (MessageValueException exc) {
        logger.log(BasicLevel.ERROR, "AcquisitionModule: can't parse defined period property.");
      }
//      props.remove(PERIOD);
    }
    if (!isDaemon && period > 0) {
      if (logger.isLoggable(BasicLevel.DEBUG)) {
        logger.log(BasicLevel.DEBUG, "schedule acquisition every " + period + "ms.");
      }
      acquisitionTask = new AcquisitionTask();
      AgentServer.getTimer().schedule(acquisitionTask, period, period);
    }

    if (props.containsKey(DestinationConstants.ACQUISITION_PERSISTENT)) {
      try {
        isPersistent = ConversionHelper.toBoolean(props.get(DestinationConstants.ACQUISITION_PERSISTENT));
        isPersistencySet = true;
      } catch (MessageValueException exc) {
        logger.log(BasicLevel.ERROR, "AcquisitionModule: can't parse defined message persistence property.");
        props.remove(DestinationConstants.ACQUISITION_PERSISTENT);
      }
//      props.remove(PERSISTENT_PROPERTY);
    }

    if (props.containsKey(DestinationConstants.ACQUISITION_PRIORITY)) {
      try {
        priority = ConversionHelper.toInt(props.get(DestinationConstants.ACQUISITION_PRIORITY));
        isPrioritySet = true;
      } catch (MessageValueException exc) {
        logger.log(BasicLevel.ERROR, "AcquisitionModule: can't parse defined message priority property.");
      }
//      props.remove(PRIORITY_PROPERTY);
    }

    if (props.containsKey(DestinationConstants.ACQUISITION_EXPIRATION)) {
      try {
        expiration = ConversionHelper.toLong(props.get(DestinationConstants.ACQUISITION_EXPIRATION));
        isExpirationSet = true;
      } catch (MessageValueException exc) {
        logger.log(BasicLevel.ERROR, "AcquisitionModule: can't parse defined message expiration property.");
      }
//      props.remove(EXPIRATION_PROPERTY);
    }

    if (props.containsKey(DestinationConstants.ACQUISITION_CLASS_NAME)
        && !props.get(DestinationConstants.ACQUISITION_CLASS_NAME).equals(acquisitionHandler.getClass().getName())) {
      logger.log(BasicLevel.ERROR,
          "AcquisitionModule: Changing dynamically the acquisition class is not allowed.");
      props.remove(DestinationConstants.ACQUISITION_CLASS_NAME);
    }

    if (isDaemon) {
      ((AcquisitionDaemon) acquisitionHandler).start(props, this);
      running = true;
    } else {
      ((AcquisitionHandler) acquisitionHandler).setProperties(props);
    }
  }
