public void setProperties(Properties properties, boolean firstTime) throws Exception {
    super.setProperties(properties, firstTime);

    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "AcquisitionQueue.setProperties prop = " + properties);
    
    this.properties = properties;
    
    diff_max = Long.parseLong(properties.getProperty(DestinationConstants.ACQ_QUEUE_MAX_MSG, String.valueOf(diff_max)));
    diff_min = Long.parseLong(properties.getProperty(DestinationConstants.ACQ_QUEUE_MIN_MSG, String.valueOf(diff_min)));
    if (diff_max < 2) diff_max = 2;
    if (diff_min >= diff_max) diff_min = diff_max -2;
    if (diff_min < 0) diff_min = 0;
    
    pending_max = Long.parseLong(properties.getProperty(DestinationConstants.ACQ_QUEUE_MAX_PND, String.valueOf(pending_max)));
    pending_min = Long.parseLong(properties.getProperty(DestinationConstants.ACQ_QUEUE_MIN_PND, String.valueOf(pending_min)));
    if (pending_max < 2) pending_max = 2;
    if (pending_min >= pending_max) pending_min = pending_max -2;
    if (pending_min < 0) pending_min = 0;
    
    if (logger.isLoggable(BasicLevel.INFO))
      logger.log(BasicLevel.INFO,
                 "AcquisitionQueue.setProperties -> " + diff_min + '/' + diff_max  + ", " + pending_min + '/' + pending_max);
    
    // Acquisition class name can only be set the first time.
    if (firstTime) {
      if (properties != null) {
        acquisitionClassName = properties.getProperty(DestinationConstants.ACQUISITION_CLASS_NAME);
        properties.remove(DestinationConstants.ACQUISITION_CLASS_NAME);
      }
      if (acquisitionClassName == null) {
        throw new RequestException("Acquisition class name not found: " + DestinationConstants.ACQUISITION_CLASS_NAME
            + " property must be set on queue creation.");
      }
      try {
        AcquisitionModule.checkAcquisitionClass(acquisitionClassName);
      } catch (Exception exc) {
        logger.log(BasicLevel.ERROR, "AcquisitionQueue: error with acquisition class.", exc);
        throw new RequestException(exc.getMessage());
      }
    } else {
      acquisitionModule.setProperties(properties);
    }
  }
