public void setProperties(Properties properties, boolean firstTime) throws Exception {
    super.setProperties(properties, firstTime);

    if (logger.isLoggable(BasicLevel.DEBUG)) {
      logger.log(BasicLevel.DEBUG, "AcquisitionTopic.setProperties prop = " + properties);
    }
    this.properties = properties;
    
    diff_max = Long.parseLong(properties.getProperty(ACQ_TOPIC_MAX_MSG, String.valueOf(diff_max)));
    diff_min = Long.parseLong(properties.getProperty(ACQ_TOPIC_MIN_MSG, String.valueOf(diff_min)));
    if (diff_max < 2) diff_max = 2;
    if (diff_min >= diff_max) diff_min = diff_max -2;
    if (diff_min < 0) diff_min = 0;
    
    if (logger.isLoggable(BasicLevel.INFO))
      logger.log(BasicLevel.INFO, "AcquisitionTopic.setProperties -> " + diff_min + '/' + diff_max);
    
    // Acquisition class name can only be set the first time.
    if (firstTime) {
      if (properties != null) {
        acquisitionClassName = properties.getProperty(DestinationConstants.ACQUISITION_CLASS_NAME);
        properties.remove(DestinationConstants.ACQUISITION_CLASS_NAME);
      }
      if (acquisitionClassName == null) {
        throw new RequestException("Acquisition class name not found: " + DestinationConstants.ACQUISITION_CLASS_NAME
            + " property must be set on topic creation.");
      }
      try {
        AcquisitionModule.checkAcquisitionClass(acquisitionClassName);
      } catch (Exception exc) {
        logger.log(BasicLevel.ERROR, "AcquisitionTopic: error with acquisition class.", exc);
        throw new RequestException(exc.getMessage());
      }
    }

    if (!firstTime) {
      acquisitionModule.setProperties(properties);
    }
  }
