private void doProcess(GetServersIdsRequest request,
                         AgentId replyTo,
                         String msgId) throws UnknownServerException {
    if (checkServerId(request.getServerId())) {
      try {
        int[] ids;
        String[] names;
        String[] hostNames;
        String domainName = request.getDomainName();
        Iterator servers;
        A3CMLConfig config = AgentServer.getConfig();
        int serversCount;
        if (domainName != null) {
          A3CMLDomain domain = config.getDomain(domainName);
          servers = domain.servers.iterator();
          serversCount = domain.servers.size();
        } else {
          servers = config.servers.values().iterator();
          serversCount = config.servers.size();
        }
        ids = new int[serversCount];
        names = new String[serversCount];
        hostNames = new String[serversCount];
        int i = 0;
        while (servers.hasNext()) {
          A3CMLServer server = (A3CMLServer) servers.next();
          ids[i] = server.sid;
          names[i] = server.name;
          hostNames[i] = server.hostname;
          i++;
        }
        GetServersIdsReply reply = new GetServersIdsReply(ids, names, hostNames);
        distributeReply(replyTo, msgId, reply);
      } catch (Exception exc) {
        if (logger.isLoggable(BasicLevel.DEBUG))
          logger.log(BasicLevel.DEBUG, "", exc);
        distributeReply(replyTo, msgId,
                        new AdminReply(false, exc.toString()));
      }
    } else {
      // Forward the request to the right AdminTopic agent.
      forward(getDefault((short) request.getServerId()),
              new FwdAdminRequestNot(request, replyTo, msgId));
    }
  }
