private static Object invokeStaticMethod(Properties prop) throws Exception {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "AdminTopic.invokeStaticMethod(" + prop + ")");

    boolean async = Boolean.parseBoolean(prop.getProperty(AdminCommandConstant.INVOKE_ASYNC));
    String className = prop.getProperty(AdminCommandConstant.INVOKE_CLASS_NAME);
    if (className == null) {
      throw new IllegalArgumentException("Class name property must be specified to invoke method.");
    }
    String methodName = prop.getProperty(AdminCommandConstant.INVOKE_METHOD_NAME);
    if (methodName == null) {
      throw new IllegalArgumentException("Method name property must be specified to invoke method.");
    }
    
    int i = 0;
    String paramType;
    List paramClasses = new ArrayList();
    final List paramValues = new ArrayList();
    while ((paramType = prop.getProperty(AdminCommandConstant.INVOKE_METHOD_ARG + i)) != null) {
      String paramValue = prop.getProperty(AdminCommandConstant.INVOKE_METHOD_ARG_VALUE + i);
      if (paramType.equals(Integer.TYPE.getName())) {
        paramClasses.add(Integer.TYPE);
        if (paramValue == null) {
          throw new IllegalArgumentException("Primitive type can't be null to invoke method.");
        }
        paramValues.add(new Integer(paramValue));
      } else if (paramType.equals(Integer.class.getName())) {
        paramClasses.add(Integer.class);
        paramValues.add(paramValue == null ? null : new Integer(paramValue));
      } else if (paramType.equals(String.class.getName())) {
        paramClasses.add(String.class);
        paramValues.add(paramValue == null ? null : paramValue);
      } else if (paramType.equals(Byte.TYPE.getName())) {
        paramClasses.add(Byte.TYPE);
        if (paramValue == null) {
          throw new IllegalArgumentException("Primitive type can't be null to invoke method.");
        }
        paramValues.add(new Byte(paramValue));
      } else if (paramType.equals(Byte.class.getName())) {
        paramClasses.add(Byte.class);
        paramValues.add(paramValue == null ? null : new Byte(paramValue));
      } else if (paramType.equals(Short.TYPE.getName())) {
        paramClasses.add(Short.TYPE);
        if (paramValue == null) {
          throw new IllegalArgumentException("Primitive type can't be null to invoke method.");
        }
        paramValues.add(new Short(paramValue));
      } else if (paramType.equals(Short.class.getName())) {
        paramClasses.add(Short.class);
        paramValues.add(paramValue == null ? null : new Short(paramValue));
      } else if (paramType.equals(Long.TYPE.getName())) {
        paramClasses.add(Long.TYPE);
        if (paramValue == null) {
          throw new IllegalArgumentException("Primitive type can't be null to invoke method.");
        }
        paramValues.add(new Long(paramValue));
      } else if (paramType.equals(Long.class.getName())) {
        paramClasses.add(Long.class);
        paramValues.add(paramValue == null ? null : new Long(paramValue));
      } else if (paramType.equals(Float.TYPE.getName())) {
        paramClasses.add(Float.TYPE);
        if (paramValue == null) {
          throw new IllegalArgumentException("Primitive type can't be null to invoke method.");
        }
        paramValues.add(new Float(paramValue));
      } else if (paramType.equals(Float.class.getName())) {
        paramClasses.add(Float.class);
        paramValues.add(paramValue == null ? null : new Float(paramValue));
      } else if (paramType.equals(Double.TYPE.getName())) {
        paramClasses.add(Double.TYPE);
        if (paramValue == null) {
          throw new IllegalArgumentException("Primitive type can't be null to invoke method.");
        }
        paramValues.add(new Double(paramValue));
      } else if (paramType.equals(Double.class.getName())) {
        paramClasses.add(Double.class);
        paramValues.add(paramValue == null ? null : new Double(paramValue));
      } else if (paramType.equals(Boolean.TYPE.getName())) {
        paramClasses.add(Boolean.TYPE);
        if (paramValue == null) {
          throw new IllegalArgumentException("Primitive type can't be null to invoke method.");
        }
        paramValues.add(new Boolean(paramValue));
      } else if (paramType.equals(Boolean.class.getName())) {
        paramClasses.add(Boolean.class);
        paramValues.add(paramValue == null ? null : new Boolean(paramValue));
      } else if (paramType.equals(Character.TYPE.getName())) {
        paramClasses.add(Character.TYPE);
        if (paramValue == null) {
          throw new IllegalArgumentException("Primitive type can't be null to invoke method.");
        }
        if (paramValue.length() == 0) {
          throw new IllegalArgumentException("Empty value for char argument.");
        }
        paramValues.add(new Character(paramValue.charAt(0)));
      } else if (paramType.equals(Character.class.getName())) {
        paramClasses.add(Character.class);
        if (paramValue != null && paramValue.length() == 0) {
          throw new IllegalArgumentException("Empty value for java.lang.Character argument.");
        }
        paramValues.add(paramValue == null ? null : new Character(paramValue.charAt(0)));
      } else {
        throw new IllegalArgumentException("Class not allowed for static invocation: " + paramType);
      }
      i++;
    }

    Class<?> clazz = Class.forName(className);
    final Method method = clazz.getMethod(methodName,
        (Class[]) paramClasses.toArray(new Class[paramClasses.size()]));
    if (! Modifier.isStatic(method.getModifiers()))
      throw new IllegalArgumentException("Specified method must be static: " + method);

    if (async) {
      Thread thread = new Thread() {
        public void run() {
          try {
            method.invoke(null, paramValues.toArray());
          } catch (Exception exc) {
            logger.log(BasicLevel.WARN, "AdminTopic.invokeStaticMethod: async invocation", exc);
          }
        }
      };
      thread.start();
      return null;
    } else {
      return method.invoke(null, paramValues.toArray());
    }
  }
