private void processAdminRequests(AgentId replyTo,
                                    String msgId,
                                    AdminRequest request,
                                    AgentId from) {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, this + ".processAdminRequests(" + msgId + ',' + request + ')');

    String info = null;
    if (request == null) {
      info = strbuf.append("Unexpected null request to AdminTopic on server [") .append(serverId).append("]").toString();
      strbuf.setLength(0);
      distributeReply(replyTo, msgId, new AdminReply(false, info));
      return;
    }

    // state change, so save.
    setSave();

    try {
      if (request instanceof StopServerRequest)
        doProcess((StopServerRequest) request, replyTo, msgId);
      else if (request instanceof CreateDestinationRequest)
        doProcess((CreateDestinationRequest) request, replyTo, msgId);
      else if (request instanceof DeleteDestination)
        doProcess((DeleteDestination) request, replyTo, msgId);
      else if (request instanceof CreateUserRequest)
        doProcess((CreateUserRequest) request, replyTo, msgId);
      else if (request instanceof UpdateUser)
        doProcess((UpdateUser) request, replyTo, msgId);
      else if (request instanceof DeleteUser)
        doProcess((DeleteUser) request, replyTo, msgId);
      else if (request instanceof SetDMQRequest)
        doProcess((SetDMQRequest) request, replyTo, msgId);
      else if (request instanceof SetThresholdRequest)
        doProcess((SetThresholdRequest) request, replyTo, msgId);
      else if (request instanceof GetServersIdsRequest)
        doProcess((GetServersIdsRequest) request, replyTo, msgId);
      else if (request instanceof GetDomainNames)
        doProcess((GetDomainNames) request, replyTo, msgId);
      else if (request instanceof GetLocalServer)
        doProcess(replyTo, msgId);
      else if (request instanceof GetDestinationsRequest)
        doProcess((GetDestinationsRequest) request, replyTo, msgId);
      else if (request instanceof GetUsersRequest)
        doProcess((GetUsersRequest) request, replyTo, msgId);
      else if (request instanceof GetRightsRequest)
        doProcess((GetRightsRequest) request, replyTo, msgId);
      else if (request instanceof GetDMQSettingsRequest)
        doProcess((GetDMQSettingsRequest) request, replyTo, msgId);
      else if (request instanceof GetStatsRequest)
        doProcess((GetStatsRequest) request, replyTo, msgId);
      else if (request instanceof DestinationAdminRequest)
        doProcess((DestinationAdminRequest) request, replyTo, msgId);
      else if (request instanceof AddServerRequest)
        doProcess((AddServerRequest) request, replyTo, msgId, from);
      else if (request instanceof AddDomainRequest)
        doProcess((AddDomainRequest) request, replyTo, msgId, from);
      else if (request instanceof RemoveServerRequest)
        doProcess((RemoveServerRequest) request, replyTo, msgId, from);
      else if (request instanceof RemoveDomainRequest)
        doProcess((RemoveDomainRequest) request, replyTo, msgId, from);
      else if (request instanceof GetConfigRequest)
        doProcess((GetConfigRequest) request, replyTo, msgId);
      else if (request instanceof UserAdminRequest)
        doProcess((UserAdminRequest) request, replyTo, msgId);
      else if (request instanceof AdminCommandRequest)
        doProcess((AdminCommandRequest) request, replyTo, msgId);
      else if (request instanceof GetJMXAttsRequest)
        doProcess((GetJMXAttsRequest) request, replyTo, msgId);
      else
        throw new MomException("Unknow administration request type: " + request.getClass().getName());
    } catch (UnknownServerException exc) {
      // Caught when a target server is invalid.
      info = strbuf.append("Request [").append(request.getClass().getName())
      .append("], successful [false]: ")
      .append(exc.getMessage()).toString();
      strbuf.setLength(0);

      distributeReply(replyTo, msgId, new AdminReply(AdminReply.UNKNOWN_SERVER, info));
    } catch (MomException exc) {
      if (logger.isLoggable(BasicLevel.WARN))
        logger.log(BasicLevel.WARN, exc);

      info = strbuf.append("Request [").append(request.getClass().getName())
          .append("], sent to AdminTopic on server [").append(serverId)
          .append("], successful [false]: ")
          .append(exc.getMessage()).toString();
      strbuf.setLength(0);

      distributeReply(replyTo, msgId, new AdminReply(false, info));
    }
  }
