protected void agentInitialize(boolean firstTime) throws Exception {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "agentInitialize(" + firstTime + ')');

    super.agentInitialize(firstTime);

    // JORAM-323: Verify if the destination is temporary.
    if ((getId().getStamp() != AgentId.JoramAdminStamp) &&
        // JMQ-142:  May be we should just verify that the agent is a special one (id < MaxWKSIdStamp).
        (getId().getStamp() != AgentId.MqttDefaultTopicStamp) &&
        (getId().getStamp() != AgentId.MqttDefault$TopicStamp)) {
      DestinationDesc desc = AdminTopic.lookupDest(getName(), getType());
      if (desc == null) {
        logger.log(BasicLevel.WARN,  "Cannot find destination in registry:" + getName());
      } else {
        if (DestinationConstants.isTemporary(desc.getType())) {
          if (logger.isLoggable(BasicLevel.DEBUG))
            logger.log(BasicLevel.DEBUG, "Set temporary field, destination will be deleted:" + getName());
          temporary = true;
        }
      }
    }

    // interceptors
    if (interceptorsProp != null) {
      interceptors = new ArrayList<MessageInterceptor>();
      InterceptorsHelper.addInterceptors(getDestinationId(), getName(), AdminCommandConstant.INTERCEPTORS, interceptorsProp, interceptors);
    }

    initialize(firstTime);

    if (getPeriod() > -1)
      task = new WakeUpTask(getId(), WakeUpNot.class, getPeriod());

    try {
      MXWrapper.registerMBean(this, getMBeanName());
    } catch (Exception exc) {
      logger.log(BasicLevel.ERROR, this + " jmx failed", exc);
    }
  }
