public void setProperties(Properties prop, boolean firstTime) throws Exception {
    if (logger.isLoggable(BasicLevel.DEBUG)) {
      logger.log(BasicLevel.DEBUG, this + ", setProperties.");
    }

    long newPeriod = -1;
    if (prop != null && prop.containsKey(DestinationConstants.WAKEUP_PERIOD)) {
      try {
        newPeriod = ConversionHelper.toLong(prop.get(DestinationConstants.WAKEUP_PERIOD));
      } catch (Exception e) {
        logger.log(BasicLevel.ERROR, this + ": error setting destination period", e);
      }
    }
    
    boolean fixedInMemory = false;
    if (prop != null && prop.containsKey(DestinationConstants.FIXED_IN_MEMORY)) 
      fixedInMemory = ConversionHelper.toBoolean(prop.get(DestinationConstants.FIXED_IN_MEMORY));
    
    if (firstTime) {
      period = newPeriod;
      fixed = fixedInMemory;
    } else {
      setPeriod(newPeriod);
      if (fixedInMemory)
        logger.log(BasicLevel.ERROR, this + ": cannot fix already created destination in memory.");
    }
    
    interceptorsProp = null;
    interceptors = null;
    if (firstTime && prop != null && prop.containsKey(AdminCommandConstant.INTERCEPTORS)) {
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG, this + ": setProperties interceptors = " + prop.get(AdminCommandConstant.INTERCEPTORS));
      //TODO: clean prop
      addInterceptor(getDestinationId(), getName(), prop);
    }
    // Interceptors are set the first time in agent initialization
    if (!firstTime) {
      if (interceptorsProp != null) {
        interceptors = new ArrayList<MessageInterceptor>();
        InterceptorsHelper.addInterceptors(getDestinationId(), getName(), AdminCommandConstant.INTERCEPTORS, interceptorsProp, interceptors);
      } else {
        interceptors = null;
      }
    }
  }
