public void setProperties(Properties properties, boolean firstTime) throws Exception {
    if (properties != null && ! properties.containsKey(DestinationConstants.WAKEUP_PERIOD)) {
      logger.log(BasicLevel.WARN,
                 "DistributionQueue.setProperties, " + DestinationConstants.WAKEUP_PERIOD + "not defined, set to 1000");
      properties.setProperty(DestinationConstants.WAKEUP_PERIOD, "1000");
    }

    super.setProperties(properties, firstTime);

    if (logger.isLoggable(BasicLevel.DEBUG)) {
      logger.log(BasicLevel.DEBUG, "DistributionQueue.setProperties prop = " + properties);
    }

    this.properties = properties;

    batchDistribution = false;
    isAsyncDistribution = false;

    if (properties != null) {
    	if (properties.containsKey(DestinationConstants.BATCH_DISTRIBUTION_OPTION)) {
    		try {
    			batchDistribution = ConversionHelper.toBoolean(properties.get(DestinationConstants.BATCH_DISTRIBUTION_OPTION));
    		} catch (MessageValueException exc) {
    			logger.log(BasicLevel.ERROR, "DistributionModule: can't parse batch option.", exc);
    		}
    	}
    	isAsyncDistribution = isAsyncDistribution(properties);
    	if (isAsyncDistribution)
    		batchDistribution = true;
    }

    if (firstTime) {
      if (properties != null) {
        distributionClassName = properties.getProperty(DestinationConstants.DISTRIBUTION_CLASS_NAME);
        properties.remove(DestinationConstants.DISTRIBUTION_CLASS_NAME);
      }
      if (distributionClassName == null) {
        throw new RequestException("Distribution class name not found: " + DestinationConstants.DISTRIBUTION_CLASS_NAME
                                   + " property must be set on queue creation.");
      }

      // Check the existence of the distribution class and the presence of a no-arg constructor.
      try {
        Class.forName(distributionClassName).getConstructor();
      } catch (Exception exc) {
        logger.log(BasicLevel.ERROR, "DistributionQueue: error with distribution class.", exc);
        throw new RequestException(exc.getMessage());
      }
    } else {
      distributionModule.setProperties(properties,firstTime);
      
    	if (distributionDaemon == null && isAsyncDistribution) {
    		// start distributionDaemon
    		distributionDaemon = new DistributionDaemon(distributionModule.getDistributionHandler(), getAgentId(), getName(), this);
    		distributionDaemon.start();
    	} else if (distributionDaemon != null && !isAsyncDistribution) {
    		// stop distributionDaemon
    		distributionDaemon.close();
    		distributionDaemon = null;
    		if (properties.containsKey(DestinationConstants.BATCH_DISTRIBUTION_OPTION)) {
      		try {
      			batchDistribution = ConversionHelper.toBoolean(properties.get(DestinationConstants.BATCH_DISTRIBUTION_OPTION));
      		} catch (MessageValueException exc) {
      			logger.log(BasicLevel.ERROR, "DistributionQueue: can't parse batch option.", exc);
      		}
      	}
    	}

      //TODO: if isAsyncDistribution change, call wakeup.
    	
    }
  }
