public void wakeUpNot(WakeUpNot not) {
    if (logger.isLoggable(BasicLevel.DEBUG) && !isAsyncDistribution) {
      logger.log(BasicLevel.DEBUG, "DistributionQueue.wakeUpNot(" + not + ')');
    }
    // Cleans outdated waiting messages
    super.wakeUpNot(not);

    // This method modifies the counters (Bug fix JORAM-232).
    setSave();

    if (distributionDaemon != null) {
      // Cleans message list using ackList from daemon.
      removeAndDeleteMessages();
    }

    for (Iterator ite = messages.iterator(); ite.hasNext();) {
      org.objectweb.joram.mom.messages.Message msg = (org.objectweb.joram.mom.messages.Message) ite.next();
      try {
        distributionModule.processMessage(msg.getFullMessage());
        nbMsgsDeliverSinceCreation++;
        ite.remove();
        if ((nbExpirations > 0 ) && msg.hasExpiration())
          nbExpirations -= 1;
        msg.delete();
      } catch (Exception exc) {
        if (logger.isLoggable(BasicLevel.DEBUG) && !isAsyncDistribution) {
          logger.log(BasicLevel.DEBUG,
                     "DistributionQueue.wakeUpNot redelivery number " + msg.getDeliveryCount() + " failed.", exc);
        } else if (logger.isLoggable(BasicLevel.DEBUG)) {
          logger.log(BasicLevel.DEBUG,
                     "DistributionQueue.wakeUpNot redelivery " + msg.getId() + " number " + msg.getDeliveryCount());
        }

        // increase the delivery count
        if (distributionDaemon == null)
          msg.incDeliveryCount();

        // If message considered as undeliverable, add it to the list of dead messages:
        if (isUndeliverable(msg)) {
          if (logger.isLoggable(BasicLevel.DEBUG)) {
            logger.log(BasicLevel.DEBUG, "Message can't be delivered, send to DMQ.");
          }
          ite.remove();
          if ((nbExpirations > 0 ) && msg.hasExpiration())
            nbExpirations -= 1;
          msg.delete();
          DMQManager dmqManager = new DMQManager(dmqId, getId());
          nbMsgsSentToDMQSinceCreation++;
          dmqManager.addDeadMessage(msg.getFullMessage(), MessageErrorConstants.UNDELIVERABLE);
          dmqManager.sendToDMQ();
          continue;
        }

        if (distributionDaemon != null) {
          synchronized (distributionDaemon) {
            // Wakeup the daemon, because the distributionDaemon can wait 
            // after a distribution exception
            distributionDaemon.notify();
          }

          if (logger.isLoggable(BasicLevel.DEBUG))
            logger.log(BasicLevel.DEBUG, "DistributionQueue.wakeUpNot distributionDaemon = " + distributionDaemon + 
                ", distributionDaemon.isEmpty() = " + distributionDaemon.isEmpty());

          // TODO (AF): verify with JMS and AMQP bridge tests
          //          if (!distributionDaemon.isEmpty()) {
          //            // needless to push an other message 
          //            // because the distributionDaemon can't distribute message now.
          //            break;
          //          } else {
          if (logger.isLoggable(BasicLevel.DEBUG))
            logger.log(BasicLevel.DEBUG, "DistributionQueue.wakeUpNot " + msg.getId());

          // Bug fix (JORAM-200): Avoid to duplicate a message already known by the daemon (either in
          // the distributeQueue or the ackedQueue).
          if (! distributionDaemon.isHandling(msg.getId())) {
            distributionDaemon.push(msg.getFullMessage());
          } else {
            // The current message is already in daemon queue, no need to parse the end of list.
            break;
          }
          //          }
        }

        if (!batchDistribution) {
          break;
        }
      }
    }
  }
