public int factorCheck(Map clusters,
                         int pendingMessages,
                         int pendingRequests,
                         int cload,
                         int pload) {
    int forwarded = 0;

    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, 
                 ">> LoadingFactor.factorCheck " + this + "\nclusters = " + clusters);

    evalRateOfFlow(pendingMessages, pendingRequests, cload, pload);
    if ((lastROFSent < 0) ||
        ((lastROFSent < 1) && (rateOfFlow > 1)) ||
        ((lastROFSent > 1) && (rateOfFlow < 1)) ||
        ((lastROFSent == 1) && (rateOfFlow != 1))) {
      dispatchLifeCycle(clusters);
      lastROFSent = rateOfFlow;
    }


    if (status == Status.WAIT && 
        statusTime < System.currentTimeMillis())
      status = Status.RUN;

    if (pendingMessages == 0)
      producerStatus = ProducerStatus.PRODUCER_NO_ACTIVITY;
    else if (pendingMessages > producThreshold)
      producerStatus = ProducerStatus.PRODUCER_HIGH_ACTIVITY;
    else
      producerStatus = ProducerStatus.PRODUCER_NORMAL_ACTIVITY;

    if (pendingRequests == 0)
      consumerStatus = ConsumerStatus.CONSUMER_NO_ACTIVITY;
    else if ((pendingRequests > consumThreshold) || (pload == 0))
      consumerStatus = ConsumerStatus.CONSUMER_HIGH_ACTIVITY;
    else 
      consumerStatus = ConsumerStatus.CONSUMER_NORMAL_ACTIVITY;

    if ((status != Status.WAIT) &&
        ((consumerStatus == ConsumerStatus.CONSUMER_HIGH_ACTIVITY) ||
         (producerStatus == ProducerStatus.PRODUCER_HIGH_ACTIVITY))) {
      forwarded = dispatchAndSendTo(clusters, pendingMessages, pendingRequests, cload, pload);
      status = Status.WAIT;
      statusTime = System.currentTimeMillis() + validityPeriod;
    }

    if (autoEvalThreshold) {
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG, 
                   "LoadingFactor.factorCheck updateThreshold - before rateOfFlow=" + rateOfFlow +
                   ", producThreshold=" + producThreshold + ", consumThreshold=" + consumThreshold );

      int deltaProd;
      int deltaCons;

      if (rateOfFlow < 1) {
        deltaProd = (int) ((pendingMessages - producThreshold) * rateOfFlow);
        deltaCons = (int) ((pendingRequests - consumThreshold) * rateOfFlow);
      } else {
        deltaProd = (int) ((pendingMessages - producThreshold) / rateOfFlow);
        deltaCons = (int) ((pendingRequests - consumThreshold) / rateOfFlow);
      }

      if (pendingMessages > 0) {
        if (deltaProd < producThreshold)
          producThreshold = producThreshold + deltaProd;
        else
          producThreshold = deltaProd;
      }

      if (pendingRequests > 0) {
        if (deltaCons < consumThreshold)
          consumThreshold = consumThreshold + deltaCons;
        else
          consumThreshold = deltaCons;
      }

      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG, 
                   "LoadingFactor.factorCheck updateThreshol - after rateOfFlow=" + rateOfFlow +
                   ", producThreshold=" + producThreshold + ", consumThreshold=" + consumThreshold );
    }
  
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, 
                 "<< LoadingFactor.factorCheck " + this);

    return forwarded;
  }
