protected final boolean addMessage(Message message, boolean throwsExceptionOnFullDest) throws AccessException {
    if (nbMaxMsg > -1 && nbMaxMsg <= (messages.size() + deliveryTable.size() + getDelayedMessageCount())) {
      if (throwsExceptionOnFullDest && isSyncExceptionOnFullDest()) {
        if (logger.isLoggable(BasicLevel.INFO))
          logger.log(BasicLevel.INFO, "addMessage " + message.getId() + " throws Exception: The queue \"" + getName() + "\" is full (syncExceptionOnFullDest).");
        throw new AccessException("The queue \"" + getName() + "\" is full.");
      }
      
      DMQManager dmqManager = new DMQManager(dmqId, getId());
      nbMsgsSentToDMQSinceCreation++;
      // JORAM-326: Saves the queue to avoid bad counter value at restart.
      if (strictCounters) setSave();
      dmqManager.addDeadMessage(message.getFullMessage(), MessageErrorConstants.QUEUE_FULL);
      dmqManager.sendToDMQ();
      return false;
    }

    if (messages.isEmpty()) {
      samePriorities = true;
      priority = message.getPriority();
      if (message.hasExpiration())
        nbExpirations = 1;
      else
        nbExpirations = 0;
    } else {
      if (samePriorities && priority != message.getPriority())
        samePriorities = false;
      if (message.hasExpiration())
        nbExpirations += 1;
    }

    if (samePriorities) {
      // Constant priorities: no need to insert the message according to its priority.
      if (receiving) {
        // Message being received: adding it at the end of the queue.
        messages.add(message);
      } else {
        // Denying or recovery: adding the message according to its original arrival order.
        int i = 0;
        for (Iterator ite = messages.iterator(); ite.hasNext();) {
          if (((Message) ite.next()).order > message.order) break;
          i++;
        }
        messages.add(i, message);
      }
    } else {
      // Non constant priorities: inserting the message according to its priority.
      Message currentMsg;
      int currentP;
      long currentO;
      int i = 0;
      for (Iterator ite = messages.iterator(); ite.hasNext();) {
        currentMsg = (Message) ite.next();
        currentP = currentMsg.getPriority();
        currentO = currentMsg.order;

        if (! receiving && currentP == message.getPriority()) {
          // Message denied or recovered, priorities are equal: inserting the
          // message according to its original arrival order.
          if (currentO > message.order) break;
        } else if (currentP < message.getPriority()) {
          // Current priority lower than the message to store: inserting it.
          break;
        }
        i++;
      }
      messages.add(i, message);
    }
    return true;
  }
