protected void denyRequest(AgentId from, DenyRequest not) {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "Queue.DenyRequest(" + from + ',' + not + ')');
    
    Enumeration ids = not.getIds();

    String msgId;
    Message message;
    QueueDelivery queueDelivery;
    DMQManager dmqManager = null;

    if (! ids.hasMoreElements()) {
      // If the deny request is empty, the denying is a contextual one: it
      // requests the denying of all the messages consumed by the denier in
      // the denying context:
      Iterator<Entry<String, QueueDelivery>> iterator = deliveryTable.iterator();
      while (iterator.hasNext()) {
        // Browsing the delivered messages:
        Entry<String, QueueDelivery> entry = iterator.next();

        msgId = entry.getKey();
        queueDelivery = entry.getValue();
        message = queueDelivery.getMessage();
        
        if (logger.isLoggable(BasicLevel.DEBUG))
          logger.log(BasicLevel.DEBUG, " -> deny msg " + msgId + "(consId = " + queueDelivery.getConsumerId() + ')');

        // If the current message has been consumed by the denier in the same
        // context: denying it.
        if (queueDelivery.getConsumerId().equals(from)
            && queueDelivery.getContextId() == not.getClientContext()) {
          
          nbMsgsDeniedSinceCreation += 1;
          // JORAM-326: Saves the queue to avoid bad counter value at restart.
          if (strictCounters) setSave();

          iterator.remove();
          if (not.isRedelivered())
            message.setRedelivered();
          else
            message.setDeliveryCount(message.getDeliveryCount()-1);
          
          if (getRedeliveryDelay() > 0 && (message.isRedelivered() || message.getDeliveryCount() > 0)) {
            message.setDeliveryTime(System.currentTimeMillis() + (getRedeliveryDelay() *1000L));
            if (logger.isLoggable(BasicLevel.DEBUG))
              logger.log(BasicLevel.DEBUG, "Queue.DenyRequest: setDeliveryTime " + message.getDeliveryTime());
          }

          // If message considered as undeliverable, adding
          // it to the list of dead messages:
          if (isUndeliverable(message)) {
            message.delete();
            if (dmqManager == null)
              dmqManager = new DMQManager(dmqId, getId());
            nbMsgsSentToDMQSinceCreation++;
            // JORAM-326: Already done above.
            dmqManager.addDeadMessage(message.getFullMessage(), MessageErrorConstants.UNDELIVERABLE);
          } else {
            try {
              // Else, putting the message back into the deliverables list:
              storeMessageHeader(message, false);
            } catch (AccessException e) { /* never happens */ }
          }

          if (logger.isLoggable(BasicLevel.DEBUG))
            logger.log(BasicLevel.DEBUG, "Message " + msgId + " denied.");
          if (logmsg.isLoggable(BasicLevel.INFO))
            logmsg.log(BasicLevel.INFO, getName() + ": denies message " + msgId);
        }
      }
    }

    // For a non empty request, browsing the denied messages:
    for (ids = not.getIds(); ids.hasMoreElements();) {
      msgId = (String) ids.nextElement();
      queueDelivery = deliveryTable.remove(msgId);

      // Message may have already been denied. For example, a proxy may deny
      // a message twice, first when detecting a connection failure - and
      // in that case it sends a contextual denying -, then when receiving 
      // the message from the queue - and in that case it also sends an
      // individual denying.
      if (queueDelivery == null) {
        if (logger.isLoggable(BasicLevel.WARN))
          logger.log(BasicLevel.WARN, " -> already denied message " + msgId);
        if (logmsg.isLoggable(BasicLevel.WARN))
          logmsg.log(BasicLevel.WARN, getName() + ": already denied message " + msgId);
        break;
      }
      
      message = queueDelivery.getMessage();
      
      nbMsgsDeniedSinceCreation += 1;

      if (not.isRedelivered())
        message.setRedelivered();
      else
        message.setDeliveryCount(message.getDeliveryCount()-1);
      
      if (getRedeliveryDelay() > 0 && (message.isRedelivered() || message.getDeliveryCount() > 0)) {
        message.setDeliveryTime(System.currentTimeMillis() + (getRedeliveryDelay() *1000L));
        if (logger.isLoggable(BasicLevel.DEBUG))
          logger.log(BasicLevel.DEBUG, "Queue.DenyRequest: setDeliveryTime " + message.getDeliveryTime());
      }

      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG, " -> deny " + msgId);
      if (logmsg.isLoggable(BasicLevel.INFO))
        logmsg.log(BasicLevel.INFO, getName() + ": denies message " + msgId);

      // state change, so save.
      setSave();

      // If message considered as undeliverable, adding it
      // to the list of dead messages:
      if (isUndeliverable(message)) {
        message.delete();
        if (dmqManager == null)
          dmqManager = new DMQManager(dmqId, getId());
        nbMsgsSentToDMQSinceCreation++;
        dmqManager.addDeadMessage(message.getFullMessage(), MessageErrorConstants.UNDELIVERABLE);
      } else {
        try {
          if (message.getDeliveryTime() > 0) {
            if (logger.isLoggable(BasicLevel.DEBUG))
              logger.log(BasicLevel.DEBUG, "Queue.DenyRequest: scheduleDeliveryTimeMessage " + message.getId() + ", reDeliveryDelay = " + getRedeliveryDelay());
            addDeliveryTimeMessage(message, not.getClientContext(), false, true);
          } else {
            // Else, putting the message back into the deliverables list:
            storeMessageHeader(message, false);
          }
        } catch (AccessException e) {/* never happens */}
      }

      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG, "Message " + msgId + " denied.");
    }
    // Sending the dead messages to the DMQ, if needed:
    if (dmqManager != null)
      dmqManager.sendToDMQ();

    // Launching a delivery sequence:
    deliverMessages(0);
  }
