protected void doClientMessages(AgentId from, ClientMessages not, boolean throwsExceptionOnFullDest) throws AccessException {
    receiving = true;
    ClientMessages cm = null;
    
    // interceptors
    if (interceptorsAvailable()) {
    	// new client message
    	cm = new ClientMessages(not.getClientContext(), not.getRequestId());
    	cm.setAsyncSend(not.getAsyncSend());
    	cm.setDMQId(not.getDMQId());
    	
    	for (Iterator msgs = not.getMessages().iterator(); msgs.hasNext();) {
    		org.objectweb.joram.shared.messages.Message message = (org.objectweb.joram.shared.messages.Message) msgs.next();
    		// set the destination name
    		message.setProperty("JoramDestinationName", getName());
        
        // JORAM-323: If it is a temporary destination there is no need to persistent messages.
        if (temporary) {
          message.persistent = false;
        }

    		// interceptors process
    		org.objectweb.joram.shared.messages.Message m = processInterceptors(message);
    		if (m == null) {
    			// send message to the DMQ
    			DMQManager dmqManager = new DMQManager(dmqId, getId());
    			nbMsgsSentToDMQSinceCreation++;
          // JORAM-326: Saves the queue to avoid bad counter value at restart.
          if (strictCounters) setSave();
    			dmqManager.addDeadMessage(message, MessageErrorConstants.INTERCEPTORS);
    			dmqManager.sendToDMQ();
    			// TODO (AF): This code makes no sense! It creates a MOM message for nothing.
    			new Message(message).releaseFullMessage();
    		} else {
    			// add message to the client message 
    			cm.addMessage(m);
    		}
    	}
    	// test client message size.
    	if (cm.getMessageCount() == 0) {
    		receiving = false;
    		return;
    	}
    } else {
    	cm = not;
    }
    
    // pre process the client message
    ClientMessages clientMsgs = preProcess(from, cm);
   
    long currentTime = System.currentTimeMillis();
    long deliveryTime = currentTime;
    if (deliveryDelay > 0)
      deliveryTime += deliveryDelay;
    
    if (clientMsgs != null) {
      Message msg;
      // Storing each received message:
      for (Iterator msgs = clientMsgs.getMessages().iterator(); msgs.hasNext();) {

        org.objectweb.joram.shared.messages.Message sharedMsg = (org.objectweb.joram.shared.messages.Message) msgs.next();
        msg = new Message(sharedMsg);
        msg.order = arrivalState.getAndIncrementArrivalCount(msg.isPersistent());

        if (logger.isLoggable(BasicLevel.DEBUG))
          logger.log(BasicLevel.DEBUG, "Queue.doClientMessages() -> " + msg.getId() + ',' + msg.order);

        if ((deliveryTime > currentTime) && (deliveryTime > sharedMsg.deliveryTime))
          sharedMsg.deliveryTime = deliveryTime;
        
        if (sharedMsg.deliveryTime > currentTime) {
          addDeliveryTimeMessage(msg, not.getClientContext(), throwsExceptionOnFullDest, false);
        } else {
          storeMessage(msg, throwsExceptionOnFullDest);
          
          // ArrivalState is saved outside the Queue agent
          // if (msg.isPersistent()) setSave();
        }
      }
    }

    // Launching a delivery sequence:
    deliverMessages(0);

    if (clientMsgs != null)
      postProcess(clientMsgs);

    receiving = false;
  }
