protected void initialize(boolean firstTime) throws Exception {
    cleanWaitingRequest(System.currentTimeMillis());

    receiving = false;

    String arrivalStateTxName = ARRIVAL_STATE_PREFIX + getId().toString();
    String deliveryTableTxName = DELIVERY_TABLE_PREFIX + getId().toString();
    if (firstTime) {
      arrivalState = new QueueArrivalState(arrivalStateTxName);
      deliveryTable = new QueueDeliveryTable(deliveryTableTxName);
      messages = new Vector<Message>();
      return;
    } else {
      arrivalState = QueueArrivalState.load(arrivalStateTxName);
      deliveryTable = QueueDeliveryTable.load(deliveryTableTxName);
    }

    // Retrieving the persisted messages, if any.
    messages = Message.loadAll(getMsgTxPrefix().toString(), Integer.MAX_VALUE);
    long currentTime = System.currentTimeMillis();
    if (logmsg.isLoggable(BasicLevel.INFO))
      logmsg.log(BasicLevel.INFO, getName() + ", start retrieves messages  " + currentTime);

    for (int index=0; index < messages.size(); ) {
      Message persistedMsg = messages.get(index);
      if (logmsg.isLoggable(BasicLevel.INFO))
        logmsg.log(BasicLevel.INFO, getName() + ": retrieves message " + persistedMsg.getId() + " -> " + persistedMsg.getDeliveryTime());

      QueueDelivery queueDelivery = deliveryTable.get(persistedMsg.getId());
      if (queueDelivery == null) {
        if (persistedMsg.getDeliveryTime() > currentTime) {
          if (logger.isLoggable(BasicLevel.DEBUG))
            logger.log(BasicLevel.DEBUG, getName() + ": schedule delayed message " + persistedMsg.getId());
          delayedMessageCount += 1;
          // TODO (AF): Be careful, this way of handling timed messages is not scalable. We should maintain an
          // ordered list of timed messages, and set a timer for the first timeout (see Scheduler class).
          AgentServer.getTimer().schedule(new QueueDeliveryTimeTask(getId(), persistedMsg, false), new Date(persistedMsg.getDeliveryTime()));
          // Remove message from the list of messages to deliver.
          messages.remove(index);
          // Do not increment index.
          continue;
        } else {
          if (logger.isLoggable(BasicLevel.DEBUG))
            logger.log(BasicLevel.DEBUG,
                       getName() + ": Adds message " + persistedMsg.getId() + " in the list of messages to deliver.");
        }
      } else {
        queueDelivery.setMessage(persistedMsg);
        if (isLocal(queueDelivery.getConsumerId())) {
          // The delivery is aborted.
          if (logger.isLoggable(BasicLevel.DEBUG))
            logger.log(BasicLevel.DEBUG, " -> deny " + persistedMsg.getId());
          deliveryTable.remove(persistedMsg.getId());
        } else {
          // The delivery is always active, remove message from the list of messages to deliver.
          messages.remove(index);
          // Do not increment index.
          continue;
        }
      }

      index += 1;
    }

    currentTime = System.currentTimeMillis();
    if (logmsg.isLoggable(BasicLevel.INFO))
      logmsg.log(BasicLevel.INFO, getName() + ", end retrieves messages  " + currentTime);
  }
