protected void processMessages(AgentId from, ClientMessages not) {
    List messages = not.getMessages();
    AgentId subscriber;
    boolean local;
    String selector;
    List deliverables;
    Message message;

    nbMsgsReceiveSinceCreation += messages.size();
    
    // interceptors process
    if (interceptorsAvailable()) {
    	DMQManager dmqManager = null;
    	List newMessages = new ArrayList();
    	Iterator it = messages.iterator();
    	while (it.hasNext()) {
    		Message m = (Message) it.next();
    		// set the destination name to the message
    		m.setProperty("JoramDestinationName", getName());
    		message = processInterceptors(m);
    		if (message != null) {
    			newMessages.add(message);
    		} else {
    			//send message to the DMQ
    			if (dmqManager == null)
    				dmqManager = new DMQManager(dmqId, getId());
          nbMsgsSentToDMQSinceCreation++;
          dmqManager.addDeadMessage(m, MessageErrorConstants.INTERCEPTORS);
    		}
    	}
    	
    	if (dmqManager != null)
    		dmqManager.sendToDMQ();
    	
    	if (!newMessages.isEmpty()) {
    		messages = newMessages;
    	} else {
    		return;
    	}
    }
    
    setNoSave();
    boolean persistent = false;

    for (Iterator subs = subscribers.iterator(); subs.hasNext();) {
      // Browsing the subscribers.
      subscriber = (AgentId) subs.next();
      local = (subscriber.getTo() == AgentServer.getServerId());
      selector = (String) selectors.get(subscriber);

      if (selector == null || selector.equals("")) {
        // Current subscriber does not filter messages: all messages
        // will be sent.
        if (! local) {
          // Subscriber not local, or no other sending occurred locally:
          // directly sending the messages.
          deliverables = messages;
          persistent = true;
        } else if (! alreadySentLocally) {
          deliverables = messages;
          alreadySentLocally = true;
        }
        // A local sending already occurred: cloning the messages.
        else {
          deliverables = new Vector();
          for (Iterator msgs = messages.iterator(); msgs.hasNext();)
            deliverables.add(((Message) msgs.next()).clone());
        }
      } else {
        // Current subscriber filters messages; sending the matching messages.
        deliverables = new Vector();
        for (int i = 0; i < messages.size(); i++) {
          message = (Message) messages.get(i);

          if (Selector.matches(message, selector)) {

            // Subscriber not local, or no other sending occurred locally:
            // directly sending the message.
            if (! local) {
              deliverables.add(message);
              persistent = true;
            } else if (! alreadySentLocally) {
              deliverables.add(message);
              alreadySentLocally = true;
            }
            // A local sending already occurred: cloning the message.
            else 
              deliverables.add(message.clone());
          }
        }  
      }
      // There are messages to send.
      if (! deliverables.isEmpty()) {
        TopicMsgsReply topicMsgsReply = new TopicMsgsReply(deliverables);
        topicMsgsReply.setPersistent(persistent);
        
        // Set the callback in any cases: local and remote
        // Remotely, the callback provides flow control.
        // Locally, the callback provides flow control and
        // reliability for persistent messages.
        not.passCallback(topicMsgsReply);

        setDmq(topicMsgsReply);
        forward(subscriber, topicMsgsReply);
        nbMsgsDeliverSinceCreation = nbMsgsDeliverSinceCreation + deliverables.size();
      }
    }
  }
