private static CountDownCallback createCallback(final AbstractJmsRequest req, final ConnectionContext ctx) {
    return new CountDownCallback(new Callback() {
      
      public void failed(List<Throwable> errors) {
        if (! directNotification) {
          // Errors are handled by UserAgent
          return;
        }
        
        Throwable error = errors.get(0);
        if (error instanceof MomException) {
          MomException exc = (MomException) error;
          ctx.pushReply(new MomExceptionReply(req.getRequestId(), exc));
        } else if (error instanceof UnknownAgentException) {
          UnknownAgentException uae = (UnknownAgentException) error;
          DestinationException exc = new DestinationException("Destination " + uae.getUnknownAgentId() + " does not exist.");
          ctx.pushReply(new MomExceptionReply(req.getRequestId(), exc));
        } else {
          if (logger.isLoggable(BasicLevel.WARN))
            logger.log(BasicLevel.WARN, errors.toString(), error);
        }
      }
      
      public void done() {
        // Be careful, this code could be executed in another thread that the engine so
        // the pushReply method must be synchronized.
        ctx.pushReply(new ServerReply(req.getRequestId()));
      }
    });
  }
