private void doFwd(AgentId from, TopicMsgsReply rep) {
    // Browsing the target subscriptions:
    TopicSubscription tSub = (TopicSubscription) topicsTable.get(from);
    if (tSub == null || tSub.isEmpty()) return;

    String subName;
    ClientSubscription sub;
    long currentTime = System.currentTimeMillis();
    // AF: TODO we should parse each message for each subscription
    // see ClientSubscription.browseNewMessages
    List<Message> messages = new ArrayList<Message>();
    for (Iterator msgs = rep.getMessages().iterator(); msgs.hasNext();) {
      org.objectweb.joram.shared.messages.Message sharedMsg = 
          (org.objectweb.joram.shared.messages.Message) msgs.next();
      Message message = new Message(sharedMsg);
      if (sharedMsg.deliveryTime > currentTime) {
        boolean isDurable = false;
        for (Iterator subNames = tSub.getNames(); subNames.hasNext();) {
          subName = (String) subNames.next();
          sub = (ClientSubscription) subsTable.get(subName);
          isDurable |= sub.getDurable();
          sub.scheduleDeliveryTimeMessage(message);
        }
        // Setting the arrival order of the messages
        // message.order = arrivalState.getAndIncrementArrivalCount();
        if (isDurable)
          persistDeliveryTimeMessage(message);
      } else {
        // Setting the arrival order of the messages
        message.order = arrivalState.getAndIncrementArrivalCount();
        messages.add(message);
      }
    }

    for (Iterator names = tSub.getNames(); names.hasNext();) {
      subName = (String) names.next();
      sub = (ClientSubscription) subsTable.get(subName);
      if (sub == null) continue;

      // Browsing the delivered messages.
      sub.browseNewMessages(messages);
    }
    
    // Save message if it is delivered to a durable subscription.
    for (Iterator msgs = messages.iterator(); msgs.hasNext();) {
      Message message = (Message) msgs.next();

      if (message.durableAcksCounter > 0) {
        if (logger.isLoggable(BasicLevel.DEBUG))
          logger.log(BasicLevel.DEBUG, " -> save message " + message);
        // TODO (AF): The message saving does it need the proxy saving ?
        if (message.isPersistent()) { 
          arrivalState.setModified();
          
          // Persisting the message.
          setMsgTxName(message);
          message.save();
          message.releaseFullMessage();
        }
      }
    }

    for (Iterator names = tSub.getNames(); names.hasNext();) {
      subName = (String) names.next();
      sub = (ClientSubscription) subsTable.get(subName);
      if (sub == null) continue;

      // If the subscription is active, launching a delivery sequence.
      if (sub.getActive() > 0) {
        ConsumerMessages consM = sub.deliver();

        if (consM != null) {
          try {
            int ctxId = sub.getContextId();
            SharedCtx sharedCtx = sharedSubs.get(subName);
            if (sharedCtx != null) {
              if(logger.isLoggable(BasicLevel.DEBUG))
                logger.log(BasicLevel.DEBUG, "Subscription "+ subName + ", sharedCtx = " + sharedCtx);
              int i = 0;
              do {
                // if shared, used the next contextId 
                Iterator<Entry<Integer, Integer>> it = sharedCtx.entrySet().iterator();
                Entry<Integer, Integer> entry = it.next();
                ClientContext ctx = (ClientContext) contexts.get(new Integer(entry.getKey()));
                if (ctx.getActivated()) {
                  ctxId = ctx.getId();
                  if(logger.isLoggable(BasicLevel.DEBUG))
                    logger.log(BasicLevel.DEBUG, "Subscription "+ subName + ", ctxId = " + ctxId);
                  sharedCtx.get(ctxId);//update LRU
                  break;
                }
                i++;
              } while (sharedCtx.size() < i);
            }
            setCtx(ctxId);
            if (activeCtx.getActivated())
              doReply(consM);
            else
              activeCtx.addPendingDelivery(consM);
          } catch (StateException pE) {
            // The context is lost: nothing to do.
          }
        }
      } else if(logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG, "Subscription " + sub + " is not active");
    }
    
    messagesTable.checkConsumedMemory();
  }
