private void doReact(AdminCommandRequest request, AgentId replyTo, String requestMsgId) {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "doReact(" + request + ", " + replyTo + ", " + requestMsgId + ')');
    Properties prop = null;
    Properties replyProp = null;
    try {
      switch (request.getCommand()) {
      case AdminCommandConstant.CMD_ADD_INTERCEPTORS:
        prop = request.getProp();

        // add interceptors out
        if (prop.containsKey(AdminCommandConstant.INTERCEPTORS_OUT)) {
          if (interceptorsPropOUT == null)
            interceptorsPropOUT = new ArrayList<Properties>();
          if (interceptorsOUT == null)
            interceptorsOUT = new ArrayList<MessageInterceptor>();
          addInterceptor(getAgentId(), getName(), AdminCommandConstant.INTERCEPTORS_OUT, interceptorsOUT, prop, interceptorsPropOUT);
        }
        // add interceptors in
        if (prop.containsKey(AdminCommandConstant.INTERCEPTORS_IN)) {
          if (interceptorsPropIN == null)
            interceptorsPropIN = new ArrayList<Properties>();
          if (interceptorsIN == null)
            interceptorsIN = new ArrayList<MessageInterceptor>();
          addInterceptor(getAgentId(), getName(), AdminCommandConstant.INTERCEPTORS_IN, interceptorsIN, prop, interceptorsPropIN);
        }
        break;

      case AdminCommandConstant.CMD_REMOVE_INTERCEPTORS:
        prop = request.getProp();
				removeInterceptor(AdminCommandConstant.INTERCEPTORS_OUT, interceptorsOUT, prop.getProperty(AdminCommandConstant.INTERCEPTORS_OUT), interceptorsPropOUT);
				removeInterceptor(AdminCommandConstant.INTERCEPTORS_IN, interceptorsIN, prop.getProperty(AdminCommandConstant.INTERCEPTORS_IN), interceptorsPropIN);
        break;

      case AdminCommandConstant.CMD_GET_INTERCEPTORS:
        replyProp = new Properties();
        if (interceptorsIN == null) {
          replyProp.put(AdminCommandConstant.INTERCEPTORS_IN, "");
        } else {
				  replyProp.put(AdminCommandConstant.INTERCEPTORS_IN, InterceptorsHelper.getListInterceptors(interceptorsIN));
        }
        if (interceptorsOUT == null) {
          replyProp.put(AdminCommandConstant.INTERCEPTORS_OUT, "");
        } else {
				  replyProp.put(AdminCommandConstant.INTERCEPTORS_OUT, InterceptorsHelper.getListInterceptors(interceptorsOUT));
        }
        break;

      case AdminCommandConstant.CMD_REPLACE_INTERCEPTORS:
        prop = request.getProp();
				if (interceptorsIN == null && prop.containsKey(AdminCommandConstant.INTERCEPTORS_IN_NEW))
          throw new Exception("interceptorsIN == null.");
				if (interceptorsOUT == null && prop.containsKey(AdminCommandConstant.INTERCEPTORS_OUT_NEW))
          throw new Exception("interceptorsOUT == null.");

        if (prop.containsKey(AdminCommandConstant.INTERCEPTORS_IN_OLD)) {
          // replace IN interceptor
				  replaceInterceptorIN(
				      getAgentId(),
				      getName(),
				      prop);
        }

        if (prop.containsKey(AdminCommandConstant.INTERCEPTORS_OUT_OLD)) {
          // replace OUT interceptor
				  replaceInterceptorOUT(
				      getAgentId(),
				      getName(),
				      prop);
        }
        break;

      case AdminCommandConstant.CMD_SET_REDELIVERY_DELAY:
        prop = request.getProp();
        if (prop != null && prop.containsKey(AdminCommandConstant.REDELIVERY_DELAY)) {
          int reDeliveryDelay;
          try {
            reDeliveryDelay = ConversionHelper.toInt(prop.get(AdminCommandConstant.REDELIVERY_DELAY));
            setRedeliveryDelay(reDeliveryDelay);
          } catch (MessageValueException e) {
            if (logger.isLoggable(BasicLevel.WARN))
              logger.log(BasicLevel.WARN, "EXCEPTION:: AdminCommandConstant handling [" + getName() + "] set the redelivery delay", e);
          }
        } else {
          throw new Exception("redeliveryDelay undefined.");
        }
        break;
        
      default:
        throw new Exception("Bad command : \"" + request.getCommand() + "\"");
      }
      // reply
			replyToTopic(new AdminCommandReply(true, AdminCommandConstant.commandNames[request.getCommand()] + " done.", replyProp), replyTo, requestMsgId, requestMsgId);
    } catch (Exception exc) {
      if (logger.isLoggable(BasicLevel.WARN))
        logger.log(BasicLevel.WARN, "", exc);
			replyToTopic(new AdminReply(-1, exc.getMessage()), replyTo, requestMsgId, requestMsgId);
    }
  }
