private void doReact(ConsumerSubRequest req) throws StateException, RequestException {
    AgentId topicId = AgentId.fromString(req.getTarget());
    String subName = req.getSubName();
    String clientId = req.getClientID();
    boolean shared = req.isShared();

    if (topicId == null)
      throw new RequestException("Cannot subscribe to an undefined topic (null).");

    if (subName == null)
      throw new RequestException("Unauthorized null subscription name.");

    boolean newTopic = !topicsTable.containsKey(topicId);
    boolean newSub = !subsTable.containsKey(subName);
    
    if (!newSub && !shared && !req.getClientID().equals(subsClientIDs.get(subName))) {
      if (logger.isLoggable(BasicLevel.WARN))
        logger.log(BasicLevel.WARN, "throw Exception : unshared durable subscription \"" + subName + "\" must use \"" 
            + subsClientIDs.get(subName) + "\" client identifier instead of " + clientId);
      throw new RequestException("unshared durable subscription \"" + subName + "\" must use \"" 
          + subsClientIDs.get(subName) + "\" client identifier instead of " + clientId);
    }
    
    if (clientId != null)
      subsClientIDs.put(subName, clientId);
    
    TopicSubscription tSub;
    ClientSubscription cSub;

    // true if a SubscribeRequest has been sent to the topic.
    boolean sent = false;

    if (newTopic) { // New topic...
      tSub = new TopicSubscription();
      topicsTable.put(topicId, tSub);
    } else { // Known topic...
      tSub = (TopicSubscription) topicsTable.get(topicId);
    }

    if (newSub) { // New subscription...
      // state change, so save.
      setSave();

      cSub = new ClientSubscription(getId(),
          activeCtxId,
          req.getRequestId(),
          req.getDurable(),
          topicId,
          req.getSubName(),
          req.getSelector(),
          req.getNoLocal(),
          dmqId,
          threshold,
          nbMaxMsg,
          messagesTable,
          clientId);

      try {
        cSub.initMessageIds();
      } catch (Exception e) {
        throw new RequestException(e.toString());
      }
      
      cSub.setProxyAgent(this);
      modifiedSubscription(cSub);

      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG, "Subscription " + subName + " created.");

      if (shared) {
        sharedSubs.put(subName, new SharedCtx(activeCtxId, req.getRequestId()));
        if (logger.isLoggable(BasicLevel.DEBUG))
          logger.log(BasicLevel.DEBUG, "Subscription sharedSubs = " + sharedSubs);
      }
      
      subsTable.put(subName, cSub);
      
      try {
        MXWrapper.registerMBean(cSub, getSubMBeanName(subName));
      } catch (Exception e) {
        if (logger.isLoggable(BasicLevel.WARN))
          logger.log(BasicLevel.WARN, "  - Could not register ClientSubscriptionMbean", e);
      }
      tSub.putSubscription(subName, req.getSelector());
      sent = updateSubscriptionToTopic(topicId, activeCtxId, req.getRequestId(), req.isAsyncSubscription());
    } else { // Existing durable subscription...
      cSub = (ClientSubscription) subsTable.get(subName);
      boolean newShared = false;
      if (shared) {
        SharedCtx sharedCtx = sharedSubs.get(subName);
        if (sharedCtx == null) {
          // the server restart, and the sharedSubs Tab is transient.
          // So set the SharedCtx.
          sharedCtx = new SharedCtx(activeCtxId, req.getRequestId());
          sharedSubs.put(subName, sharedCtx);
        }
        
        if (!sharedCtx.containsKey(activeCtxId)) {
          sharedCtx.put(activeCtxId, req.getRequestId());
          newShared = true;
          if (logger.isLoggable(BasicLevel.DEBUG))
            logger.log(BasicLevel.DEBUG, "Existing durable subscription add new SharedCtx : " + sharedCtx);
        }
      }
      
      if (cSub.getActive() > 0 && !newShared)
        throw new StateException("The durable subscription " + subName + " has already been activated.");

      // Updated topic: updating the subscription to the previous topic.
      boolean updatedTopic = !topicId.equals(cSub.getTopicId());
      if (updatedTopic) {
        TopicSubscription oldTSub =
          (TopicSubscription) topicsTable.get(cSub.getTopicId());
        oldTSub.removeSubscription(subName);
        updateSubscriptionToTopic(cSub.getTopicId(), -1, -1, req.isAsyncSubscription());
      }

      // Updated selector?
      boolean updatedSelector;
      if (req.getSelector() == null && cSub.getSelector() != null)
        updatedSelector = true;
      else if (req.getSelector() != null && cSub.getSelector() == null)
        updatedSelector = true;
      else if (req.getSelector() == null && cSub.getSelector() == null)
        updatedSelector = false;
      else
        updatedSelector = !req.getSelector().equals(cSub.getSelector());

      // Reactivating the subscription.
      cSub.reactivate(activeCtxId, req.getRequestId(), topicId, req.getSelector(), req.getNoLocal());

      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG, "Subscription " + subName + " reactivated.");

      // Updated subscription: updating subscription to topic.
      if (updatedTopic || updatedSelector) {
        tSub.putSubscription(subName, req.getSelector());
        sent = updateSubscriptionToTopic(topicId, activeCtxId, req.getRequestId(), req.isAsyncSubscription());
      }
    }
    // Activating the subscription.
    activeCtx.addSubName(subName);

    // Acknowledging the request, if needed.
    if (!sent)
      sendNot(getId(), new SyncReply(activeCtxId, new ServerReply(req)));
    
    // Forward client subscription (should be ignored if topicId isn't an ElasticTopic)
    Channel.sendTo(topicId,new ClientSubscriptionNot(subName));
  }
