private void doReact(int key, CommitRequest req, CallbackNotification callbackNotification) {
    // The commit may involve some local agents
    int asyncReplyCount = 0;

    Enumeration pms = req.getProducerMessages();
    if (pms != null) {
      while (pms.hasMoreElements()) {
        // process interceptors
        ProducerMessages pm = processInterceptors(key, (ProducerMessages) pms.nextElement());
        if (pm == null)
          continue;
        AgentId destId = AgentId.fromString(pm.getTarget());
        ClientMessages not = new ClientMessages(key, 
            req.getRequestId(), pm.getMessages());
        setDmq(not);
        if (destId.getTo() == getId().getTo()) {
          // local sending
          not.setPersistent(false);
          if (req.getAsyncSend()) {
            not.setAsyncSend(true);
          } else if (callbackNotification.hasCallback()) {
            callbackNotification.passCallback(not);
          } else {
            asyncReplyCount++;
          }
        }
        sendNot(destId, not);
      }
    }

    Enumeration acks = req.getAckRequests();
    if (acks != null) {
      while (acks.hasMoreElements()) {
        SessAckRequest sar = (SessAckRequest) acks.nextElement();
        if (sar.getQueueMode()) {
          AgentId qId = AgentId.fromString(sar.getTarget());
          Vector ids = sar.getIds();
          AcknowledgeRequest not = new AcknowledgeRequest(activeCtxId, req
              .getRequestId(), ids);
          if (qId.getTo() == getId().getTo()) {
            // local sending
            not.setPersistent(false);
            // No reply to wait for
          }

          sendNot(qId, not);
        } else {
          String subName = sar.getTarget();
          ClientSubscription sub = (ClientSubscription) subsTable.get(subName);
          if (sub != null) {
            sub.acknowledge(sar.getIds().iterator());
            // TODO (AF): is it needed to save the proxy ?
            // if (sub.getDurable())
            // Assumes that there is nothing to save in the UserAgent.
            //setSave();
          }
        }
      }
    }

    if (!req.getAsyncSend()) {
      if (! callbackNotification.hasCallback()) {
        if (asyncReplyCount == 0) {
          sendNot(getId(), new SendReplyNot(key, req
            .getRequestId()));
        } else {
          // we need to wait for the replies
          // from the local agents
          // before replying to the client.
          activeCtx.addMultiReplyContext(req.getRequestId(), asyncReplyCount);
        }
      }
      // else the callback handles the ack
    }
    // else the client doesn't expect any ack
  }
