public ProxyMessage receive() throws Exception {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "IOControl.receive()");
    
    try {
      while (true) {
        byte[] bytes = receiveQueue.take();
        if (bytes.length == 0) {
          if (logger.isLoggable(BasicLevel.DEBUG))
            logger.log(BasicLevel.DEBUG, "IOControl: The reader offer a closing marker, so closed.");
          throw new IOException("Connection closed.");
        }
        ByteArrayInputStream bais = new ByteArrayInputStream(bytes);
        long messageId = StreamUtil.readLongFrom(bais);
        long ackId = StreamUtil.readLongFrom(bais);
        AbstractJmsRequest obj = (AbstractJmsRequest) AbstractJmsMessage.read(bais);
        receivedCount++;

        if (messageId > inputCounter) {
          inputCounter = messageId;
          if (!noAckedQueue) { 
            synchronized (this) {
              if (unackCounter < windowSize) {
                unackCounter++;
              } else {
                send(new ProxyMessage(-1, messageId, null));
              }
            }
          }
          return new ProxyMessage(messageId, ackId, obj);
        }
        // TODO (AF): May be we have either to ack anew the message, or to close the connection.
        logger.log(BasicLevel.WARN, "IOControl.receive: already received message: " + messageId + " -> " + obj);
      }
    } catch (InterruptedException exc) {
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG, exc);
      close();
      throw new IllegalStateException("Interrupted receive: Connection closed.");
    } catch (IOException exc) {
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG, "IOControl.receive", exc);
      close();
      throw exc;
    }
  }
