protected void doFtp(FtpMessage msg) {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "doFtp(" + msg + ')');
    
    String urlName = null;
    long crc = -1;
    boolean ack = false;
    
    try {
      urlName = msg.getStringProperty(SharedObj.url);
      crc = msg.getLongProperty(SharedObj.crc);
      ack = msg.getBooleanProperty(SharedObj.ack);

      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG, "doFtp urlName = " + urlName + ", crc = " + crc + ", ack = " + ack);
      
      URL url = new URL(urlName);
      String urlFileName = url.getFile();
      String fileName = null;
      String type = null;
      String remotePath = null;
      
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG,
                   "--- doFtp : url host = " + url.getHost() + ", urlFileName = " + urlFileName);

      if (urlFileName.indexOf(";") > 1) {
        fileName = urlFileName.substring(
          urlFileName.lastIndexOf('/')+1,urlFileName.indexOf(";"));
        type = urlFileName.substring(
          urlFileName.lastIndexOf("=")+1,urlFileName.length());
      } else {
        fileName = urlFileName.substring(
          urlFileName.lastIndexOf('/')+1,urlFileName.length());
      }
      
      if (urlFileName.indexOf('/') < urlFileName.lastIndexOf('/'))
        remotePath = urlFileName.substring(
          urlFileName.indexOf('/')+1,urlFileName.lastIndexOf('/'));
      
      
      String userInfo = url.getUserInfo();
      String remoteUser = user;
      String remotePass = pass;
      if (userInfo != null) {
        remoteUser = userInfo.substring(0,userInfo.indexOf(':'));
        remotePass = userInfo.substring(userInfo.indexOf(':')+1,userInfo.length());
      }
      String protocol = url.getProtocol();
      int port = url.getPort();

      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG, 
                   "doFtp : remoteUser = " + remoteUser + 
                   ", protocol = " + protocol + 
                   ", port = " + port);

      String file = transfer.getFile(protocol,
                                     InetAddress.getByName(url.getHost()).getHostName(),
                                     port,
                                     remoteUser,
                                     remotePass,
                                     remotePath, 
                                     path, 
                                     fileName,
                                     fileName,
                                     type,
                                     crc);
      
      file = file.replace('\\','/');
      if (!file.startsWith("/")) file = "/" + file;
      
      URI uri = new URI("file", null, file, null, null);
      uri = uri.normalize();

      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG, "--- doFtp : uri = " + uri);
      
      FtpMessage clone = (FtpMessage) msg.clone();
      clone.clearProperties();
      for (Enumeration e = msg.getPropertyNames(); e.hasMoreElements(); ) {
        String key = (String) e.nextElement();
        clone.setObjectProperty(key, msg.getObjectProperty(key));
      }
      clone.setStringProperty("url", uri.toString());
      
      Channel.sendTo(destId, new FtpNot(clientContext, 
                                        requestId,
                                        clone.getSharedMessage()));
      
    } catch (Exception exc) {
      if (logger.isLoggable(BasicLevel.ERROR))
        logger.log(BasicLevel.ERROR, "--- doFtp", exc);

      DMQManager dmqManager = new DMQManager(dmqId, destId);
      dmqManager.addDeadMessage(msg.getSharedMessage(), MessageErrorConstants.UNEXPECTED_ERROR);
      dmqManager.sendToDMQ();
    }
  }
