public void start(Properties properties, ReliableTransmitter transmitter) {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "Start JMSAcquisition.");
    
    this.transmitter = transmitter;

    destName = properties.getProperty(DESTINATION_NAME_PROP);
    if (destName == null) {
      throw new IllegalArgumentException("Missing Destination JNDI name.");
    }

    long updatePeriod = 5000L;
    try {
      if (properties.containsKey(UPDATE_PERIOD_PROP)) {
        updatePeriod = Long.parseLong(properties.getProperty(UPDATE_PERIOD_PROP));
      }
    } catch (NumberFormatException nfe) {
      logger.log(BasicLevel.ERROR, "Property " + UPDATE_PERIOD_PROP
          + "could not be parsed properly, use default value.", nfe);
    }

    connectionNames = null;
    if (properties.containsKey(ROUTING_PROP)) {
      connectionNames = JMSConnectionService.convertToList(properties.getProperty(ROUTING_PROP));
    }

    durableSubscriptionName = null;
    if (properties.containsKey(DURABLE_SUBSCRIPTION_PROP)) {
      durableSubscriptionName = properties.getProperty(DURABLE_SUBSCRIPTION_PROP);
    }

    selector = null;
    if (properties.containsKey(SELECTOR_PROP)) {
      selector = properties.getProperty(SELECTOR_PROP);
    }

    if (connectionUpdater == null) {
      connectionUpdater = new ConnectionUpdater(updatePeriod);
    }
    connectionUpdater.addUpdateListener(this);
  }
