public synchronized void updateConnections() {
    List<JMSModule> connections = JMSConnectionService.getInstance().getConnections();

    for (JMSModule connection : connections) {
      if (!listeners.containsKey(connection.getName())) {
        if (connectionNames == null || connectionNames.contains(connection.getName())) {
          if (logger.isLoggable(BasicLevel.DEBUG)) {
            logger.log(BasicLevel.DEBUG,
                       "Creating a new consumer for connection: " + connection.getName(), new Exception());
          }
          try {
            dest = (Destination) connection.retrieveJndiObject(destName);
  
            Session session = connection.getCnx().createSession(true, Session.AUTO_ACKNOWLEDGE);
            MessageConsumer consumer;
            if (dest instanceof Queue) {
              consumer = session.createConsumer(dest, selector);
            } else {
              if (durableSubscriptionName != null) {
                consumer = session.createDurableSubscriber((Topic) dest, durableSubscriptionName, selector, false);
              } else {
                consumer = session.createConsumer(dest, selector);
              }
            }
            if (logger.isLoggable(BasicLevel.DEBUG)) {
              logger.log(BasicLevel.DEBUG, "setConsumer: consumer=" + consumer);
            }
  
            JmsListener listener = new JmsListener(session, connection);
            consumer.setMessageListener(listener);
            connection.getCnx().start();
            connection.addExceptionListener(listener);
            listeners.put(connection.getName(), listener);
          } catch (Exception e) {
            logger.log(BasicLevel.ERROR,
                "Error while starting consumer on connection: " + connection.getCnxFactName(), e);
          }
        }
      }
    }
  }
