protected void doConnect() throws JMSException {
    if (logger.isLoggable(BasicLevel.DEBUG)) {
      logger.log(BasicLevel.DEBUG, "doConnect()");
    }

    if (userName != null && password != null) {
      cnx = cnxFact.createConnection(userName, password);
    } else {
      cnx = cnxFact.createConnection();
    }
    
    try {
      if (clientID == null) {
        // Be careful, durable subscriptions need a ClientID !!
        logger.log(BasicLevel.WARN,
                   "JMSModule.doConnect: Connection " + name + " does not define a ClientID");
//        cnx.setClientID("joramBridge_" + name + "_" + AgentServer.getServerId());
      } else {
        cnx.setClientID(clientID);
      }

      cnx.setExceptionListener(this);

      if (logger.isLoggable(BasicLevel.DEBUG)) {
        logger.log(BasicLevel.DEBUG, "doConnect: cnx=" + cnx);
      }
    } catch (JMSException exc) {
      if (logger.isLoggable(BasicLevel.WARN)) {
        logger.log(BasicLevel.WARN, "Connection " + name + " failed", exc);
      }
      if (cnx != null) {
        try {
          cnx.close();
        } catch (JMSException exc2) {
          if (logger.isLoggable(BasicLevel.WARN)) {
            logger.log(BasicLevel.WARN, "Can't close failed connection", exc2);
          }
        } finally {
          cnx = null;
        }
      }
      throw exc;
    }
  }
