public void onMessage(javax.jms.Message jmsMessage) {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "JMSBridgeModule.onMessage(" + jmsMessage + ')');
    try {
      Xid xid = null;
      synchronized (lock) {
        try {
          if (isXA) {
            xid = new XidImpl(new byte[0], 1, (agentId.toString() + System.currentTimeMillis()).getBytes());
            if (logger.isLoggable(BasicLevel.DEBUG))
              logger.log(BasicLevel.DEBUG, "JMSBridgeModule.onMessage: xid=" + xid);

            try {
              consumerRes.start(xid, XAResource.TMNOFLAGS);
            } catch (XAException e) {
              if (logger.isLoggable(BasicLevel.WARN))
                logger.log(BasicLevel.WARN, "JMSBridgeModule.onMessage: XA can't start resource : " + consumerRes, e);
            }
          }
          org.objectweb.joram.client.jms.Message clientMessage = 
            org.objectweb.joram.client.jms.Message.convertJMSMessage(jmsMessage);
          org.objectweb.joram.client.jms.Message.prepareJMSMessage(clientMessage);
          Message momMessage = clientMessage.getMomMsg();
          if (isXA) {
            try {
              consumerRes.end(xid, XAResource.TMSUCCESS);
              if (logger.isLoggable(BasicLevel.DEBUG))
                logger.log(BasicLevel.DEBUG, "JMSBridgeModule.onMessage: XA end " + consumerRes);
            } catch (XAException e) {
              if (logger.isLoggable(BasicLevel.DEBUG))
                logger.log(BasicLevel.DEBUG, "JMSBridgeModule.onMessage: XA resource end(...) failed: " + consumerRes, e);
              throw new JMSException("onMessage: XA resource end(...) failed: " + consumerRes + " :: " + e.getMessage());
            }
            try {
              int ret = consumerRes.prepare(xid);
              if (ret == XAResource.XA_OK)
                consumerRes.commit(xid, false);
              if (logger.isLoggable(BasicLevel.DEBUG))
                logger.log(BasicLevel.DEBUG, "JMSBridgeModule.onMessage: XA commit " + consumerRes);
            } catch (XAException e) {
              if (logger.isLoggable(BasicLevel.DEBUG))
                logger.log(BasicLevel.DEBUG, "JMSBridgeModule.onMessage: XA resource rollback(" + xid + ")", e);
              try {
                consumerRes.rollback(xid);
                if (logger.isLoggable(BasicLevel.DEBUG))
                  logger.log(BasicLevel.DEBUG, "JMSBridgeModule.onMessage: XA rollback " + consumerRes);
              } catch (XAException e1) { }
              throw new JMSException("onMessage: XA resource rollback(" + xid + ") failed: " + 
                  consumerRes + " :: " + e.getMessage());
            }

          } else {
            if (logger.isLoggable(BasicLevel.DEBUG))
              logger.log(BasicLevel.DEBUG, "JMSBridgeModule.onMessage: commit.");
            consumerSession.commit();
          }
          if (logger.isLoggable(BasicLevel.DEBUG))
            logger.log(BasicLevel.DEBUG, "JMSBridgeModule.onMessage: send JMSBridgeDeliveryNot.");
          Channel.sendTo(agentId, new JMSBridgeDeliveryNot(momMessage));

        } catch (MessageFormatException conversionExc) {
          // Conversion error: denying the message.
          if (isXA) {
            try {
              consumerRes.rollback(xid);
              if (logger.isLoggable(BasicLevel.DEBUG))
                logger.log(BasicLevel.DEBUG, "JMSBridgeModule.onMessage: XA rollback " + consumerRes);
            } catch (XAException e1) { }
          } else {
            consumerSession.rollback();
            if (logger.isLoggable(BasicLevel.DEBUG))
              logger.log(BasicLevel.DEBUG, "JMSBridgeModule.onMessage: rollback.");
          }
        }
      }
    } catch (JMSException exc) {
      // Commit or rollback failed: nothing to do.
      if (logger.isLoggable(BasicLevel.WARN))
        logger.log(BasicLevel.WARN, "JMSBridgeModule.onMessage: ", exc);
    }
  }
