public void send(org.objectweb.joram.shared.messages.Message message)
  throws JMSException {
    if (! usable)
      throw new IllegalStateException(notUsableMessage);

    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "send(" + message + ')');

    synchronized (lock) {
      try {
        Xid xid = null;
        if (isXA) {
          xid = new XidImpl(new byte[0], 1, message.id.getBytes());
          if (logger.isLoggable(BasicLevel.DEBUG))
            logger.log(BasicLevel.DEBUG, "send: xid=" + xid);

          try {
            producerRes.start(xid, XAResource.TMNOFLAGS);
          } catch (XAException e) {
            if (logger.isLoggable(BasicLevel.WARN))
              logger.log(BasicLevel.WARN, "Exception:: XA can't start resource : " + producerRes, e);
          }
        }
        producer.send(org.objectweb.joram.client.jms.Message.wrapMomMessage(null, message));
        if (logger.isLoggable(BasicLevel.DEBUG))
          logger.log(BasicLevel.DEBUG, "send: " + producer + " send.");
        acknowledge(message);
        if (logger.isLoggable(BasicLevel.DEBUG))
          logger.log(BasicLevel.DEBUG, "send: acknowledge.");
        if (isXA) {
          try {
            producerRes.end(xid, XAResource.TMSUCCESS);
            if (logger.isLoggable(BasicLevel.DEBUG))
              logger.log(BasicLevel.DEBUG, "send: XA end " + producerRes);
          } catch (XAException e) {
            throw new JMSException("resource end(...) failed: " + producerRes + " :: " + e.getMessage());
          }
          try {
            int ret = producerRes.prepare(xid);
            if (ret == XAResource.XA_OK)
              producerRes.commit(xid, false);
            if (logger.isLoggable(BasicLevel.DEBUG))
              logger.log(BasicLevel.DEBUG, "send: XA commit " + producerRes);
          } catch (XAException e) {
            try {
              producerRes.rollback(xid);
              if (logger.isLoggable(BasicLevel.DEBUG))
                logger.log(BasicLevel.DEBUG, "send: XA rollback " + producerRes);
            } catch (XAException e1) { }
            throw new JMSException("XA resource rollback(" + xid + ") failed: " + 
                producerRes + " :: " + e.getMessage());
          }
        }
      } catch (javax.jms.JMSException exc) {
        // Connection failure? Keeps the message for later delivery.
        qout.add(message);
        // Try to reconnect?
        onException(exc);
        if (logger.isLoggable(BasicLevel.WARN))
          logger.log(BasicLevel.WARN, "send: Exception qout=" + qout);
      }
    }
  }
