public void init(Properties properties) {
    destName = properties.getProperty(DestinationConstants.DESTINATION_NAME_PROP);
    if (destName == null) {
      throw new IllegalArgumentException("Missing Destination JNDI name.");
    }
    if (properties.containsKey(DestinationConstants.REST_HOST_PROP)) {
      hostName = properties.getProperty(DestinationConstants.REST_HOST_PROP);
    }

    if (properties.containsKey(DestinationConstants.REST_PORT_PROP)) {
      try {
        port = Integer.parseInt(properties.getProperty(DestinationConstants.REST_PORT_PROP));
      } catch (NumberFormatException nfe) {
        logger.log(BasicLevel.ERROR, "Property " + DestinationConstants.REST_PORT_PROP
            + " could not be parsed properly, use default value.", nfe);
      }
    }
    if (properties.containsKey(DestinationConstants.REST_USERNAME_PROP)) {
      userName = properties.getProperty(DestinationConstants.REST_USERNAME_PROP);
    }
    if (properties.containsKey(DestinationConstants.REST_PASSWORD_PROP)) {
      password = properties.getProperty(DestinationConstants.REST_PASSWORD_PROP);
    }
    if (properties.containsKey(DestinationConstants.TIMEOUT_PROP)) {
      try {
        timeout = Long.parseLong(properties.getProperty(DestinationConstants.TIMEOUT_PROP));
      } catch (NumberFormatException exc) { }
    }
    if (properties.containsKey(DestinationConstants.NB_MAX_MSG_PROP)) {
      try {
        nbMaxMsg = Integer.parseInt(properties.getProperty(DestinationConstants.NB_MAX_MSG_PROP));
      } catch (NumberFormatException exc) { }
    }
    
    // init client and target
    if (client == null) {
      ClientConfig config = new ClientConfig();
      client = ClientBuilder.newClient(config);
      target = client.target(UriBuilder.fromUri("http://" + hostName + ":" + port + "/joram/").build());
    }
    if (logger.isLoggable(BasicLevel.DEBUG)) {
      logger.log(BasicLevel.DEBUG, "RESTAcquisition.init Target : " + target.getUri());
    }
    // create the consumer
    if (uriCreateConsumer != null) {
      client.target(uriCloseConsumer).request().accept(MediaType.TEXT_PLAIN).delete();
      uriCreateConsumer = null;
    }
    if (properties.containsKey(DestinationConstants.MEDIA_TYPE_JSON_PROP)) {
      mediaTypeJson = Boolean.parseBoolean(properties.getProperty(DestinationConstants.MEDIA_TYPE_JSON_PROP));
    }
    createConsumer();
  }
