@Override
  public void retrieve(ReliableTransmitter transmitter) throws Exception {
    
    if (uriConsume == null)
      return;
    
    try {
      ArrayList<Message> messages = new ArrayList<>();
      while (messages.size() < nbMaxMsg) {
        //timeout = 0 => NoWait
        Builder builder = null;
        Message message = null;
        if (!mediaTypeJson) {
          //TEXT
          builder = client.target(uriConsume)
              .queryParam("timeout", timeout)
              .request().accept(MediaType.TEXT_PLAIN);
          Response response = builder.get();
          String msg = response.readEntity(String.class);
          if (200 != response.getStatus() || msg == null || msg.isEmpty())
            break;
          message = new Message();
          message.type = Message.TEXT;
          message.setText(msg);
          
        } else {
          //JSON
          builder = client.target(uriConsume)
              .queryParam("timeout", timeout)
              .request().accept(MediaType.APPLICATION_JSON);

          Response response = builder.get();

          //        if (logger.isLoggable(BasicLevel.DEBUG))
          //          logger.log(BasicLevel.DEBUG, "RESTAcquisition.retrieve response = " + response);
          String json = response.readEntity(String.class);

          if (200 != response.getStatus() || json == null || json.isEmpty() || "null".equals(json))
            break;

          try {
            Gson gson = new GsonBuilder().create();
            HashMap<String, Object> msg = gson.fromJson(json, HashMap.class);
            if (msg == null) {
              String text = gson.fromJson(json, String.class);
              if (text != null) {
                message = new Message();
                message.type = Message.TEXT;
                message.setText(text);
              }
            } else {

              if (logger.isLoggable(BasicLevel.DEBUG))
                logger.log(BasicLevel.DEBUG, "RESTAcquisition.retrieve msg = " + msg);

              message = new Message();
              //get Properties
              Map jmsProperties = (Map) msg.get("properties");
              if (jmsProperties != null && jmsProperties.size() > 0) {
                Set<Map.Entry> entrySet = jmsProperties.entrySet();
                for (Map.Entry entry : entrySet) {
                  String key = (String) entry.getKey();
                  ArrayList value = (ArrayList) entry.getValue();
                  String propType = (String) value.get(1);
                  Object propValue = null;
                  switch (propType) {
                  case "java.lang.Boolean":
                    propValue = Boolean.parseBoolean((String)value.get(0));
                    break;
                  case "java.lang.Byte":
                    propValue = Byte.parseByte((String)value.get(0));
                    break;
                  case "java.lang.Short":
                    propValue = Short.parseShort((String)value.get(0));
                    break;
                  case "java.lang.Integer":
                    propValue = Integer.parseInt((String)value.get(0));
                    break;
                  case "java.lang.Long":
                    propValue = Long.parseLong((String)value.get(0));
                    break;
                  case "java.lang.Float":
                    propValue = Float.parseFloat((String)value.get(0));
                    break;
                  case "java.lang.Double":
                    propValue = Double.parseDouble((String)value.get(0));
                    break;
                  case "java.lang.String":
                    propValue = (String)value.get(0);
                    break;

                  default:
                    if (logger.isLoggable(BasicLevel.WARN))
                      logger.log(BasicLevel.WARN, "RESTAcquisition.retrieve property type not supported: " + propType);
                    break;
                  }
                  if (key != null && propValue != null)
                    message.setProperty(key, propValue);
                }
              }

              //Get Header
              Map jmsHeader = (Map) msg.get("header");
              if (jmsHeader != null && jmsHeader.size() > 0) {
                setMessageHeader(jmsHeader, message);
              }

              //Get body
              String type = (String) msg.get("type");
              message.jmsType = type;
              switch (type) {
              case "TextMessage": {
                String jmsBody =  (String) msg.get("body");
                message.type = Message.TEXT;
                message.setText(jmsBody);
              } break;

              case "MapMessage": {
                Map jsonBody =  (Map) msg.get("body");
                Map map = getMapMessage(jsonBody);
                message.type = Message.MAP;
                try {
                  ByteArrayOutputStream baos = new ByteArrayOutputStream();
                  ObjectOutputStream oos = new ObjectOutputStream(baos);
                  oos.writeObject(map);
                  oos.flush();
                  message.setBody(baos.toByteArray());
                  oos.close();
                  baos.close();
                } catch (IOException exc) {
                  MessageFormatException jExc =
                    new MessageFormatException("The message body could not be serialized.");
                  jExc.setLinkedException(exc);
                  throw jExc;
                }
              } break;

              case "BytesMessage": {
                ArrayList jmsBody =  (ArrayList) msg.get("body");
                message.type = Message.BYTES;
                byte[] bytes = new byte[((ArrayList) jmsBody).size()];
                for (int i = 0; i < ((ArrayList) jmsBody).size(); i++) {
                  Object value = ((ArrayList) jmsBody).get(i);
                  bytes[i] = ((Number) value).byteValue();
                }
                message.body = bytes;
              } break;

              default:
                logger.log(BasicLevel.ERROR, "TODO::: RESTAcquisition.retrieve type = " + type + " not supported.");
                break;
              }
            }
          } catch (Exception e) {
            if (logger.isLoggable(BasicLevel.WARN))
              logger.log(BasicLevel.WARN, "RESTAcquisition.retrieve json = " + json, e);
            message = null;
          }
        }
        
        if (message != null)
          messages.add(message);
      }

      if (messages.size() > 0)
        transmitter.transmit(messages, persistent);
    } catch (Exception e) {
      if (logger.isLoggable(BasicLevel.WARN))
        logger.log(BasicLevel.WARN, "RESTAcquisition.retrieve", e);
    }
  }
