private void createProducer(String userName, String password) throws Exception {
    if (uriCloseProducer != null)
      return;

    URI base = UriBuilder.fromUri("http://" + hostName + ":" + port + "/joram/").build();
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG,
          "RestDistribution.createProducer(), use base URI " + base);

    // Initializes URI
    uriSendNextMsg = null;

    // Initializes Rest client and target
    try {
      // It seems that there is no exceptions thrown by these methods.
      client = ClientBuilder.newClient(new ClientConfig() // TODO (AF): Fix these properties with configuration values
          .property(ClientProperties.CONNECT_TIMEOUT, connectTimeout)
          .property(ClientProperties.READ_TIMEOUT, readTimeout));
    } catch (Exception exc) {
      if (logger.isLoggable(BasicLevel.ERROR))
        logger.log(BasicLevel.ERROR,
            "RestDistribution.createProducer(): cannot initialize Rest client", exc);
      throw exc;
    }
    
    // Get the destination
    Response response = null;
    try {
      response = client.target(base).path("jndi").path(destName)
          .request().accept(MediaType.TEXT_PLAIN).head();
    } catch (Exception exc) {
      if (logger.isLoggable(BasicLevel.ERROR))
        logger.log(BasicLevel.ERROR,
            "RestDistribution.createProducer(): cannot get destination " + destName, exc);
      throw exc;
    }
    
    if (response.getStatus() == 201) {
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG,
            "RestDistribution.createProducer(): get destination -> " + response.getStatusInfo());
    } else {
      if (logger.isLoggable(BasicLevel.ERROR))
        logger.log(BasicLevel.ERROR,
            "RestDistribution.createProducer(): cannot get destination " + destName + " -> " + response.getStatusInfo());
      throw new Exception("Cannot get destination " + destName);
    }

    try {
      URI uriCreateProducer = response.getLink("create-producer").getUri();
      // TODO (AF): to remove (use FormParam alternate URI)
      uriCreateProducer = new URI(uriCreateProducer.toString() + "-fp");
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG,
            "RestDistribution.createProducer(): create-producer = " + uriCreateProducer);

      // TODO (AF): We should fix name and client-id to be unique.
      WebTarget target = client.target(uriCreateProducer);
      if (prodName != null)  target = target.queryParam("name", prodName);
      if (clientId != null)  target = target.queryParam("client-id", clientId);
      if (userName != null) target = target.queryParam("user", userName);
      if (password != null) target = target.queryParam("password", password);
      if (idleTimeout != null)  target = target.queryParam("idle-timeout", idleTimeout);

      response  = target.request().accept(MediaType.TEXT_PLAIN).post(Entity.entity(null, MediaType.APPLICATION_FORM_URLENCODED));
    } catch (Exception exc) {
      if (logger.isLoggable(BasicLevel.ERROR))
        logger.log(BasicLevel.ERROR,
            "RestDistribution.createProducer(): cannot create producer", exc);
      throw exc;
    }
      
    if (response.getStatus() == 201) {
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG,
            "RestDistribution.createProducer(): create producer -> " + response.getStatusInfo());

      uriCloseProducer = response.getLink("close-context").getUri();
      uriSendNextMsg = response.getLink("send-next-message").getUri();
    } else {
      if (logger.isLoggable(BasicLevel.ERROR))
        logger.log(BasicLevel.ERROR,
            "RestDistribution.createProducer(): cannot create producer -> " + response.getStatusInfo());
      throw new Exception("Cannot create producer");
    }
  }
