private void sendNextMessage(Message message) throws Exception {
    Response response = null;

    if (uriSendNextMsg == null) {
      logger.log(BasicLevel.ERROR, 
          "RestDistribution.sendNextMessage(): URI not initialized.");
      throw new Exception("URI not initialized");
    }
    
    if (message.properties == null && message.type == Message.TEXT) {
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG,
            "RestDistribution.sendNextMessage: Send simple message");

      // If the message contains only text and defines no properties, we can send an
      // optimized message without using JSON.
      
      WebTarget target = client.target(uriSendNextMsg)
          .queryParam("delivery-mode", (message.persistent?Message.PERSISTENT:Message.NON_PERSISTENT))
          .queryParam("priority", message.priority);
      if (message.deliveryTime > 0)
        target = target.queryParam("delivery-time", message.deliveryTime);
      if (message.expiration > 0)
        target = target.queryParam("time-to-live", (message.expiration - System.currentTimeMillis()));
      if (message.correlationId != null && !message.correlationId.isEmpty())
        target = target.queryParam("correlation-id", message.correlationId);
      
      response =  target.request()
          .accept(MediaType.TEXT_PLAIN).post(Entity.entity(message.getText(), MediaType.TEXT_PLAIN));
      
      if (response.getStatus() != 200) {
        if (logger.isLoggable(BasicLevel.ERROR))
          logger.log(BasicLevel.ERROR,
              "RestDistribution.sendNextMessage: cannot send message -> " + response.getStatus());
        throw new Exception("Cannot send message: " + response.getStatus());
      } else {
        if (logger.isLoggable(BasicLevel.DEBUG))
          logger.log(BasicLevel.DEBUG,
              "RestDistribution.sendNextMessage: message sent -> " + response.getStatus());
      }
    } else {
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG,
            "RestDistribution.sendNextMessage: Send JSON message");
      
      // Use JSON to encode the message
      HashMap<String, Object> maps = new HashMap<>();
      
      // Encode message body
      if (message.type == Message.TEXT) {
        maps.put("type", TextMessage);
        maps.put("body", message.getText());
      } else if (message.type == Message.BYTES) {
        maps.put("type", BytesMessage);
        maps.put("body", message.body);
      } else if (message.type == Message.MAP) {
        maps.put("type", MapMessage);
        maps.put("body", getMapMessageToJsonBodyMap(message));
      } else {
        logger.log(BasicLevel.ERROR,
            "RestDistribution.sendNextMessage: type " + message.type + " not yet supported.");
        throw new Exception("Message type " + message.type + " not yet supported.");
      }
      
      // Transform JMS message properties
      if (message.properties != null) {
        HashMap<String, Object> props = new HashMap<>();
        Enumeration e = message.properties.keys();
        while (e.hasMoreElements()) {
          String key = (String) e.nextElement();
          Object value = message.properties.get(key);
          props.put(key, new String[]{value.toString(), value.getClass().getName()});
        }
        maps.put("properties", props);
      }

      // message header
      HashMap<String, Object> header = new HashMap<>();
      if (message.correlationId != null)
        header.put("CorrelationID", new String[]{message.correlationId, String.class.getName()});
      if (message.priority > 0)
        header.put("Priority", new String[]{""+message.priority, Integer.class.getName()});
      // TODO (AF): not correct?
//      header.put("Type", message.jmsType);
          
      //TODO (AF): other headers prop
      maps.put("header", header);

      Gson gson = new GsonBuilder().create();
      String json = gson.toJson(maps);

      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG, "RESTDistribution.sendMessage: json " + json);
      
      // Send next message
      response = client.target(uriSendNextMsg).request().accept(MediaType.TEXT_PLAIN).post( 
          Entity.entity(json, MediaType.APPLICATION_JSON));
      
      if (response.getStatus() != 200) {
        if (logger.isLoggable(BasicLevel.ERROR))
          logger.log(BasicLevel.ERROR,
              "RestDistribution.sendNextMessage: cannot send message -> " + response.getStatus());
        throw new Exception("Cannot send message: " + response.getStatus());
      } else {
        if (logger.isLoggable(BasicLevel.DEBUG))
          logger.log(BasicLevel.DEBUG,
              "RestDistribution.sendNextMessage: message sent -> " + response.getStatus());
      }
    }
    
    uriSendNextMsg = response.getLink("send-next-message").getUri();
  }
