private void createConsumer() throws Exception {
    if (uriCloseConsumer != null)
      return;

    URI base = UriBuilder.fromUri("http://" + hostName + ":" + port + "/joram/").build();
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG,
          "RestAcquisitionAsync.createConsumer(), use base URI " + base);
        
    // Initializes URI
    uriAcknowledgeMsg = null;
    uriReceiveNextMsg = null;
    
    // Initializes Rest client and target
    try {
      // It seems that there is no exceptions thrown by these methods.
      client = ClientBuilder.newClient(
          new ClientConfig() // TODO (AF): Fix these properties with configuration values
          .property(ClientProperties.CONNECT_TIMEOUT, connectTimeout)
          .property(ClientProperties.READ_TIMEOUT, Integer.parseInt(timeout) + readTimeout));
    } catch (Exception exc) {
      if (logger.isLoggable(BasicLevel.ERROR))
        logger.log(BasicLevel.ERROR,
            "RestAcquisitionAsync.createConsumer(): cannot initialize Rest client", exc);
      throw exc;
    }
    
    // Get the destination
    Response response = null;
    try {
      response = client.target(base).path("jndi").path(destName).request().accept(MediaType.TEXT_PLAIN).head();
    } catch (Exception exc) {
      if (logger.isLoggable(BasicLevel.ERROR))
        logger.log(BasicLevel.ERROR,
            "RestAcquisitionAsync.createConsumer(): cannot get destination " + destName, exc);
      throw exc;
    }
    
    if (response.getStatus() == 201) {
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG,
            "RestAcquisitionAsync.createConsumer(): get destination -> " + response.getStatusInfo());
    } else {
      if (logger.isLoggable(BasicLevel.ERROR))
        logger.log(BasicLevel.ERROR,
            "RestAcquisitionAsync.createConsumer(): cannot get destination " + destName + " -> " + response.getStatusInfo());
      throw new Exception("Cannot get destination " + destName);
    }
    
    try {
      // Get URI to create a consumer in ClientAcknowledge mode.
      URI uriCreateConsumer = response.getLink("create-consumer-client-ack").getUri();
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG, "RestAcquisitionAsync.createConsumer(): create-consumer = " + uriCreateConsumer);

      // TODO (AF): We should fix name and client-id to be unique.
      WebTarget target = client.target(uriCreateConsumer);
      if (consName != null)  target = target.queryParam("name", consName);
      if (clientId != null)  target = target.queryParam("client-id", clientId);
      // Normally each consumer resource need to be explicitly closed, this parameter allows to set the idle time
      // in seconds in which the consumer context will be closed if idle.
      if (idleTimeout != null)  target = target.queryParam("idle-timeout", idleTimeout);
      if (userName != null) target = target.queryParam("user", userName);
      if (password != null) target = target.queryParam("password", password);

      // TODO (AF): to remove (use FormParam alternate URI)
//      response = target.request().accept(MediaType.TEXT_PLAIN).post(Entity.entity(null, MediaType.APPLICATION_FORM_URLENCODED));
      response = target.request().accept(MediaType.TEXT_PLAIN).post(null);
    } catch (Exception exc) {
      if (logger.isLoggable(BasicLevel.ERROR))
        logger.log(BasicLevel.ERROR,
            "RestAcquisitionAsync.createConsumer(): cannot create consumer", exc);
      throw exc;
    }

    if (response.getStatus() == 201) {
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG,
            "RestAcquisitionAsync.createConsumer(): create consumer -> " + response.getStatusInfo());

      uriCloseConsumer = response.getLink("close-context").getUri();
      uriAcknowledgeMsg = null;
      uriReceiveNextMsg = response.getLink("receive-next-message").getUri();
    } else {
      if (logger.isLoggable(BasicLevel.ERROR))
        logger.log(BasicLevel.ERROR,
            "RestAcquisitionAsync.createConsumer(): cannot create consumer -> " + response.getStatusInfo());
      throw new Exception("Cannot create consumer");
    }
  }
