private Message createJSonMessage(HashMap<String, Object> map) throws Exception {
    Message msg = new Message();

    // Get JMS header
    setJMSMessageHeader(msg, (Map) map.get("header"));

    // Get JMS properties
    setJMSProperties(msg, (Map) map.get("properties"));

    if (msg.id == null) {
      if (logger.isLoggable(BasicLevel.WARN))
        logger.log(BasicLevel.WARN,
            "RESTAcquisitionAsync.createJSonMessage: message unique identifier not set");
      // TODO (AF): Should set a unique message identifier
      msg.id = uriReceiveNextMsg.getPath();
    }
    
    // Get message body
    String type = (String) map.get("type");
    Object body = map.get("body");
    if (body == null ) {
      if (logger.isLoggable(BasicLevel.ERROR))
        logger.log(BasicLevel.ERROR,
            "RESTAcquisitionAsync.createJSonMessage: no body definition for the message");
      throw new Exception("Cannot convert message");
    }
    
    switch (type) {
    case "TextMessage": {
      msg.type = Message.TEXT;
      if (body instanceof String) {
        try {
          msg.setText((String) body);
          return msg;
        } catch (Exception exc) {
          if (logger.isLoggable(BasicLevel.ERROR))
            logger.log(BasicLevel.ERROR,
                "RESTAcquisitionAsync.createJSonMessage: error setting message body", exc);
          throw new Exception("Cannot convert message", exc);
        }
      } else {
        if (logger.isLoggable(BasicLevel.ERROR))
          logger.log(BasicLevel.ERROR,
              "RESTAcquisitionAsync.createJSonMessage: body of TextMessage should not be " + body.getClass());
        throw new Exception("Cannot convert message");
      }
    }
    case "MapMessage": {
      if (body instanceof Map) {
        msg.type = Message.MAP;
        try {
          ByteArrayOutputStream baos = new ByteArrayOutputStream();
          ObjectOutputStream oos = new ObjectOutputStream(baos);
          oos.writeObject(getMapMessage((Map) body));
          oos.flush();
          msg.setBody(baos.toByteArray());
          oos.close();
          baos.close();
          return msg;
        } catch (Exception exc) {
          if (logger.isLoggable(BasicLevel.ERROR))
            logger.log(BasicLevel.ERROR,
                "RESTAcquisitionAsync.createJSonMessage: error serializing message body", exc);
          throw new Exception("Cannot convert message", exc);
        }
      } else {
        if (logger.isLoggable(BasicLevel.ERROR))
          logger.log(BasicLevel.ERROR,
              "RESTAcquisitionAsync.createJSonMessage: body of MapMessage should not be " + body.getClass());
        throw new Exception("Cannot convert message");
      }
    }
    case "BytesMessage": {
      if (body instanceof ArrayList) {
        ArrayList jmsBody =  (ArrayList) body;
        msg.type = Message.BYTES;
        byte[] bytes = new byte[jmsBody.size()];
        try {
          for (int i = 0; i < bytes.length; i++) {
            bytes[i] = ((Number) jmsBody.get(i)).byteValue();
          }
        } catch (Exception exc) {
          if (logger.isLoggable(BasicLevel.ERROR))
            logger.log(BasicLevel.ERROR,
                "RESTAcquisitionAsync.createJSonMessage: error converting BytesMessage", exc);
          throw new Exception("Cannot convert message", exc);
        }
        msg.body = bytes;
        return msg;
      } else {
        if (logger.isLoggable(BasicLevel.ERROR))
          logger.log(BasicLevel.ERROR,
              "RESTAcquisitionAsync.createJSonMessage: body of BytesMessage should not be " + body.getClass());
        throw new Exception("Cannot convert message");
      }
    }
    default:
      logger.log(BasicLevel.ERROR,
          "RESTAcquisitionAsync.createJSonMessage: type " + type + " not supported.");
      throw new Exception("Cannot convert message");
    }
  }
