private Message recvNextMessage() throws Exception {
    Response response = null;
    Message msg = null;
    
    if (uriReceiveNextMsg == null) {
      logger.log(BasicLevel.ERROR, 
          "RestAcquisitionAsync.recvNextMessage(): URI not initialized.");
      throw new Exception("URI not initialized");
    }

    if (mediaTypeJson) {
      response = client.target(uriReceiveNextMsg)
          .queryParam("timeout", timeout)
          .request()
          .accept(MediaType.APPLICATION_JSON)
          .get();
      if (response.getStatus() != 200) {
        if (logger.isLoggable(BasicLevel.WARN))
          logger.log(BasicLevel.WARN, 
              "RestAcquisitionAsync.receiveNextMessage: cannot receive next message ->" + response.getStatusInfo());
        
        return null;
      }

      String json = response.readEntity(String.class);
      if ((json == null) || json.isEmpty() || "null".equals(json)){
        if (logger.isLoggable(BasicLevel.WARN))
          logger.log(BasicLevel.WARN, 
              "RestAcquisitionAsync.receiveNextMessage: receive empty message.");
        
        return null;
      }
      
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG, 
            "RestAcquisitionAsync.receiveNextMessage: receive " + json);
      
      Gson gson = new GsonBuilder().create();
      HashMap<String, Object> map = gson.fromJson(json, HashMap.class);
      if (map != null) {
        try {
          msg = createJSonMessage(map);
        } catch (Exception exc) {
          if (logger.isLoggable(BasicLevel.ERROR))
            logger.log(BasicLevel.ERROR, 
                "RestAcquisitionAsync.receiveNextMessage: cannot create message", exc);

          return null;
        }
      } else {
        String text = gson.fromJson(json, String.class);
        if (text != null) {
          if (logger.isLoggable(BasicLevel.WARN))
            logger.log(BasicLevel.WARN, 
                "RestAcquisitionAsync.receiveNextMessage: not receive a JSon message -> " + json);
          
          try {
            msg = createTextMessage(text);
          } catch (Exception exc) {
            if (logger.isLoggable(BasicLevel.ERROR))
              logger.log(BasicLevel.ERROR, 
                  "RestAcquisitionAsync.receiveNextMessage: cannot create message", exc);

            return null;
          }
        } else {
          if (logger.isLoggable(BasicLevel.WARN))
            logger.log(BasicLevel.WARN, 
                "RestAcquisitionAsync.receiveNextMessage: receive bad message -> " + json);
          
          return null;
        }
      }
    } else {
      response = client.target(uriReceiveNextMsg)
          .queryParam("timeout", timeout)
          .request()
          .accept(MediaType.TEXT_PLAIN)
          .get();
      if (response.getStatus() != 200) {
        if (logger.isLoggable(BasicLevel.WARN))
          logger.log(BasicLevel.WARN, 
              "RestAcquisitionAsync.receiveNextMessage: cannot receive next message ->" + response.getStatusInfo());
        
        return null;
      }

      String text = response.readEntity(String.class);
      if ((text == null) || text.isEmpty()) {
        if (logger.isLoggable(BasicLevel.WARN))
          logger.log(BasicLevel.WARN, 
              "RestAcquisitionAsync.receiveNextMessage: receive empty message.");
        
        return null;
      }
      
      try {
        msg = createTextMessage(text);
      } catch (Exception exc) {
        if (logger.isLoggable(BasicLevel.ERROR))
          logger.log(BasicLevel.ERROR, 
              "RestAcquisitionAsync.receiveNextMessage: cannot create message", exc);

        return null;
      }
    }
    
    uriReceiveNextMsg = response.getLink("receive-next-message").getUri();
    uriAcknowledgeMsg = response.getLink("acknowledge-message").getUri();

    return msg;
  }
