private void setJMSMessageHeader(Message msg, Map header) {
    if (header == null || (header.size() == 0))  {
      if (logger.isLoggable(BasicLevel.WARN))
        logger.log(BasicLevel.WARN,
            "RESTAcquisitionAsync.setJMSMessageHeader: empty JMS header map");
      return;
    }

    if (header.containsKey("DeliveryMode")) {
      try {
        msg.persistent = "PERSISTENT".equals(header.get("DeliveryMode"));
      } catch (Exception e) { 
        if (logger.isLoggable(BasicLevel.WARN))
          logger.log(BasicLevel.WARN,
              "RESTAcquisitionAsync.setJMSMessageHeader -- DeliveryMode = " + header.get("DeliveryMode"));
      }
    }

    if (header.containsKey("Priority")) {
      try {
        msg.priority = ((Double) header.get("Priority")).intValue();
      } catch (Exception e) { 
        if (logger.isLoggable(BasicLevel.WARN))
          logger.log(BasicLevel.WARN,
              "RESTAcquisitionAsync.setJMSMessageHeader -- Priority = " + header.get("Priority"));
      }
    }

    if (header.containsKey("Redelivered")) {
      try {
        msg.redelivered = (boolean) header.get("Redelivered");
      } catch (Exception e) { 
        if (logger.isLoggable(BasicLevel.WARN))
          logger.log(BasicLevel.WARN,
              "RESTAcquisitionAsync.setJMSMessageHeader-- Redelivered = " + header.get("Redelivered"));
      }
    }

    if (header.containsKey("Timestamp")) {
      try {
        msg.timestamp = ((Double) header.get("Timestamp")).longValue();
      } catch (Exception e) { 
        if (logger.isLoggable(BasicLevel.WARN))
          logger.log(BasicLevel.WARN,
              "RESTAcquisitionAsync.setJMSMessageHeader-- Timestamp = " + header.get("Timestamp"));
      }
    }

    if (header.containsKey("Expiration")) {
      try {
        msg.expiration = ((Double) header.get("Expiration")).longValue();
      } catch (Exception e) { 
        if (logger.isLoggable(BasicLevel.WARN))
          logger.log(BasicLevel.WARN,
              "RESTAcquisitionAsync.setJMSMessageHeader -- Expiration = " + header.get("Expiration"));
      }
    }

    if (header.containsKey("CorrelationID")) {
      try {
        msg.correlationId = (String) header.get("CorrelationID");
      } catch (Exception e) {
        if (logger.isLoggable(BasicLevel.WARN))
          logger.log(BasicLevel.WARN,
              "RESTAcquisitionAsync.setJMSMessageHeader -- CorrelationID = " + header.get("CorrelationID"));
      }
    }

    if (header.containsKey("CorrelationIDAsBytes")) {
      msg.setJMSCorrelationIDAsBytes((byte[]) header.get("CorrelationIDAsBytes"));
      if (logger.isLoggable(BasicLevel.WARN))
        logger.log(BasicLevel.DEBUG, "-- CorrelationIDAsBytes = " + header.get("CorrelationIDAsBytes"));
    }

    // TODO (AF): Is it correct? The destination should correspond to the current destination.
    if (header.containsKey("Destination")) {
      try {
        Map dest = (Map) header.get("Destination");
        String id = (String) dest.get("agentId");
        String name = (String) dest.get("adminName");
        byte type = ((Double) dest.get("type")).byteValue();
        msg.setDestination(id, name, type);
      } catch (Exception e) {
        if (logger.isLoggable(BasicLevel.WARN))
          logger.log(BasicLevel.WARN, "-- Destination = " + header.get("Destination"));
      }
    }

    if (header.containsKey("MessageID")) {
      try {
        msg.id = (String) header.get("MessageID");
      } catch (Exception e) {
        if (logger.isLoggable(BasicLevel.WARN))
          logger.log(BasicLevel.WARN,
              "RESTAcquisitionAsync.setJMSMessageHeader -- MessageID = " + header.get("MessageID"));
      }
    }

    if (header.containsKey("ReplyTo")) {
      try {
        msg.replyToId = (String) header.get("ReplyTo");
      } catch (Exception e) {
        if (logger.isLoggable(BasicLevel.WARN))
          logger.log(BasicLevel.WARN,
              "RESTAcquisitionAsync.setJMSMessageHeader -- ReplyTo = " + header.get("ReplyTo"));
      }
    }

    if (header.containsKey("Type")) {
      try {
        msg.jmsType = (String) header.get("Type");
      } catch (Exception e) { 
        if (logger.isLoggable(BasicLevel.WARN))
          logger.log(BasicLevel.WARN,
              "RESTAcquisitionAsync.setJMSMessageHeader -- Type = " + header.get("Type"));
      }
    }
  }
