private synchronized void initPublicKey() throws Exception {
    // Keystore file
    String keystoreFile = Configuration.getProperty(KEYSTORE_FILE);
    if (keystoreFile == null) {
      throw new IllegalStateException("The '" + KEYSTORE_FILE + "' attribute was not found but this attribute is mandatory");
    }

    // Keystore pass
    String keystorePass = Configuration.getProperty(KEYSTORE_PASS);
    if (keystorePass == null) {
      throw new IllegalStateException("The '" + KEYSTORE_PASS + "' attribute was not found but this attribute is mandatory");
    }

    // Alias
    String alias = Configuration.getProperty(KEYSTORE_ALIAS);
    if (alias == null) {
      throw new IllegalStateException("The '" + KEYSTORE_ALIAS + "' attribute was not found but this attribute is mandatory");
    }

    // Check that the file exists
    File f = new File(keystoreFile);
    if (!f.exists()) {
      throw new IllegalStateException("The keystore file named '" + f + "' was not found.");
    }

    // Gets the keystore instance
    KeyStore keyStore = null;
    try {
      keyStore = KeyStore.getInstance(KeyStore.getDefaultType());
    } catch (KeyStoreException e) {
      throw new IllegalStateException("Error while getting a keystore ':" + e.getMessage());
    }

    // Load the keystore file
    try {
      keyStore.load(new BufferedInputStream(new FileInputStream(f)), keystorePass.toCharArray());
    } catch (NoSuchAlgorithmException e) {
      throw new IllegalStateException("Error while loading the keystore file '" + f + "'." + e.getMessage());
    } catch (CertificateException e) {
      throw new IllegalStateException("Error while loading the keystore file '" + f + "'." + e.getMessage());
    } catch (FileNotFoundException e) {
      throw new IllegalStateException("Error while loading the keystore file '" + f + "'." + e.getMessage());
    } catch (IOException e) {
      throw new IllegalStateException("Error while loading the keystore file '" + f + "'." + e.getMessage());
    }

    // Get certificate
    Certificate cert;
    try {
      cert = keyStore.getCertificate(alias);
    } catch (KeyStoreException e) {
      throw new IllegalStateException("Error while getting the alias '" + alias + "' in the keystore file '" + keystoreFile + "':" + e.getMessage());
    }

    // set the public key
    publickey = cert.getPublicKey();
  }
