public void setIdentity(String user, String passwd, String pJaasEntryName) throws Exception {
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "JonasIdentity.setIdentity(" + user + ", ****)");

    principal = user;
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, 
          "JonasIdentity.setIdentity principal = " + principal);

    try {
      String jaasEntryName=null;
      if (Configuration.getBoolean("joram.security.jaas.entryName")) {
    	  jaasEntryName = Configuration.getProperty("joram.security.jaas.entryName");
      } else if (pJaasEntryName!=null) {
    	  jaasEntryName = pJaasEntryName;
      } else {
    	  jaasEntryName = JAAS_ENTRY_NAME; //default
      }
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG, "setIdentity: jaasEntryName = "  + jaasEntryName);
      loginContext = new LoginContext(jaasEntryName, new NoInputCallbackHandler(user, passwd));
    } catch (LoginException e) {
      if (logger.isLoggable(BasicLevel.ERROR))
        logger.log(BasicLevel.ERROR, "EXCEPTION setIdentity::",e);
      throw new Exception(e.getMessage());
    }

    // Negotiate a login via this LoginContext
    try {
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG, 
            "JonasIdentity.setIdentity factory initial = " + 
            Configuration.getProperty(Context.INITIAL_CONTEXT_FACTORY)); 
      loginContext.login();     
      subject = loginContext.getSubject();
      if (subject == null) {
        if (logger.isLoggable(BasicLevel.ERROR))
          logger.log(BasicLevel.ERROR, "No subject for the user " + principal);
        throw new Exception("No subject for the user " + principal);
      }

    } catch (AccountExpiredException e) {
      if (logger.isLoggable(BasicLevel.ERROR))
        logger.log(BasicLevel.ERROR, "Account expired for the user " + principal, e);
      throw new Exception("Account expired for the user " + principal, e);
    } catch (CredentialExpiredException e) {
      if (logger.isLoggable(BasicLevel.ERROR))
        logger.log(BasicLevel.ERROR, "Credential expired for the user " + principal, e);
      throw new Exception("Credential expired for the user " + principal, e);
    } catch (FailedLoginException e) {
      if (logger.isLoggable(BasicLevel.ERROR))
        logger.log(BasicLevel.ERROR, "Failed Login for the user " + principal, e);
      throw new Exception("Failed Login for the user " + principal, e);
    } catch (LoginException e) {
      if (logger.isLoggable(BasicLevel.ERROR))
        logger.log(BasicLevel.ERROR, "Login exception for the user " + principal, e);
      throw new Exception("Login exception for the user " + principal, e);
    }
  }
