public static void init() throws Exception {
    String config = AgentServer.getProperty(FileMonitoringTimerTask.MONITORING_CONFIG_PATH_PROPERTY,
                                            FileMonitoringTimerTask.DEFAULT_MONITORING_CONFIG_PATH);
    try {
      // if "fileMonitoring.props" file exists configure a FileMonitoringTimerTask.
      File file = new File(config);
      if (file.exists()) {
        long period = AgentServer.getLong(FileMonitoringTimerTask.MONITORING_CONFIG_PERIOD_PROPERTY,
                                          FileMonitoringTimerTask.DEFAULT_MONITORING_CONFIG_PERIOD).longValue();
        String results = AgentServer.getProperty(FileMonitoringTimerTask.MONITORING_RESULT_PATH_PROPERTY,
                                                 FileMonitoringTimerTask.DEFAULT_MONITORING_RESULT_PATH);

        Properties monitoringProps = new Properties();
        monitoringProps.load(new FileInputStream(file));

        fileMonitoringTimerTask = new FileMonitoringTimerTask(getTimer(), period, monitoringProps, results);
        try {
          fileMonitoringTimerTask.MBean_name = "server=" + AgentServer.getName() + ",cons=FileMonitoring";
          MXWrapper.registerMBean(fileMonitoringTimerTask,
                                  "AgentServer", fileMonitoringTimerTask.MBean_name);
        } catch (Exception exc) {
          logger.log(BasicLevel.ERROR, AgentServer.getName() + " jmx failed", exc);
        }
      }
    } catch (Exception exc) {
      logger.log(BasicLevel.WARN, AgentServer.getName() + " Cannot read monitoring configuration file: " + config, exc);
    }

    config = AgentServer.getProperty(LogMonitoringTimerTask.MONITORING_CONFIG_PATH_PROPERTY,
                                     LogMonitoringTimerTask.DEFAULT_MONITORING_CONFIG_PATH);
    try {
      // if "logMonitoring.props" file exists configure a LogMonitoringTimerTask.
      File file = new File(config);
      if (file.exists()) {
        long period = AgentServer.getLong(LogMonitoringTimerTask.MONITORING_CONFIG_PERIOD_PROPERTY,
                                          LogMonitoringTimerTask.DEFAULT_MONITORING_CONFIG_PERIOD).longValue();        
        String logname = AgentServer.getProperty(LogMonitoringTimerTask.MONITORING_RESULT_LOGGER_PROPERTY,
                                                 LogMonitoringTimerTask.DEFAULT_MONITORING_RESULT_LOGGER);
        Logger l = Debug.getLogger(logname);
        int level = AgentServer.getInteger(LogMonitoringTimerTask.MONITORING_RESULT_LEVEL_PROPERTY,
                                              LogMonitoringTimerTask.DEFAULT_MONITORING_RESULT_LEVEL).intValue();
        String msg = AgentServer.getProperty(LogMonitoringTimerTask.MONITORING_RESULT_MESSAGE_PROPERTY,
                                                LogMonitoringTimerTask.DEFAULT_MONITORING_RESULT_MESSAGE);

        Properties monitoringProps = new Properties();
        monitoringProps.load(new FileInputStream(file));

        logMonitoringTimerTask = new LogMonitoringTimerTask(getTimer(), period, monitoringProps, l, msg, level);
        try {
          logMonitoringTimerTask.MBean_name = "server=" + AgentServer.getName() + ",cons=LogMonitoring";
          MXWrapper.registerMBean(logMonitoringTimerTask,
                                  "AgentServer", logMonitoringTimerTask.MBean_name);
        } catch (Exception exc) {
          logger.log(BasicLevel.ERROR, AgentServer.getName() + " jmx failed", exc);
        }
      }
    } catch (Exception exc) {
      logger.log(BasicLevel.WARN, AgentServer.getName() + " Cannot read monitoring configuration file: " + config, exc);
    }

    config = AgentServer.getProperty(WindowMonitoringTimerTask.MONITORING_CONFIG_PATH_PROPERTY,
                                            WindowMonitoringTimerTask.DEFAULT_MONITORING_CONFIG_PATH);
    try {
      // if "fileMonitoring.props" file exists configure a FileMonitoringTimerTask.
      File file = new File(config);
      if (file.exists()) {
        long period = AgentServer.getLong(WindowMonitoringTimerTask.MONITORING_CONFIG_PERIOD_PROPERTY,
                                          WindowMonitoringTimerTask.DEFAULT_MONITORING_CONFIG_PERIOD).longValue();

        Properties monitoringProps = new Properties();
        monitoringProps.load(new FileInputStream(file));

        windowMonitoringTimerTask = new WindowMonitoringTimerTask(getTimer(), period, monitoringProps);
        try {
          windowMonitoringTimerTask.MBean_name = "server=" + AgentServer.getName() + ",cons=WindowMonitoring";
          MXWrapper.registerMBean(windowMonitoringTimerTask,
                                  "AgentServer", windowMonitoringTimerTask.MBean_name);
        } catch (Exception exc) {
          logger.log(BasicLevel.ERROR, AgentServer.getName() + " jmx failed", exc);
        }
      }
    } catch (Exception exc) {
      logger.log(BasicLevel.WARN, AgentServer.getName() + " Cannot read monitoring configuration file: " + config, exc);
    }
  }
