@POST
  @Path("/queue/{destName}")
  @Produces(MediaType.TEXT_PLAIN)
  @Consumes(MediaType.APPLICATION_JSON)
  public synchronized Response createQueue(
      @Context HttpHeaders headers,
      @PathParam("destName") String destName,
      @DefaultValue("org.objectweb.joram.mom.dest.Queue") @QueryParam("class-name") String className,
      @DefaultValue("-1") @QueryParam("server-id") int serverId,
      @DefaultValue("false") @QueryParam("free-reading") boolean freeReading,
      @DefaultValue("false") @QueryParam("free-writing") boolean freeWriting,
      @DefaultValue("true") @QueryParam("jndi-bind") boolean bind,
      @QueryParam("jndi-name") String jndiName,
      @Context UriInfo uriInfo,
      String json) {

    if (logger.isLoggable(BasicLevel.INFO))
      logger.log(BasicLevel.INFO, "POST: " + uriInfo.getAbsolutePathBuilder());

    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "createQueue(" + headers + ", " + destName + ", " + className + ", " + serverId + 
          freeReading + ", " + freeWriting + ", " + bind + ", " + uriInfo + ")");

    Response.ResponseBuilder builder = null;
    Properties props = null;
    if (json != null) {
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG, "json = " + json);
      Gson gson = new GsonBuilder().create();
      props = gson.fromJson(json, Properties.class);
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG, "props = " + props);
    }

    try {
      Destination dest = null;
      // create the queue
      if (props != null) {
        if (props.containsKey("className"))
          className = props.getProperty("className");
        if (serverId == -1)
          serverId = helper.getLocalServerId();
        if (props.containsKey("serverId"))
          serverId = Integer.parseInt(props.getProperty("serverId"));
        dest = helper.createQueue(serverId, destName, className, props);
      } else if (serverId > -1) {
        dest = helper.createQueue(serverId, destName);
      } else {
        dest = helper.createQueue(destName);
      }
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG,"dest = " + dest);

      // set right
      if (freeReading)
        dest.setFreeReading();
      if (freeWriting)
        dest.setFreeWriting();

      if (bind || jndiName != null) {
        String name = dest.getAdminName();
        if (jndiName != null)
          name = jndiName;
        helper.rebind(name, dest);
      }

    } catch (Exception e) {
      if (logger.isLoggable(BasicLevel.WARN))
        logger.log(BasicLevel.WARN, e);
      if (e instanceof JMSSecurityRuntimeException)
        builder = Response.status(Response.Status.UNAUTHORIZED).entity(e.toString());
      else
        builder = Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity(e.toString());
      return builder.build();
    }

    builder = Response.status(Response.Status.CREATED);
    // TODO: Adds links?
    return builder.build();
  }
