@GET
  @Path("/tcp/create")
  @Produces({MediaType.TEXT_PLAIN})
  public synchronized Response createTcpConnectionFactory(
      @Context HttpHeaders headers,
      @QueryParam("jndi-name") String jndiName,
      @QueryParam("host") String host, 
      @QueryParam("port") int port,
      @DefaultValue("org.objectweb.joram.client.jms.tcp.ReliableTcpClient") @QueryParam("reliable-class") String reliableClass,
      @Context UriInfo uriInfo) {
 
    if (logger.isLoggable(BasicLevel.INFO))
      logger.log(BasicLevel.INFO, "GET: " + uriInfo.getAbsolutePathBuilder());
    
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "createTcpConnectionFactory(" + headers + ", " + jndiName + ", " + host + ", " + port + 
          ", " + reliableClass + ", " + uriInfo + ")");

    Response.ResponseBuilder builder = null;
    try {
      // Create tcp connection factory
      ConnectionFactory cf = null;
      if (host == null)
        cf = helper.createTcpConnectionFactory();
      else
        cf = helper.createTcpConnectionFactory(host, port, reliableClass);

      // bind the connection factory
      if (jndiName != null)
        helper.rebind(jndiName, cf);

      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG, "createTcpConnectionFactory cf = " + cf);

    } catch (Exception e) {
      if (logger.isLoggable(BasicLevel.WARN))
        logger.log(BasicLevel.WARN, e);
      if (e instanceof JMSSecurityRuntimeException)
        builder = Response.status(Response.Status.UNAUTHORIZED).entity(e.toString());
      else
        builder = Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity(e.toString());
      return builder.build();
    }

    builder = Response.status(Response.Status.CREATED);
    // TODO: Adds links?
    return builder.build();
  }
