@POST
  @Path("/user/{userName}")
  @Produces({MediaType.TEXT_PLAIN})
  @Consumes(MediaType.APPLICATION_JSON)
  public synchronized Response createUser(
      @Context HttpHeaders headers,
      @PathParam("userName") String userName,
      @NotNull @QueryParam("password")String password,
      @DefaultValue("-1") @QueryParam("server-id") int serverId,
      @DefaultValue("org.objectweb.joram.shared.security.SimpleIdentity") @QueryParam("identity-class-name") String identityClassName,
      @Context UriInfo uriInfo,
      String json) {
 
    if (logger.isLoggable(BasicLevel.INFO))
      logger.log(BasicLevel.INFO, "POST: " + uriInfo.getAbsolutePathBuilder());
    
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "createUser(" + headers + ", " + userName + ", " + uriInfo + ")");

    Response.ResponseBuilder builder = null;

    if (password == null) {
      builder = Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("The password is null.");
      return builder.build();
    }

    Properties props = null;
    if (json != null) {
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG, "json = " + json);
      Gson gson = new GsonBuilder().create();
      props = gson.fromJson(json, Properties.class);
      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG, "props = " + props);
    }

    try {
      // Create the user
      User user = null;
      if (props == null) {
        user = helper.createUser(userName, password);
      } else {
        if (serverId < 0)
          serverId = helper.getLocalServerId();
        user = helper.createUser(userName, password, serverId, identityClassName, props);
      }

      if (logger.isLoggable(BasicLevel.DEBUG))
        logger.log(BasicLevel.DEBUG, "user = " + user);

    } catch (Exception e) {
      if (logger.isLoggable(BasicLevel.WARN))
        logger.log(BasicLevel.WARN, e);
      if (e instanceof JMSSecurityRuntimeException)
        builder = Response.status(Response.Status.UNAUTHORIZED).entity(e.toString());
      else
        builder = Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity(e.toString());
      return builder.build();
    }

    builder = Response.status(Response.Status.CREATED);
    // TODO: Adds links?
    return builder.build();
  }
