@DELETE
  @Path("/queue/{destName}")
  @Produces(MediaType.TEXT_PLAIN)
  public synchronized Response deleteQueue(
      @Context HttpHeaders headers,
      @PathParam("destName") String destName,
      @DefaultValue("-1") @QueryParam("server-id") int serverId,
      @DefaultValue("true") @QueryParam("jndi-unbind") boolean unbind,
      @QueryParam("jndi-name") String jndiName,
      @Context UriInfo uriInfo) {

    if (logger.isLoggable(BasicLevel.INFO))
      logger.log(BasicLevel.INFO, "DELETE: " + uriInfo.getAbsolutePathBuilder());
    
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "deleteQueue(" + headers + ", " + destName + ", " + ", " + serverId + 
          ", " + unbind + ", " + uriInfo + ")");
    
    Response.ResponseBuilder builder = null;
    try {
      // delete the queue
      if (serverId < 0)
        serverId = helper.getLocalServerId();
      Destination dest = helper.createQueue(serverId, destName);
      String name = dest.getAdminName();
      dest.delete();
      
      if (unbind || jndiName != null) {
        if (jndiName != null)
          name = jndiName;
        helper.unbind(name);
      }

    } catch (Exception e) {
      if (logger.isLoggable(BasicLevel.WARN))
        logger.log(BasicLevel.WARN, e);
      if (e instanceof JMSSecurityRuntimeException)
        builder = Response.status(Response.Status.UNAUTHORIZED).entity(e.toString());
      else
        builder = Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity(e.toString());
      return builder.build();
    }

    builder = Response.status(Response.Status.OK);
    return builder.build();
  }
