public void start(BundleContext bundleContext) throws Exception {
    this.context = bundleContext;
    ServiceReference<HttpService> reference = bundleContext.getServiceReference(HttpService.class);
    if (reference == null) {
      logger.log(BasicLevel.ERROR, "rest.jms.Activator ServiceReference<HttpService> = null");
      throw new Exception("rest.jms.Activator ServiceReference<HttpService> = null");
    }
    httpService = bundleContext.getService(reference);
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "rest.jms.activator httpService = " + httpService);
    
    ClassLoader myClassLoader = getClass().getClassLoader();
    ClassLoader originalContextClassLoader = Thread.currentThread().getContextClassLoader();
    try {
      Thread.currentThread().setContextClassLoader(myClassLoader);
      
      String serviceName = bundleContext.getProperty(SERVICE_NAME);
      if (serviceName != null && !serviceName.isEmpty()) {
        servletAlias = serviceName.startsWith("/") ? serviceName : "/" + serviceName;
      }
      
      // set properties from felix configuration
      Helper.getInstance().setGlobalProperties(bundleContext);
      
      Dictionary<String, String> jerseyServletParams = new Hashtable<>();
      jerseyServletParams.put("javax.ws.rs.Application", JmsJerseyApplication.class.getName());
      if (logger.isLoggable(BasicLevel.INFO))
        logger.log(BasicLevel.INFO, "start: REGISTERING SERVLETS " + servletAlias);
      
      // register the servlet
      httpService.registerServlet(servletAlias, new ServletContainer(), jerseyServletParams, null);

      int period = Helper.DFLT_CLEANER_PERIOD;
      String value = bundleContext.getProperty(Helper.BUNDLE_CLEANER_PERIOD_PROP);
      if (value != null && !value.isEmpty()) {
        try {
          period = Integer.parseInt(value);
        } catch (NumberFormatException exc) {
          if (logger.isLoggable(BasicLevel.WARN))
            logger.log(BasicLevel.WARN,
                "Bad configuration property " + Helper.BUNDLE_CLEANER_PERIOD_PROP + ", should be a number: " + value, exc);
        }
      }
      if (period > 0) {
        cleanerTask = new CleanerTask();
        cleanerTask.setPeriod(period);
        cleanerTask.start();
      }
    } finally {
      Thread.currentThread().setContextClassLoader(originalContextClassLoader);
    }
  }
