@HEAD
  @Path("/{name}/" + CONTEXT_ROLLBACK)
  @Produces(MediaType.TEXT_PLAIN)
  @Consumes(MediaType.TEXT_PLAIN)
  public Response rollback(
      @Context HttpHeaders headers,
      @PathParam("name") String ctxName,
      @Context UriInfo uriInfo) {

    if (logger.isLoggable(BasicLevel.INFO))
      logger.log(BasicLevel.INFO, "HEAD: " + uriInfo.getAbsolutePathBuilder());

    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "rollback(" + headers + ", " + ctxName + ", " + uriInfo);
    
    Response.ResponseBuilder builder = null;
    try {

      if (ctxName == null) {
        builder = Response.status(Response.Status.EXPECTATION_FAILED).entity("The producer/consumer name is null.");
        return builder.build();
      }

      SessionContext ctx = helper.getSessionCtx(ctxName);
      if (ctx == null) {
        ctx = helper.getSessionCtx(ctxName);
      }

      try {
        if (! ctx.getJmsContext().getTransacted()) {
          builder = Response.status(Response.Status.INTERNAL_SERVER_ERROR).
              entity("The jmsContext for " + ctxName + " is not transacted.");
          return builder.build();
        }
      } catch (Exception e) {
        if (logger.isLoggable(BasicLevel.WARN))
          logger.log(BasicLevel.WARN, "", e);
        builder = Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity(e.toString());
        return builder.build();
      }

      try {
        // rollback
        helper.rollback(ctxName);
      } catch (Exception e) {
        if (logger.isLoggable(BasicLevel.WARN))
          logger.log(BasicLevel.WARN, "", e);
        builder = Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity(e.toString());
        return builder.build();
      }

      builder = Response.status(Response.Status.OK);

      if (ctx instanceof ProducerContext) {
        // link send message
        UriBuilder nextBuilder = UriBuilder.fromUri(uriInfo.getBaseUri()).path(CONTEXT).path(ctxName);
        builder.link(nextBuilder.build(), CONTEXT_SEND);

        // link send next message
        nextBuilder = UriBuilder.fromUri(uriInfo.getBaseUri()).path(CONTEXT).path(ctxName).path(""+(ctx.getLastId()+1));
        builder.link(nextBuilder.build(), CONTEXT_SEND_NEXT);
      } 

      if (ctx instanceof ConsumerContext) {
        // link consume message
        UriBuilder nextBuilder = UriBuilder.fromUri(uriInfo.getBaseUri()).path(CONTEXT).path(ctxName);
        builder.link(nextBuilder.build(), CONTEXT_CONSUME);

        // link consume next message
        nextBuilder = UriBuilder.fromUri(uriInfo.getBaseUri()).path(CONTEXT).path(ctxName).path("" + (ctx.getLastId()+1));
        builder.link(nextBuilder.build(), CONTEXT_CONSUME_NEXT);
      }

      return builder.build();
    } finally {
      logLinks(builder);
    }
  }
