@POST
  @Path("/{name}")
  @Consumes(MediaType.APPLICATION_JSON)
  @Produces(MediaType.TEXT_PLAIN)
  public Response sendMsgJson(
      @Context HttpHeaders headers,
      @PathParam("name") String prodName,
      @DefaultValue("-1")@QueryParam("delivery-mode") int deliveryMode,
      @DefaultValue("-1")@QueryParam("delivery-time") long deliveryTime,
      @DefaultValue("-1")@QueryParam("priority") int priority,
      @DefaultValue("-1")@QueryParam("time-to-live") long timeToLive,
      @QueryParam("correlation-id") String correlationID,
      @Context UriInfo uriInfo,
      String json) {

    if (logger.isLoggable(BasicLevel.INFO))
      logger.log(BasicLevel.INFO, "POST: " + uriInfo.getAbsolutePathBuilder());

    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "sendMsg(" + headers + ", " + prodName + ", " + deliveryMode + ", " +
          deliveryTime + ", " + priority + ", " + timeToLive + ", " + correlationID + ", " + 
          uriInfo + ", " + json);
    
    Response.ResponseBuilder builder = null;
    try {
      if (prodName == null) {
        if (logger.isLoggable(BasicLevel.WARN))
          logger.log(BasicLevel.WARN, "sendMsg: The producer name is null.");
        builder = Response.status(Response.Status.EXPECTATION_FAILED).entity("The producer name is null.");
        return builder.build();
      }
      
      long msgId = 0;
      try {
        String jmsType = null;
        Map jmsHeaders = null;
        Map jmsProps = null;
        Object jmsBody = null;
        if (json != null) {
          if (logger.isLoggable(BasicLevel.DEBUG))
            logger.log(BasicLevel.DEBUG, "json = " + json);
          Gson gson = new GsonBuilder().create();
          HashMap<String, Object> maps = gson.fromJson(json, HashMap.class);
          if (logger.isLoggable(BasicLevel.DEBUG))
            logger.log(BasicLevel.DEBUG, "maps = " + maps);
          
          // get the message type
          jmsType = (String) maps.get(JMS_TYPE);
          
          // get the headers
          jmsHeaders = (Map) maps.get(JMS_HEADER);
          if (logger.isLoggable(BasicLevel.DEBUG))
            logger.log(BasicLevel.DEBUG, "jmsHeaders = " + jmsHeaders);
          
          // get the properties
          jmsProps = (Map) maps.get(JMS_PROPERTIES);
          if (logger.isLoggable(BasicLevel.DEBUG))
            logger.log(BasicLevel.DEBUG, "jmsProps = " + jmsProps);

          // get the body
          jmsBody = maps.get(JMS_BODY);
          if (logger.isLoggable(BasicLevel.DEBUG))
            logger.log(BasicLevel.DEBUG, "jmsBody = " + jmsBody);
        }

        // send the message
        msgId = helper.send(prodName, jmsType, jmsHeaders, jmsProps, jmsBody, 
            deliveryMode, deliveryTime, priority, timeToLive, correlationID);
        if (logger.isLoggable(BasicLevel.DEBUG))
          logger.log(BasicLevel.DEBUG, "sendMsg: msgId = " + msgId); 
      } catch (Exception e) {
        if (logger.isLoggable(BasicLevel.WARN))
          logger.log(BasicLevel.WARN, "", e);
        builder = Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity(e.toString());
        return builder.build();
      }

      builder = Response.status(Response.Status.OK);

      // link send message
      UriBuilder nextBuilder = uriInfo.getAbsolutePathBuilder();
      URI next = nextBuilder.build();
      builder.link(next, CONTEXT_SEND);

      // link send next message
      nextBuilder = uriInfo.getAbsolutePathBuilder().path(""+(msgId+1));
      next = nextBuilder.build();
      builder.link(next, CONTEXT_SEND_NEXT);

      //TODO : DUPS_OK

      try {
        if (helper.getSessionCtx(prodName).getJmsContext().getTransacted()) {
          // link commit message
          nextBuilder = uriInfo.getAbsolutePathBuilder().path(CONTEXT_COMMIT);
          builder.link(nextBuilder.build(), CONTEXT_COMMIT);
          
          // link rollback message
          nextBuilder = uriInfo.getAbsolutePathBuilder().path(CONTEXT_ROLLBACK);
          builder.link(nextBuilder.build(), CONTEXT_ROLLBACK);
        }
      } catch (Exception e) {
        if (logger.isLoggable(BasicLevel.WARN))
          logger.log(BasicLevel.WARN, "", e);
        builder = Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity(e.toString());
        return builder.build();
      }
      return builder.build();
    } finally {
      logLinks(builder);
    }
  }
