@POST
  @Path("/{name}/{id}")
  @Consumes(MediaType.APPLICATION_JSON)
  @Produces(MediaType.TEXT_PLAIN)
  public Response sendMsgJson(
      @Context HttpHeaders headers,
      @PathParam("name") String prodName,
      @PathParam("id") long id,
      @DefaultValue("-1")@QueryParam("delivery-mode") int deliveryMode,
      @DefaultValue("-1")@QueryParam("delivery-time") long deliveryTime,
      @DefaultValue("-1")@QueryParam("priority") int priority,
      @DefaultValue("-1")@QueryParam("time-to-live") long timeToLive,
      @QueryParam("correlation-id") String correlationID,
      @Context UriInfo uriInfo,
      String json) {

    if (logger.isLoggable(BasicLevel.INFO))
      logger.log(BasicLevel.INFO, "POST: " + uriInfo.getAbsolutePathBuilder());
    
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "sendMsg(" + headers + ", " + prodName + ", " + id + ", " + deliveryMode + ", " +
          deliveryTime + ", " + priority + ", " + timeToLive + ", " + correlationID + ", " + uriInfo + ", " + json);

    Response.ResponseBuilder builder = null;
    try {
      if (prodName == null) {
        if (logger.isLoggable(BasicLevel.WARN))
          logger.log(BasicLevel.WARN, "sendMsg: The producer name is null.");
        builder = Response.status(Response.Status.EXPECTATION_FAILED).entity("The producer name is null.");
        return builder.build();
      }

      SessionContext prodCtx = helper.getSessionCtx(prodName);
      if (prodCtx == null) {
        if (logger.isLoggable(BasicLevel.WARN))
          logger.log(BasicLevel.WARN, "Unknown " + prodName + ", prodCtx == null");  
        builder = Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Unknown " + prodName + ", prodCtx == null");
        return builder.build();
      }

      if (id < prodCtx.getLastId()) {
        if (logger.isLoggable(BasicLevel.DEBUG))
          logger.log(BasicLevel.DEBUG, "sendMsg: The message already send, nothing to do.");
        //message already send, nothing to do
        builder = Response.status(Response.Status.OK);
        // TODO: Adds links?
        return builder.build();
      }

      try {
        Map jmsHeaders = null;
        Map jmsProps = null;
        Object jmsBody =null;
        String jmsType = null;
        if (json != null) {
          if (logger.isLoggable(BasicLevel.DEBUG))
            logger.log(BasicLevel.DEBUG, "json = " + json);
          Gson gson = new GsonBuilder().create();
          HashMap<String, Object> maps = gson.fromJson(json, HashMap.class);
          if (logger.isLoggable(BasicLevel.DEBUG))
            logger.log(BasicLevel.DEBUG, "maps = " + maps);

          // get the jms message type
          jmsType = (String) maps.get(JMS_TYPE);

          // get the jms headers
          jmsHeaders = (Map) maps.get(JMS_HEADER);
          if (logger.isLoggable(BasicLevel.DEBUG))
            logger.log(BasicLevel.DEBUG, "jmsHeaders = " + jmsHeaders);

          // get the jms properties
          jmsProps = (Map) maps.get(JMS_PROPERTIES);
          if (logger.isLoggable(BasicLevel.DEBUG))
            logger.log(BasicLevel.DEBUG, "jmsProps = " + jmsProps);

          // get the jms body
          jmsBody = maps.get(JMS_BODY);
          if (logger.isLoggable(BasicLevel.DEBUG))
            logger.log(BasicLevel.DEBUG, "jmsBody = " + jmsBody);
        }

        // send the message
        long msgId = helper.send(prodName, jmsType, jmsHeaders, jmsProps, jmsBody, 
            deliveryMode, deliveryTime, priority, timeToLive, correlationID);
        if (logger.isLoggable(BasicLevel.DEBUG))
          logger.log(BasicLevel.DEBUG, "sendMsg: msgId = " + msgId); 
      } catch (Exception e) {
        if (logger.isLoggable(BasicLevel.WARN))
          logger.log(BasicLevel.WARN, "", e);
        builder = Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity(e.toString());
        return builder.build();
      }

      builder = Response.status(Response.Status.OK);

      // link send message
      UriBuilder nextBuilder = UriBuilder.fromUri(uriInfo.getBaseUri()).path(CONTEXT).path(prodName);
      builder.link(nextBuilder.build(), CONTEXT_SEND);

      // link send next message
      nextBuilder = UriBuilder.fromUri(uriInfo.getBaseUri()).path(CONTEXT).path(prodName).path(""+(prodCtx.getLastId()+1));
      builder.link(nextBuilder.build(), CONTEXT_SEND_NEXT);

      //TODO : DUPS_OK

      try {
        if (prodCtx.getJmsContext().getTransacted()) {
          // link commit message
          nextBuilder = UriBuilder.fromUri(uriInfo.getBaseUri()).path(CONTEXT).path(prodName).path(CONTEXT_COMMIT);
          builder.link(nextBuilder.build(), CONTEXT_COMMIT);
          
          // link rollback message
          nextBuilder = UriBuilder.fromUri(uriInfo.getBaseUri()).path(CONTEXT).path(prodName).path(CONTEXT_ROLLBACK);
          builder.link(nextBuilder.build(), CONTEXT_ROLLBACK);
        }
      } catch (Exception e) {
        if (logger.isLoggable(BasicLevel.WARN))
          logger.log(BasicLevel.WARN, "", e);
        builder = Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity(e.toString());
        return builder.build();
      }
      return builder.build();
    } finally {
      logLinks(builder);
    }
  }
