@POST
  @Path("/{name}/{id}")
  @Consumes(MediaType.TEXT_PLAIN)
  @Produces(MediaType.TEXT_PLAIN)
  public Response sendMsg(
      @Context HttpHeaders headers,
      @PathParam("name") String prodName,
      @PathParam("id") long id,
      @DefaultValue("-1")@QueryParam("delivery-mode") int deliveryMode,
      @DefaultValue("-1")@QueryParam("delivery-time") long deliveryTime,
      @DefaultValue("-1")@QueryParam("priority") int priority,
      @DefaultValue("-1")@QueryParam("time-to-live") long timeToLive,
      @QueryParam("correlation-id") String correlationID,
      @Context UriInfo uriInfo,
      String body) {

    if (logger.isLoggable(BasicLevel.INFO))
      logger.log(BasicLevel.INFO, "POST: " + uriInfo.getAbsolutePathBuilder());
    
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "sendMsg(" + headers + ", " + prodName + ", " + id + ", " + deliveryMode + ", " +
          deliveryTime + ", " + priority + ", " + timeToLive + ", " + correlationID + ", " + uriInfo + ", " + body);

    Response.ResponseBuilder builder = null;
    try {
      if (prodName == null) {
        if (logger.isLoggable(BasicLevel.WARN))
          logger.log(BasicLevel.WARN, "sendMsg: The producer name is null.");
        builder = Response.status(Response.Status.EXPECTATION_FAILED).entity("The producer name is null.");
        return builder.build();
      }

      SessionContext prodCtx = helper.getSessionCtx(prodName);
      if (prodCtx == null) {
        if (logger.isLoggable(BasicLevel.WARN))
          logger.log(BasicLevel.WARN, "Unknown " + prodName + ", prodCtx == null");  
        builder = Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity("Unknown " + prodName + ", prodCtx == null");
        return builder.build();
      }

      if (id < prodCtx.getLastId()) {
        if (logger.isLoggable(BasicLevel.DEBUG))
          logger.log(BasicLevel.DEBUG, "sendMsg: The message already send, nothing to do.");
        //message already send, nothing to do
        builder = Response.status(Response.Status.OK);
        // TODO: Adds links?
        return builder.build();
      }

      try {
        // send the message
        long msgId = helper.send(prodName, TextMessage.class.getSimpleName(), null, null, body, 
            deliveryMode, deliveryTime, priority, timeToLive, correlationID);
        if (logger.isLoggable(BasicLevel.DEBUG))
          logger.log(BasicLevel.DEBUG, "sendMsg: msgId = " + msgId); 
      } catch (Exception e) {
        if (logger.isLoggable(BasicLevel.WARN))
          logger.log(BasicLevel.WARN, "", e);
        builder = Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity(e.toString());
        return builder.build();
      }

      builder = Response.status(Response.Status.OK);

      // link send message
      UriBuilder nextBuilder = UriBuilder.fromUri(uriInfo.getBaseUri()).path(CONTEXT).path(prodName);
      builder.link(nextBuilder.build(), CONTEXT_SEND);

      // link send next message
      nextBuilder = UriBuilder.fromUri(uriInfo.getBaseUri()).path(CONTEXT).path(prodName).path(""+(prodCtx.getLastId()+1));
      builder.link(nextBuilder.build(), CONTEXT_SEND_NEXT);

      //TODO : DUPS_OK

      try {
        if (prodCtx.getJmsContext().getTransacted()) {
          // link commit message
          nextBuilder = UriBuilder.fromUri(uriInfo.getBaseUri()).path(CONTEXT).path(prodName).path(CONTEXT_COMMIT);
          builder.link(nextBuilder.build(), CONTEXT_COMMIT);

          // link rollback message
          nextBuilder = UriBuilder.fromUri(uriInfo.getBaseUri()).path(CONTEXT).path(prodName).path(CONTEXT_ROLLBACK);
          builder.link(nextBuilder.build(), CONTEXT_ROLLBACK);
        }
      } catch (Exception e) {
        if (logger.isLoggable(BasicLevel.WARN))
          logger.log(BasicLevel.WARN, "", e);
        builder = Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity(e.toString());
        return builder.build();
      }
      return builder.build();
    } finally {
      logLinks(builder);
    }
  }
