@HEAD
  @Path("/{destName}")
  @Produces(MediaType.TEXT_PLAIN)
  public synchronized Response lookupDestination(
      @Context HttpHeaders headers,
      @PathParam("destName") String destName,
      @Context UriInfo uriInfo) {

    if (logger.isLoggable(BasicLevel.INFO))
      logger.log(BasicLevel.INFO, "HEAD: " + uriInfo.getAbsolutePathBuilder());
    
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "lookupDestination(" + headers + ", " + destName + ", " + uriInfo + ")");

    Response.ResponseBuilder builder = null;
    try {

      try {
        if (helper.lookupDestination(destName) == null) {
          builder = Response.status(Response.Status.NOT_FOUND);
          UriBuilder nextBuilder = uriInfo.getAbsolutePathBuilder();
          URI next = nextBuilder.build();
          builder.link(next, "lookup");
          return builder.build();
        }
      } catch (Exception e) {
        if (logger.isLoggable(BasicLevel.WARN))
          logger.log(BasicLevel.WARN, e);
        builder = Response.status(Response.Status.INTERNAL_SERVER_ERROR).entity(e.getMessage());
        UriBuilder nextBuilder = uriInfo.getAbsolutePathBuilder();
        URI next = nextBuilder.build();
        builder.link(next, "lookup");
        return builder.build();
      }

      builder = Response.status(Response.Status.CREATED);

      //link to the create producer
      UriBuilder nextBuilder = uriInfo.getAbsolutePathBuilder().path(JmsService.JMS_CREATE_PROD);
      builder.link(nextBuilder.build(), JmsService.JMS_CREATE_PROD);
      //link to the create producer DUPS_OK_ACKNOWLEDGE
      nextBuilder = uriInfo.getAbsolutePathBuilder().path(JmsService.JMS_CREATE_PROD);
      nextBuilder.queryParam("session-mode", JMSContext.DUPS_OK_ACKNOWLEDGE);
      builder.link(nextBuilder.build(), JmsService.JMS_CREATE_PROD+"-dups-ok");
      //link to the create producer SESSION_TRANSACTED
      nextBuilder = uriInfo.getAbsolutePathBuilder().path(JmsService.JMS_CREATE_PROD);
      nextBuilder.queryParam("session-mode", JMSContext.SESSION_TRANSACTED);
      builder.link(nextBuilder.build(), JmsService.JMS_CREATE_PROD+"-transacted");
      //link to the create consumer
      nextBuilder = uriInfo.getAbsolutePathBuilder().path(JmsService.JMS_CREATE_CONS);
      builder.link(nextBuilder.build(), JmsService.JMS_CREATE_CONS);
      //link to the create consumer DUPS_OK_ACKNOWLEDGE
      nextBuilder = uriInfo.getAbsolutePathBuilder().path(JmsService.JMS_CREATE_CONS);
      nextBuilder.queryParam("session-mode", JMSContext.DUPS_OK_ACKNOWLEDGE);
      builder.link(nextBuilder.build(), JmsService.JMS_CREATE_CONS+"-dups-ok");
      //link to the create consumer CLIENT_ACKNOWLEDGE
      nextBuilder = uriInfo.getAbsolutePathBuilder().path(JmsService.JMS_CREATE_CONS);
      nextBuilder.queryParam("session-mode", JMSContext.CLIENT_ACKNOWLEDGE);
      builder.link(nextBuilder.build(), JmsService.JMS_CREATE_CONS+"-client-ack");
      //link to create consumer SESSION_TRANSACTED
      nextBuilder = uriInfo.getAbsolutePathBuilder().path(JmsService.JMS_CREATE_CONS);
      nextBuilder.queryParam("session-mode", JMSContext.SESSION_TRANSACTED);
      builder.link(nextBuilder.build(), JmsService.JMS_CREATE_CONS+"-transacted");
      //link to the lookup
      nextBuilder = uriInfo.getAbsolutePathBuilder();
      builder.link(nextBuilder.build(), "lookup");
      return builder.build();
    } finally {
      JmsContextService.logLinks(builder);
    }
  }
