synchronized long send(
      String type, 
      Map<String, Object> jmsHeaders, 
      Map<String, Object> jmsProps, 
      Object jmsBody, 
      int deliveryMode,
      long deliveryDelay,
      int priority,
      long timeToLive,
      String correlationID) throws Exception {
    // creates the JMS Message
    Message msg = createMessage(type, jmsBody);
    // Sets JMS Message properties
    setJMSProperties(msg, jmsProps);
    
    // Determines the JMS Message QoS, first from jmsHeaders map, second from Rest call
    // parameters (priority), and last using default value from producer.
    if (jmsHeaders != null) {
      if (deliveryMode == -1) {
        try {
          Integer value = (Integer) Helper.getValue(jmsHeaders, "DeliveryMode");
          if (value != null)
            deliveryMode = value.intValue();
        } catch (Exception exc) {
          logger.log(BasicLevel.WARN, "ProducerContext.send(); bad DeliveryMode value", exc);
        }
      }
      if (deliveryDelay == -1) {
        try {
          Long value = (Long) Helper.getValue(jmsHeaders, "DeliveryTime");
          if (value != null)
            deliveryDelay = value.longValue();
        } catch (Exception exc) {
          logger.log(BasicLevel.WARN, "ProducerContext.send(); bad DeliveryTime value", exc);
        }
      }
      if (priority == -1) {
        try {
          Integer value = (Integer) Helper.getValue(jmsHeaders, "Priority");
          if (value != null)
            priority = value.intValue();
        } catch (Exception exc) {
          logger.log(BasicLevel.WARN, "ProducerContext.send(); bad Priority value", exc);
        }
      }
      if (timeToLive == -1) {
        try {
          Long value = (Long) Helper.getValue(jmsHeaders, "Expiration");
          if (value != null)
            timeToLive = value.longValue();
        } catch (Exception exc) {
          logger.log(BasicLevel.WARN, "ProducerContext.send(); bad Expiration value", exc);
        }
      }
      if (correlationID == null) {
        try {
          String value = (String) Helper.getValue(jmsHeaders, "CorrelationID");
          if (value != null)
            correlationID = value;
        } catch (Exception exc) {
          logger.log(BasicLevel.WARN, "ProducerContext.send(); bad CorrelationID value", exc);
        }
      }
    }
    
    if (correlationID == null)
      correlationID = dfltCorrelationID;
    if (correlationID != null)
      msg.setJMSCorrelationID(correlationID);
    
    if (deliveryMode == -1)
      deliveryMode = dfltDeliveryMode;
    if (deliveryDelay == -1)
      deliveryDelay = dfltDeliveryDelay;
    if (priority == -1)
      priority = dfltPriority;
    if (timeToLive == -1)
      timeToLive = dfltTimeToLive;
    
    // send the message
    getProducer().setDeliveryMode(deliveryMode).setPriority(priority).setDeliveryDelay(deliveryDelay).setTimeToLive(timeToLive).send(getDest(), msg);
    // Increment the last id
    incLastId();
    //update activity
    getClientCtx().setLastActivity(System.currentTimeMillis());
    
    return getLastId();
  }
