@GET
  @Path("/domains/{domain}/{objectName}")
  @Produces(MediaType.APPLICATION_JSON)
  public Response getObjectNameJson(
      @PathParam("domain") String domain,
      @PathParam("objectName") String objName,
      @Context UriInfo uriInfo) 
          throws Exception {
    
    if (logger.isLoggable(BasicLevel.INFO))
      logger.log(BasicLevel.INFO, "GET: " + uriInfo.getAbsolutePathBuilder());
    
    if (logger.isLoggable(BasicLevel.DEBUG))
      logger.log(BasicLevel.DEBUG, "getObjectNameJson(" + domain + ", " + objName + ", " + uriInfo + ")");
    
    ResponseBuilder builder = Response.status(Response.Status.OK);
    ByteArrayOutputStream out = new ByteArrayOutputStream();
    JsonWriter writer = new JsonWriter(new OutputStreamWriter(out, "UTF-8"));
    writer.setIndent("  ");
    ObjectName objectName = ObjectName.getInstance(objName);
    MBeanInfo mbeanInfo = mbs.getMBeanInfo(objectName);
    MBeanAttributeInfo[] attributes = mbeanInfo.getAttributes();
    writer.beginObject();
    for (MBeanAttributeInfo attribute : attributes) {
      //link
      builder.link(uriInfo.getAbsolutePathBuilder()
          .path(attribute.getName()).build(), attribute.getName());
      writer.name(attribute.getName());
      try {
        writer.value(getAttribute(objectName, attribute.getName()));
      } catch (Exception e) {
        writer.value(e.getClass().getName() + ": " + e.getMessage());
      }
    }
    writer.flush();
    writer.endObject();
    writer.close();
    String json = out.toString();
    // add Json to the response
    builder.entity(json);

    return builder.build();
  }
