synchronized ActionReturn request(Destination dest, String callee, Action action, long timeout) throws JMSException {
    if (dest == null)
        throw new IllegalStateException("Cannot request \"null\" destination");
    
    if (timeout < 0)
      throw new IllegalStateException("Invalid timeout:" + timeout);

    ObjectMessage request = session.createObjectMessage();
    if (timeout != 0) request.setJMSReplyTo(queue);
    request.setStringProperty("callee", callee);
    request.setIntProperty("type", action.getType());
    request.setObject(action);
    prod.send(dest, request);
    if (timeout == 0) return null;
    String msgid = request.getJMSMessageID();
    long end = System.currentTimeMillis() + timeout;

    Message reply = null;
    while (timeout > 0) {
      reply = null;
      reply = cons.receive(timeout);
      if (reply == null) break;
      if (msgid.equals(reply.getJMSCorrelationID()))
        break;
      timeout = end - System.currentTimeMillis();
    }
    if (reply == null) return null;

    return new ActionReturn(reply.getIntProperty("replyCode"),
                            reply.getStringProperty("replyMsg"));
  }
