public void run() {
    // creating the GUIs representing the CustomerServer 
    customerGUI1 = new GUI("Customer Server", "Deliver", "Don't deliver", this, 300, 100) ;
    customerGUI2 = new GUI("Customer Server", "Not validated by StockServer and/or BillingServer", this, 320, 120) ;
    
    try {
      // getting initial context
      ictx = new InitialContext();
      // connecting to agent agCustomerConnQ
      QueueConnectionFactory qcf;
      qcf = (QueueConnectionFactory) ictx.lookup("qcf");
      // connecting to queueItems, queueBills and queueDelivery 
      Queue queueItems;
      queueItems = (Queue) ictx.lookup("qItems");
      Queue queueBills ;
      queueBills = (Queue) ictx.lookup("qBills");
      Queue queueDelivery ;
      queueDelivery = (Queue) ictx.lookup("qDelivery");
      ictx.close();

      // creating a QueueConnection 
      QueueConnection qc = qcf.createQueueConnection("customer", "customer");
      // creating a QueueSession     
      qsession = qc.createQueueSession(true, Session.AUTO_ACKNOWLEDGE);
      // creating a QueueReceiver (receiving from queueItems) 
      QueueReceiver qrItems = qsession.createReceiver(queueItems);
      // creating a QueueReceiver (receiving from queueBills) 
      QueueReceiver qrBills = qsession.createReceiver(queueBills);
      // creating a QueueSender (sending to queueDelivery)
      qs = qsession.createSender(queueDelivery) ;
      // starting the QueueConnection 
      qc.start() ;
	
      // creating lock object
      lock = new Object() ;
      
      System.out.println("CustomerServer is ready.") ;
      
      while (true) {
        // ObjectMessage got from the FifoQueue
        ObjectMessage msg ;
        
        // waiting for the FifoQueue to be filled 
        msg = (ObjectMessage) queue.get() ;
     
        // poping out FifoQueue's first ObjectMessage 
        msg = (ObjectMessage) queue.pop();
        
        // if msg encapsulates a QuitMessage
        if (msg.getObject() instanceof QuitMessage) {
          // getting the QuitMessage
          QuitMessage quitMsg = (QuitMessage) msg.getObject() ;
          // creating an ObjectMessage and encapsulating the QuitMessage 
          ObjectMessage msgSent = qsession.createObjectMessage();
          msgSent.setObject(quitMsg) ;
          // forwarding the QuitMessage to DeliveryServer 
          qs.send(msgSent) ;
          qsession.commit() ;
          
          // closing sessions and connections
          tsession.close() ;
          tc.close() ;
          qsession.close() ;
          qc.close() ;
          
          System.out.println("Sessions and connections closed by CustomerServer.");
          System.exit(0) ;
        }
        
        // if msg encapsulates an OrderMessage, treat it
        else if (msg.getObject() instanceof OrderMessage) {
          // get encapsulated OrderMessage 
          orderMsg = (OrderMessage) msg.getObject() ;
        
          System.out.println("Message received by CustomerServer from WebServer: " +  orderMsg.id);
        
	  // waiting for an ObjectMessage from queueItems 
	  ObjectMessage msgRec = (ObjectMessage) qrItems.receive() ;
	  // getting encapsulated OkMessage 
	  OkMessage okMsg = (OkMessage)(msgRec.getObject()) ;
	
	  System.out.println("Message received by CustomerServer from InventoryServer: " + okMsg.id);
	
	  // updating ok attribute in current OrderMessage 
	  orderMsg.inventoryOK = okMsg.ok ;

	  // waiting for an ObjectMessage from queueBills 
	  msgRec = (ObjectMessage) qrBills.receive() ;
	  // getting encapsulated OkMessage 
	  okMsg = (OkMessage)(msgRec.getObject()) ;
        
	  System.out.println("Message received by CustomerServer from BillingServer: " + okMsg.id);
	  
	  // updating corresponding attribute in current OrderMessage 
	  orderMsg.billingOK = okMsg.ok ;

	  if (orderMsg.billingOK && orderMsg.inventoryOK) {
	    // updating and activating GUI1 
	    customerGUI1.updateId(okMsg.id) ;
	    customerGUI1.updateItem(okMsg.item) ;
            customerGUI1.setVisible(true) ;
          }
	  else {
	    // updating and activating GUI2 
	    customerGUI2.updateId(okMsg.id) ;
	    customerGUI2.updateItem(okMsg.item) ;
            customerGUI2.setVisible(true) ;
          }
        
          // waiting for GUI interaction
          synchronized(lock) {
            lock.wait() ;
          }
        }
      }
    } catch (Exception exc) {
      System.out.println("Exception caught in CustomerServer thread: " + exc);
      exc.printStackTrace() ;
    }	  
  }
