public void run() {
    // creating the GUI representing the DeliveryServer 
    deliveryGUI = new GUI("Delivery Server", "To be delivered", this, 300, 600);
        
    try {
      // getting initial context
      ictx = new InitialContext();
      // connecting to agent agDeliveryConnQ 
      QueueConnectionFactory qcf;
      qcf = (QueueConnectionFactory) ictx.lookup("qcf");
      // connecting to queueDelivery
      Queue queueDelivery ;
      queueDelivery = (Queue) ictx.lookup("qDelivery");
      ictx.close();

      // creating a QueueConnection 
      QueueConnection qc = qcf.createQueueConnection("delivery", "delivery");
      // creating a QueueSession  
      QueueSession qsession ;       
      qsession = qc.createQueueSession(true, Session.AUTO_ACKNOWLEDGE);
      // creating a QueueReceiver
      QueueReceiver qr = qsession.createReceiver(queueDelivery);
      // starting the connection
      qc.start() ;
      
      System.out.println("DeliveryServer is ready.") ;
      
      while (true) {
        // receiving an ObjectMessage from queueDelivery
    	ObjectMessage msg = (ObjectMessage) qr.receive() ;
	
        // if msg encapsulates a QuitMessage, close session and connection
        if (msg.getObject() instanceof QuitMessage) {
          // commiting the reception
          qsession.commit() ;
        	
          // closing session and connection
          qsession.close() ;
          qc.close() ;
        
          System.out.println("Session and connection closed by DeliveryServer.");
          System.exit(0) ;
        }
        
        // if msg encapsulates an OrderMessage, treat it
        else if (msg.getObject() instanceof OrderMessage) {
          // commiting the reception
          qsession.commit() ;
        	
          // get OrderMessage 
          OrderMessage orderMsg = (OrderMessage) msg.getObject() ;
        
          System.out.println("Message received by DeliveryServer from CustomerServer: " + orderMsg.id) ;
        
          // updating and activating the GUI 
          deliveryGUI.updateId(orderMsg.id) ;
          deliveryGUI.updateItem(orderMsg.item) ;
          deliveryGUI.setVisible(true) ;
        }
      }
    }  catch (Exception exc) {
      System.out.println("Exception caught in DeliveryServer thread: " + exc) ;
      exc.printStackTrace() ;
    }	  
  }
