@Override
    public List<AdminUserField> selectByFilter( AdminUserFieldFilter auFieldFilter )
    {
        List<AdminUserField> listUserFields = new ArrayList<AdminUserField>( );
        List<String> listFilter = new ArrayList<String>( );

        if ( auFieldFilter.containsIdAttribute( ) )
        {
            listFilter.add( SQL_FILTER_ID_ATTRIBUTE );
        }

        if ( auFieldFilter.containsIdUser( ) )
        {
            listFilter.add( SQL_FILTER_ID_USER );
        }

        if ( auFieldFilter.containsIdField( ) )
        {
            listFilter.add( SQL_FILTER_ID_FIELD );
        }

        StringBuilder sbSQL = new StringBuilder( SQL_QUERY_SELECT );

        if ( listFilter.size( ) > 0 )
        {
            boolean bIsFirst = true;

            for ( String filter : listFilter )
            {
                if ( bIsFirst )
                {
                    sbSQL.append( SQL_WHERE );
                    bIsFirst = false;
                }
                else
                {
                    sbSQL.append( SQL_AND );
                }

                sbSQL.append( filter );
            }
        }

        DAOUtil daoUtil = new DAOUtil( sbSQL.toString( ) );
        int nIndex = 1;

        if ( auFieldFilter.containsIdAttribute( ) )
        {
            daoUtil.setInt( nIndex++, auFieldFilter.getIdAttribute( ) );
        }

        if ( auFieldFilter.containsIdUser( ) )
        {
            daoUtil.setInt( nIndex++, auFieldFilter.getIdUser( ) );
        }

        if ( auFieldFilter.containsIdField( ) )
        {
            daoUtil.setInt( nIndex++, auFieldFilter.getIdField( ) );
        }

        daoUtil.executeQuery( );

        while ( daoUtil.next( ) )
        {
            AdminUserField userField = new AdminUserField( );
            userField.setIdUserField( daoUtil.getInt( 1 ) );
            userField.setValue( daoUtil.getString( 6 ) );

            // USER
            AdminUser user = new AdminUser( );
            user.setUserId( daoUtil.getInt( 2 ) );
            user.setAccessCode( daoUtil.getString( 7 ) );
            user.setLastName( daoUtil.getString( 8 ) );
            user.setFirstName( daoUtil.getString( 9 ) );
            user.setEmail( daoUtil.getString( 10 ) );
            user.setStatus( daoUtil.getInt( 11 ) );
            user.setLocale( new Locale( daoUtil.getString( 12 ) ) );
            user.setUserLevel( daoUtil.getInt( 13 ) );
            userField.setUser( user );

            // ATTRIBUTE
            IAttribute attribute = null;

            try
            {
                attribute = (IAttribute) Class.forName( daoUtil.getString( 14 ) ).newInstance( );
            }
            catch( ClassNotFoundException e )
            {
                // class doesn't exist
                AppLogService.error( e );
            }
            catch( InstantiationException e )
            {
                // Class is abstract or is an interface or haven't accessible
                // builder
                AppLogService.error( e );
            }
            catch( IllegalAccessException e )
            {
                // can't access to the class
                AppLogService.error( e );
            }

            attribute.setIdAttribute( daoUtil.getInt( 3 ) );
            attribute.setTitle( daoUtil.getString( 15 ) );
            attribute.setHelpMessage( daoUtil.getString( 16 ) );
            attribute.setMandatory( daoUtil.getBoolean( 17 ) );
            attribute.setPosition( daoUtil.getInt( 18 ) );
            attribute.setAttributeType( new Locale( daoUtil.getString( 12 ) ) );
            userField.setAttribute( attribute );

            // ATTRIBUTEFIELD
            // Here the attribute field may not exist (for example when
            // using an non-mandatory combo box attribute). It will have
            // and idField of 0.
            // Use an empty object (with nulls, zeroes and false) because
            // most of the code relies on this value beeing not null
            // to access the idField.
            AttributeField attributeField = new AttributeField( );
            attributeField.setIdField( daoUtil.getInt( 4 ) );
            attributeField.setTitle( daoUtil.getString( 19 ) );
            attributeField.setValue( daoUtil.getString( 20 ) );
            attributeField.setDefaultValue( daoUtil.getBoolean( 21 ) );
            attributeField.setHeight( daoUtil.getInt( 22 ) );
            attributeField.setWidth( daoUtil.getInt( 23 ) );
            attributeField.setMaxSizeEnter( daoUtil.getInt( 24 ) );
            attributeField.setMultiple( daoUtil.getBoolean( 25 ) );
            attributeField.setPosition( daoUtil.getInt( 26 ) );
            userField.setAttributeField( attributeField );

            // FILE
            if ( daoUtil.getObject( 5 ) != null ) // f.id_file
            {
                File file = new File( );
                file.setIdFile( daoUtil.getInt( 5 ) ); // f.id_file
                userField.setFile( file );
            }

            listUserFields.add( userField );
        }

        daoUtil.free( );

        return listUserFields;
    }
