@Override
    public AdminUser login( String strAccessCode, String strUserPassword, HttpServletRequest request ) throws LoginException
    {
        // Test the number of errors during an interval of minutes
        int nMaxFailed = AdminUserService.getIntegerSecurityParameter( PROPERTY_MAX_ACCESS_FAILED );
        int nIntervalMinutes = AdminUserService.getIntegerSecurityParameter( PROPERTY_INTERVAL_MINUTES );

        if ( ( nMaxFailed > 0 ) && ( nIntervalMinutes > 0 ) )
        {
            // Creating a record of connections log
            UserLog userLog = new UserLog( );
            userLog.setAccessCode( strAccessCode );
            userLog.setIpAddress( SecurityUtil.getRealIp( request ) );
            userLog.setDateLogin( new java.sql.Timestamp( new java.util.Date( ).getTime( ) ) );

            int nNbFailed = UserLogHome.getLoginErrors( userLog, nIntervalMinutes );

            if ( nNbFailed > nMaxFailed )
            {
                throw new FailedLoginException( );
            }
        }

        IPassword pasword = _dao.loadPassword( strAccessCode );

        if ( !pasword.check( strUserPassword ) )
        {
            throw new FailedLoginException( );
        }

        if ( pasword.isLegacy( ) )
        {
            // upgrade password storage
            IPassword upgradedPassword = _passwordFactory.getPasswordFromCleartext( strUserPassword );
            _dao.store( strAccessCode, upgradedPassword );
        }

        LuteceDefaultAdminUser user = _dao.load( strAccessCode, this );

        if ( ( user.getPasswordMaxValidDate( ) != null ) && ( user.getPasswordMaxValidDate( ).getTime( ) < new java.util.Date( ).getTime( ) ) )
        {
            _dao.updateResetPassword( user, Boolean.TRUE );
        }

        AdminUserService.updateUserExpirationDate( user );

        return user;
    }
