public static String checkPassword( HttpServletRequest request, String strPassword, int nUserId, boolean bSkipHistoryCheck )
    {
        // Minimum password length
        int nMinimumLength = AdminUserService.getIntegerSecurityParameter( DSKEY_PASSWORD_MINIMUM_LENGTH );

        if ( ( nMinimumLength > 0 ) && ( strPassword.length( ) < nMinimumLength ) )
        {
            Object [ ] param = {
                nMinimumLength
            };

            return AdminMessageService.getMessageUrl( request, PROPERTY_MESSAGE_MINIMUM_PASSWORD_LENGTH, param, AdminMessage.TYPE_STOP );
        }

        // Password format
        boolean bUserPasswordFormatUpperLowerCase = AdminUserService.getBooleanSecurityParameter( DSKEY_PASSWORD_FORMAT_UPPER_LOWER_CASE );
        boolean bUserPasswordFormatNumero = AdminUserService.getBooleanSecurityParameter( DSKEY_PASSWORD_FORMAT_NUMERO );
        boolean bUserPasswordFormatSpecialCaracters = AdminUserService.getBooleanSecurityParameter( DSKEY_PASSWORD_FORMAT_SPECIAL_CHARACTERS );

        if ( ( bUserPasswordFormatUpperLowerCase || bUserPasswordFormatNumero || bUserPasswordFormatSpecialCaracters )
                && !PasswordUtil.checkPasswordFormat( strPassword, bUserPasswordFormatUpperLowerCase, bUserPasswordFormatNumero,
                        bUserPasswordFormatSpecialCaracters ) )
        {
            StringBuffer strParam = new StringBuffer( );

            // Add Message Upper Lower Case
            if ( bUserPasswordFormatUpperLowerCase )
            {
                strParam.append( I18nService.getLocalizedString( PROPERTY_MESSAGE_PASSWORD_FORMAT_UPPER_LOWER_CASE, request.getLocale( ) ) );
            }

            // Add Message Numero
            if ( bUserPasswordFormatNumero )
            {
                if ( bUserPasswordFormatUpperLowerCase )
                {
                    strParam.append( ", " );
                }

                strParam.append( I18nService.getLocalizedString( PROPERTY_MESSAGE_PASSWORD_FORMAT_NUMERO, request.getLocale( ) ) );
            }

            // Add Message Special Characters
            if ( bUserPasswordFormatSpecialCaracters )
            {
                if ( bUserPasswordFormatUpperLowerCase || bUserPasswordFormatNumero )
                {
                    strParam.append( ", " );
                }

                strParam.append( I18nService.getLocalizedString( PROPERTY_MESSAGE_PASSWORD_FORMAT_SPECIAL_CHARACTERS, request.getLocale( ) ) );
            }

            Object [ ] param = {
                strParam.toString( )
            };

            return AdminMessageService.getMessageUrl( request, PROPERTY_MESSAGE_PASSWORD_FORMAT, param, AdminMessage.TYPE_STOP );
        }

        // Check password history
        if ( ( nUserId > 0 ) && !bSkipHistoryCheck )
        {
            int nPasswordHistorySize = AdminUserService.getIntegerSecurityParameter( DSKEY_PASSWORD_HISTORY_SIZE );

            if ( nPasswordHistorySize > 0 )
            {
                List<IPassword> passwordHistory = AdminUserHome.selectUserPasswordHistory( nUserId );

                if ( nPasswordHistorySize < passwordHistory.size( ) )
                {
                    passwordHistory = passwordHistory.subList( 0, nPasswordHistorySize );
                }

                for ( IPassword password : passwordHistory )
                {
                    if ( password.check( strPassword ) )
                    {
                        return AdminMessageService.getMessageUrl( request, PROPERTY_MESSAGE_PASSWORD_ALREADY_USED, AdminMessage.TYPE_STOP );
                    }
                }
            }

            int nTSWSizePasswordChange = AdminUserService.getIntegerSecurityParameter( DSKEY_TSW_SIZE_PASSWORD_CHANGE );
            int nMaximumNumberPasswordChange = AdminUserService.getIntegerSecurityParameter( DSKEY_MAXIMUM_NUMBER_PASSWORD_CHANGE );

            if ( nMaximumNumberPasswordChange > 0 )
            {
                Timestamp minDate;

                if ( nTSWSizePasswordChange > 0 )
                {
                    minDate = new Timestamp( new java.util.Date( ).getTime( ) - DateUtil.convertDaysInMiliseconds( nTSWSizePasswordChange ) );
                }
                else
                {
                    minDate = new Timestamp( 0 );
                }

                if ( AdminUserHome.countUserPasswordHistoryFromDate( minDate, nUserId ) >= nMaximumNumberPasswordChange )
                {
                    return AdminMessageService.getMessageUrl( request, PROPERTY_MESSAGE_MAX_PASSWORD_CHANGE, AdminMessage.TYPE_STOP );
                }
            }
        }

        return null;
    }
