public static String getXmlFromUser( AdminUser user, boolean bIncludeRoles, boolean bIncludeRights, boolean bIncludeWorkgroups, boolean bIncludeAttributes,
            List<IAttribute> listAttributes )
    {
        StringBuffer sbXml = new StringBuffer( );
        DateFormat dateFormat = new SimpleDateFormat( );

        XmlUtil.beginElement( sbXml, CONSTANT_XML_USER );
        XmlUtil.addElement( sbXml, CONSTANT_XML_ACCESS_CODE, user.getAccessCode( ) );
        XmlUtil.addElement( sbXml, CONSTANT_XML_LAST_NAME, user.getLastName( ) );
        XmlUtil.addElement( sbXml, CONSTANT_XML_FIRST_NAME, user.getFirstName( ) );
        XmlUtil.addElement( sbXml, CONSTANT_XML_EMAIL, user.getEmail( ) );
        XmlUtil.addElement( sbXml, CONSTANT_XML_STATUS, Integer.toString( user.getRealStatus( ) ) );
        XmlUtil.addElement( sbXml, CONSTANT_XML_LOCALE, user.getLocale( ).toString( ) );
        XmlUtil.addElement( sbXml, CONSTANT_XML_LEVEL, Integer.toString( user.getUserLevel( ) ) );
        XmlUtil.addElement( sbXml, CONSTANT_XML_MUST_CHANGE_PASSWORD, Boolean.toString( user.isPasswordReset( ) ) );
        XmlUtil.addElement( sbXml, CONSTANT_XML_ACCESSIBILITY_MODE, Boolean.toString( user.getAccessibilityMode( ) ) );

        String strPasswordMaxValidDate = StringUtils.EMPTY;

        if ( user.getPasswordMaxValidDate( ) != null )
        {
            strPasswordMaxValidDate = dateFormat.format( user.getPasswordMaxValidDate( ) );
        }

        XmlUtil.addElement( sbXml, CONSTANT_XML_PASSWORD_MAX_VALID_DATE, strPasswordMaxValidDate );

        String strAccountMaxValidDate = StringUtils.EMPTY;

        if ( user.getAccountMaxValidDate( ) != null )
        {
            strAccountMaxValidDate = dateFormat.format( user.getAccountMaxValidDate( ) );
        }

        XmlUtil.addElement( sbXml, CONSTANT_XML_ACCOUNT_MAX_VALID_DATE, strAccountMaxValidDate );

        String strDateLastLogin = StringUtils.EMPTY;

        if ( user.getDateLastLogin( ) != null )
        {
            strDateLastLogin = dateFormat.format( user.getDateLastLogin( ) );
        }

        XmlUtil.addElement( sbXml, CONSTANT_XML_DATE_LAST_LOGIN, strDateLastLogin );

        if ( bIncludeRoles )
        {
            Map<String, AdminRole> mapRoles = AdminUserHome.getRolesListForUser( user.getUserId( ) );
            XmlUtil.beginElement( sbXml, CONSTANT_XML_ROLES );

            for ( String strRole : mapRoles.keySet( ) )
            {
                XmlUtil.addElement( sbXml, CONSTANT_XML_ROLE, strRole );
            }

            XmlUtil.endElement( sbXml, CONSTANT_XML_ROLES );
        }

        if ( bIncludeRights )
        {
            XmlUtil.beginElement( sbXml, CONSTANT_XML_RIGHTS );

            Map<String, Right> mapRights = AdminUserHome.getRightsListForUser( user.getUserId( ) );

            for ( String strRight : mapRights.keySet( ) )
            {
                XmlUtil.addElement( sbXml, CONSTANT_XML_RIGHT, strRight );
            }

            XmlUtil.endElement( sbXml, CONSTANT_XML_RIGHTS );
        }

        if ( bIncludeWorkgroups )
        {
            XmlUtil.beginElement( sbXml, CONSTANT_XML_WORKGROUPS );

            ReferenceList refListWorkgroups = AdminWorkgroupHome.getUserWorkgroups( user );

            for ( ReferenceItem refItem : refListWorkgroups )
            {
                XmlUtil.addElement( sbXml, CONSTANT_XML_WORKGROUP, refItem.getCode( ) );
            }

            XmlUtil.endElement( sbXml, CONSTANT_XML_WORKGROUPS );
        }

        if ( bIncludeAttributes )
        {
            Map<String, Object> mapAttributes = AdminUserFieldService.getAdminUserFields( listAttributes, user.getUserId( ), LocaleService.getDefault( ) );
            XmlUtil.beginElement( sbXml, CONSTANT_XML_ATTRIBUTES );

            for ( Entry<String, Object> entry : mapAttributes.entrySet( ) )
            {
                String strAttributeKey = entry.getKey( );
                Object value = entry.getValue( );

                if ( value instanceof List<?> )
                {
                    List<AdminUserField> listFields = (List<AdminUserField>) value;

                    for ( AdminUserField adminUserFields : listFields )
                    {
                        if ( adminUserFields.getIdUserField( ) > 0 )
                        {
                            XmlUtil.beginElement( sbXml, CONSTANT_XML_ATTRIBUTE );
                            XmlUtil.addElement( sbXml, CONSTANT_XML_ATTRIBUTE_ID, strAttributeKey );
                            XmlUtil.addElement( sbXml, CONSTANT_XML_ATTRIBUTE_FIELD_ID, adminUserFields.getAttributeField( ).getIdField( ) );
                            XmlUtil.addElement( sbXml, CONSTANT_XML_ATTRIBUTE_VALUE, adminUserFields.getValue( ) );
                            XmlUtil.endElement( sbXml, CONSTANT_XML_ATTRIBUTE );
                        }
                    }
                }
            }

            XmlUtil.endElement( sbXml, CONSTANT_XML_ATTRIBUTES );
        }

        XmlUtil.endElement( sbXml, CONSTANT_XML_USER );

        return sbXml.toString( );
    }
