@Override
    public String getPage( HttpServletRequest request, int nMode ) throws UserNotSignedException, SiteMessageException
    {
        // Gets XPage info from the lutece.properties
        String strName = request.getParameter( PARAM_XPAGE_APP );

        XPageApplicationEntry entry = getApplicationEntry( strName );

        // TODO : Handle entry == null
        if ( ( entry != null ) && ( entry.isEnable( ) ) )
        {
            XPage page = null;
            List<String> listRoles = entry.getRoles( );

            if ( SecurityService.isAuthenticationEnable( ) && ( listRoles.size( ) > 0 ) )
            {
                LuteceUser user = SecurityService.getInstance( ).getRegisteredUser( request );

                if ( user != null )
                {
                    boolean bAutorized = false;

                    for ( String strRole : listRoles )
                    {
                        if ( SecurityService.getInstance( ).isUserInRole( request, strRole ) )
                        {
                            bAutorized = true;
                        }
                    }

                    if ( bAutorized )
                    {
                        XPageApplication application = getXPageSessionInstance( request, entry );
                        page = application.getPage( request, nMode, entry.getPlugin( ) );
                    }
                    else
                    {
                        // The user doesn't have the correct role
                        String strAccessDeniedTemplate = SecurityService.getInstance( ).getAccessDeniedTemplate( );
                        HtmlTemplate tAccessDenied = AppTemplateService.getTemplate( strAccessDeniedTemplate );
                        page = new XPage( );
                        page.setContent( tAccessDenied.getHtml( ) );
                    }
                }
                else
                {
                    throw new UserNotSignedException( );
                }
            }
            else
            {
                XPageApplication application = getXPageSessionInstance( request, entry );
                page = application.getPage( request, nMode, entry.getPlugin( ) );
            }

            if ( page.isStandalone( ) )
            {
                return page.getContent( );
            }

            PageData data = new PageData( );

            data.setContent( page.getContent( ) );
            data.setName( page.getTitle( ) );

            // set the page path. Done by adding the extra-path information to the pathLabel.
            String strXml = page.getXmlExtendedPathLabel( );

            if ( strXml == null )
            {
                data.setPagePath( PortalService.getXPagePathContent( page.getPathLabel( ), 0, request ) );
            }
            else
            {
                data.setPagePath( PortalService.getXPagePathContent( page.getPathLabel( ), 0, strXml, request ) );
            }

            return PortalService.buildPageContent( data, nMode, request );
        }
        else
        {
            AppLogService.error( "The specified Xpage '" + SecurityUtil.logForgingProtect( strName )
                    + "' cannot be retrieved. Check installation of your Xpage application." );
            SiteMessageService.setMessage( request, MESSAGE_ERROR_APP_BODY, SiteMessage.TYPE_ERROR );

            return null; // unreachable because SiteMessageService.setMessage throws
        }
    }
