protected List<CSVMessageDescriptor> readCSVFile( Reader reader, CSVReader csvReader, int nColumnNumber, boolean bCheckFileBeforeProcessing,
            boolean bExitOnError, boolean bSkipFirstLine, Locale locale, String strBaseUrl )
    {
        List<CSVMessageDescriptor> listMessages = new ArrayList<CSVMessageDescriptor>( );
        int nLineNumber = 0;

        if ( bSkipFirstLine )
        {
            try
            {
                nLineNumber++;
                csvReader.readNext( );
            }
            catch( IOException e )
            {
                AppLogService.error( e.getMessage( ), e );

                CSVMessageDescriptor error = new CSVMessageDescriptor( CSVMessageLevel.ERROR, 1, I18nService.getLocalizedString( MESSAGE_ERROR_READING_FILE,
                        locale ) );
                listMessages.add( error );

                if ( bExitOnError )
                {
                    StreamUtil.safeClose( csvReader );
                    StreamUtil.safeClose( reader );

                    return listMessages;
                }
            }
        }

        List<String [ ]> listLines = null;

        if ( bCheckFileBeforeProcessing )
        {
            listLines = new ArrayList<String [ ]>( );

            String [ ] strLine = null;

            do
            {
                try
                {
                    nLineNumber++;
                    strLine = csvReader.readNext( );
                }
                catch( IOException e )
                {
                    AppLogService.error( e.getMessage( ), e );

                    CSVMessageDescriptor error = new CSVMessageDescriptor( CSVMessageLevel.ERROR, nLineNumber, I18nService.getLocalizedString(
                            MESSAGE_ERROR_READING_FILE, locale ) );
                    listMessages.add( error );

                    if ( bExitOnError )
                    {
                        StreamUtil.safeClose( csvReader );
                        StreamUtil.safeClose( reader );

                        Collections.sort( listMessages );

                        return listMessages;
                    }
                }

                if ( strLine != null )
                {
                    listLines.add( strLine );
                }
            }
            while ( strLine != null );

            List<CSVMessageDescriptor> listCheckErrors = checkCSVFileValidity( listLines, nColumnNumber, bSkipFirstLine, locale );

            if ( listCheckErrors.size( ) > 0 )
            {
                if ( doesListMessageContainError( listCheckErrors ) )
                {
                    listCheckErrors.addAll( 0, listMessages );
                    StreamUtil.safeClose( csvReader );
                    StreamUtil.safeClose( reader );

                    Collections.sort( listMessages );

                    return listCheckErrors;
                }
            }

            nLineNumber = 0;
        }

        boolean bHasMoreLines = true;
        int nNbLinesWithoutErrors = 0;
        String [ ] strLine = null;
        Iterator<String [ ]> iterator = null;

        if ( listLines != null )
        {
            iterator = listLines.iterator( );
        }

        while ( bHasMoreLines )
        {
            nLineNumber++;

            if ( iterator != null )
            {
                if ( iterator.hasNext( ) )
                {
                    strLine = iterator.next( );
                }
                else
                {
                    strLine = null;
                    bHasMoreLines = false;
                }
            }
            else
            {
                try
                {
                    strLine = csvReader.readNext( );
                }
                catch( IOException e )
                {
                    strLine = null;
                    AppLogService.error( e.getMessage( ), e );

                    CSVMessageDescriptor error = new CSVMessageDescriptor( CSVMessageLevel.ERROR, nLineNumber, I18nService.getLocalizedString(
                            MESSAGE_ERROR_READING_FILE, locale ) );
                    listMessages.add( error );

                    if ( bExitOnError )
                    {
                        bHasMoreLines = false;
                    }
                }
            }

            if ( strLine != null )
            {
                try
                {
                    List<CSVMessageDescriptor> listLinesMessages = null;

                    if ( !bCheckFileBeforeProcessing )
                    {
                        listLinesMessages = checkCSVLineColumnNumber( strLine, nColumnNumber, nLineNumber, locale );

                        if ( !doesListMessageContainError( listLinesMessages ) )
                        {
                            List<CSVMessageDescriptor> listFileCheckMessages = checkLineOfCSVFile( strLine, nLineNumber, locale );

                            if ( ( listFileCheckMessages != null ) && ( listFileCheckMessages.size( ) > 0 ) )
                            {
                                if ( ( listLinesMessages != null ) && ( listLinesMessages.size( ) > 0 ) )
                                {
                                    listLinesMessages.addAll( listFileCheckMessages );
                                }
                                else
                                {
                                    listLinesMessages = listFileCheckMessages;
                                }
                            }
                        }

                        if ( ( listLinesMessages != null ) && ( listLinesMessages.size( ) > 0 ) )
                        {
                            listMessages.addAll( listLinesMessages );
                        }
                    }

                    // If the line has no error
                    if ( !doesListMessageContainError( listLinesMessages ) )
                    {
                        List<CSVMessageDescriptor> listMessagesOfCurrentLine = readLineOfCSVFile( strLine, nLineNumber, locale, strBaseUrl );

                        if ( ( listMessagesOfCurrentLine != null ) && ( listMessagesOfCurrentLine.size( ) > 0 ) )
                        {
                            listMessages.addAll( listMessagesOfCurrentLine );
                        }

                        if ( doesListMessageContainError( listMessagesOfCurrentLine ) )
                        {
                            if ( bExitOnError )
                            {
                                bHasMoreLines = false;
                            }
                        }
                        else
                        {
                            nNbLinesWithoutErrors++;
                        }
                    }
                }
                catch( Exception e )
                {
                    AppLogService.error( e.getMessage( ), e );

                    CSVMessageDescriptor error = new CSVMessageDescriptor( CSVMessageLevel.ERROR, nLineNumber, I18nService.getLocalizedString(
                            MESSAGE_UNKOWN_ERROR, locale ) );
                    listMessages.add( error );

                    if ( bExitOnError )
                    {
                        bHasMoreLines = false;
                    }
                }
            }
            else
            {
                bHasMoreLines = false;
            }
        }
        StreamUtil.safeClose( csvReader );
        StreamUtil.safeClose( reader );

        // We incremented the line number for the last line that didn't exist
        nLineNumber--;

        if ( bSkipFirstLine )
        {
            nLineNumber--;
        }

        List<CSVMessageDescriptor> listMessagesEndOfProcess = getEndOfProcessMessages( nLineNumber, nNbLinesWithoutErrors, locale );

        if ( ( listMessagesEndOfProcess != null ) && ( listMessagesEndOfProcess.size( ) > 0 ) )
        {
            listMessages.addAll( 0, listMessagesEndOfProcess );
        }

        Collections.sort( listMessages );

        return listMessages;
    }
