@SuppressWarnings( "deprecation" )
    @Override
    public void run( )
    {
        StringBuilder sbLogs = null;
        StringBuilder sbResult = new StringBuilder( );

        Timestamp currentTimestamp = new Timestamp( new java.util.Date( ).getTime( ) );
        List<Integer> accountsToSetAsExpired = AdminUserHome.getIdUsersWithExpiredLifeTimeList( currentTimestamp );

        // We first set as expirated user that have reached their life time limit
        if ( ( accountsToSetAsExpired != null ) && ( accountsToSetAsExpired.size( ) > 0 ) )
        {
            int nbAccountToExpire = accountsToSetAsExpired.size( );
            String strBody = DatabaseTemplateService.getTemplateFromKey( PARAMETER_CORE_EXPIRATION_MAIL );

            String defaultUserParameter = DefaultUserParameterHome.findByKey( PARAMETER_EXPIRED_ALERT_MAIL_SENDER );
            String strSender = ( defaultUserParameter == null ) ? StringUtils.EMPTY : defaultUserParameter;

            defaultUserParameter = DefaultUserParameterHome.findByKey( PARAMETER_EXPIRED_ALERT_MAIL_SUBJECT );

            String strSubject = ( defaultUserParameter == null ) ? StringUtils.EMPTY : defaultUserParameter;

            for ( Integer nIdUser : accountsToSetAsExpired )
            {
                try
                {
                    AdminUser user = AdminUserHome.findByPrimaryKey( nIdUser );
                    String strUserMail = user.getEmail( );

                    if ( ( strUserMail != null ) && StringUtils.isNotBlank( strUserMail ) )
                    {
                        Map<String, String> model = new HashMap<String, String>( );
                        addParametersToModel( model, nIdUser );

                        HtmlTemplate template = AppTemplateService.getTemplateFromStringFtl( strBody, user.getLocale( ), model );
                        MailService.sendMailHtml( strUserMail, strSender, strSender, strSubject, template.getHtml( ) );
                    }
                }
                catch( Exception e )
                {
                    AppLogService.error( "AccountLifeTimeDaemon - Error sending expiration alert to admin user : " + e.getMessage( ), e );
                }
            }

            AdminUserHome.updateUserStatus( accountsToSetAsExpired, AdminUser.EXPIRED_CODE );

            sbLogs = new StringBuilder( );
            sbLogs.append( "AccountLifeTimeDaemon - " );
            sbLogs.append( Integer.toString( nbAccountToExpire ) );
            sbLogs.append( " account(s) have expired" );
            AppLogService.info( sbLogs.toString( ) );
            sbResult.append( sbLogs.toString( ) );
            sbResult.append( "\n" );
        }
        else
        {
            AppLogService.info( "AccountLifeTimeDaemon - No expired admin user found" );
            sbResult.append( "AccountLifeTimeDaemon - No expired admin user found\n" );
        }

        // We send first alert to users
        long nbDaysBeforeFirstAlert = AdminUserService.getIntegerSecurityParameter( PARAMETER_TIME_BEFORE_ALERT_ACCOUNT );

        Timestamp firstAlertMaxDate = new Timestamp( currentTimestamp.getTime( ) + DateUtil.convertDaysInMiliseconds( nbDaysBeforeFirstAlert ) );

        if ( nbDaysBeforeFirstAlert <= 0 )
        {
            AppLogService.info( "AccountLifeTimeDaemon - First alert deactivated, skipping" );
            sbResult.append( "AccountLifeTimeDaemon - First alert deactivated, skipping\n" );
        }
        else
        {
            List<Integer> userIdListToSendFirstAlert = AdminUserHome.getIdUsersToSendFirstAlert( firstAlertMaxDate );

            if ( ( userIdListToSendFirstAlert != null ) && ( userIdListToSendFirstAlert.size( ) > 0 ) )
            {
                int nbFirstAlertSent = userIdListToSendFirstAlert.size( );
                String strBody = DatabaseTemplateService.getTemplateFromKey( PARAMETER_CORE_FIRST_ALERT_MAIL );

                String defaultUserParameter = DefaultUserParameterHome.findByKey( PARAMETER_FIRST_ALERT_MAIL_SENDER );
                String strSender = ( defaultUserParameter == null ) ? StringUtils.EMPTY : defaultUserParameter;

                defaultUserParameter = DefaultUserParameterHome.findByKey( PARAMETER_FIRST_ALERT_MAIL_SUBJECT );

                String strSubject = ( defaultUserParameter == null ) ? StringUtils.EMPTY : defaultUserParameter;

                for ( Integer nIdUser : userIdListToSendFirstAlert )
                {
                    try
                    {
                        AdminUser user = AdminUserHome.findByPrimaryKey( nIdUser );
                        String strUserMail = user.getEmail( );

                        if ( ( strUserMail != null ) && StringUtils.isNotBlank( strUserMail ) )
                        {
                            Map<String, String> model = new HashMap<String, String>( );
                            addParametersToModel( model, nIdUser );

                            HtmlTemplate template = AppTemplateService.getTemplateFromStringFtl( strBody, user.getLocale( ), model );
                            MailService.sendMailHtml( strUserMail, strSender, strSender, strSubject, template.getHtml( ) );
                        }
                    }
                    catch( Exception e )
                    {
                        AppLogService.error( "AccountLifeTimeDaemon - Error sending first alert to admin user : " + e.getMessage( ), e );
                    }
                }

                AdminUserHome.updateNbAlert( userIdListToSendFirstAlert );

                sbLogs = new StringBuilder( );
                sbLogs.append( "AccountLifeTimeDaemon - " );
                sbLogs.append( Integer.toString( nbFirstAlertSent ) );
                sbLogs.append( " first alert(s) have been sent" );
                AppLogService.info( sbLogs.toString( ) );
                sbResult.append( sbLogs.toString( ) );
                sbResult.append( "\n" );

                userIdListToSendFirstAlert = null;
            }
            else
            {
                AppLogService.info( "AccountLifeTimeDaemon - No first alert to send" );
                sbResult.append( "AccountLifeTimeDaemon - No first alert to send\n" );
            }
        }

        // We send other alert to users
        int maxNumberOfAlerts = AdminUserService.getIntegerSecurityParameter( PARAMETER_NB_ALERT_ACCOUNT );
        int nbDaysBetweenAlerts = AdminUserService.getIntegerSecurityParameter( PARAMETER_TIME_BETWEEN_ALERTS_ACCOUNT );
        Timestamp timeBetweenAlerts = new Timestamp( DateUtil.convertDaysInMiliseconds( nbDaysBetweenAlerts ) );

        if ( ( maxNumberOfAlerts <= 0 ) || ( nbDaysBetweenAlerts <= 0 ) )
        {
            AppLogService.info( "AccountLifeTimeDaemon - Other alerts deactivated, skipping" );
            sbResult.append( "AccountLifeTimeDaemon - Other alerts deactivated, skipping\n" );
        }
        else
        {
            List<Integer> userIdListToSendNextAlert = AdminUserHome.getIdUsersToSendOtherAlert( firstAlertMaxDate, timeBetweenAlerts, maxNumberOfAlerts );

            if ( ( userIdListToSendNextAlert != null ) && ( userIdListToSendNextAlert.size( ) > 0 ) )
            {
                int nbOtherAlertSent = userIdListToSendNextAlert.size( );
                String strBody = DatabaseTemplateService.getTemplateFromKey( PARAMETER_CORE_OTHER_ALERT_MAIL );

                String defaultUserParameter = DefaultUserParameterHome.findByKey( PARAMETER_OTHER_ALERT_MAIL_SENDER );
                String strSender = ( defaultUserParameter == null ) ? StringUtils.EMPTY : defaultUserParameter;

                defaultUserParameter = DefaultUserParameterHome.findByKey( PARAMETER_OTHER_ALERT_MAIL_SUBJECT );

                String strSubject = ( defaultUserParameter == null ) ? StringUtils.EMPTY : defaultUserParameter;

                for ( Integer nIdUser : userIdListToSendNextAlert )
                {
                    try
                    {
                        AdminUser user = AdminUserHome.findByPrimaryKey( nIdUser );
                        String strUserMail = user.getEmail( );

                        if ( ( strUserMail != null ) && StringUtils.isNotBlank( strUserMail ) )
                        {
                            Map<String, String> model = new HashMap<String, String>( );
                            addParametersToModel( model, nIdUser );

                            HtmlTemplate template = AppTemplateService.getTemplateFromStringFtl( strBody, user.getLocale( ), model );
                            MailService.sendMailHtml( strUserMail, strSender, strSender, strSubject, template.getHtml( ) );
                        }
                    }
                    catch( Exception e )
                    {
                        AppLogService.error( "AccountLifeTimeDaemon - Error sending next alert to admin user : " + e.getMessage( ), e );
                    }
                }

                AdminUserHome.updateNbAlert( userIdListToSendNextAlert );

                sbLogs = new StringBuilder( );
                sbLogs.append( "AccountLifeTimeDaemon - " );
                sbLogs.append( Integer.toString( nbOtherAlertSent ) );
                sbLogs.append( " next alert(s) have been sent" );
                AppLogService.info( sbLogs.toString( ) );
                sbResult.append( sbLogs.toString( ) );

                userIdListToSendNextAlert = null;
            }
            else
            {
                AppLogService.info( "AccountLifeTimeDaemon - No next alert to send" );
                sbResult.append( "AccountLifeTimeDaemon - No next alert to send" );
            }
        }

        if ( AdminUserService.getBooleanSecurityParameter( PARAMETER_NOTIFY_USER_PASSWORD_EXPIRED ) )
        {
            // We notify users with expired passwords
            List<Integer> accountsWithPasswordsExpired = AdminUserHome.getIdUsersWithExpiredPasswordsList( currentTimestamp );

            if ( ( accountsWithPasswordsExpired != null ) && ( accountsWithPasswordsExpired.size( ) > 0 ) )
            {
                String strSender = AdminUserService.getSecurityParameter( PARAMETER_PASSWORD_EXPIRED_MAIL_SENDER );
                String strSubject = AdminUserService.getSecurityParameter( PARAMETER_PASSWORD_EXPIRED_MAIL_SUBJECT );
                String strBody = DatabaseTemplateService.getTemplateFromKey( PARAMETER_CORE_PASSWORD_EXPIRED_ALERT_MAIL );

                if ( StringUtils.isNotBlank( strBody ) )
                {
                    for ( Integer nIdUser : accountsWithPasswordsExpired )
                    {
                        AdminUser user = AdminUserHome.findByPrimaryKey( nIdUser );
                        String strUserMail = user.getEmail( );

                        if ( StringUtils.isNotBlank( strUserMail ) )
                        {
                            Map<String, String> model = new HashMap<String, String>( );
                            addParametersToModel( model, nIdUser );

                            HtmlTemplate template = AppTemplateService.getTemplateFromStringFtl( strBody, LocaleService.getDefault( ), model );

                            MailService.sendMailHtml( strUserMail, strSender, strSender, strSubject, template.getHtml( ) );
                        }
                    }
                }

                AdminUserHome.updateChangePassword( accountsWithPasswordsExpired );
                sbLogs = new StringBuilder( );
                sbLogs.append( "AccountLifeTimeDaemon - " );
                sbLogs.append( Integer.toString( accountsWithPasswordsExpired.size( ) ) );
                sbLogs.append( " user(s) have been notified their password has expired" );
                AppLogService.info( sbLogs.toString( ) );
                sbResult.append( sbLogs.toString( ) );
                sbResult.append( "\n" );
            }
            else
            {
                AppLogService.info( "AccountLifeTimeDaemon - No expired passwords" );
                sbResult.append( "AccountLifeTimeDaemon - No expired passwords" );
            }
        }
        else
        {
            AppLogService.info( "AccountLifeTimeDaemon - Expired passwords notification deactivated, skipping" );
            sbResult.append( "AccountLifeTimeDaemon - Expired passwords notification deactivated, skipping" );
        }

        setLastRunLogs( sbResult.toString( ) );
    }
