public static void registerDaemon( DaemonEntry entry ) throws LuteceInitException
    {
        if ( _mapDaemonEntries.containsKey( entry.getId( ) ) )
        {
            AppLogService.error( "Ignoring attempt to register already registered daemon " + entry.getId( ) );
            return;
        }
        String strIntervalKey = getIntervalKey( entry.getId( ) );
        String strIntervalKeyDefaultValue = null;

        // init interval value if no exists
        if ( !DatastoreService.existsInstanceKey( strIntervalKey ) )
        {
            strIntervalKeyDefaultValue = AppPropertiesService.getProperty( "daemon." + entry.getId( ) + ".interval", "10" );
            DatastoreService.setInstanceDataValue( strIntervalKey, strIntervalKeyDefaultValue );
        }

        String strIntervalKeyValue = DatastoreService.getInstanceDataValue( strIntervalKey, strIntervalKeyDefaultValue );

        long lInterval = Long.valueOf( strIntervalKeyValue );

        String strOnStartupKey = getOnStartupKey( entry.getId( ) );
        String strOnStartupDefaultValue = null;

        // init onStartup value if no exists
        if ( !DatastoreService.existsInstanceKey( strOnStartupKey ) )
        {
            strOnStartupDefaultValue = AppPropertiesService.getProperty( "daemon." + entry.getId( ) + ".onstartup", "0" ).equals( "1" ) ? DatastoreService.VALUE_TRUE
                    : DatastoreService.VALUE_FALSE;
            DatastoreService.setInstanceDataValue( strOnStartupKey, strOnStartupDefaultValue );
        }

        String strOnStarupvalue = DatastoreService.getInstanceDataValue( strOnStartupKey, strOnStartupDefaultValue );
        boolean bOnStartup = Boolean.valueOf( strOnStarupvalue );

        entry.setInterval( lInterval );
        entry.setOnStartUp( bOnStartup );

        try
        {
            entry.loadDaemon( );
        }
        catch( ClassNotFoundException e )
        {
            throw new LuteceInitException( "Couldn't instantiate daemon: " + entry.getId( ), e );
        }
        catch( InstantiationException e )
        {
            throw new LuteceInitException( "Couldn't instantiate daemon: " + entry.getId( ), e );
        }
        catch( IllegalAccessException e )
        {
            throw new LuteceInitException( "Couldn't instantiate daemon: " + entry.getId( ), e );
        }

        // Add plugin name to Daemon class
        if ( entry.getPluginName( ) != null )
        {
            entry.getDaemon( ).setPluginName( entry.getPluginName( ) );
        }

        _mapDaemonEntries.put( entry.getId( ), entry );

        AppLogService.info( "New Daemon registered : " + entry.getId( ) );
    }
