public static void init( ServletContext context ) throws LuteceInitException
    {
        _context = context;
        AppLogService.info( "Initialize plugins filters" );

        for ( LuteceFilter filter : FilterService.getInstance( ).getFilters( ) )
        {
            // Catch exception for each filter to execute all chain
            try
            {
                if ( filter.getPlugin( ).isInstalled( ) )
                {
                    // Create a FilterConfig wrapper to provide init parameters to the filter
                    LuteceFilterConfig filterConfig = new LuteceFilterConfig( filter.getName( ), _context, filter.getInitParameters( ) );
                    filter.getFilter( ).init( filterConfig );
                    AppLogService.info( " * filter '" + filter.getName( ) + "' from plugin " + filter.getPlugin( ).getName( ) + " initialized." );
                }
            }
            catch( Exception e )
            {
                AppLogService.error( "Error execution init() method - Filter " + filter.getName( ), e );
                throw new LuteceInitException( "Error execution init() method - Filter " + filter.getName( ), e );
            }
        }

        sortFilters( );

        if ( AppLogService.isDebugEnabled( ) )
        {
            AppLogService.debug( "Displaying filters order" );

            for ( LuteceFilter filter : FilterService.getInstance( ).getFilters( ) )
            {
                AppLogService.debug( filter.getName( ) + " - order = " + filter.getOrder( ) );
            }
        }
    }
