public void doFilter( ServletRequest requestServlet, ServletResponse responseServlet, FilterChain chain ) throws IOException, ServletException
    {
        AppLogService.debug( "MainFilter : doFilter()" );

        HttpServletRequest request = (HttpServletRequest) requestServlet;
        HttpServletResponse response = (HttpServletResponse) responseServlet;
        LuteceFilterChain chainPluginsFilters = new LuteceFilterChain( );

        for ( LuteceFilter filter : FilterService.getInstance( ).getFilters( ) )
        {
            AppLogService.debug( "PluginFilter : " + filter.getName( ) + " - url pattern : " + filter.getMappingUrlPattern( ) );

            // Catch exception for each filter to execute all chain
            try
            {
                // Checks mapping and plugin status
                if ( matchMapping( filter, request ) && filter.getPlugin( ).isInstalled( ) )
                {
                    chainPluginsFilters.setFollowChain( false );
                    filter.getFilter( ).doFilter( request, response, chainPluginsFilters );

                    if ( !chainPluginsFilters.shouldFollowChain( ) )
                    {
                        // The filter didn't call chain.doFilter so the chain should be interrupted
                        return;
                    }

                    // the filter may have changed (wrapped) the request [like CAS filter] or the response
                    request = (HttpServletRequest) chainPluginsFilters.getRequest( );
                    response = (HttpServletResponse) chainPluginsFilters.getResponse( );
                }
            }
            catch( Exception e )
            {
                AppLogService.error( "Error execution doFilter method - Filter " + filter.getName( ), e );
            }
        }

        // Follow the standard filters chain
        chain.doFilter( request, response );
        // We check that some transactions is not still running for the current thread
        TransactionManager.rollBackEveryTransaction( );
    }
