protected void processRequest( HttpServletRequest request, HttpServletResponse response ) throws ServletException
    {
        String strResourceId = request.getParameter( PARAMETER_ID );
        String strResourceTypeId = request.getParameter( PARAMETER_RESOURCE_TYPE );

        // Passing the request through thread local variables to keep binary compatibility
        // because the ImageResourceProvider doesn't pass it explicitly. When everything
        // is java8, we could instead use default methods of the interface.
        LocalVariables.setLocal( getServletConfig( ), request, response );

        try
        {
            ImageResource image;

            if ( strResourceId != null )
            {
                int nResourceId = Integer.parseInt( strResourceId );
                image = ImageResourceManager.getImageResource( strResourceTypeId, nResourceId );

                // Test the field image value
                if ( getImageExist( image ) )
                {
                    response.setContentType( image.getMimeType( ) );

                    OutputStream out = null;
                    try
                    {
                        out = response.getOutputStream( );
                        out.write( image.getImage( ) );
                        out.flush( );
                        out.close( );
                    }
                    catch( IOException ex )
                    {
                        AppLogService.error( "ImageServlet error : " + ex.getMessage( ), ex );
                    }
                    finally
                    {
                        StreamUtil.safeClose( out );
                    }
                }
                else
                {
                    ServletContext sc = getServletContext( );
                    String strImageUrl = AppPathService.getAbsolutePathFromRelativePath( AppPropertiesService.getProperty( PROPERTY_PATH_IMAGES ) + "/"
                            + AppPropertiesService.getProperty( PROPERTY_IMAGE_PAGE_DEFAULT ) ); //
                    response.setContentType( sc.getMimeType( strImageUrl ) );

                    File file = new File( strImageUrl );
                    response.setContentLength( (int) file.length( ) );

                    FileInputStream in = null;
                    OutputStream out = null;

                    try
                    {
                        // Open the file and output streams
                        in = new FileInputStream( file );

                        out = response.getOutputStream( );

                        // Copy the contents of the file to the output stream
                        byte [ ] buf = new byte [ 1024];
                        int count;
                        while ( ( count = in.read( buf ) ) >= 0 )
                        {
                            out.write( buf, 0, count );
                        }

                        in.close( );
                        out.close( );
                    }
                    catch( IOException ex )
                    {
                        AppLogService.error( "ImageServlet error : " + ex.getMessage( ), ex );
                    }
                    finally
                    {
                        StreamUtil.safeClose( in );
                        StreamUtil.safeClose( out );
                    }
                }
            }
        }
        finally
        {
            LocalVariables.setLocal( null, null, null );
        }
    }
