public static void initServices( ServletContext context, String strConfPath, String strRealPath )
    {
        try
        {
            Thread.currentThread( ).setName( "Lutece-MainThread" );
            // Initializes a very basic logging system (everything to stdout)
            AppLogService.preinit( );
            // Initializes the properties download files containing the variables used by the application
            AppPropertiesService.init( strConfPath );

            // Initializes the template services from the servlet context information
            AppTemplateService.init( PATH_TEMPLATES );

            // Initializes the Datastore Service
            DatastoreService.init( );

            if ( strRealPath != null )
            {
                // Initializes the properties download files containing the
                // variables used by the application
                initProperties( strRealPath );
            }

            // Initializes the log service from the property files
            AppLogService.init( strConfPath, FILE_PROPERTIES_CONFIG );
            AppLogService.info( "Starting LUTECE ..." );
            AppLogService.info( "Running version " + AppInfo.getVersion( ) );

            // BeanUtil initialization, considering Lutèce availables locales and date format properties
            BeanUtil.init( );

            // Initializes the connection pools
            AppConnectionService.init( strConfPath, FILE_PROPERTIES_DATABASE, "portal" );
            AppLogService.info( "Creating connexions pool 'portal'." );

            // Spring ApplicationContext initialization
            AppLogService.info( "Loading context files ..." );
            SpringContextService.init( context );

            // Initialize and run StartUp services
            AppLogService.info( "Running extra startup services ..." );
            StartUpServiceManager.init( );

            // XmlTransformer service cache manager
            XmlTransformerCacheService.init( );

            AdminMailingListService.init( );

            // Initializes Search Engine Indexation Service
            IndexationService.init( );

            // Initializes PluginService
            AppLogService.info( "Initializing plugins ..." );
            PluginService.init( );

            // Initializes FilterService and ServletService
            AppLogService.info( "Initializing plugins filters ..." );
            FilterService.init( context );
            AppLogService.info( "Initializing plugins servlets ..." );
            ServletService.init( context );

            // Trace Contents services loading
            traceContentServicesLoading( );

            // Initializes the SecurityService
            SecurityService.init( );

            // Initializes plugins autoincludes - needs to be launched before the daemons (indexer could fail)
            AppTemplateService.initAutoIncludes( );

            // Initializes the daemons service
            AppDaemonService.init( );

            // Initializes the admin authentication module
            AdminAuthenticationService.init( );

            // Initialize FileImageService
            FileImageService.init( );

            // Initialize AdminUserService
            AdminUserService.init( );

            // Process post startup services
            AppLogService.info( "Running post startup services ..." );
            PostStartUpServiceManager.init( );

            // Initialize Content Post Processor Service
            ContentPostProcessorService.init( );

            _bInitSuccessfull = true;

            logStartupTime( );

            // Start datastore's cache after all processes that may use Datastore
            DatastoreService.startCache( );
        }
        catch( LuteceInitException e )
        {
            _strLoadingFailureCause = e.getMessage( );

            Throwable cause = e.getCause( );

            while ( cause != null )
            {
                _strLoadingFailureDetails = cause.getMessage( );
                cause = cause.getCause( );
            }
        }
    }
