@Override
    public synchronized void run( )
    {
        Logger logger = Logger.getLogger( "lutece.mail" );
        logger.setAdditivity( false );

        String strHost = AppPropertiesService.getProperty( PROPERTY_MAIL_HOST );
        String strUsername = AppPropertiesService.getProperty( PROPERTY_MAIL_USERNAME, null );
        String strPassword = AppPropertiesService.getProperty( PROPERTY_MAIL_PASSWORD, null );
        int nStmpPort = AppPropertiesService.getPropertyInt( PROPERTY_MAIL_PORT, DEFAULT_SMTP_PORT );
        int nWaitTime = AppPropertiesService.getPropertyInt( PROPERTY_MAIL_DEAMON_WAITTIME, 1 );
        int nCount = AppPropertiesService.getPropertyInt( PROPERTY_MAIL_DEAMON_COUNT, 1000 );
        long nRetryWaitTime = AppPropertiesService.getPropertyLong( PROPERTY_MAIL_DAEMON_RETRYONERROR_WAITTIME, 60L );
        TimeUnit retryWaitTimeUnit = TimeUnit.valueOf( AppPropertiesService.getProperty( PROPERTY_MAIL_DAEMON_RETRYONERROR_WAITTIME_UNIT, "SECONDS" ) );

        // Initializes a mail session with the SMTP server
        StringBuilder sbLogs = new StringBuilder( );
        StringBuilder sbLogsLine;
        IMailQueue queue = MailService.getQueue( );

        if ( queue.size( ) != 0 )
        {
            sbLogs.append( new Date( ).toString( ) );

            Session session = MailUtil.getMailSession( strHost, nStmpPort, strUsername, strPassword );
            Transport transportSmtp = null;

            try
            {
                transportSmtp = MailUtil.getTransport( session );
            }
            catch( NoSuchProviderException e )
            {
                AppLogService.error( e );
            }

            if ( transportSmtp != null )
            {
                try
                {
                    transportSmtp.connect( strHost, nStmpPort, strUsername, strPassword );

                    MailItem mail = queue.consume( );
                    int count = 0;

                    while ( mail != null )
                    {
                        try
                        {
                            if ( mail.isUniqueRecipientTo( ) )
                            {
                                List<String> listAdressTo = MailUtil.getAllStringAdressOfRecipients( mail.getRecipientsTo( ) );

                                for ( String strAdressTo : listAdressTo )
                                {
                                    sbLogsLine = new StringBuilder( );
                                    // just one recipient by mail
                                    mail.setRecipientsTo( strAdressTo );
                                    sendMail( mail, strHost, transportSmtp, session, sbLogsLine );
                                    logger.info( sbLogsLine.toString( ) );
                                    sbLogs.append( "\r\n" );
                                    sbLogs.append( sbLogsLine );
                                }
                            }
                            else
                            {
                                sbLogsLine = new StringBuilder( );
                                sendMail( mail, strHost, transportSmtp, session, sbLogsLine );
                                logger.info( sbLogsLine.toString( ) );
                                sbLogs.append( "\r\n" );
                                sbLogs.append( sbLogsLine );
                            }
                        }
                        catch( MessagingException e )
                        {
                            // if the connection is dead or not in the connected state
                            // we put the mail in the queue before end process
                            queue.send( mail );
                            AppLogService.error( "Error while sending a message. Will schedule a retry", e );
                            AppDaemonService.signalDaemon( DAEMON_ID, nRetryWaitTime, retryWaitTimeUnit );
                            break;
                        }

                        mail = queue.consume( );

                        // Tempo
                        count++;

                        if ( ( count % nCount ) == 0 )
                        {
                            transportSmtp.close( );
                            AppDaemonService.signalDaemon( DAEMON_ID, nWaitTime, TimeUnit.MILLISECONDS );
                            break;
                        }
                    }

                    transportSmtp.close( );
                }
                catch( MessagingException e )
                {
                    sbLogs.append( "MailService - Error sending mail (MessagingException): " );
                    sbLogs.append( e.getMessage( ) );
                    AppLogService.error( "MailService - Error sending mail (MessagingException): " + e.getMessage( ), e );
                }
                catch( Exception e )
                {
                    sbLogs.append( "MailService - Error sending mail : " );
                    sbLogs.append( e.getMessage( ) );
                    AppLogService.error( "MailService - Error sending mail : " + e.getMessage( ), e );
                }
            }

            // reset all resource stored in MailAttachmentCacheService
            MailAttachmentCacheService.getInstance( ).resetCache( );
            setLastRunLogs( sbLogs.toString( ) );
        }
        else
        {
            sbLogs.append( "\r\nNo mail to send " );
            sbLogs.append( new Date( ).toString( ) );
            logger.debug( sbLogs.toString( ) );
        }
    }
