public String buildPageContent( String strIdPage, int nMode, HttpServletRequest request, Boolean bCanBeCached ) throws SiteMessageException
    {
        int nIdPage = 0;
        Page page = null;

        nIdPage = Integer.parseInt( strIdPage );

        boolean bPageExist = PageHome.checkPageExist( nIdPage );

        if ( bPageExist )
        {
            page = PageHome.getPage( nIdPage );
        }
        else
        {
            // If there is a problem finding the page, returns the home page
            nIdPage = PortalService.getRootPageId( );
            page = PageHome.getPage( nIdPage );
        }

        PageData data = new PageData( );
        data.setName( page.getName( ) );
        data.setPagePath( PortalService.getPagePathContent( nIdPage, nMode, request ) );
        data.setTheme( page.getCodeTheme( ) );
        data.setMetaKeywords( page.getMetaKeywords( ) );
        data.setMetaDescription( page.getMetaDescription( ) );
        data.setDisplayDateUpdate( page.getDisplayDateUpdate( ) );
        data.setDateUpdate( page.getDateUpdate( ) );

        // Checks the page role (v1.1)
        String strRole = page.getRole( );

        if ( !strRole.equals( Page.ROLE_NONE ) && ( SecurityService.isAuthenticationEnable( ) ) && ( nMode != MODE_ADMIN ) )
        {
            LuteceUser user = SecurityService.getInstance( ).getRegisteredUser( request );

            if ( ( user == null ) && ( !SecurityService.getInstance( ).isExternalAuthentication( ) ) )
            {
                // The user is not registered and identify itself with the
                // Portal authentication
                String strAccessControledTemplate = SecurityService.getInstance( ).getAccessControledTemplate( );
                HashMap<String, Object> model = new HashMap<String, Object>( );
                String strLoginUrl = SecurityService.getInstance( ).getLoginPageUrl( );
                model.put( MARK_URL_LOGIN, strLoginUrl );

                HtmlTemplate tAccessControled = AppTemplateService.getTemplate( strAccessControledTemplate, request.getLocale( ), model );

                data.setContent( tAccessControled.getHtml( ) );

                return PortalService.buildPageContent( nIdPage, data, nMode, request );
            }

            if ( !SecurityService.getInstance( ).isUserInRole( request, strRole ) )
            {
                // The user doesn't have the correct role
                String strAccessDeniedTemplate = SecurityService.getInstance( ).getAccessDeniedTemplate( );
                HtmlTemplate tAccessDenied = AppTemplateService.getTemplate( strAccessDeniedTemplate, request.getLocale( ) );
                data.setContent( tAccessDenied.getHtml( ) );

                return PortalService.buildPageContent( nIdPage, data, nMode, request );
            }
        }

        // Added in v2.0
        // Add the page authorization
        if ( nMode == MODE_ADMIN )
        {
            AdminUser user = AdminUserService.getAdminUser( request );

            if ( isAuthorizedAdminPage( nIdPage, PageResourceIdService.PERMISSION_VIEW, user ) )
            {
                // Fill a PageData structure for those elements
                data.setContent( getPageContent( nIdPage, nMode, request ) );
            }
            else
            {
                data.setContent( I18nService.getLocalizedString( PROPERTY_MESSAGE_PAGE_ACCESS_DENIED, user.getLocale( ) ) );
            }
        }
        else
        {
            data.setContent( getPageContent( nIdPage, nMode, request ) );
        }

        if ( nIdPage == PortalService.getRootPageId( ) )
        {
            // This page is the home page.
            data.setHomePage( true );
        }

        return PortalService.buildPageContent( nIdPage, data, nMode, request );
    }
