@Override
    public String getPage( String strIdPage, int nMode, HttpServletRequest request ) throws SiteMessageException
    {
        try
        {
            String strPage = "";

            // The cache is enable !
            if ( _cachePages.isCacheEnable( ) )
            {
                // Get request paramaters and store them in a HashMap
                Enumeration<?> enumParam = request.getParameterNames( );
                HashMap<String, String> htParamRequest = new HashMap<String, String>( );
                String paramName = "";

                while ( enumParam.hasMoreElements( ) )
                {
                    paramName = (String) enumParam.nextElement( );
                    htParamRequest.put( paramName, request.getParameter( paramName ) );
                }

                if ( !htParamRequest.containsKey( Parameters.PAGE_ID ) )
                {
                    htParamRequest.put( Parameters.PAGE_ID, strIdPage );
                }

                if ( !htParamRequest.containsKey( Parameters.BASE_URL ) )
                {
                    htParamRequest.put( Parameters.BASE_URL, AppPathService.getBaseUrl( request ) );
                }

                LuteceUser user = SecurityService.getInstance( ).getRegisteredUser( request );
                String strUserTheme = ThemesService.getUserTheme( request );

                if ( strUserTheme != null )
                {
                    htParamRequest.put( KEY_THEME, strUserTheme );
                }

                // we add the key in the memory key only if cache is enable
                String strKey = getKey( htParamRequest, nMode, user );

                // get page from cache
                strPage = (String) _cachePages.getFromCache( strKey );

                if ( strPage == null )
                {
                    // only one thread can evaluate the page
                    synchronized( strKey )
                    {
                        // can be useful if an other thread had evaluate the
                        // page
                        strPage = (String) _cachePages.getFromCache( strKey );

                        // ignore checkstyle, this double verification is useful
                        // when page cache has been created when thread is
                        // blocked on synchronized
                        if ( strPage == null )
                        {
                            Boolean bCanBeCached = Boolean.TRUE;

                            AppLogService.debug( "Page generation " + strKey );

                            RedirectionResponseWrapper response = new RedirectionResponseWrapper( LocalVariables.getResponse( ) );

                            LocalVariables.setLocal( LocalVariables.getConfig( ), LocalVariables.getRequest( ), response );
                            request.setAttribute( ATTRIBUTE_CORE_CAN_PAGE_BE_CACHED, null );
                            // The key is not in the cache, so we have to build
                            // the page
                            strPage = buildPageContent( strIdPage, nMode, request, bCanBeCached );

                            // We check if the page contains portlets that can not be cached.
                            if ( ( request.getAttribute( ATTRIBUTE_CORE_CAN_PAGE_BE_CACHED ) != null )
                                    && !(Boolean) request.getAttribute( ATTRIBUTE_CORE_CAN_PAGE_BE_CACHED ) )
                            {
                                bCanBeCached = Boolean.FALSE;
                            }

                            if ( response.getRedirectLocation( ) != null )
                            {
                                AppLogService.debug( "Redirection found " + response.getRedirectLocation( ) );
                                strPage = REDIRECTION_KEY + response.getRedirectLocation( );
                            }

                            // Add the page to the cache if the page can be
                            // cached
                            if ( bCanBeCached.booleanValue( ) && ( nMode != MODE_ADMIN ) )
                            {
                                _cachePages.putInCache( strKey, strPage );
                            }
                        }
                        else
                        {
                            AppLogService.debug( "Page read from cache after synchronisation " + strKey );
                        }
                    }
                }
                else
                {
                    AppLogService.debug( "Page read from cache " + strKey );
                }

                // redirection handling
                if ( strPage.startsWith( REDIRECTION_KEY ) )
                {
                    strPage = strPage.replaceFirst( REDIRECTION_KEY, "" );

                    try
                    {
                        LocalVariables.getResponse( ).sendRedirect( strPage );
                    }
                    catch( IOException e )
                    {
                        AppLogService.error( "Error on sendRedirect for " + strPage );
                    }
                }
            }
            else
            {
                Boolean bCanBeCached = Boolean.FALSE;
                strPage = buildPageContent( strIdPage, nMode, request, bCanBeCached );
            }

            return strPage;
        }
        catch( NumberFormatException nfe )
        {
            AppLogService.error( "PageService.getPage() : " + nfe.getLocalizedMessage( ), nfe );

            throw new PageNotFoundException( );
        }
    }
