private String getPortletContent( HttpServletRequest request, Portlet portlet, Map<String, String> mapRequestParams, int nMode )
            throws SiteMessageException
    {
        if ( ( nMode != MODE_ADMIN ) && ( portlet.getStatus( ) == Portlet.STATUS_UNPUBLISHED ) )
        {
            return StringUtils.EMPTY;
        }

        String strRole = portlet.getRole( );

        if ( !strRole.equals( Page.ROLE_NONE ) && ( SecurityService.isAuthenticationEnable( ) ) && ( nMode != MODE_ADMIN ) )
        {
            if ( !SecurityService.getInstance( ).isUserInRole( request, strRole ) )
            {
                return StringUtils.EMPTY;
            }
        }

        if ( request != null )
        {
            String strPluginName = portlet.getPluginName( );
            request.setAttribute( PARAMETER_PLUGIN_NAME, strPluginName );
        }

        String strPortletContent = StringUtils.EMPTY;

        // Add the admin buttons for portlet management on admin mode
        if ( nMode == MODE_ADMIN )
        {
            strPortletContent = addAdminButtons( request, portlet );
        }

        String strKey = StringUtils.EMPTY;

        if ( portlet.isContentGeneratedByXmlAndXsl( ) )
        {
            Map<String, String> mapParams = mapRequestParams;
            Map<String, String> mapXslParams = portlet.getXslParams( );

            if ( mapParams != null )
            {
                if ( mapXslParams != null )
                {
                    for ( Entry<String, String> entry : mapXslParams.entrySet( ) )
                    {
                        mapParams.put( entry.getKey( ), entry.getValue( ) );
                    }
                }
            }
            else
            {
                mapParams = mapXslParams;
            }

            Properties outputProperties = ModeHome.getOuputXslProperties( nMode );

            String strXslUniqueId = XSL_UNIQUE_PREFIX + String.valueOf( portlet.getStyleId( ) );

            if ( ( ( nMode != MODE_ADMIN ) && _cachePortlets.isCacheEnable( ) ) )
            {
                LuteceUser user = null;

                if ( SecurityService.isAuthenticationEnable( ) )
                {
                    user = SecurityService.getInstance( ).getRegisteredUser( request );
                }

                boolean bCanBeCached = ( user != null ) ? ( portlet.canBeCachedForConnectedUsers( ) ) : ( portlet.canBeCachedForAnonymousUsers( ) );

                if ( bCanBeCached )
                {
                    mapParams.put( PARAMETER_PORTLET, String.valueOf( portlet.getId( ) ) );
                    strKey = _cksPortlet.getKey( mapParams, nMode, user );

                    String strPortlet = (String) _cachePortlets.getFromCache( strKey );

                    if ( strPortlet != null )
                    {
                        return strPortlet;
                    }
                }
            }

            XmlTransformerService xmlTransformerService = new XmlTransformerService( );
            String strPortletXmlContent = portlet.getXml( request );
            strPortletContent += xmlTransformerService.transformBySourceWithXslCache( strPortletXmlContent, portlet.getXslSource( nMode ), strXslUniqueId,
                    mapParams, outputProperties );
        }
        else
        {
            if ( ( ( nMode != MODE_ADMIN ) && _cachePortlets.isCacheEnable( ) ) )
            {
                LuteceUser user = null;

                if ( SecurityService.isAuthenticationEnable( ) )
                {
                    user = SecurityService.getInstance( ).getRegisteredUser( request );
                }

                boolean bCanBeCached = ( user != null ) ? ( portlet.canBeCachedForConnectedUsers( ) ) : ( portlet.canBeCachedForAnonymousUsers( ) );

                if ( bCanBeCached )
                {
                    mapRequestParams.put( PARAMETER_PORTLET, String.valueOf( portlet.getId( ) ) );
                    strKey = _cksPortlet.getKey( mapRequestParams, nMode, user );

                    String strPortlet = (String) _cachePortlets.getFromCache( strKey );

                    if ( strPortlet != null )
                    {
                        return strPortlet;
                    }
                }
            }

            strPortletContent += portlet.getHtmlContent( request );
        }

        if ( ( nMode != MODE_ADMIN ) && _cachePortlets.isCacheEnable( ) && StringUtils.isNotEmpty( strKey ) )
        {
            _cachePortlets.putInCache( strKey, strPortletContent );
        }

        return strPortletContent;
    }
