private static void loadPluginFromFile( File file, boolean bRegisterAsPlugin ) throws LuteceInitException
    {
        PluginFile pluginFile = new PluginFile( );
        pluginFile.load( file.getAbsolutePath( ) );

        String strPluginClass = pluginFile.getPluginClass( );

        if ( strPluginClass != null )
        {
            try
            {
                Plugin plugin = (Plugin) Class.forName( strPluginClass ).newInstance( );
                plugin.load( pluginFile );

                if ( bRegisterAsPlugin )
                {
                    plugin.setStatus( getPluginStatus( plugin ) );
                    registerPlugin( plugin );
                }
                else
                {
                    plugin.setStatus( true );
                    registerCore( plugin );
                }

                // If the plugin requires a database connection pool then
                // get the pool name and initialize its ConnectionService
                if ( plugin.isDbPoolRequired( ) )
                {
                    String strPoolName = getPluginPoolName( plugin );
                    plugin.setPoolName( strPoolName );
                    plugin.initConnectionService( strPoolName );
                }

                plugin.init( );

                // plugin installed event
                PluginEvent event = new PluginEvent( plugin, PluginEvent.PLUGIN_INSTALLED );
                notifyListeners( event );
            }
            catch( Exception e )
            {
                throw new LuteceInitException( "Error instantiating plugin defined in file : " + file.getAbsolutePath( ), e );
            }
        }
        else
        {
            AppLogService.error( "No plugin class defined in file : " + file.getAbsolutePath( ) );
        }
    }
