private static void processIncrementalIndexing( ) throws CorruptIndexException, IOException, InterruptedException, SiteMessageException
    {
        _sbLogs.append( "\r\nIncremental Indexing ...\r\n" );

        // incremental indexing
        Collection<IndexerAction> actions = IndexerActionHome.getList( );

        for ( IndexerAction action : actions )
        {
            // catch any exception coming from an indexer to prevent global indexation to fail
            try
            {
                SearchIndexer indexer = _mapIndexers.get( action.getIndexerName( ) );

                if ( action.getIdTask( ) == IndexerAction.TASK_DELETE )
                {
                    deleteDocument( action );
                }
                else
                {
                    List<org.apache.lucene.document.Document> luceneDocuments = indexer.getDocuments( action.getIdDocument( ) );

                    if ( ( luceneDocuments != null ) && ( luceneDocuments.size( ) > 0 ) )
                    {
                        for ( org.apache.lucene.document.Document doc : luceneDocuments )
                        {
                            if ( ( action.getIdPortlet( ) == ALL_DOCUMENT )
                                    || ( ( doc.get( SearchItem.FIELD_DOCUMENT_PORTLET_ID ) != null ) && ( doc.get( SearchItem.FIELD_DOCUMENT_PORTLET_ID )
                                            .equals( doc.get( SearchItem.FIELD_UID ) + "&" + action.getIdPortlet( ) ) ) ) )
                            {
                                processDocument( action, doc );
                            }
                        }
                    }
                }

                removeIndexerAction( action.getIdAction( ) );
            }
            catch( Exception e )
            {
                error( action, e, StringUtils.EMPTY );
            }
        }

        // reindexing all pages.
        _writer.deleteDocuments( new Term( SearchItem.FIELD_TYPE, PARAM_TYPE_PAGE ) );
        _mapIndexers.get( PageIndexer.INDEXER_NAME ).indexDocuments( );
    }
