public List<SearchResult> getSearchResults( String strQuery, HttpServletRequest request )
    {
        ArrayList<SearchItem> listResults = new ArrayList<SearchItem>( );
        ArrayList<Query> listFilter = new ArrayList<Query>( );
        IndexSearcher searcher = null;
        boolean bFilterResult = false;
        LuteceUser user = null;
        String [ ] typeFilter = request.getParameterValues( PARAMETER_TYPE_FILTER );
        String strDateAfter = request.getParameter( PARAMETER_DATE_AFTER );
        String strDateBefore = request.getParameter( PARAMETER_DATE_BEFORE );
        boolean bDateAfter = false;
        boolean bDateBefore = false;
        Query allFilter = null;
        String strTagFilter = request.getParameter( PARAMETER_TAG_FILTER );

        if ( SecurityService.isAuthenticationEnable( ) )
        {
            user = SecurityService.getInstance( ).getRegisteredUser( request );

            Query [ ] filtersRole = null;

            if ( user != null )
            {
                String [ ] userRoles = SecurityService.getInstance( ).getRolesByUser( user );

                if ( userRoles != null )
                {
                    filtersRole = new Query [ userRoles.length + 1];

                    for ( int i = 0; i < userRoles.length; i++ )
                    {
                        Query queryRole = new TermQuery( new Term( SearchItem.FIELD_ROLE, userRoles [i] ) );
                        filtersRole [i] = queryRole;
                    }
                }
                else
                {
                    bFilterResult = true;
                }
            }
            else
            {
                filtersRole = new Query [ 1];
            }

            if ( !bFilterResult )
            {
                Query queryRole = new TermQuery( new Term( SearchItem.FIELD_ROLE, Page.ROLE_NONE ) );
                filtersRole [filtersRole.length - 1] = queryRole;
                BooleanQuery.Builder booleanQueryBuilderRole = new BooleanQuery.Builder( );
                for ( Query filterRole : filtersRole )
                {
                    booleanQueryBuilderRole.add( filterRole, BooleanClause.Occur.SHOULD );
                }
                listFilter.add( booleanQueryBuilderRole.build( ) );
            }
        }

        if ( StringUtils.isNotBlank( strDateAfter ) || StringUtils.isNotBlank( strDateBefore ) )
        {
            BytesRef strAfter = null;
            BytesRef strBefore = null;

            if ( StringUtils.isNotBlank( strDateAfter ) )
            {
                Date dateAfter = DateUtil.formatDate( strDateAfter, request.getLocale( ) );
                strAfter = new BytesRef( DateTools.dateToString( dateAfter, Resolution.DAY ) );
                bDateAfter = true;
            }

            if ( StringUtils.isNotBlank( strDateBefore ) )
            {
                Date dateBefore = DateUtil.formatDate( strDateBefore, request.getLocale( ) );
                strBefore = new BytesRef( DateTools.dateToString( dateBefore, Resolution.DAY ) );
                bDateBefore = true;
            }

            Query queryDate = new TermRangeQuery( SearchItem.FIELD_DATE, strAfter, strBefore, bDateAfter, bDateBefore );
            listFilter.add( queryDate );
        }

        if ( ( typeFilter != null ) && ( typeFilter.length > 0 ) && !typeFilter [0].equals( SearchService.TYPE_FILTER_NONE ) )
        {
            Query [ ] filtersType = new Query [ typeFilter.length];

            for ( int i = 0; i < typeFilter.length; i++ )
            {
                Query queryType = new TermQuery( new Term( SearchItem.FIELD_TYPE, typeFilter [i] ) );
                filtersType [i] = queryType;
            }

            BooleanQuery.Builder booleanQueryBuilder = new BooleanQuery.Builder( );
            for ( Query filterType : filtersType )
            {
                booleanQueryBuilder.add( filterType, BooleanClause.Occur.SHOULD );
            }
            listFilter.add( booleanQueryBuilder.build( ) );
        }

        if ( !listFilter.isEmpty( ) )
        {
            BooleanQuery.Builder booleanQueryBuilder = new BooleanQuery.Builder( );
            for ( Query filter : listFilter )
            {
                booleanQueryBuilder.add( filter, BooleanClause.Occur.MUST );
            }
            allFilter = booleanQueryBuilder.build( );
        }

        try( Directory directory = IndexationService.getDirectoryIndex( ) ; IndexReader ir = DirectoryReader.open( directory ) ; )
        {
            searcher = new IndexSearcher( ir );

            BooleanQuery.Builder bQueryBuilder = new BooleanQuery.Builder( );

            if ( StringUtils.isNotBlank( strTagFilter ) )
            {
                QueryParser parser = new QueryParser( SearchItem.FIELD_METADATA, IndexationService.getAnalyser( ) );

                Query queryMetaData = parser.parse( ( strQuery != null ) ? strQuery : "" );
                bQueryBuilder.add( queryMetaData, BooleanClause.Occur.SHOULD );

                parser = new QueryParser( SearchItem.FIELD_SUMMARY, IndexationService.getAnalyser( ) );

                Query querySummary = parser.parse( ( strQuery != null ) ? strQuery : "" );
                bQueryBuilder.add( querySummary, BooleanClause.Occur.SHOULD );
            }
            else
            {
                QueryParser parser = new QueryParser( SearchItem.FIELD_CONTENTS, IndexationService.getAnalyser( ) );

                String operator = request.getParameter( PARAMETER_DEFAULT_OPERATOR );

                if ( StringUtils.isNotEmpty( operator ) && operator.equals( PARAMETER_OPERATOR_AND ) )
                {
                    parser.setDefaultOperator( QueryParser.AND_OPERATOR );
                }

                Query queryContent = parser.parse( ( StringUtils.isNotBlank( strQuery ) ) ? strQuery : "" );
                bQueryBuilder.add( queryContent, BooleanClause.Occur.SHOULD );
            }

            Query query = bQueryBuilder.build( );

            if ( allFilter != null )
            {
                BooleanQuery.Builder bQueryBuilderWithFilter = new BooleanQuery.Builder( );
                bQueryBuilderWithFilter.add( allFilter, BooleanClause.Occur.FILTER );
                bQueryBuilderWithFilter.add( query, BooleanClause.Occur.MUST );
                query = bQueryBuilderWithFilter.build( );
            }

            // Get results documents
            TopDocs topDocs = searcher.search( query, MAX_RESPONSES );
            ScoreDoc [ ] hits = topDocs.scoreDocs;

            for ( int i = 0; i < hits.length; i++ )
            {
                int docId = hits [i].doc;
                Document document = searcher.doc( docId );
                SearchItem si = new SearchItem( document );

                if ( ( !bFilterResult ) || ( si.getRole( ).equals( Page.ROLE_NONE ) )
                        || ( SecurityService.getInstance( ).isUserInRole( request, si.getRole( ) ) ) )
                {
                    listResults.add( si );
                }
            }
        }
        catch( Exception e )
        {
            AppLogService.error( e.getMessage( ), e );
        }

        return convertList( listResults );
    }
