protected Document getDocument( Page page, String strUrl ) throws IOException, InterruptedException, SiteMessageException
    {
        FieldType ft = new FieldType( StringField.TYPE_STORED );
        ft.setOmitNorms( false );

        FieldType ftNotStored = new FieldType( StringField.TYPE_NOT_STORED );
        ftNotStored.setOmitNorms( false );
        ftNotStored.setTokenized( false );

        // make a new, empty document
        Document doc = new Document( );

        // Add the url as a field named "url". Use an UnIndexed field, so
        // that the url is just stored with the document, but is not searchable.
        doc.add( new Field( SearchItem.FIELD_URL, strUrl, ft ) );

        // Add the last modified date of the file a field named "modified".
        // Use a field that is indexed (i.e. searchable), but don't tokenize
        // the field into words.
        String strDate = DateTools.dateToString( page.getDateUpdate( ), DateTools.Resolution.DAY );
        doc.add( new Field( SearchItem.FIELD_DATE, strDate, ft ) );

        // Add the uid as a field, so that index can be incrementally maintained.
        // This field is not stored with document, it is indexed, but it is not
        // tokenized prior to indexing.
        String strIdPage = String.valueOf( page.getId( ) );
        doc.add( new Field( SearchItem.FIELD_UID, strIdPage, ftNotStored ) );

        String strPageContent = _pageService.getPageContent( page.getId( ), 0, null );
        ContentHandler handler = new BodyContentHandler( );
        Metadata metadata = new Metadata( );

        try
        {
            new HtmlParser( ).parse( new ByteArrayInputStream( strPageContent.getBytes( ) ), handler, metadata, new ParseContext( ) );
        }
        catch( SAXException e )
        {
            throw new AppException( "Error during page parsing." );
        }
        catch( TikaException e )
        {
            throw new AppException( "Error during page parsing." );
        }

        // the content of the article is recovered in the parser because this one
        // had replaced the encoded caracters (as &eacute;) by the corresponding special caracter (as ?)
        StringBuilder sb = new StringBuilder( handler.toString( ) );

        // Add the tag-stripped contents as a Reader-valued Text field so it will
        // get tokenized and indexed.
        StringBuilder sbFieldContent = new StringBuilder( );
        StringBuilder sbFieldMetadata = new StringBuilder( );
        sbFieldContent.append( page.getName( ) ).append( " " ).append( sb.toString( ) );

        // Add the metadata description of the page if it exists
        if ( page.getDescription( ) != null )
        {
            sbFieldContent.append( " " ).append( page.getDescription( ) );
        }

        // Add the metadata keywords of the page if it exists
        String strMetaKeywords = page.getMetaKeywords( );

        if ( StringUtils.isNotBlank( strMetaKeywords ) )
        {
            sbFieldContent.append( " " ).append( strMetaKeywords );
            sbFieldMetadata.append( strMetaKeywords );
        }

        doc.add( new Field( SearchItem.FIELD_CONTENTS, sbFieldContent.toString( ), TextField.TYPE_NOT_STORED ) );

        if ( StringUtils.isNotBlank( page.getMetaDescription( ) ) )
        {
            if ( sbFieldMetadata.length( ) > 0 )
            {
                sbFieldMetadata.append( " " );
            }

            sbFieldMetadata.append( page.getMetaDescription( ) );
        }

        if ( sbFieldMetadata.length( ) > 0 )
        {
            doc.add( new Field( SearchItem.FIELD_METADATA, sbFieldMetadata.toString( ), TextField.TYPE_NOT_STORED ) );
        }

        // Add the title as a separate Text field, so that it can be searched
        // separately.
        doc.add( new Field( SearchItem.FIELD_TITLE, page.getName( ), ft ) );

        if ( StringUtils.isNotBlank( page.getDescription( ) ) )
        {
            // Add the summary as an UnIndexed field, so that it is stored and returned
            // with hit documents for display.
            doc.add( new StoredField( SearchItem.FIELD_SUMMARY, page.getDescription( ) ) );
        }

        doc.add( new Field( SearchItem.FIELD_TYPE, INDEX_TYPE_PAGE, ft ) );
        doc.add( new Field( SearchItem.FIELD_ROLE, page.getRole( ), ft ) );

        // return the document
        return doc;
    }
