public static void init( ServletContext servletContext ) throws LuteceInitException
    {
        try
        {
            // Register this service as a PluginEventListener
            PluginService.registerPluginEventListener( _instance );

            // timing
            Date dateBegin = new Date( );

            // Load the core context file : core_context.xml
            String strConfPath = AppPathService.getAbsolutePathFromRelativePath( PATH_CONF );
            String strContextFile = "file:" + strConfPath + FILE_CORE_CONTEXT;

            GenericWebApplicationContext gwac = new GenericWebApplicationContext( servletContext );
            gwac.setId( getContextName( servletContext ) );

            XmlBeanDefinitionReader xmlReader = new XmlBeanDefinitionReader( gwac );
            xmlReader.loadBeanDefinitions( strContextFile );

            // _context = new ClassPathXmlApplicationContext( strContextFile );
            AppLogService.info( "Context file loaded : " + FILE_CORE_CONTEXT );

            // Load all context files found in the conf/plugins directory
            // Files are loaded separatly with an individual try/catch block
            // to avoid stopping the process in case of a failure
            // The global context generation will fail if a bean in any file cannot be built.
            String strConfPluginsPath = strConfPath + DIR_PLUGINS;
            File dirConfPlugins = new File( strConfPluginsPath );
            FilenameFilter filterContext = new ContextFileFilter( );
            String [ ] filesContext = dirConfPlugins.list( filterContext );

            loadContexts( filesContext, strConfPluginsPath, xmlReader );

            // we now load overriding beans
            AppLogService.info( "Loading plugins context overrides" );

            String strCoreContextOverrideFile = strConfPath + DIR_OVERRIDE + FILE_CORE_CONTEXT;
            File fileCoreContextOverride = new File( strCoreContextOverrideFile );

            if ( fileCoreContextOverride.exists( ) )
            {
                AppLogService.debug( "Context file loaded : core_context" );
                xmlReader.loadBeanDefinitions( "file:" + strCoreContextOverrideFile );
            }
            else
            {
                AppLogService.debug( "No core_context override found" );
            }

            // load plugins overrides
            String strConfPluginsOverridePath = strConfPath + DIR_OVERRIDE_PLUGINS;
            File dirConfOverridePlugins = new File( strConfPluginsOverridePath );

            if ( dirConfOverridePlugins.exists( ) )
            {
                String [ ] filesOverrideContext = dirConfOverridePlugins.list( filterContext );
                loadContexts( filesOverrideContext, strConfPluginsOverridePath, xmlReader );
            }

            gwac.refresh( );

            _context = gwac;

            AppLogService.info( "Spring context loaded in " + ( new Date( ).getTime( ) - dateBegin.getTime( ) ) + "ms" );
        }
        catch( Exception e )
        {
            AppLogService.error( "Error initializing Spring Context Service " + e.getMessage( ), e );
            throw new LuteceInitException( "Error initializing Spring Context Service", e );
        }
    }
