private XPage processController( HttpServletRequest request ) throws UserNotSignedException, SiteMessageException
    {
        Method [ ] methods = ReflectionUtils.getAllDeclaredMethods( getClass( ) );

        try
        {
            if ( isMessageBox( request ) )
            {
                return messageBox( request );
            }

            // Process views
            Method m = MVCUtils.findViewAnnotedMethod( request, methods );

            if ( m != null )
            {
                return (XPage) m.invoke( this, request );
            }

            // Process actions
            m = MVCUtils.findActionAnnotedMethod( request, methods );

            if ( m != null )
            {
                return (XPage) m.invoke( this, request );
            }

            // No view or action found so display the default view
            m = MVCUtils.findDefaultViewMethod( methods );

            return (XPage) m.invoke( this, request );
        }
        catch( InvocationTargetException e )
        {
            if ( e.getTargetException( ) instanceof UserNotSignedException )
            {
                throw (UserNotSignedException) e.getTargetException( );
            }

            if ( e.getTargetException( ) instanceof SiteMessageException )
            {
                throw (SiteMessageException) e.getTargetException( );
            }

            if ( e.getTargetException( ) instanceof RuntimeException )
            {
                throw new AppException( "MVC Error dispaching view and action ", (RuntimeException) e.getTargetException( ) );
            }

            throw new AppException( "MVC Error dispaching view and action ", e );
        }
        catch( IllegalAccessException e )
        {
            throw new AppException( "MVC Error dispaching view and action ", e );
        }
    }
