public static String sendResource( HttpServletRequest request ) throws SiteMessageException
    {
        String strSenderEmail = DatastoreService.getDataValue( KEY_WEBMASTER_EMAIL, "no-reply@mydomain.com" );
        String strSenderName = request.getParameter( PARAMETER_SENDER_NAME );
        String strSenderFirstName = request.getParameter( PARAMETER_SENDER_FIRST_NAME );
        String strReceipientEmail = request.getParameter( Parameters.EMAIL );
        String strContent = request.getParameter( PARAMETER_CONTENT );
        String strExtendableResourceType = request.getParameter( PARAMETER_EXTENDABLE_RESOURCE_TYPE );
        String strIdExtendableResource = request.getParameter( PARAMETER_ID_EXTENDABLE_RESOURCE );
        String strSend = request.getParameter( PARAMETER_SEND );
        IExtendableResource resource = null;

        String strError = null;

        // If the form was submited, we check data
        if ( strSend != null )
        {
            if ( StringUtils.isBlank( strSenderEmail ) || StringUtils.isBlank( strSenderName ) || StringUtils.isBlank( strSenderFirstName )
                    || StringUtils.isBlank( strReceipientEmail ) || StringUtils.isBlank( strContent ) )
            {
                strError = I18nService.getLocalizedString( MESSAGE_ERROR_MANDATORY_FIELDS, request.getLocale( ) );
            }

            if ( ( strError != null ) && ( !AdminUserService.checkEmail( strSenderEmail ) || !AdminUserService.checkEmail( strReceipientEmail ) ) )
            {
                strError = I18nService.getLocalizedString( MESSAGE_ERROR_WRONG_SENDER_EMAIL, request.getLocale( ) );
            }
        }

        // We get the resource from its resource service
        IExtendableResourceService resourceService = null;
        List<IExtendableResourceService> listExtendableResourceService = SpringContextService.getBeansOfType( IExtendableResourceService.class );

        for ( IExtendableResourceService extendableResourceService : listExtendableResourceService )
        {
            if ( extendableResourceService.isInvoked( strExtendableResourceType ) )
            {
                resourceService = extendableResourceService;
                resource = extendableResourceService.getResource( strIdExtendableResource, strExtendableResourceType );
            }
        }

        if ( ( resourceService == null ) || ( resource == null ) )
        {
            SiteMessageService.setMessage( request, MESSAGE_NO_RESOURCE_FOUND, SiteMessage.TYPE_ERROR );
            throw new SiteMessageException( );
        }

        String strResourceUrl = resourceService.getResourceUrl( strIdExtendableResource, strExtendableResourceType );
        Map<String, Object> model = new HashMap<String, Object>( );
        model.put( MARK_RESOURCE, resource );
        model.put( MARK_RESOURCE_URL, strResourceUrl );
        model.put( Markers.BASE_URL, AppPathService.getBaseUrl( request ) );

        if ( ( strSend != null ) && ( strError == null ) )
        {
            Map<String, Object> mailModel = new HashMap<String, Object>( );
            mailModel.put( Markers.BASE_URL, AppPathService.getBaseUrl( request ) );
            mailModel.put( MARK_RESOURCE, resource );
            mailModel.put( PARAMETER_SENDER_EMAIL, strSenderEmail );
            mailModel.put( PARAMETER_SENDER_NAME, strSenderName );
            mailModel.put( PARAMETER_SENDER_FIRST_NAME, strSenderFirstName );
            mailModel.put( Parameters.EMAIL, strReceipientEmail );
            mailModel.put( PARAMETER_CONTENT, EditorBbcodeService.getInstance( ).parse( strContent ) );
            mailModel.put( MARK_RESOURCE_URL, resourceService.getResourceUrl( strIdExtendableResource, strExtendableResourceType ) );

            HtmlTemplate template = AppTemplateService.getTemplate( TEMPLATE_EMAIL_SEND_RESOURCE, request.getLocale( ), mailModel );
            MailService.sendMailHtml( strReceipientEmail, strSenderFirstName + CONSTANT_SPACE + strSenderName, strSenderEmail,
                    resource.getExtendableResourceName( ), template.getHtml( ) );
            model.put( MARK_SUCCESS, MARK_SUCCESS );
        }
        else
        {
            model.put( PARAMETER_SENDER_NAME, strSenderName );
            model.put( PARAMETER_SENDER_FIRST_NAME, strSenderFirstName );
            model.put( Parameters.EMAIL, strReceipientEmail );
            model.put( PARAMETER_CONTENT, strContent );
            model.put( MARK_ERROR, strError );
        }

        model.put( Markers.PAGE_MAIN_MENU, StringUtils.EMPTY );

        HtmlTemplate template = AppTemplateService.getTemplate( TEMPLATE_SEND_RESOURCE, request.getLocale( ), model );

        return template.getHtml( );
    }
