public String getRemovePortlet( HttpServletRequest request ) throws AccessDeniedException
    {
        String strPortletId = request.getParameter( Parameters.PORTLET_ID );
        if ( !StringUtils.isNumeric( strPortletId ) )
        {
            return AdminMessageService.getMessageUrl( request, Messages.MANDATORY_FIELDS, AdminMessage.TYPE_ERROR );
        }
        int nPortletId = Integer.parseInt( strPortletId );
        Portlet portlet = null;
        try
        {
            portlet = PortletHome.findByPrimaryKey( nPortletId );
        }
        catch( NullPointerException e )
        {
            AppLogService.error( "Error looking for portlet with id " + nPortletId, e );
        }
        if ( portlet == null || portlet.getId( ) != nPortletId )
        {
            return AdminMessageService.getMessageUrl( request, Messages.MESSAGE_INVALID_ENTRY, new Object [ ] {
                nPortletId
            }, AdminMessage.TYPE_ERROR );
        }
        AdminUser user = AdminUserService.getAdminUser( request );
        if ( !RBACService.isAuthorized( PortletType.RESOURCE_TYPE, portlet.getPortletTypeId( ), PortletResourceIdService.PERMISSION_MANAGE, user ) )
        {
            throw new AccessDeniedException( "User " + user + " is not authorized to permission " + PortletResourceIdService.PERMISSION_MANAGE + " on portlet "
                    + nPortletId );
        }
        String strUrl = JSP_REMOVE_PORTLET;
        String strTarget = "_top";
        Map<String, Object> parameters = new HashMap<>( );
        parameters.put( Parameters.PORTLET_ID, strPortletId );
        parameters.put( SecurityTokenService.PARAMETER_TOKEN, SecurityTokenService.getInstance( ).getToken( request, JSP_REMOVE_PORTLET ) );

        if ( PortletHome.hasAlias( nPortletId ) )
        {
            return AdminMessageService.getMessageUrl( request, PROPERTY_MESSAGE_WARNING_PORTLET_ALIAS, new Object [ ] {
                portlet.getName( )
            }, null, strUrl, strTarget, AdminMessage.TYPE_CONFIRMATION, parameters );
        }

        ArrayList<String> listErrors = new ArrayList<String>( );
        Locale locale = AdminUserService.getLocale( request );
        if ( !PortletRemovalListenerService.getService( ).checkForRemoval( strPortletId, listErrors, locale ) )
        {
            String strCause = AdminMessageService.getFormattedList( listErrors, locale );
            Object [ ] args = {
                    strCause, portlet.getName( )
            };

            return AdminMessageService.getMessageUrl( request, MESSAGE_CANNOT_REMOVE_PORTLET, args, MESSAGE_CANNOT_REMOVE_PORTLET_TITLE, strUrl, strTarget,
                    AdminMessage.TYPE_STOP, parameters );
        }

        return AdminMessageService.getMessageUrl( request, PROPERTY_MESSAGE_CONFIRM_REMOVE_PORTLET, new Object [ ] {
            portlet.getName( )
        }, null, strUrl, strTarget, AdminMessage.TYPE_CONFIRMATION, parameters );
    }
