public String doCreateMode( HttpServletRequest request ) throws AccessDeniedException
    {
        String strDescription = request.getParameter( Parameters.MODE_DESCRIPTION );
        String strPath = request.getParameter( Parameters.MODE_PATH );

        // Mandatory fields
        if ( strDescription.equals( "" ) || strPath.equals( "" ) )
        {
            return AdminMessageService.getMessageUrl( request, Messages.MANDATORY_FIELDS, AdminMessage.TYPE_STOP );
        }

        if ( strPath != null && ( strPath.endsWith( "/" ) || strPath.endsWith( "\\" ) ) )
        {
            strPath = strPath.substring(0, strPath.length()-1);
        }

        if ( SecurityUtil.containsPathManipulationChars(request, strPath) )
        {
            throw new AccessDeniedException( "Invalid path" );
        }
        
        strPath += File.separator;

        File dirPath = new File( AppPathService.getPath( PROPERTY_PATH_XSL ) + strPath );

        if ( dirPath.exists( ) )
        {
            return AdminMessageService.getMessageUrl( request, Messages.PATH_ALREADY_EXISTS, AdminMessage.TYPE_STOP );
        }

        if ( !SecurityTokenService.getInstance( ).validate( request, TEMPLATE_CREATE_MODE ) )
        {
            throw new AccessDeniedException( "Invalid security token" );
        }

        if ( !dirPath.mkdir( ) )
        {
            return AdminMessageService.getMessageUrl( request, Messages.PATH_CREATION_ERROR, JSP_PATH + JSP_MANAGE_MODES, AdminMessage.TYPE_STOP );
        }

        Mode mode = new Mode( );
        mode.setDescription( strDescription );
        mode.setPath( strPath );

        /* Since v1.2 */
        mode.setOutputXslPropertyMethod( request.getParameter( Parameters.MODE_OUTPUT_XSL_METHOD ) );
        mode.setOutputXslPropertyVersion( request.getParameter( Parameters.MODE_OUTPUT_XSL_VERSION ) );
        mode.setOutputXslPropertyMediaType( request.getParameter( Parameters.MODE_OUTPUT_XSL_MEDIA_TYPE ) );
        mode.setOutputXslPropertyEncoding( request.getParameter( Parameters.MODE_OUTPUT_XSL_ENCODING ) );
        mode.setOutputXslPropertyIndent( request.getParameter( Parameters.MODE_OUTPUT_XSL_INDENT ) );
        mode.setOutputXslPropertyOmitXmlDeclaration( request.getParameter( Parameters.MODE_OUTPUT_XSL_OMIT_XML_DECLARATION ) );
        mode.setOutputXslPropertyStandalone( request.getParameter( Parameters.MODE_OUTPUT_XSL_STANDALONE ) );

        ModeHome.create( mode );

        // If the process is successfull, redirects towards the theme view
        return JSP_MANAGE_MODES;
    }
