public synchronized boolean isAllowed( String strRemoteAddr, int iContentLength )
    {
        AppLogService.debug( "DosGuard : isAllowed(" + strRemoteAddr + ", " + iContentLength + ")" );

        // Ignore the requests under the minimum size
        if ( iContentLength < _nMinContentLength )
        {
            AppLogService.debug( "ContentLength is below minimum, ignored" );

            return true;
        }

        // Record the time of this request
        long lRequestTime = System.currentTimeMillis( );
        AppLogService.debug( "Request time : " + lRequestTime );

        // Test if IP was previously recorded
        Long previousRequestTime = _mapLastRequestTimes.get( strRemoteAddr );
        AppLogService.debug( "Previous request time : " + previousRequestTime );

        if ( previousRequestTime != null )
        {
            AppLogService.debug( "IP is in the map" );

            // Test if IP is allowed to make a new request
            if ( lRequestTime > ( previousRequestTime.longValue( ) + _nMinInterval ) )
            {
                AppLogService.debug( "IP is allowed to make a new request" );

                // Clean up
                this.cleanExpiredEntries( );

                // Update the map with the new time
                _mapLastRequestTimes.put( strRemoteAddr, Long.valueOf( lRequestTime ) );

                // Add a new entry in the list
                _listOrderedRequests.addFirst( new Entry( strRemoteAddr, lRequestTime ) );

                return true;
            }

            AppLogService.debug( "IP is not allowed to make a new request" );

            return false;
        }

        AppLogService.debug( "IP is not in the map" );

        // Clean up
        this.cleanExpiredEntries( );

        // Add the IP and the time to the map
        _mapLastRequestTimes.put( strRemoteAddr, Long.valueOf( lRequestTime ) );

        // Add a new entry in the list
        _listOrderedRequests.addFirst( new Entry( strRemoteAddr, lRequestTime ) );

        return true;
    }
