public String doForgotPassword( HttpServletRequest request ) throws Exception
    {
        // get mail from user
        String strAccessCode = request.getParameter( Parameters.ACCESS_CODE );
        Locale locale = AdminUserService.getLocale( request );

        if ( StringUtils.isEmpty( strAccessCode ) )
        {
            return AdminMessageService.getMessageUrl( request, Messages.MANDATORY_FIELDS, AdminMessage.TYPE_STOP );
        }

        if ( locale == null )
        {
            locale = LocaleService.getDefault( );
        }

        // if user or mail not found, send admin message
        AdminUser user = AdminUserHome.findUserByLogin( strAccessCode );

        if ( ( user == null ) || StringUtils.isEmpty( user.getEmail( ) ) )
        {
            return JSP_URL_FORM_CONTACT;
        }

        // make password reset token
        Date timestamp = new Date( );
        String strToken = AdminUserService.getUserPasswordResetToken( user, timestamp, request );

        // send password rest token by e-mail
        String strSenderEmail = MailService.getNoReplyEmail( );
        String strEmailSubject = I18nService.getLocalizedString( MESSAGE_EMAIL_SUBJECT, locale );
        HashMap<String, Object> model = new HashMap<String, Object>( );
        model.put( MARK_TOKEN, strToken );
        model.put( MARK_TIMESTAMP, timestamp.getTime( ) );
        model.put( MARK_USER_ID, user.getUserId( ) );
        model.put( MARK_LOGIN_URL, AppPathService.getBaseUrl( request ) + "jsp/admin/AdminResetPassword.jsp" );
        model.put( MARK_SITE_LINK, MailService.getSiteLink( AppPathService.getBaseUrl( request ), false ) );
        Date tokenExpiryDate = new Date( timestamp.getTime( )
                + ( 1000L * 60 * AdminUserService.getIntegerSecurityParameter( AdminUserService.DSKEY_RESET_TOKEN_VALIDITY ) ) );
        model.put( MARK_RESET_TOKEN_VALIDITY, tokenExpiryDate );
        model.put( MARK_LOCK_RESET_TOKEN_TO_SESSION, AdminUserService.getBooleanSecurityParameter( AdminUserService.DSKEY_LOCK_RESET_TOKEN_TO_SESSION ) );
        HtmlTemplate template = AppTemplateService.getTemplate( TEMPLATE_ADMIN_EMAIL_FORGOT_PASSWORD, locale, model );

        MailService.sendMailHtml( user.getEmail( ), strSenderEmail, strSenderEmail, strEmailSubject, template.getHtml( ) );

        return AdminMessageService.getMessageUrl( request, MESSAGE_SENDING_SUCCESS, JSP_URL_ADMIN_LOGIN, AdminMessage.TYPE_INFO );
    }
