public String doLogin( HttpServletRequest request ) throws Exception
    {
        if ( request.getScheme( ).equals( CONSTANT_HTTP ) && AppHTTPSService.isHTTPSSupportEnabled( ) )
        {
            return JSP_URL_ADMIN_LOGIN;
        }
        if ( !SecurityTokenService.getInstance( ).validate( request, TEMPLATE_ADMIN_LOGIN ) )
        {
            throw new AccessDeniedException( "Invalid security token" );
        }

        // recovery of the login attributes
        String strAccessCode = request.getParameter( Parameters.ACCESS_CODE );
        String strPassword = request.getParameter( Parameters.PASSWORD );

        if ( strAccessCode == null || strPassword == null )
        {
            // TIME RESISTANT ATTACK
            // Computation time is equal to the time needed by a legitimate user
            strAccessCode = "";
            strPassword = "";
        }

        String strLoginUrl = AdminAuthenticationService.getInstance( ).getLoginPageUrl( );

        try
        {
            AdminAuthenticationService.getInstance( ).loginUser( request, strAccessCode, strPassword );
        }
        catch( FailedLoginException ex )
        {
            // Creating a record of connections log
            UserLog userLog = new UserLog( );
            userLog.setAccessCode( strAccessCode );
            userLog.setIpAddress( SecurityUtil.getRealIp( request ) );
            userLog.setDateLogin( new java.sql.Timestamp( new java.util.Date( ).getTime( ) ) );
            userLog.setLoginStatus( UserLog.LOGIN_DENIED ); // will be inserted only if access denied
            UserLogHome.addUserLog( userLog );

            return AdminMessageService.getMessageUrl( request, Messages.MESSAGE_AUTH_FAILURE, strLoginUrl, AdminMessage.TYPE_STOP );
        }
        catch( LoginException ex )
        {
            AppLogService.error( "Error during connection for user access code :" + SecurityUtil.logForgingProtect( strAccessCode ), ex );

            return AdminMessageService.getMessageUrl( request, Messages.MESSAGE_AUTH_FAILURE, strLoginUrl, AdminMessage.TYPE_STOP );
        }

        UrlItem url;

        AdminUser user = AdminUserHome.findUserByLogin( strAccessCode );

        if ( user.isPasswordReset( ) )
        {
            String strRedirectUrl = AdminMessageService.getMessageUrl( request, Messages.MESSAGE_USER_MUST_CHANGE_PASSWORD,
                    JSP_URL_MODIFY_DEFAULT_USER_PASSOWRD, AdminMessage.TYPE_ERROR );
            url = new UrlItem( strRedirectUrl );
        }
        else
        {
            String strNextUrl = AdminAuthenticationService.getInstance( ).getLoginNextUrl( request );

            if ( StringUtils.isNotBlank( strNextUrl ) )
            {
                url = new UrlItem( strNextUrl );
            }
            else
            {
                url = AppPathService.resolveRedirectUrl( request, AppPathService.getAdminMenuUrl( ) );
            }
        }

        return url.getUrl( );
    }
