public String doCreateAdminUser( HttpServletRequest request ) throws AccessDeniedException
    {
        String strAccessCode = request.getParameter( PARAMETER_ACCESS_CODE );
        String strLastName = request.getParameter( PARAMETER_LAST_NAME );
        String strFirstName = request.getParameter( PARAMETER_FIRST_NAME );
        String strEmail = request.getParameter( PARAMETER_EMAIL );
        String strStatus = request.getParameter( PARAMETER_STATUS );
        String strUserLevel = request.getParameter( PARAMETER_USER_LEVEL );
        String strNotifyUser = request.getParameter( PARAMETER_NOTIFY_USER );
        String strAccessibilityMode = request.getParameter( PARAMETER_ACCESSIBILITY_MODE );
        String strWorkgroupKey = request.getParameter( PARAMETER_WORKGROUP_KEY );

        if ( StringUtils.isEmpty( strAccessCode ) )
        {
            return AdminMessageService.getMessageUrl( request, Messages.MANDATORY_FIELDS, AdminMessage.TYPE_STOP );
        }

        if ( StringUtils.isEmpty( strLastName ) )
        {
            return AdminMessageService.getMessageUrl( request, Messages.MANDATORY_FIELDS, AdminMessage.TYPE_STOP );
        }

        if ( StringUtils.isEmpty( strFirstName ) )
        {
            return AdminMessageService.getMessageUrl( request, Messages.MANDATORY_FIELDS, AdminMessage.TYPE_STOP );
        }

        if ( StringUtils.isBlank( strEmail ) )
        {
            return AdminMessageService.getMessageUrl( request, Messages.MANDATORY_FIELDS, AdminMessage.TYPE_STOP );
        }

        if ( !AdminUserService.checkEmail( strEmail ) )
        {
            return AdminUserService.getEmailErrorMessageUrl( request );
        }

        // check again that access code is not in use
        if ( AdminUserHome.checkAccessCodeAlreadyInUse( strAccessCode ) != -1 )
        {
            return AdminMessageService.getMessageUrl( request, PROPERTY_MESSAGE_ACCESS_CODE_ALREADY_USED, AdminMessage.TYPE_STOP );
        }

        // check again that email is not in use
        if ( AdminUserHome.checkEmailAlreadyInUse( strEmail ) != -1 )
        {
            return AdminMessageService.getMessageUrl( request, PROPERTY_MESSAGE_EMAIL_ALREADY_USED, AdminMessage.TYPE_STOP );
        }

        // defines the new created user level
        int nNewUserLevel = Integer.valueOf( strUserLevel );

        // check if the user is still an admin
        if ( !( getUser( ).hasRights( nNewUserLevel ) || getUser( ).isAdmin( ) ) )
        {
            return AdminMessageService.getMessageUrl( request, Messages.USER_ACCESS_DENIED, AdminMessage.TYPE_STOP );
        }

        // creation in no-module mode : we manage the password
        if ( AdminAuthenticationService.getInstance( ).isDefaultModuleUsed( ) )
        {
            LuteceDefaultAdminUser user = new LuteceDefaultAdminUser( );
            String strFirstPassword = request.getParameter( PARAMETER_FIRST_PASSWORD );
            String strSecondPassword = request.getParameter( PARAMETER_SECOND_PASSWORD );

            if ( StringUtils.isEmpty( strFirstPassword ) )
            {
                return AdminMessageService.getMessageUrl( request, Messages.MANDATORY_FIELDS, AdminMessage.TYPE_STOP );
            }

            if ( !strFirstPassword.equals( strSecondPassword ) )
            {
                return AdminMessageService.getMessageUrl( request, PROPERTY_MESSAGE_DIFFERENTS_PASSWORD, AdminMessage.TYPE_STOP );
            }

            String strUrl = AdminUserService.checkPassword( request, strFirstPassword, 0 );

            if ( StringUtils.isNotEmpty( strUrl ) )
            {
                return strUrl;
            }

            user.setPassword( AdminUserService.encryptPassword( strFirstPassword ) );

            user.setPasswordMaxValidDate( AdminUserService.getPasswordMaxValidDate( ) );
            user.setAccountMaxValidDate( AdminUserService.getAccountMaxValidDate( ) );

            user.setAccessCode( strAccessCode );
            user.setLastName( strLastName );
            user.setFirstName( strFirstName );
            user.setEmail( strEmail );
            user.setStatus( Integer.parseInt( strStatus ) );
            user.setLocale( new Locale( request.getParameter( PARAMETER_LANGUAGE ) ) );

            user.setUserLevel( nNewUserLevel );
            user.setPasswordReset( Boolean.TRUE );
            user.setAccessibilityMode( strAccessibilityMode != null );
            user.setWorkgroupKey( strWorkgroupKey );

            String strError = AdminUserFieldService.checkUserFields( request, getLocale( ) );

            if ( strError != null )
            {
                return strError;
            }
            if ( !SecurityTokenService.getInstance( ).validate( request, JSP_URL_CREATE_USER ) )
            {
                throw new AccessDeniedException( "Invalid security token" );
            }
            AdminUserHome.create( user );
            AdminUserFieldService.doCreateUserFields( user, request, getLocale( ) );

            if ( ( strNotifyUser != null ) && strNotifyUser.equals( CONSTANTE_UN ) )
            {
                // Notify user for the creation of this account
                AdminUserService.notifyUser( AppPathService.getBaseUrl( request ), user, strFirstPassword, PROPERTY_MESSAGE_EMAIL_SUBJECT_NOTIFY_USER,
                        TEMPLATE_NOTIFY_USER );
            }
        }
        else
        {
            AdminUser user = new AdminUser( );
            user.setAccessCode( strAccessCode );
            user.setLastName( strLastName );
            user.setFirstName( strFirstName );
            user.setEmail( strEmail );
            user.setStatus( Integer.parseInt( strStatus ) );
            user.setLocale( new Locale( request.getParameter( PARAMETER_LANGUAGE ) ) );

            user.setUserLevel( nNewUserLevel );
            user.setAccessibilityMode( strAccessibilityMode != null );
            user.setWorkgroupKey( strWorkgroupKey );

            String strError = AdminUserFieldService.checkUserFields( request, getLocale( ) );

            if ( strError != null )
            {
                return strError;
            }
            if ( !SecurityTokenService.getInstance( ).validate( request, JSP_URL_CREATE_USER ) )
            {
                throw new AccessDeniedException( "Invalid security token" );
            }

            AdminUserHome.create( user );
            AdminUserFieldService.doCreateUserFields( user, request, getLocale( ) );
        }

        return JSP_MANAGE_USER;
    }
