public DefaultPluginActionResult doExportUsers( HttpServletRequest request, HttpServletResponse response ) throws IOException
    {
        DefaultPluginActionResult result = new DefaultPluginActionResult( );

        if ( !RBACService.isAuthorized( AdminUser.RESOURCE_TYPE, RBAC.WILDCARD_RESOURCES_ID, AdminUserResourceIdService.PERMISSION_IMPORT_EXPORT_USERS,
                getUser( ) ) )
        {
            result.setHtmlContent( getManageAdminUsers( request ) );

            return result;
        }

        String strXslExportId = request.getParameter( PARAMETER_XSL_EXPORT_ID );
        String strExportAttributes = request.getParameter( PARAMETER_EXPORT_ATTRIBUTES );
        String strExportRoles = request.getParameter( PARAMETER_EXPORT_ROLES );
        String strExportRights = request.getParameter( PARAMETER_EXPORT_RIGHTS );
        String strExportWorkgroups = request.getParameter( PARAMETER_EXPORT_WORKGROUPS );
        boolean bExportAttributes = StringUtils.isNotEmpty( strExportAttributes );
        boolean bExportRoles = StringUtils.isNotEmpty( strExportRoles );
        boolean bExportRights = StringUtils.isNotEmpty( strExportRights );
        boolean bExportWorkgroups = StringUtils.isNotEmpty( strExportWorkgroups );

        if ( StringUtils.isBlank( strXslExportId ) )
        {
            Object [ ] tabRequiredFields = {
                I18nService.getLocalizedString( FIELD_XSL_EXPORT, getLocale( ) )
            };
            result.setRedirect( AdminMessageService.getMessageUrl( request, MESSAGE_MANDATORY_FIELD, tabRequiredFields, AdminMessage.TYPE_STOP ) );

            return result;
        }

        int nIdXslExport = Integer.parseInt( strXslExportId );

        XslExport xslExport = XslExportHome.findByPrimaryKey( nIdXslExport );

        Collection<AdminUser> listUsers = AdminUserHome.findUserList( );

        List<IAttribute> listAttributes = AttributeService.getInstance( ).getAllAttributesWithFields( LocaleService.getDefault( ) );
        List<IAttribute> listAttributesFiltered = new ArrayList<IAttribute>( );

        for ( IAttribute attribute : listAttributes )
        {
            if ( attribute instanceof ISimpleValuesAttributes )
            {
                listAttributesFiltered.add( attribute );
            }
        }

        StringBuffer sbXml = new StringBuffer( XmlUtil.getXmlHeader( ) );
        XmlUtil.beginElement( sbXml, CONSTANT_XML_USERS );

        for ( AdminUser user : listUsers )
        {
            if ( !user.isStatusAnonymized( ) )
            {
                sbXml.append( AdminUserService.getXmlFromUser( user, bExportRoles, bExportRights, bExportWorkgroups, bExportAttributes, listAttributesFiltered ) );
            }
        }

        XmlUtil.endElement( sbXml, CONSTANT_XML_USERS );

        String strXml = StringUtil.replaceAccent( sbXml.toString( ) );
        String strExportedUsers = XslExportService.exportXMLWithXSL( nIdXslExport, strXml );

        if ( CONSTANT_MIME_TYPE_CSV.contains( xslExport.getExtension( ) ) )
        {
            response.setContentType( CONSTANT_MIME_TYPE_CSV );
        }
        else
            if ( CONSTANT_EXTENSION_XML_FILE.contains( xslExport.getExtension( ) ) )
            {
                response.setContentType( CONSTANT_MIME_TYPE_XML );
            }
            else
            {
                response.setContentType( CONSTANT_MIME_TYPE_OCTETSTREAM );
            }

        String strFileName = CONSTANT_EXPORT_USERS_FILE_NAME + CONSTANT_POINT + xslExport.getExtension( );
        response.setHeader( CONSTANT_ATTACHEMENT_DISPOSITION, CONSTANT_ATTACHEMENT_FILE_NAME + strFileName + CONSTANT_QUOTE );

        PrintWriter out = response.getWriter( );
        out.write( strExportedUsers );
        out.flush( );
        out.close( );

        return null;
    }
