public String doModifyAdminUser( HttpServletRequest request ) throws AccessDeniedException
    {
        String strUserId = request.getParameter( PARAMETER_USER_ID );
        String strAccessCode = request.getParameter( PARAMETER_ACCESS_CODE );
        String strLastName = request.getParameter( PARAMETER_LAST_NAME );
        String strFirstName = request.getParameter( PARAMETER_FIRST_NAME );
        String strEmail = request.getParameter( PARAMETER_EMAIL );
        String strStatus = request.getParameter( PARAMETER_STATUS );
        String strAccessibilityMode = request.getParameter( PARAMETER_ACCESSIBILITY_MODE );
        String strWorkgroupKey = request.getParameter( PARAMETER_WORKGROUP_KEY );

        int nUserId = Integer.parseInt( strUserId );

        AdminUser userToModify = AdminUserHome.findByPrimaryKey( nUserId );
        AdminUser currentUser = AdminUserService.getAdminUser( request );

        if ( !isUserAuthorizedToModifyUser( currentUser, userToModify ) )
        {
            throw new AccessDeniedException( MESSAGE_NOT_AUTHORIZED );
        }

        if ( StringUtils.isEmpty( strAccessCode ) )
        {
            return AdminMessageService.getMessageUrl( request, Messages.MANDATORY_FIELDS, AdminMessage.TYPE_STOP );
        }

        if ( StringUtils.isEmpty( strLastName ) )
        {
            return AdminMessageService.getMessageUrl( request, Messages.MANDATORY_FIELDS, AdminMessage.TYPE_STOP );
        }

        if ( StringUtils.isEmpty( strFirstName ) )
        {
            return AdminMessageService.getMessageUrl( request, Messages.MANDATORY_FIELDS, AdminMessage.TYPE_STOP );
        }

        if ( StringUtils.isBlank( strEmail ) )
        {
            return AdminMessageService.getMessageUrl( request, Messages.MANDATORY_FIELDS, AdminMessage.TYPE_STOP );
        }

        if ( !AdminUserService.checkEmail( strEmail ) )
        {
            return AdminUserService.getEmailErrorMessageUrl( request );
        }

        int checkCode = AdminUserHome.checkAccessCodeAlreadyInUse( strAccessCode );

        // check again that access code is not in use
        if ( ( checkCode != -1 ) && ( checkCode != nUserId ) )
        {
            return AdminMessageService.getMessageUrl( request, PROPERTY_MESSAGE_ACCESS_CODE_ALREADY_USED, AdminMessage.TYPE_STOP );
        }

        checkCode = AdminUserHome.checkEmailAlreadyInUse( strEmail );

        // check again that email is not in use
        if ( ( checkCode != -1 ) && ( checkCode != nUserId ) )
        {
            return AdminMessageService.getMessageUrl( request, PROPERTY_MESSAGE_EMAIL_ALREADY_USED, AdminMessage.TYPE_STOP );
        }

        // modification in no-module mode : we manage the password
        if ( AdminAuthenticationService.getInstance( ).isDefaultModuleUsed( ) )
        {
            LuteceDefaultAdminUser user = AdminUserHome.findLuteceDefaultAdminUserByPrimaryKey( nUserId );

            user.setUserId( nUserId );
            user.setAccessCode( strAccessCode );
            user.setLastName( strLastName );
            user.setFirstName( strFirstName );
            user.setEmail( strEmail );
            user.setWorkgroupKey( strWorkgroupKey );

            int nStatus = Integer.parseInt( strStatus );

            if ( nStatus != user.getStatus( ) )
            {
                user.setStatus( nStatus );
                AdminUserService.notifyUser( AppPathService.getBaseUrl( request ), user, PROPERTY_MESSAGE_EMAIL_SUBJECT_CHANGE_STATUS,
                        TEMPLATE_ADMIN_EMAIL_CHANGE_STATUS );
            }

            user.setLocale( new Locale( request.getParameter( PARAMETER_LANGUAGE ) ) );
            user.setAccessibilityMode( strAccessibilityMode != null );

            String strError = AdminUserFieldService.checkUserFields( request, getLocale( ) );

            if ( strError != null )
            {
                return strError;
            }

            if ( !SecurityTokenService.getInstance( ).validate( request, JSP_URL_MODIFY_USER ) )
            {
                throw new AccessDeniedException( "Invalid security token" );
            }

            AdminUserHome.update( user, PasswordUpdateMode.IGNORE );

            AdminUserFieldService.doModifyUserFields( user, request, getLocale( ), getUser( ) );
        }
        else
        {
            AdminUser user = new AdminUser( );
            user.setUserId( nUserId );
            user.setAccessCode( strAccessCode );
            user.setLastName( strLastName );
            user.setFirstName( strFirstName );
            user.setEmail( strEmail );
            user.setStatus( Integer.parseInt( strStatus ) );
            user.setLocale( new Locale( request.getParameter( PARAMETER_LANGUAGE ) ) );
            user.setAccessibilityMode( strAccessibilityMode != null );
            user.setWorkgroupKey( strWorkgroupKey );

            String strError = AdminUserFieldService.checkUserFields( request, getLocale( ) );

            if ( strError != null )
            {
                return strError;
            }

            if ( !SecurityTokenService.getInstance( ).validate( request, JSP_URL_MODIFY_USER ) )
            {
                throw new AccessDeniedException( "Invalid security token" );
            }

            AdminUserHome.update( user );

            AdminUserFieldService.doModifyUserFields( user, request, getLocale( ), getUser( ) );
        }

        return JSP_MANAGE_USER;
    }
