@Override
    public void doFilter( ServletRequest request, ServletResponse response, FilterChain chain ) throws IOException, ServletException
    {
        HttpServletRequest req = (HttpServletRequest) request;
        HttpServletResponse resp = (HttpServletResponse) response;

        AppLogService.debug( LOGGER_NAME, "Accessing url : " + getResquestedUrl( req ) );

        if ( isPrivateUrl( req ) )
        {
            try
            {
                filterAccess( req );
            }
            catch( UserNotSignedException e )
            {
                AdminAuthenticationService.getInstance( ).setLoginNextUrl( req );

                String strRedirectUrl = null;

                if ( AdminAuthenticationService.getInstance( ).isExternalAuthentication( ) )
                {
                    AppLogService.debug( LOGGER_NAME, "New session behind external authentication : " + getResquestedUrl( req ) );

                    strRedirectUrl = AdminMessageService.getMessageUrl( req, Messages.MESSAGE_USER_NEW_SESSION, getRedirectUrlExternalAuthentication( req ),
                            AdminMessage.TYPE_INFO );
                }
                else
                {
                    AppLogService.debug( LOGGER_NAME, "Access NOT granted to url : " + getResquestedUrl( req ) );

                    strRedirectUrl = AdminMessageService.getMessageUrl( req, Messages.MESSAGE_USER_NOT_AUTHENTICATED, getRedirectUrl( req ),
                            AdminMessage.TYPE_WARNING );
                }

                resp.sendRedirect( getAbsoluteUrl( req, strRedirectUrl ) );

                return;
            }
            catch( AccessDeniedException e )
            {
                AppLogService.debug( LOGGER_NAME, "Access NOT granted to url : " + getResquestedUrl( req ) );

                String strRedirectUrl = AdminMessageService.getMessageUrl( req, Messages.MESSAGE_AUTH_FAILURE, getRedirectUrl( req ), AdminMessage.TYPE_ERROR );
                resp.sendRedirect( getAbsoluteUrl( req, strRedirectUrl ) );

                return;
            }
            catch( PasswordResetException e )
            {
                if ( !getResquestedUrl( req ).equals( getChangePasswordUrl( req ) ) && !getResquestedUrl( req ).equals( getLoginUrl( req ) ) )
                {
                    String strRedirectUrl = AdminMessageService.getMessageUrl( req, Messages.MESSAGE_USER_MUST_CHANGE_PASSWORD, getChangePasswordUrl( req ),
                            AdminMessage.TYPE_ERROR );
                    resp.sendRedirect( getAbsoluteUrl( req, strRedirectUrl ) );

                    return;
                }
            }
        }

        chain.doFilter( request, response );
    }
