public void filterSortAndPaginate( HttpServletRequest request, List<T> items )
    {
        List<T> filteredSortedPaginatedItems = new ArrayList<T>( items );

        boolean bSubmitedDataTable = hasDataTableFormBeenSubmited( request );

        // FILTER
        Collection<DataTableFilter> listFilters = _filterPanel.getListFilter( );
        boolean bUpdateFilter = false;
        boolean bResetFilter = false;

        // We check if filters must be updated or cleared
        if ( bSubmitedDataTable )
        {
            bResetFilter = StringUtils.equals( request.getParameter( FilterPanel.PARAM_FILTER_PANEL_PREFIX + FilterPanel.PARAM_RESET_FILTERS ),
                    Boolean.TRUE.toString( ) );
            bUpdateFilter = true;

            if ( !bResetFilter )
            {
                bUpdateFilter = StringUtils.equals( request.getParameter( FilterPanel.PARAM_FILTER_PANEL_PREFIX + FilterPanel.PARAM_UPDATE_FILTERS ),
                        Boolean.TRUE.toString( ) );
            }
        }

        for ( DataTableFilter filter : listFilters )
        {
            String strFilterValue;

            if ( bSubmitedDataTable && bUpdateFilter )
            {
                // We update or clear filters
                strFilterValue = request.getParameter( FilterPanel.PARAM_FILTER_PANEL_PREFIX + filter.getParameterName( ) );

                if ( !bResetFilter && ( filter.getFilterType( ) == DataTableFilterType.BOOLEAN ) && ( strFilterValue == null ) )
                {
                    strFilterValue = Boolean.FALSE.toString( );
                }

                filter.setValue( strFilterValue );
            }
            else
            {
                strFilterValue = filter.getValue( );
            }

            if ( StringUtils.isNotBlank( strFilterValue ) )
            {
                List<T> bufferList = new ArrayList<T>( );

                for ( T item : filteredSortedPaginatedItems )
                {
                    Method method = getMethod( item, filter.getParameterName( ), CONSTANT_GET );

                    if ( ( method == null ) && ( filter.getFilterType( ) == DataTableFilterType.BOOLEAN ) )
                    {
                        method = getMethod( item, filter.getParameterName( ), CONSTANT_IS );
                    }

                    if ( method != null )
                    {
                        try
                        {
                            Object value = method.invoke( item );

                            if ( ( value != null ) && strFilterValue.equals( value.toString( ) ) )
                            {
                                bufferList.add( item );
                            }
                        }
                        catch( Exception e )
                        {
                            AppLogService.error( e.getMessage( ), e );
                        }
                    }
                }

                filteredSortedPaginatedItems.retainAll( bufferList );
            }
        }

        // SORT
        if ( bSubmitedDataTable )
        {
            // We update the sort parameters
            String strSortedAttributeName = request.getParameter( Parameters.SORTED_ATTRIBUTE_NAME );

            if ( strSortedAttributeName != null )
            {
                // We update sort properties
                _strSortedAttributeName = strSortedAttributeName;
                _bIsAscSort = Boolean.parseBoolean( request.getParameter( Parameters.SORTED_ASC ) );
            }
        }

        // We sort the items
        if ( _strSortedAttributeName != null )
        {
            Collections.sort( filteredSortedPaginatedItems, new AttributeComparator( _strSortedAttributeName, _bIsAscSort ) );
        }

        // PAGINATION
        if ( bSubmitedDataTable )
        {
            // We update the pagination properties
            if ( _bEnablePaginator )
            {
                int nOldItemsPerPage = _nItemsPerPage;
                _nItemsPerPage = Paginator.getItemsPerPage( request, Paginator.PARAMETER_ITEMS_PER_PAGE, _nItemsPerPage, _nDefautlItemsPerPage );

                // If the number of items per page has changed, we switch to the first page
                if ( _nItemsPerPage != nOldItemsPerPage )
                {
                    _strCurrentPageIndex = Integer.toString( 1 );
                }
                else
                {
                    _strCurrentPageIndex = Paginator.getPageIndex( request, Paginator.PARAMETER_PAGE_INDEX, _strCurrentPageIndex );
                }
            }
            else
            {
                _strCurrentPageIndex = Integer.toString( 1 );
                _nItemsPerPage = filteredSortedPaginatedItems.size( );
            }
        }

        // We paginate create the new paginator
        _paginator = new LocalizedPaginator<T>( filteredSortedPaginatedItems, _nItemsPerPage, getSortUrl( ), Paginator.PARAMETER_PAGE_INDEX,
                _strCurrentPageIndex, request.getLocale( ) );
    }
