private static void processNestedTags( StringBuffer buffer, String tagName, String openSubstWithParam, String closeSubstWithParam,
            String openSubstWithoutParam, String closeSubstWithoutParam, String internalSubst, boolean processInternalTags, boolean acceptParam,
            boolean requiresQuotedParam )
    {
        String str = buffer.toString( );

        Stack openStack = new Stack( );
        Set subsOpen = new HashSet( );
        Set subsClose = new HashSet( );
        Set subsInternal = new HashSet( );

        String openTag = CR_LF + "\\[" + tagName + ( acceptParam ? ( requiresQuotedParam ? "(?:=\"(.*?)\")?" : "(?:=\"?(.*?)\"?)?" ) : "" ) + "\\]" + CR_LF;
        String closeTag = CR_LF + "\\[/" + tagName + "\\]" + CR_LF;
        String internTag = CR_LF + "\\[\\*\\]" + CR_LF;

        String patternString = "(" + openTag + ")|(" + closeTag + ")";

        if ( processInternalTags )
        {
            patternString += ( "|(" + internTag + ")" );
        }

        Pattern tagsPattern = Pattern.compile( patternString );
        Matcher matcher = tagsPattern.matcher( str );

        int openTagGroup;
        int paramGroup;
        int closeTagGroup;
        int internalTagGroup;

        if ( acceptParam )
        {
            openTagGroup = 1;
            paramGroup = 2;
            closeTagGroup = 3;
            internalTagGroup = 4;
        }
        else
        {
            openTagGroup = 1;
            paramGroup = -1; // INFO
            closeTagGroup = 2;
            internalTagGroup = 3;
        }

        while ( matcher.find( ) )
        {
            int length = matcher.end( ) - matcher.start( );
            MutableCharSequence matchedSeq = new MutableCharSequence( str, matcher.start( ), length );

            // test opening tags
            if ( matcher.group( openTagGroup ) != null )
            {
                if ( acceptParam && ( matcher.group( paramGroup ) != null ) )
                {
                    matchedSeq._strParam = matcher.group( paramGroup );
                }

                openStack.push( matchedSeq );

                // test closing tags
            }
            else
                if ( ( matcher.group( closeTagGroup ) != null ) && !openStack.isEmpty( ) )
                {
                    MutableCharSequence openSeq = (MutableCharSequence) openStack.pop( );

                    if ( acceptParam )
                    {
                        matchedSeq._strParam = openSeq._strParam;
                    }

                    subsOpen.add( openSeq );
                    subsClose.add( matchedSeq );

                    // test internal tags
                }
                else
                    if ( processInternalTags && ( matcher.group( internalTagGroup ) != null ) && ( !openStack.isEmpty( ) ) )
                    {
                        subsInternal.add( matchedSeq );
                    }
        }

        LinkedList subst = new LinkedList( );
        subst.addAll( subsOpen );
        subst.addAll( subsClose );
        subst.addAll( subsInternal );

        Collections.sort( subst, new Comparator( )
        {
            @Override
            public int compare( Object o1, Object o2 )
            {
                MutableCharSequence s1 = (MutableCharSequence) o1;
                MutableCharSequence s2 = (MutableCharSequence) o2;

                return -( s1._nStart - s2._nStart );
            }
        } );

        buffer.delete( 0, buffer.length( ) );

        int start = 0;

        while ( !subst.isEmpty( ) )
        {
            MutableCharSequence seq = (MutableCharSequence) subst.removeLast( );
            buffer.append( str.substring( start, seq._nStart ) );

            if ( subsClose.contains( seq ) )
            {
                if ( seq._strParam != null )
                {
                    buffer.append( closeSubstWithParam );
                }
                else
                {
                    buffer.append( closeSubstWithoutParam );
                }
            }
            else
                if ( subsInternal.contains( seq ) )
                {
                    buffer.append( internalSubst );
                }
                else
                    if ( subsOpen.contains( seq ) )
                    {
                        Matcher m = Pattern.compile( openTag ).matcher( str.substring( seq._nStart, seq._nStart + seq._bLength ) );

                        if ( m.matches( ) )
                        {
                            if ( acceptParam && ( seq._strParam != null ) )
                            {
                                buffer.append( //
                                openSubstWithParam.replaceAll( "\\{BBCODE_PARAM\\}", seq._strParam ) );
                            }
                            else
                            {
                                buffer.append( openSubstWithoutParam );
                            }
                        }
                    }

            start = seq._nStart + seq._bLength;
        }

        buffer.append( str.substring( start ) );
    }
