private synchronized Connection getConnection( long timeout ) throws SQLException
    {
        // Get a pooled Connection from the cache or a new one.
        // Wait if all are checked out and the max limit has
        // been reached.
        long startTime = System.currentTimeMillis( );
        long remaining = timeout;
        Connection conn = null;

        while ( ( conn = getPooledConnection( ) ) == null )
        {
            try
            {
                _logger.debug( "Waiting for connection. Timeout=" + remaining );

                wait( remaining );
            }
            catch( InterruptedException e )
            {
                _logger.debug( "A connection has been released by another thread." );
            }

            remaining = timeout - ( System.currentTimeMillis( ) - startTime );

            if ( remaining <= 0 )
            {
                // Timeout has expired
                _logger.debug( "Time-out while waiting for connection" );
                throw new SQLException( "getConnection() timed-out" );
            }
        }

        // Check if the Connection is still OK
        if ( !isConnectionOK( conn ) )
        {
            // It was bad. Try again with the remaining timeout
            _logger.error( "Removed selected bad connection from pool" );

            return getConnection( remaining );
        }

        _nCheckedOut++;
        _logger.debug( "Delivered connection from pool" );
        _logger.debug( getStats( ) );

        return conn;
    }
