public void testLoginUpgradePassword( )
    {
        LuteceDefaultAdminAuthentication adminAuth = getLuteceDefaultAdminAuthentication( );
        AdminUserDAO adminUserDAO = getAdminUserDAO( );
        String randomUsername = "user" + new SecureRandom( ).nextLong( );

        LuteceDefaultAdminUser user = new LuteceDefaultAdminUser( randomUsername, new LuteceDefaultAdminAuthentication( ) );
        user.setPassword( new IPassword( )
        {

            @Override
            public boolean isLegacy( )
            {
                return true;
            }

            @Override
            public String getStorableRepresentation( )
            {
                return "PLAINTEXT:" + PASSWORD;
            }

            @Override
            public boolean check( String strCleartextPassword )
            {
                return PASSWORD.equals( strCleartextPassword );
            }
        } );
        user.setFirstName( randomUsername );
        user.setLastName( randomUsername );
        user.setEmail( randomUsername + "@lutece.fr" );
        adminUserDAO.insert( user );
        try
        {
            // check that password is legacy
            LuteceDefaultAdminUser defaultAdminUser = adminUserDAO.loadDefaultAdminUser( user.getUserId( ) );
            assertNotNull( defaultAdminUser );
            assertTrue( defaultAdminUser.getPassword( ).isLegacy( ) );
            // login
            AdminUser authenticated = adminAuth.login( randomUsername, PASSWORD, new MockHttpServletRequest( ) );
            assertNotNull( authenticated );
            // check that password is not legacy anymore
            LuteceDefaultAdminUser defaultAdminUserAthenticated = adminUserDAO.loadDefaultAdminUser( authenticated.getUserId( ) );
            assertNotNull( defaultAdminUserAthenticated );
            assertFalse( defaultAdminUserAthenticated.getPassword( ).isLegacy( ) );
            // retry login to check that password has not changed
            authenticated = adminAuth.login( randomUsername, PASSWORD, new MockHttpServletRequest( ) );
            assertNotNull( authenticated );
        }
        catch( LoginException e )
        {
            fail( e.getMessage( ) );
        }
        finally
        {
            adminUserDAO.delete( user.getUserId( ) );
        }
    }
