private void testEnqueueCoalesce( boolean shouldThrow ) throws ClassNotFoundException, InstantiationException, IllegalAccessException,
            InterruptedException, BrokenBarrierException, TimeoutException
    {
        BlockingQueue<DaemonEntry> queue = new LinkedBlockingQueue<>( );
        ExecutorService executor = new ImmediateExecutorService( );
        DaemonScheduler scheduler = new DaemonScheduler( queue, executor );
        try
        {
            DaemonEntry executing = getDaemonEntry( "JUNIT-executing" );
            TestDaemon executingDaemon = (TestDaemon) executing.getDaemon( );
            executingDaemon.setRunThrows( shouldThrow );
            assertTrue( scheduler.enqueue( executing, 0L, TimeUnit.MILLISECONDS ) );
            executingDaemon.go( );
            DaemonEntry inqueue = getDaemonEntry( "JUNIT-inqueue" );
            TestDaemon inqueueDaemon = (TestDaemon) inqueue.getDaemon( );
            inqueueDaemon.setRunThrows( shouldThrow );
            assertTrue( scheduler.enqueue( inqueue, 0L, TimeUnit.MILLISECONDS ) );
            assertTrue( scheduler.enqueue( inqueue, 0L, TimeUnit.MILLISECONDS ) );
            executingDaemon.waitForCompletion( );
            inqueueDaemon.go( );
            inqueueDaemon.waitForCompletion( );
            try
            {
                inqueueDaemon.go( 200, TimeUnit.MILLISECONDS );
                fail( "Daemon started twice but should have been coalesced" );
            }
            catch( TimeoutException e )
            {

            }
        }
        finally
        {
            scheduler.shutdown( );
        }
    }
