private void testScheduleTwice( boolean shouldThrow ) throws ClassNotFoundException, InstantiationException, IllegalAccessException, InterruptedException,
            BrokenBarrierException, TimeoutException
    {
        BlockingQueue<DaemonEntry> queue = new LinkedBlockingQueue<>( );
        ExecutorService executor = Executors.newSingleThreadExecutor( );
        DaemonScheduler scheduler = new DaemonScheduler( queue, executor );
        try
        {
            DaemonEntry entry = getDaemonEntry( "JUNIT" );
            TestDaemon testDaemon = (TestDaemon) entry.getDaemon( );
            testDaemon.setRunThrows( shouldThrow );
            Instant start = Instant.now( );
            scheduler.schedule( entry, 0L, TimeUnit.MICROSECONDS );
            scheduler.schedule( entry, 500L, TimeUnit.MILLISECONDS );
            assertFalse( testDaemon.hasRun( ) );
            testDaemon.go( );
            testDaemon.waitForCompletion( );
            assertTrue( testDaemon.hasRun( ) );
            testDaemon.go( );
            long timeForSecondRun = Duration.between( start, Instant.now( ) ).toMillis( );
            assertTrue( "Second run was " + timeForSecondRun + "ms after start", 1000L <= timeForSecondRun );
            testDaemon.waitForCompletion( );
            assertTrue( testDaemon.hasRun( ) );
        }
        finally
        {
            scheduler.shutdown( );
        }
    }
