public void testPageVisibility( ) throws IOException, LuteceInitException
    {
        // create pages
        final Random rand = new SecureRandom( );
        Page pageNoRole = createPage( "page." + rand.nextLong( ) );
        Page pageRole1 = createPage( "page.role1." + rand.nextLong( ), ROLE1 );
        Page pageRole2 = createPage( "page.role2." + rand.nextLong( ), ROLE2 );

        boolean authStatus = enableAuthentication( );
        boolean cacheStatus = enablePortalMenuServiceCache( );

        try
        {
            // test twice to test the cache
            for ( int i = 0; i < 2; i++ )
            {
                // test menu content with no user
                HttpServletRequest request = new MockHttpServletRequest( );
                String menu = PortalMenuService.getInstance( ).getMenuContent( 0, PortalMenuService.MODE_NORMAL, PortalMenuService.MENU_MAIN, request );
                assertTrue( "Portal menu should contain page not associated with a role named " + pageNoRole.getName( ) + " (call " + ( i + 1 ) + ")",
                        menu.contains( pageNoRole.getName( ) ) );
                assertFalse( "Portal menu should not contain page associated with role " + ROLE1 + " named " + pageRole1.getName( ) + " (call " + ( i + 1 )
                        + ")", menu.contains( pageRole1.getName( ) ) );
                assertFalse( "Portal menu should not contain page associated with role " + ROLE2 + " named " + pageRole2.getName( ) + " (call " + ( i + 1 )
                        + ")", menu.contains( pageRole2.getName( ) ) );

                // test menu content with no role
                @SuppressWarnings( "serial" )
                LuteceUser user = new LuteceUser( "junit", SecurityService.getInstance( ).getAuthenticationService( ) )
                {
                    @Override
                    public String getName( )
                    {
                        // user name is different on each call
                        return "user" + rand.nextLong( );
                    }
                };

                request.getSession( ).setAttribute( "lutece_user", user );
                menu = PortalMenuService.getInstance( ).getMenuContent( 0, PortalMenuService.MODE_NORMAL, PortalMenuService.MENU_MAIN, request );
                assertTrue( "Portal menu should contain page not associated with a role named " + pageNoRole.getName( ) + " (call " + ( i + 1 ) + ")",
                        menu.contains( pageNoRole.getName( ) ) );
                assertFalse( "Portal menu should not contain page associated with role " + ROLE1 + " named " + pageRole1.getName( ) + " (call " + ( i + 1 )
                        + ")", menu.contains( pageRole1.getName( ) ) );
                assertFalse( "Portal menu should not contain page associated with role " + ROLE2 + " named " + pageRole2.getName( ) + " (call " + ( i + 1 )
                        + ")", menu.contains( pageRole2.getName( ) ) );
                // test menu content with ROLE1
                user.setRoles( Arrays.asList( ROLE1 ) );
                menu = PortalMenuService.getInstance( ).getMenuContent( 0, PortalMenuService.MODE_NORMAL, PortalMenuService.MENU_MAIN, request );
                assertTrue( "Portal menu should contain page not associated with a role named " + pageNoRole.getName( ) + " (call " + ( i + 1 ) + ")",
                        menu.contains( pageNoRole.getName( ) ) );
                assertTrue( "Portal menu should contain page associated with role " + ROLE1 + " named " + pageRole1.getName( ) + " (call " + ( i + 1 ) + ")",
                        menu.contains( pageRole1.getName( ) ) );
                assertFalse( "Portal menu should not contain page associated with role " + ROLE2 + " named " + pageRole2.getName( ) + " (call " + ( i + 1 )
                        + ")", menu.contains( pageRole2.getName( ) ) );

                // test menu content with ROLE2
                user.setRoles( Arrays.asList( ROLE2 ) );
                menu = PortalMenuService.getInstance( ).getMenuContent( 0, PortalMenuService.MODE_NORMAL, PortalMenuService.MENU_MAIN, request );
                assertTrue( "Portal menu should contain page not associated with a role named " + pageNoRole.getName( ) + " (call " + ( i + 1 ) + ")",
                        menu.contains( pageNoRole.getName( ) ) );
                assertFalse( "Portal menu should not contain page associated with role " + ROLE1 + " named " + pageRole1.getName( ) + " (call " + ( i + 1 )
                        + ")", menu.contains( pageRole1.getName( ) ) );
                assertTrue( "Portal menu should contain page associated with role " + ROLE2 + " named " + pageRole2.getName( ) + " (call " + ( i + 1 ) + ")",
                        menu.contains( pageRole2.getName( ) ) );

                // test menu content with ROLE1 and ROLE2
                user.setRoles( Arrays.asList( ROLE1, ROLE2 ) );
                menu = PortalMenuService.getInstance( ).getMenuContent( 0, PortalMenuService.MODE_NORMAL, PortalMenuService.MENU_MAIN, request );
                assertTrue( "Portal menu should contain page not associated with a role named " + pageNoRole.getName( ) + " (call " + ( i + 1 ) + ")",
                        menu.contains( pageNoRole.getName( ) ) );
                assertTrue( "Portal menu should contain page associated with role " + ROLE1 + " named " + pageRole1.getName( ) + " (call " + ( i + 1 ) + ")",
                        menu.contains( pageRole1.getName( ) ) );
                assertTrue( "Portal menu should contain page associated with role " + ROLE2 + " named " + pageRole2.getName( ) + " (call " + ( i + 1 ) + ")",
                        menu.contains( pageRole2.getName( ) ) );

                // test menu content with ROLE2 and ROLE1
                user.setRoles( Arrays.asList( ROLE2, ROLE1 ) );

                String menu2 = PortalMenuService.getInstance( ).getMenuContent( 0, PortalMenuService.MODE_NORMAL, PortalMenuService.MENU_MAIN, request );
                assertTrue( "Role order should not matter to the cache (call " + ( i + 1 ) + ")", menu == menu2 );
            }
        }
        finally
        {
            // cleanup
            restoreAuthentication( authStatus );
            restorePortalMenuServiceCache( cacheStatus );

            IPageService pageService = (IPageService) SpringContextService.getBean( "pageService" );
            pageService.removePage( pageNoRole.getId( ) );
            pageService.removePage( pageRole1.getId( ) );
            pageService.removePage( pageRole2.getId( ) );
        }
    }
