public void testDoModifyDefaultAdminUserPassword( ) throws AccessDeniedException
    {
        AdminUserDAO adminUserDAO = getAdminUserDAO( );
        String randomUsername = "user" + new SecureRandom( ).nextLong( );
        String password = "Pa55word!";
        IPasswordFactory passwordFactory = SpringContextService.getBean( IPasswordFactory.BEAN_NAME );

        LuteceDefaultAdminUser user = new LuteceDefaultAdminUser( randomUsername, new LuteceDefaultAdminAuthentication( ) );
        user.setPassword( passwordFactory.getPasswordFromCleartext( password ) );
        user.setFirstName( randomUsername );
        user.setLastName( randomUsername );
        user.setEmail( randomUsername + "@lutece.fr" );
        adminUserDAO.insert( user );
        try
        {
            AdminMenuJspBean instance = new AdminMenuJspBean( );
            // no args
            MockHttpServletRequest request = new MockHttpServletRequest( );
            request.getSession( true ).setAttribute( "lutece_admin_user", user );
            instance.doModifyDefaultAdminUserPassword( request );
            AdminMessage message = AdminMessageService.getMessage( request );
            assertNotNull( message );
            assertEquals( I18nService.getLocalizedString( Messages.MANDATORY_FIELDS, Locale.FRENCH ), message.getText( Locale.FRENCH ) );

            request = new MockHttpServletRequest( );
            request.getSession( true ).setAttribute( "lutece_admin_user", user );
            request.addParameter( Parameters.PASSWORD_CURRENT, password );
            instance.doModifyDefaultAdminUserPassword( request );
            message = AdminMessageService.getMessage( request );
            assertNotNull( message );
            assertEquals( I18nService.getLocalizedString( Messages.MANDATORY_FIELDS, Locale.FRENCH ), message.getText( Locale.FRENCH ) );

            request = new MockHttpServletRequest( );
            request.getSession( true ).setAttribute( "lutece_admin_user", user );
            request.addParameter( Parameters.PASSWORD_CURRENT, password );
            request.addParameter( Parameters.NEW_PASSWORD, password + "_mod" );
            instance.doModifyDefaultAdminUserPassword( request );
            message = AdminMessageService.getMessage( request );
            assertNotNull( message );
            assertEquals( I18nService.getLocalizedString( Messages.MANDATORY_FIELDS, Locale.FRENCH ), message.getText( Locale.FRENCH ) );

            request = new MockHttpServletRequest( );
            request.getSession( true ).setAttribute( "lutece_admin_user", user );
            request.addParameter( Parameters.PASSWORD_CURRENT, password );
            request.addParameter( Parameters.CONFIRM_NEW_PASSWORD, password + "_mod" );
            instance.doModifyDefaultAdminUserPassword( request );
            message = AdminMessageService.getMessage( request );
            assertNotNull( message );
            assertEquals( I18nService.getLocalizedString( Messages.MANDATORY_FIELDS, Locale.FRENCH ), message.getText( Locale.FRENCH ) );

            request = new MockHttpServletRequest( );
            request.getSession( true ).setAttribute( "lutece_admin_user", user );
            request.addParameter( Parameters.NEW_PASSWORD, password );
            instance.doModifyDefaultAdminUserPassword( request );
            message = AdminMessageService.getMessage( request );
            assertNotNull( message );
            assertEquals( I18nService.getLocalizedString( Messages.MANDATORY_FIELDS, Locale.FRENCH ), message.getText( Locale.FRENCH ) );

            request = new MockHttpServletRequest( );
            request.getSession( true ).setAttribute( "lutece_admin_user", user );
            request.addParameter( Parameters.NEW_PASSWORD, password );
            request.addParameter( Parameters.CONFIRM_NEW_PASSWORD, password + "_mod" );
            instance.doModifyDefaultAdminUserPassword( request );
            message = AdminMessageService.getMessage( request );
            assertNotNull( message );
            assertEquals( I18nService.getLocalizedString( Messages.MANDATORY_FIELDS, Locale.FRENCH ), message.getText( Locale.FRENCH ) );

            request = new MockHttpServletRequest( );
            request.getSession( true ).setAttribute( "lutece_admin_user", user );
            request.addParameter( Parameters.CONFIRM_NEW_PASSWORD, password + "_mod" );
            instance.doModifyDefaultAdminUserPassword( request );
            message = AdminMessageService.getMessage( request );
            assertNotNull( message );
            assertEquals( I18nService.getLocalizedString( Messages.MANDATORY_FIELDS, Locale.FRENCH ), message.getText( Locale.FRENCH ) );

            request = new MockHttpServletRequest( );
            request.getSession( true ).setAttribute( "lutece_admin_user", user );
            request.addParameter( Parameters.PASSWORD_CURRENT, password );
            request.addParameter( Parameters.NEW_PASSWORD, password );
            request.addParameter( Parameters.CONFIRM_NEW_PASSWORD, password + "_mod" );
            instance.doModifyDefaultAdminUserPassword( request );
            message = AdminMessageService.getMessage( request );
            assertNotNull( message );
            assertEquals( I18nService.getLocalizedString( "portal.users.message.password.confirm.error", Locale.FRENCH ), message.getText( Locale.FRENCH ) );

            request = new MockHttpServletRequest( );
            request.getSession( true ).setAttribute( "lutece_admin_user", user );
            request.addParameter( Parameters.PASSWORD_CURRENT, "BOGUS" );
            request.addParameter( Parameters.NEW_PASSWORD, password + "_mod" );
            request.addParameter( Parameters.CONFIRM_NEW_PASSWORD, password + "_mod" );
            instance.doModifyDefaultAdminUserPassword( request );
            message = AdminMessageService.getMessage( request );
            assertNotNull( message );
            assertEquals( I18nService.getLocalizedString( "portal.users.message.password.wrong.current", Locale.FRENCH ), message.getText( Locale.FRENCH ) );

            request = new MockHttpServletRequest( );
            request.getSession( true ).setAttribute( "lutece_admin_user", user );
            request.addParameter( Parameters.PASSWORD_CURRENT, password );
            request.addParameter( Parameters.NEW_PASSWORD, password );
            request.addParameter( Parameters.CONFIRM_NEW_PASSWORD, password );
            instance.doModifyDefaultAdminUserPassword( request );
            message = AdminMessageService.getMessage( request );
            assertNotNull( message );
            assertEquals( I18nService.getLocalizedString( "portal.users.message.password.new.equals.current", Locale.FRENCH ), message.getText( Locale.FRENCH ) );

            request = new MockHttpServletRequest( );
            request.getSession( true ).setAttribute( "lutece_admin_user", user );
            request.addParameter( Parameters.PASSWORD_CURRENT, password );
            request.addParameter( Parameters.NEW_PASSWORD, password + "_mod" );
            request.addParameter( Parameters.CONFIRM_NEW_PASSWORD, password + "_mod" );
            request.addParameter( SecurityTokenService.PARAMETER_TOKEN, SecurityTokenService.getInstance( ).getToken( request, "admin/user/modify_password_default_module.html" ) );
            instance.doModifyDefaultAdminUserPassword( request );
            message = AdminMessageService.getMessage( request );
            assertNotNull( message );
            assertEquals( AppPropertiesService.getProperty( "lutece.admin.logout.url" ), message.getUrl( ) );

            List<IPassword> history = AdminUserHome.selectUserPasswordHistory( user.getUserId( ) );
            assertEquals( 1, history.size( ) );
            assertTrue( history.get( 0 ).check( password + "_mod" ) );
        }
        finally
        {
            adminUserDAO.delete( user.getUserId( ) );
            AdminUserHome.removeAllPasswordHistoryForUser( user.getUserId( ) );
        }

    }
