public void testGetRemovePortletWithPortletRemovalListener( ) throws AccessDeniedException
    {
        AdminPagePortletJspBean bean = new AdminPagePortletJspBean( );
        MockHttpServletRequest request = new MockHttpServletRequest( );
        Portlet portlet = null;
        AdminUser user = null;
        try
        {
            portlet = getPortlet( );
            user = getAdminUser( );
            request.addParameter( Parameters.PORTLET_ID, Integer.toString( portlet.getId( ) ) );
            Utils.registerAdminUser( request, user );
            final int nPortletId = portlet.getId( );
            final String removalRefusedMessage = "REMOVAL_REFUSED_" + nPortletId;
            PortletRemovalListenerService.getService( ).registerListener( new RemovalListener( )
            {
                // removalListener cannot be unregistered. Try not to interfere with other tests
                private boolean first = true;

                @Override
                public String getRemovalRefusedMessage( String id, Locale locale )
                {
                    return removalRefusedMessage;
                }

                @Override
                public boolean canBeRemoved( String id )
                {
                    // always allow removal after first use
                    boolean res = !first || !id.equals( Integer.toString( nPortletId ) );
                    first = false;
                    return res;
                }
            } );
            String url = bean.getRemovePortlet( request );
            assertNotNull( url );
            AdminMessage message = AdminMessageService.getMessage( request );
            assertNotNull( message );
            assertNotNull( message.getRequestParameters( ).get( SecurityTokenService.PARAMETER_TOKEN ) );
            assertEquals( message.getType( ), AdminMessage.TYPE_STOP );
            ReferenceList listLanguages = I18nService.getAdminLocales( Locale.FRANCE );
            for ( ReferenceItem lang : listLanguages )
            {
                assertTrue( message.getText( new Locale( lang.getCode( ) ) ).contains( portlet.getName( ) ) );
                assertTrue( message.getText( new Locale( lang.getCode( ) ) ).contains( removalRefusedMessage ) );
            }
        }
        finally
        {
            if ( portlet != null )
            {
                removePortlet( portlet );
            }
            if ( user != null )
            {
                removeUser( user );
            }
        }
    }
