public void testDoResetCachesOneCache( ) throws AccessDeniedException
    {
        CacheListener cacheEventListener = new CacheListener( );
        int cacheIndex = -1;
        for ( CacheableService service : CacheService.getCacheableServicesList( ) )
        {
            cacheIndex++;
            if ( service instanceof AbstractCacheableService )
            {
                ( ( AbstractCacheableService ) service ).getCache( ).getCacheEventNotificationService( )
                        .registerListener( cacheEventListener );
                break;
            }
        }
        assertFalse( "There should be at least one active AbstractCacheableService", cacheIndex == -1 );
        CacheListener allCacheEventListener = new CacheListener( );
        long registeredListener = CacheService.getCacheableServicesList( ).stream( )
                .filter( service -> service instanceof AbstractCacheableService && service.isCacheEnable( ) )
                .map( service -> ( ( AbstractCacheableService ) service ).getCache( )
                        .getCacheEventNotificationService( ) )
                .peek( rel -> rel.registerListener( allCacheEventListener ) ).count( );
        assertFalse( "There should be at least one active AbstractCacheableService", 0 == registeredListener );
        MockHttpServletRequest request = new MockHttpServletRequest( );
        Utils.registerAdminUserWithRigth( request, new AdminUser( ), CacheJspBean.RIGHT_CACHE_MANAGEMENT );
        request.addParameter( "id_cache", Integer.toString( cacheIndex ) );
        request.addParameter( SecurityTokenService.PARAMETER_TOKEN,
                SecurityTokenService.getInstance( ).getToken( request, "admin/system/manage_caches.html" ) );
        CacheJspBean.doResetCaches( request );
        assertEquals( "Only one cache should have been reset", 1, allCacheEventListener.getCallCount( ) );
        assertEquals( "The target cache should have been reset", 1, cacheEventListener.getCallCount( ) );
    }
