@Override
    protected void tearDown( ) throws Exception
    {
        // Attempt to unlock test daemon threads that would be blocked on the barriers, for
        // example if the test throws an unexpected exception, causing it to not call go() and waitforcompletion() to unlock the barriers.
        // A stuck thread would make the next test start with the daemon already running
        // (even though it is unregistered, because the logic to remove running daemons is done at the end of the thread),
        // so the calls the go() and waitcompletion() could be imbalanced. And it's highly
        // confusing that the tests keep this kind of state between them.
        // Note that the thread would die off eventually because the barriers have a timeout, but tests
        // continue to execute in the mean time and fail with obscure reasons.
        _testDaemon.resetGo( );
        _testDaemon.resetCompletion( );

        DatastoreService.removeInstanceData( DAEMON_INTERVAL_DSKEY );
        AppDaemonService.stopDaemon( JUNIT_DAEMON );
        AppDaemonService.unregisterDaemon( JUNIT_DAEMON );
        restoreInitialStartDelay( origMaxInitialStartDelay );
        assertEquals( "Failed to restore daemon initial start delay", origMaxInitialStartDelay,
                AppPropertiesService.getProperty( "daemon.maxInitialStartDelay" ) );
        super.tearDown( );
    }
