protected IProblem readProblem(String problemname)
            throws ParseFormatException, IOException, ContradictionException {
        log("solving " + problemname); //$NON-NLS-1$
        log("reading problem ... "); //$NON-NLS-1$
        SolverDecorator<ISolver> decorator = null;
        ISolver originalProblem;
        if (feedWithDecorated) {
            decorator = (SolverDecorator<ISolver>) this.solver;
            originalProblem = decorator.decorated();
        } else {
            originalProblem = this.solver;
        }
        this.reader = createReader(originalProblem, problemname);
        IProblem aProblem = this.reader.parseInstance(problemname);
        if (this.reader.hasAMapping()) {
            SearchListener<?> listener = this.solver.getSearchListener();
            if (listener instanceof DotSearchTracing) {
                ((DotSearchTracing) listener)
                        .setMapping(this.reader.getMapping());
            }
        }
        log("... done. Wall clock time " //$NON-NLS-1$
                + (System.currentTimeMillis() - this.beginTime) / 1000.0
                + "s."); //$NON-NLS-1$
        log("declared #vars     " + aProblem.nVars()); //$NON-NLS-1$
        if (this.solver.nVars() < this.solver.realNumberOfVariables()) {
            log("internal #vars     " + this.solver.realNumberOfVariables()); //$NON-NLS-1$
        }
        log("#constraints  " + aProblem.nConstraints()); //$NON-NLS-1$
        aProblem.printInfos(this.out);
        if (System.getProperty("UNSATPROOF") != null) {
            String proofFile = problemname + ".rupproof";
            this.solver.setSearchListener(
                    new RupSearchListener<ISolverService>(proofFile));
            if (!this.isSilent()) {
                System.out.println(this.solver.getLogPrefix()
                        + "Generating unsat proof in file " + proofFile);
            }
        }
        if (feedWithDecorated) {
            return decorator;
        }
        return aProblem;
    }
