public void displayResult(ISolver solver, IProblem problem, ILogAble logger,
            PrintWriter out, Reader reader, long beginTime,
            boolean displaySolutionLine) {
        if (solver != null) {
            out.flush();
            double wallclocktime = (System.currentTimeMillis() - beginTime)
                    / 1000.0;
            solver.printStat(out);
            out.println(ANSWER_PREFIX + exitCode);
            if (exitCode != ExitCode.UNKNOWN
                    && exitCode != ExitCode.UNSATISFIABLE) {
                int[] model = problem.model();
                if (System.getProperty("prime") != null) {
                    int initiallength = model.length;
                    logger.log("returning a prime implicant ...");
                    long beginpi = System.currentTimeMillis();
                    model = solver.primeImplicant();
                    long endpi = System.currentTimeMillis();
                    logger.log("removed " + (initiallength - model.length)
                            + " literals");
                    logger.log("pi computation time: " + (endpi - beginpi)
                            + " ms");
                }
                if (System.getProperty("backbone") != null) {
                    logger.log("computing the backbone of the formula ...");
                    long beginpi = System.currentTimeMillis();
                    model = solver.primeImplicant();
                    try {
                        IVecInt backbone = Backbone.instance().compute(solver,
                                model);
                        long endpi = System.currentTimeMillis();
                        out.print(solver.getLogPrefix());
                        reader.decode(backbone.toArray(), out);
                        out.println();
                        logger.log("backbone computation time: "
                                + (endpi - beginpi) + " ms");
                    } catch (TimeoutException e) {
                        logger.log("timeout, cannot compute the backbone.");
                    }

                }
                if (nbSolutionFound >= 1) {
                    logger.log("Found " + nbSolutionFound + " solution(s)");
                } else {
                    out.print(SOLUTION_PREFIX);
                    reader.decode(model, out);
                    out.println();
                }
            }
            logger.log("Total wall clock time (in seconds) : " + wallclocktime); //$NON-NLS-1$
        }
    }
