public void solve(IProblem problem, Reader reader, ILogAble logger,
            PrintWriter out, long beginTime) {
        boolean isSatisfiable = false;
        this.nbSolutions = 0;
        IOptimizationProblem optproblem = (IOptimizationProblem) problem;
        exitCode = ExitCode.UNKNOWN;

        this.out = out;
        this.beginTime = beginTime;
        this.problem = optproblem;

        try {
            while (optproblem.admitABetterSolution()) {
                ++this.nbSolutions;
                if (!isSatisfiable) {
                    if (optproblem.nonOptimalMeansSatisfiable()) {
                        logger.log("SATISFIABLE");
                        exitCode = ExitCode.SATISFIABLE;
                        if (optproblem.hasNoObjectiveFunction()) {
                            return;
                        }
                    } else if (isIncomplete) {
                        exitCode = ExitCode.UPPER_BOUND;
                    }
                    isSatisfiable = true;
                    logger.log("OPTIMIZING..."); //$NON-NLS-1$
                }
                logger.log("Got one! Elapsed wall clock time (in seconds):" //$NON-NLS-1$
                        + (System.currentTimeMillis() - beginTime) / 1000.0);
                out.println(CURRENT_OPTIMUM_VALUE_PREFIX
                        + optproblem.getObjectiveValue());
                optproblem.discardCurrentSolution();
            }
            if (isSatisfiable) {
                exitCode = ExitCode.OPTIMUM_FOUND;
            } else {
                exitCode = ExitCode.UNSATISFIABLE;
            }
        } catch (ContradictionException ex) {
            assert isSatisfiable;
            exitCode = ExitCode.OPTIMUM_FOUND;
        } catch (TimeoutException e) {
            logger.log("timeout");
        }

    }
