public int[] compute(Solver<? extends DataStructureFactory> solver) {
        long begin = System.currentTimeMillis();
        IVecInt[] watched = new IVecInt[solver.voc.nVars() * 2 + 2];
        for (int d : solver.fullmodel) {
            watched[toInternal(d)] = new VecInt();
        }
        int[] count = new int[solver.constrs.size()];
        Constr constr;
        IVecInt watch;
        for (int i = 0; i < solver.constrs.size(); i++) {
            constr = solver.constrs.get(i);
            if (!constr.canBeSatisfiedByCountingLiterals()) {
                throw new IllegalStateException(
                        "Algo2 does not work with constraints other than clauses and cardinalities"
                                + constr.getClass());
            }
            count[i] = 0;
            for (int j = 0; j < constr.size(); j++) {
                watch = watched[constr.get(j)];
                if (watch != null) {
                    // satisfied literal
                    watch.push(i);
                }
            }
        }
        for (int d : solver.fullmodel) {
            for (IteratorInt it = watched[toInternal(d)].iterator(); it
                    .hasNext();) {
                count[it.next()]++;
            }
        }
        this.prime = new int[solver.voc.nVars() + 1];
        int d;
        for (int i = 0; i < this.prime.length; i++) {
            this.prime[i] = 0;
        }
        for (IteratorInt it = solver.implied.iterator(); it.hasNext();) {
            d = it.next();
            this.prime[Math.abs(d)] = d;
        }
        int removed = 0;
        int posremoved = 0;
        int propagated = 0;
        int constrNumber;
        top: for (int i = 0; i < solver.decisions.size(); i++) {
            d = solver.decisions.get(i);
            for (IteratorInt it = watched[toInternal(d)].iterator(); it
                    .hasNext();) {
                constrNumber = it.next();
                if (count[constrNumber] == solver.constrs.get(constrNumber)
                        .requiredNumberOfSatisfiedLiterals()) {
                    this.prime[Math.abs(d)] = d;
                    propagated++;
                    continue top;
                }
            }
            removed++;
            if (d > 0 && d > solver.nVars()) {
                posremoved++;
            }
            for (IteratorInt it = watched[toInternal(d)].iterator(); it
                    .hasNext();) {
                count[it.next()]--;
            }
        }
        int[] implicant = new int[this.prime.length - removed - 1];
        int index = 0;
        for (int i : this.prime) {
            if (i != 0) {
                implicant[index++] = i;
            }
        }
        long end = System.currentTimeMillis();
        if (solver.isVerbose()) {
            System.out.printf(
                    "%s prime implicant computation statistics ALGO2%n",
                    solver.getLogPrefix());
            System.out
                    .printf("%s implied: %d, decision: %d, removed %d (+%d), propagated %d, time(ms):%d %n",
                            solver.getLogPrefix(), solver.implied.size(),
                            solver.decisions.size(), removed, posremoved,
                            propagated, end - begin);
        }
        return implicant;
    }
