public int[] compute(Solver<? extends DataStructureFactory> solver) {
        assert solver.qhead == solver.trail.size()
                + solver.learnedLiterals.size();
        long begin = System.currentTimeMillis();
        if (solver.learnedLiterals.size() > 0) {
            solver.qhead = solver.trail.size();
        }
        if (solver.isVerbose()) {
            System.out.printf("%s implied: %d, decision: %d %n",
                    solver.getLogPrefix(), solver.implied.size(),
                    solver.decisions.size());
        }
        prime = new int[solver.realNumberOfVariables() + 1];
        int p, d;
        for (int i = 0; i < prime.length; i++) {
            prime[i] = 0;
        }
        boolean noproblem;
        for (IteratorInt it = solver.implied.iterator(); it.hasNext();) {
            d = it.next();
            p = toInternal(d);
            prime[Math.abs(d)] = d;
            noproblem = setAndPropagate(solver, p);
            assert noproblem;
        }
        boolean canBeRemoved;
        int rightlevel;
        int removed = 0;
        int posremoved = 0;
        int propagated = 0;
        int tested = 0;
        int l2propagation = 0;

        for (int i = 0; i < solver.decisions.size(); i++) {
            d = solver.decisions.get(i);
            assert !solver.voc.isFalsified(toInternal(d));
            if (solver.voc.isSatisfied(toInternal(d))) {
                // d has been propagated
                prime[Math.abs(d)] = d;
                propagated++;
            } else if (setAndPropagate(solver, toInternal(-d))) {
                canBeRemoved = true;
                tested++;
                rightlevel = solver.currentDecisionLevel();
                for (int j = i + 1; j < solver.decisions.size(); j++) {
                    l2propagation++;
                    if (!setAndPropagate(solver,
                            toInternal(solver.decisions.get(j)))) {
                        canBeRemoved = false;
                        break;
                    }
                }
                solver.cancelUntil(rightlevel);
                if (canBeRemoved) {
                    // it is not a necessary literal
                    solver.forget(Math.abs(d));
                    IConstr confl = solver.propagate();
                    assert confl == null;
                    removed++;
                    if (d > 0 && d > solver.nVars()) {
                        posremoved++;
                    }
                } else {
                    prime[Math.abs(d)] = d;
                    solver.cancel();
                    assert solver.voc.isUnassigned(toInternal(d));
                    noproblem = setAndPropagate(solver, toInternal(d));
                    assert noproblem;
                }
            } else {
                // conflict, literal is necessary
                prime[Math.abs(d)] = d;
                solver.cancel();
                noproblem = setAndPropagate(solver, toInternal(d));
                assert noproblem;
            }
        }
        solver.cancelUntil(0);
        int[] implicant = new int[prime.length - removed - 1];
        int index = 0;
        for (int i : prime) {
            if (i != 0) {
                implicant[index++] = i;
            }
        }
        long end = System.currentTimeMillis();
        if (solver.isVerbose()) {
            System.out.printf(
                    "%s prime implicant computation statistics ORIG%n",
                    solver.getLogPrefix());
            System.out
                    .printf("%s implied: %d, decision: %d, removed %d (+%d), tested %d, propagated %d), l2 propagation:%d, time(ms):%d %n",
                            solver.getLogPrefix(), solver.implied.size(),
                            solver.decisions.size(), removed, posremoved,
                            tested, propagated, l2propagation, end - begin);
        }
        return implicant;

    }
