public int[] compute(Solver<? extends DataStructureFactory> solver) {
        assert solver.qhead == solver.trail.size()
                + solver.learnedLiterals.size();
        long begin = System.currentTimeMillis();
        if (solver.learnedLiterals.size() > 0) {
            solver.qhead = solver.trail.size();
        }
        this.prime = new int[solver.voc.nVars() + 1];
        int p;
        for (int i = 0; i < this.prime.length; i++) {
            this.prime[i] = 0;
        }
        // unit clauses need to be handled specifically
        for (int i = 0; i < solver.trail.size(); i++) {
            isMandatory(solver.trail.get(i));
        }
        for (int d : solver.fullmodel) {
            p = toInternal(d);
            if (solver.voc.isUnassigned(p)) {
                solver.assume(p);
            }
        }
        for (int d : solver.fullmodel) {
            reduceClausesContainingTheNegationOfPI(solver, toInternal(d));
        }

        int removed = 0;
        int posremoved = 0;
        int propagated = 0;
        for (int d : fullModel(solver)) {
            if (this.prime[Math.abs(d)] != 0) {
                // d has been propagated
                propagated++;
            } else {
                // it is not a mandatory literal
                solver.forget(Math.abs(d));
                reduceClausesContainingTheNegationOfPI(solver, toInternal(-d));
                removed++;
                if (d > 0 && d > solver.nVars()) {
                    posremoved++;
                }
            }
        }
        solver.cancelUntil(0);
        int[] implicant = new int[propagated];
        int index = 0;
        for (int i : this.prime) {
            if (i != 0) {
                implicant[index++] = i;
            }
        }
        long end = System.currentTimeMillis();
        if (solver.isVerbose()) {
            System.out.printf(
                    "%s prime implicant computation statistics BRESIL (reverse = %b)%n",
                    solver.getLogPrefix(), this.comparator != null);
            System.out.printf(
                    "%s implied: %d, decision: %d, removed %d (+%d), propagated %d, time(ms):%d %n",
                    solver.getLogPrefix(), solver.implied.size(),
                    solver.decisions.size(), removed, posremoved, propagated,
                    end - begin);
        }
        return implicant;
    }
