private List<IVecInt> computeAllMSS(IVecInt assumptions,
            SolutionFoundListener listener, ISolver min4Inc, IVecInt pLits) {
        if (css.isVerbose()) {
            System.out.println(css.getLogPrefix() + "Computing all MSSes ...");
        }
        css.internalState();
        int nVar = css.nVars();

        IVecInt blockingClause;

        IVecInt secondPhaseClause;

        IVecInt fullMSS = new VecInt();
        IVecInt mss;

        int clause;

        for (int i = 0; i < css.getAddedVars().size(); i++) {
            fullMSS.push(i + 1);
        }

        // first phase
        try {

            while (min4Inc.isSatisfiable(assumptions)) {
                int[] fullmodel = min4Inc.modelWithInternalVariables();

                mss = new VecInt();
                fullMSS.copyTo(mss);

                blockingClause = new VecInt();
                secondPhaseClause = new VecInt();
                for (int i = 0; i < pLits.size(); i++) {
                    clause = Math.abs(pLits.get(i));
                    if (fullmodel[clause - 1] > 0) {
                        blockingClause.push(-clause);
                        secondPhaseClause.push(clause - nVar);
                        mss.remove(clause - nVar);
                    }
                }

                mssList.add(mss);

                listener.onSolutionFound(mss);

                secondPhaseClauses.add(secondPhaseClause);
                try {
                    css.addBlockingClause(blockingClause);
                } catch (ContradictionException e) {
                    Logger.getLogger("org.sat4j.core").log(Level.INFO,
                            "Trivial inconsistency", e);
                    break;
                }
            }

        } catch (TimeoutException e) {
            Logger.getLogger("org.sat4j.core").log(Level.INFO,
                    "Timeout during the first stage", e);
        }
        if (css.isVerbose()) {
            System.out.println(css.getLogPrefix() + "... done.");
        }
        css.externalState();
        return mssList;
    }
