public IVecInt explain(ISolver solver, Map<Integer, ?> constrs,
            IVecInt assumps) throws TimeoutException {
        this.computationCanceled = false;
        IVecInt encodingAssumptions = new VecInt(
                constrs.size() + assumps.size());
        assumps.copyTo(encodingAssumptions);
        IVecInt firstExplanation = solver.unsatExplanation();
        if (firstExplanation.size() == 1) {
            IVecInt results = new VecInt();
            results.push(-firstExplanation.get(0));
            return results;
        }
        if (solver.isVerbose()) {
            System.out.print(solver.getLogPrefix() + "initial unsat core ");
            firstExplanation.sort();
            for (IteratorInt it = firstExplanation.iterator(); it.hasNext();) {
                System.out.print(constrs.get(-it.next()));
                System.out.print(" ");
            }
            System.out.println();
        }
        for (int i = 0; i < firstExplanation.size();) {
            if (assumps.contains(firstExplanation.get(i))) {
                firstExplanation.delete(i);
            } else {
                i++;
            }
        }
        Set<Integer> constraintsVariables = constrs.keySet();
        IVecInt remainingVariables = new VecInt(constraintsVariables.size());
        for (Integer v : constraintsVariables) {
            remainingVariables.push(v);
        }
        int p;
        for (IteratorInt it = firstExplanation.iterator(); it.hasNext();) {
            p = it.next();
            if (p < 0) {
                p = -p;
            }
            remainingVariables.remove(p);
            encodingAssumptions.push(p);
        }
        remainingVariables.copyTo(encodingAssumptions);
        boolean shouldContinue;
        int startingPoint = assumps.size();
        do {
            shouldContinue = false;
            int i = startingPoint;
            encodingAssumptions.set(i, -encodingAssumptions.get(i));
            assert encodingAssumptions.get(i) < 0;
            while (!this.computationCanceled
                    && solver.isSatisfiable(encodingAssumptions)) {
                i++;
                assert encodingAssumptions.get(i) > 0;
                encodingAssumptions.set(i, -encodingAssumptions.get(i));
            }
            if (!this.computationCanceled && i > startingPoint) {
                assert !solver.isSatisfiable(encodingAssumptions);
                if (i < encodingAssumptions.size()) {
                    // latest constraint is for sure responsible for the
                    // inconsistency.
                    int tmp = encodingAssumptions.get(i);
                    for (int j = i; j > startingPoint; j--) {
                        encodingAssumptions.set(j,
                                -encodingAssumptions.get(j - 1));
                    }
                    encodingAssumptions.set(startingPoint, tmp);
                    if (solver.isVerbose()) {
                        System.out.println(solver.getLogPrefix()
                                + constrs.get(tmp) + " is mandatory ");
                    }
                }
                shouldContinue = true;
            }
            startingPoint++;
        } while (!this.computationCanceled && shouldContinue
                && solver.isSatisfiable(encodingAssumptions));
        if (this.computationCanceled) {
            throw new TimeoutException();
        }
        IVecInt constrsKeys = new VecInt(startingPoint);
        for (int i = assumps.size(); i < startingPoint; i++) {
            constrsKeys.push(-encodingAssumptions.get(i));
        }
        return constrsKeys;
    }
