@Test
    public void testWithReset() throws TimeoutException, ContradictionException {
        ISolver solver = SolverFactory.newDefault();
        int[] clause;
        boolean res;

        // prepare the solver to accept MAXVAR variables. MANDATORY
        solver.newVar(4);
        // not mandatory for SAT solving. MANDATORY for MAXSAT solving
        solver.setExpectedNumberOfClauses(6);
        // Feed the solver using Dimacs format, using arrays of int
        // (best option to avoid dependencies on SAT4J IVecInt)

        // test empty
        res = solver.isSatisfiable();
        assertTrue(res);
        solver.reset();

        // test one clause
        solver.newVar(1);
        clause = new int[] { -4 };
        solver.addClause(new VecInt(clause));
        res = solver.isSatisfiable();
        assertTrue(res);
        solver.reset();

        // test multiply statements
        solver.newVar(4);
        addData(solver);
        assertTrue(solver.isSatisfiable());

        clause = new int[] { -4 };
        solver.addClause(new VecInt(clause));
        try {
            addData(solver);
            res = solver.isSatisfiable();
        } catch (ContradictionException e) {
            res = false;
        }
        assertFalse(res);
        solver.reset();
    }
