@Test
    public void testMichalReportedProblem() throws ContradictionException,
            TimeoutException {
        WeightedMaxSatDecorator maxSATSolver = new WeightedMaxSatDecorator(
                SolverFactory.newLight());

        final int OPTIMUM_FOUND = 0;
        final int UNSATISFIABLE = 1;

        maxSATSolver.newVar(2);
        maxSATSolver.setExpectedNumberOfClauses(4);

        int[] clause_1 = { 1, 2 };
        maxSATSolver.addSoftClause(1,new VecInt(clause_1));

        int[] clause_2 = { -1, -2 };
        maxSATSolver.addSoftClause(100,new VecInt(clause_2));

        int[] clause_3 = { 1, -2 };
        maxSATSolver.addSoftClause(1000,new VecInt(clause_3));

        int[] clause_4 = { -1, 2 };
        maxSATSolver.addSoftClause(100000, new VecInt(clause_4));

        IOptimizationProblem problem = new PseudoOptDecorator(maxSATSolver);

        int exitCode = UNSATISFIABLE;
        boolean isSatisfiable = false;
        try {
            while (problem.admitABetterSolution()) {
                isSatisfiable = true;
                problem.discardCurrentSolution();
            }
            if (isSatisfiable) {
                exitCode = OPTIMUM_FOUND;
            } else {
                exitCode = UNSATISFIABLE;
            }
        } catch (ContradictionException ex) {
            assert isSatisfiable;
            exitCode = OPTIMUM_FOUND;
        }

        assertEquals(OPTIMUM_FOUND, exitCode);
        int[] model = problem.model();
        assertEquals(2, model.length);
        assertEquals(-1, model[0]);
        assertEquals(-2, model[1]);
    }
