@Override
    public boolean isSatisfiable(IVecInt myAssumps) throws TimeoutException {
        this.assumps.clear();
        myAssumps.copyTo(this.assumps);
        this.begin = System.currentTimeMillis();
        if (this.problem.hasNoObjectiveFunction()) {
            return this.problem.isSatisfiable(myAssumps);
        }
        boolean satisfiable = false;
        try {
            while (this.problem.admitABetterSolution(myAssumps)) {
                satisfiable = true;
                sfl.onSolutionFound(this.problem.model());
                this.problem.discardCurrentSolution();
                if (isVerbose()) {
                    System.out.println(getLogPrefix()
                            + "Current objective function value: "
                            + this.problem.getObjectiveValue() + "("
                            + (System.currentTimeMillis() - this.begin) / 1000.0
                            + "s)");
                }
            }
            expireTimeout();
            sfl.onUnsatTermination();
            if (isVerbose()) {
                System.out.println(getLogPrefix()
                        + "Optimal objective function value: "
                        + this.problem.getObjectiveValue() + "("
                        + (System.currentTimeMillis() - this.begin) / 1000.0
                        + "s)");
            }
        } catch (TimeoutException e) {
            if (isVerbose()) {
                System.out.println(getLogPrefix() + "Solver timed out after "
                        + (System.currentTimeMillis() - this.begin) / 1000.0
                        + "s)");
            }
            if (!satisfiable) {
                throw e;
            }
        } catch (ContradictionException ce) {
            expireTimeout();
            sfl.onUnsatTermination();
        }
        return satisfiable;
    }
