public BigInteger resolve(PBConstr cpb, int litImplied,
            VarActivityListener val) {
        assert litImplied > 1;
        int nLitImplied = litImplied ^ 1;
        if (cpb == null || !this.weightedLits.containsKey(nLitImplied)) {
            // no resolution
            // undo operation should be anticipated
            int litLevel = levelToIndex(this.voc.getLevel(litImplied));
            int lit = 0;
            if (this.byLevel[litLevel] != null) {
                if (this.byLevel[litLevel].contains(litImplied)) {
                    lit = litImplied;
                    assert this.weightedLits.containsKey(litImplied);
                } else if (this.byLevel[litLevel].contains(nLitImplied)) {
                    lit = nLitImplied;
                    assert this.weightedLits.containsKey(nLitImplied);
                }
            }

            if (lit > 0) {
                this.byLevel[litLevel].remove(lit);
                if (this.byLevel[0] == null) {
                    this.byLevel[0] = new VecInt();
                }
                this.byLevel[0].push(lit);
            }
            return this.degree;
        }

        if (this.allowSkipping) {
            if (this.weightedLits.get(nLitImplied).negate()
                    .compareTo(slackConflict()) > 0) {
                if (this.endingSkipping)
                    stats.incNumberOfEndingSkipping();
                else
                    stats.incNumberOfInternalSkipping();

                // no resolution
                // undo operation should be anticipated
                int litLevel = levelToIndex(this.voc.getLevel(litImplied));
                this.byLevel[litLevel].remove(nLitImplied);
                if (this.byLevel[0] == null) {
                    this.byLevel[0] = new VecInt();
                }
                this.byLevel[0].push(nLitImplied);
                assert slackConflict().signum() < 0;
                return this.degree;
            } else
                this.endingSkipping = false;

        }

        stats.incNumberOfDerivationSteps();
        assert slackConflict().signum() < 0;
        assert this.degree.signum() >= 0;

        // coefficients of the constraint must be copied in an other structure
        // in order to make reduction operations.
        BigInteger[] coefsCons = null;
        BigInteger degreeCons = cpb.getDegree();

        // search of the index of the implied literal
        int ind = 0;
        while (cpb.get(ind) != litImplied) {
            ind++;
        }

        assert cpb.get(ind) == litImplied;
        assert cpb.getCoef(ind) != BigInteger.ZERO;

        if (cpb.getCoef(ind).equals(BigInteger.ONE)) {
            // then we know that the resolvant will still be a conflict (cf.
            // Dixon's property)
            this.coefMultCons = this.weightedLits.get(nLitImplied);
            this.coefMult = BigInteger.ONE;
            // updating of the degree of the conflict
            degreeCons = degreeCons.multiply(this.coefMultCons);
        } else {
            IWatchPb wpb = (IWatchPb) cpb;
            coefsCons = wpb.getCoefs();
            degreeCons = rmSatLit
                    .removeSatisfiedLiteralsFromHigherDecisionLevels(wpb,
                            coefsCons, currentLevel, degreeCons);
            if (this.weightedLits.get(nLitImplied).equals(BigInteger.ONE)) {
                // then we know that the resolvant will still be a conflict (cf.
                // Dixon's property)
                this.coefMult = coefsCons[ind];
                this.coefMultCons = BigInteger.ONE;
                // updating of the degree of the conflict
                this.degree = this.degree.multiply(this.coefMult);
            } else if (coefsCons[ind].equals(BigInteger.ONE)) {
                // it is now again possible -
                // then we know that the resolvant will still be a conflict (cf.
                // Dixon's property)
                this.coefMultCons = this.weightedLits.get(nLitImplied);
                this.coefMult = BigInteger.ONE;
                // updating of the degree of the conflict
                degreeCons = degreeCons.multiply(this.coefMultCons);
            } else {
                // pb-constraint has to be reduced
                // to obtain a conflictual result from the cutting plane
                // DLB Findbugs warning ok
                assert positiveCoefs(coefsCons);
                degreeCons = reduceUntilConflict(litImplied, ind, coefsCons,
                        degreeCons, wpb);
                // updating of the degree of the conflict
                degreeCons = degreeCons.multiply(this.coefMultCons);
                this.degree = this.degree.multiply(this.coefMult);

                // Updating the stats about the reduction.
                for (int i = 0; i < cpb.size(); i++) {
                    if (coefsCons[i].signum() != 0) {
                        if (this.voc.isUnassigned(cpb.get(i))) {
                            this.stats.incNumberOfRemainingUnassigned();
                        } else {
                            this.stats.incNumberOfRemainingAssigned();
                        }
                    }
                }
            }

            // coefficients of the conflict must be multiplied by coefMult
            if (!this.coefMult.equals(BigInteger.ONE)) {
                for (int i = 0; i < size(); i++) {
                    changeCoef(i, this.weightedLits.getCoef(i)
                            .multiply(this.coefMult));
                }
            }
        }
        assert slackConflict().signum() < 0;

        // cutting plane
        this.degree = cuttingPlane(cpb, degreeCons, coefsCons,
                this.coefMultCons, val);
        // neither litImplied nor nLitImplied is present in coefs structure
        assert !this.weightedLits.containsKey(litImplied);
        assert !this.weightedLits.containsKey(nLitImplied);
        // neither litImplied nor nLitImplied is present in byLevel structure
        assert getLevelByLevel(litImplied) == -1;
        assert getLevelByLevel(nLitImplied) == -1;
        assert this.degree.signum() > 0;
        assert slackConflict().signum() < 0;

        // saturation
        this.degree = saturation();
        assert slackConflict().signum() < 0;
        divideCoefs();
        return this.degree;
    }
