@Override
    public boolean propagate(UnitPropagationListener s, int p) {
        this.voc.watch(p, this);

        assert this.watchCumul >= computeLeftSide() : "" + this.watchCumul + "/"
                + computeLeftSide() + ":" + this.learnt;

        // compute the new value for watchCumul
        long coefP;
        if (this.litToCoeffs == null) {
            // finding the index for p in the array of literals
            int indiceP = 0;
            while ((this.lits[indiceP] ^ 1) != p) {
                indiceP++;
            }

            // compute the new value for watchCumul
            coefP = this.coefs[indiceP];
        } else {
            coefP = this.litToCoeffs.get(p ^ 1);
        }
        long newcumul = this.watchCumul - coefP;

        if (newcumul < this.degree) {
            // there is a conflict
            assert !isSatisfiable();
            return false;
        }

        // if no conflict, not(p) can be propagated
        // allow a later un-assignation
        this.voc.undos(p).push(this);
        // really update watchCumul
        this.watchCumul = newcumul;

        // propagation
        int ind = 0;
        // The trail position helps finding conflicts.
        int trailPosition = this.voc.getTrailPosition(p);
        // limit is the margin between the sum of the coefficients of the
        // satisfied+unassigned literals
        // and the degree of the constraint
        long limit = this.watchCumul - this.degree;
        // for each coefficient greater than limit
        while (ind < this.coefs.length && limit < this.coefs[ind]) {
            // its corresponding literal may be implied
            int lit = this.lits[ind];
            if (this.voc.isFalsified(lit)
                    && this.voc.getTrailPosition(lit) > trailPosition) {
                // We are unaware that this literal has been falsified.
                // As such, we expect it to be propagatable to true.
                // Since it is not possible, there is a conflict.
                assert !isSatisfiable();
                return false;
            }
            if (this.voc.isUnassigned(lit)) {
                // Enqueuing is always possible in this case.
                boolean enqueued = s.enqueue(lit, this);
                assert enqueued;
            }
            ind++;
        }

        assert this.learnt || this.watchCumul >= computeLeftSide();
        assert this.watchCumul >= computeLeftSide();
        // No conflict was detected, but this does NOT mean that the constraint
        // is not conflictual.
        return true;
    }
