@Test(expected = IllegalStateException.class)
    public void testIssueWithUnitPropagation()
            throws ContradictionException, TimeoutException {
        IVecInt lits1 = new VecInt(new int[] { 1, 2, 3 });
        IVecInt lits2 = new VecInt(new int[] { 1, 2 });
        IVecInt lits3 = new VecInt(new int[] { -2, -3 });
        IVecInt lits4 = new VecInt(new int[] { 3 });
        IVecInt lits5 = new VecInt(new int[] { 2 });
        // Working call
        IPBSolver solver = SolverFactory.newDefault();
        solver.addAtMost(lits1, 2); // add x1 + x2 + x3 <= 2
        IConstr constr = solver.addAtLeast(lits2, 2); // add x1 + x2 >= 2
        solver.addClause(lits3); // add not(x2) v not(x3)
        assertTrue(solver.isSatisfiable());
        // Buggy call
        solver.removeConstr(constr); // remove x1 + x2 >= 2
        boolean contradict = false;
        try {
            solver.addClause(lits4); // add unit clause x3 : should propagate
                                     // not x2
        } catch (ContradictionException ce) {
            contradict = true;
        }
        assertFalse(contradict);
        assertTrue(solver.isSatisfiable());
        try {
            solver.addClause(lits5); // add unit clause x2 : should because
                                     // UNSAT
        } catch (ContradictionException ce) {
            contradict = true;
        }
        assertTrue(contradict || !solver.isSatisfiable());
    }
