@Test(expected = IllegalStateException.class)
    public void testMixingConstraints()
            throws ContradictionException, TimeoutException {
        IVecInt lits1 = new VecInt(new int[] { 1, 2, 3 });
        IVecInt lits2 = new VecInt(new int[] { 1, 2 });
        IVecInt lits3 = new VecInt(new int[] { -2, -3 });
        IVecInt lits4 = new VecInt(new int[] { 2, 3 });
        // Working call
        IPBSolver solver = SolverFactory.newDefault();
        solver.addAtMost(lits1, 2); // add x1 + x2 + x3 <= 2
        IConstr constr = solver.addAtLeast(lits2, 2); // add x1 + x2 >= 2
        solver.addClause(lits3); // add not(x2) v not(x3)
        assertTrue(solver.isSatisfiable());
        // Buggy call
        solver.removeConstr(constr); // remove x1 + x2 >= 2
        boolean contradict = false;
        try {
            solver.addAtLeast(lits4, 2); // add x2 + x3 >= 2; should contradict
                                         // not(x2) v not(x3)
        } catch (ContradictionException ce) {
            contradict = true;
        }
        assertTrue(contradict || !solver.isSatisfiable());
    }
