@Test
    public void testPBCase() throws ContradictionException, TimeoutException {

        IPBSolver solver = SolverFactory.newDefault();

        // +1 x6 >= 1 [+1 x6 >= 1]
        solver.addPseudoBoolean(transform1(new int[] { 6 }),
                transform2(new int[] { 1 }), true, BigInteger.valueOf(1));

        // +1 x6 +1 ~x5 >= 1 [+1 x6 -1 x5 >= 0]
        solver.addPseudoBoolean(transform1(new int[] { 6, -5 }),
                transform2(new int[] { 1, 1 }), true, BigInteger.valueOf(1));

        // +1 ~x6 +1 x5 >= 1 [-1 x6 +1 x5 >= 0]
        solver.addPseudoBoolean(transform1(new int[] { -6, 5 }),
                transform2(new int[] { 1, 1 }), true, BigInteger.valueOf(1));

        // +1 x6 +1 ~x4 >= 1 [+1 x6 -1 x4 >= 0]
        solver.addPseudoBoolean(transform1(new int[] { 6, -4 }),
                transform2(new int[] { 1, 1 }), true, BigInteger.valueOf(1));

        // +1 ~x6 +1 x4 >= 1 [-1 x6 +1 x4 >= 0]
        solver.addPseudoBoolean(transform1(new int[] { -6, 4 }),
                transform2(new int[] { 1, 1 }), true, BigInteger.valueOf(1));

        // +1 x4 +1 ~x2 +1 ~x1 >= 2 [+1 x4 -1 x2 -1 x1 >= 0]
        solver.addPseudoBoolean(transform1(new int[] { 4, -2, -1 }),
                transform2(new int[] { 1, 1, 1 }), true, BigInteger.valueOf(2));

        // +1 ~x4 +1 x2 +1 x1 >= 1 [-1 x4 +1 x2 +1 x1 >= 0]
        solver.addPseudoBoolean(transform1(new int[] { -4, 2, 1 }),
                transform2(new int[] { 1, 1, 1 }), true, BigInteger.valueOf(1));

        IVecInt backbone = RemiUtils.backbone(solver);
        assertEquals(3, backbone.size());
        assertTrue(backbone.contains(6));
        assertTrue(backbone.contains(5));
        assertTrue(backbone.contains(4));
    }
