void parseLine(String line) throws ContradictionException {
        // Skip commented line
        if (line.startsWith(COMMENT_SYMBOL)) {
            return;
        }
        if (line.startsWith("p")) {
            return;
        }
        if (line.startsWith("min:") || line.startsWith("min :")) {
            return; // we will use that case later
        }
        if (line.startsWith("max:") || line.startsWith("max :")) {
            return; // we will use that case later
        }

        // skip name of constraints:
        int index = line.indexOf(":");
        if (index != -1) {
            line = line.substring(index + 1);
        }

        IVecInt lits = new VecInt();
        IVec<BigInteger> coeffs = new Vec<BigInteger>();
        Scanner stk = new Scanner(line)
                .useDelimiter("\\s*\\*\\s*|\\s*\\+\\s*|\\s+");
        while (stk.hasNext()) {
            String token = stk.next();
            if (">=".equals(token) || "<=".equals(token) || "=".equals(token)) {
                assert stk.hasNext();
                String tok = stk.next();
                // we need to remove + from the integer
                if (tok.startsWith("+")) {
                    tok = tok.substring(1);
                }
                BigInteger d = new BigInteger(tok);

                try {
                    if (">=".equals(token) || "=".equals(token)) {
                        this.solver.addPseudoBoolean(lits, coeffs, true, d);
                    }
                    if ("<=".equals(token) || "=".equals(token)) {
                        this.solver.addPseudoBoolean(lits, coeffs, false, d);
                    }
                } catch (ContradictionException ce) {
                    throw ce;
                }
            } else {
                // on est toujours en train de lire la partie gauche de la
                // contrainte
                if ("+".equals(token)) {
                    assert stk.hasNext();
                    token = stk.next();
                } else if ("-".equals(token)) {
                    assert stk.hasNext();
                    token = token + stk.next();
                }
                BigInteger coef;
                // should contain a coef and a literal
                try {
                    // we need to remove + from the integer
                    if (token.startsWith("+")) {
                        token = token.substring(1);
                    }
                    coef = new BigInteger(token);
                    assert stk.hasNext();
                    token = stk.next();
                } catch (NumberFormatException nfe) {
                    // its only an identifier
                    coef = BigInteger.ONE;
                }
                if ("-".equals(token) || "~".equals(token)) {
                    assert stk.hasNext();
                    token = token + stk.next();
                }
                boolean negative = false;
                if (token.startsWith("+")) {
                    token = token.substring(1);
                } else if (token.startsWith("-")) {
                    token = token.substring(1);
                    assert coef.equals(BigInteger.ONE);
                    coef = BigInteger.ONE.negate();
                } else if (token.startsWith("~")) {
                    token = token.substring(1);
                    negative = true;
                }
                Integer id = this.map.get(token);
                if (id == null) {
                    id = this.decode.size() + 1;
                    this.map.put(token, id);
                    this.decode.push(token);
                }
                coeffs.push(coef);
                int lid = (negative ? -1 : 1) * id.intValue();
                lits.push(lid);
                assert coeffs.size() == lits.size();
            }
        }
    }
