public void initSearchListeners() {
        List<SearchListener<ISolverService>> listeners = new ArrayList<SearchListener<ISolverService>>();

        if (this.isPlotActivated) {
            if (this.gnuplotBased) {
                this.solverVisu = new GnuplotBasedSolverVisualisation(
                        this.visuPreferences, this.solver.nVars(),
                        this.instancePath, this);
                if (this.visuPreferences.isDisplayClausesEvaluation()) {
                    listeners.add(new LearnedTracing(
                            new FileBasedVisualizationTool(
                                    this.whereToWriteFiles + "-learned")));
                }
                if (this.visuPreferences.isDisplayClausesSize()) {
                    listeners.add(new LearnedClausesSizeTracing(
                            new FileBasedVisualizationTool(
                                    this.whereToWriteFiles
                                            + "-learned-clauses-size"),
                            new FileBasedVisualizationTool(
                                    this.whereToWriteFiles
                                            + "-learned-clauses-size-restart"),
                            new FileBasedVisualizationTool(
                                    this.whereToWriteFiles
                                            + "-learned-clauses-size-clean")));
                }
                if (this.visuPreferences.isDisplayConflictsDecision()) {
                    listeners
                            .add(new ConflictLevelTracing(
                                    new FileBasedVisualizationTool(
                                            this.whereToWriteFiles
                                                    + "-conflict-level"),
                                    new FileBasedVisualizationTool(
                                            this.whereToWriteFiles
                                                    + "-conflict-level-restart"),
                                    new FileBasedVisualizationTool(
                                            this.whereToWriteFiles
                                                    + "-conflict-level-clean")));
                }
                if (this.visuPreferences.isDisplayConflictsTrail()) {
                    listeners
                            .add(new ConflictDepthTracing(
                                    new FileBasedVisualizationTool(
                                            this.whereToWriteFiles
                                                    + "-conflict-depth"),
                                    new FileBasedVisualizationTool(
                                            this.whereToWriteFiles
                                                    + "-conflict-depth-restart"),
                                    new FileBasedVisualizationTool(
                                            this.whereToWriteFiles
                                                    + "-conflict-depth-clean")));
                }

                if (this.visuPreferences.isDisplayDecisionIndexes()) {
                    listeners.add(new DecisionTracing(
                            new FileBasedVisualizationTool(
                                    this.whereToWriteFiles
                                            + "-decision-indexes-pos"),
                            new FileBasedVisualizationTool(
                                    this.whereToWriteFiles
                                            + "-decision-indexes-neg"),
                            new FileBasedVisualizationTool(
                                    this.whereToWriteFiles
                                            + "-decision-indexes-restart"),
                            new FileBasedVisualizationTool(
                                    this.whereToWriteFiles
                                            + "-decision-indexes-clean")));
                }

                if (this.visuPreferences.isDisplaySpeed()) {
                    listeners
                            .add(new SpeedTracing(
                                    new FileBasedVisualizationTool(
                                            this.whereToWriteFiles + "-speed"),
                                    new FileBasedVisualizationTool(
                                            this.whereToWriteFiles
                                                    + "-speed-clean"),
                                    new FileBasedVisualizationTool(
                                            this.whereToWriteFiles
                                                    + "-speed-restart")));
                }
                if (this.visuPreferences.isDisplayVariablesEvaluation()) {
                    listeners.add(new HeuristicsTracing(
                            new FileBasedVisualizationTool(
                                    this.whereToWriteFiles + "-heuristics")));
                }
            }

            else if (this.chartBased) {

                if (this.solverVisu != null) {
                    this.solverVisu.end();
                }

                this.solverVisu = new JChartBasedSolverVisualisation(
                        this.visuPreferences);

                ((JChartBasedSolverVisualisation) this.solverVisu)
                        .setnVar(this.solver.nVars());
                if (this.visuPreferences.isDisplayClausesEvaluation()) {
                    listeners
                            .add(new LearnedTracing(
                                    new ChartBasedVisualizationTool(
                                            ((JChartBasedSolverVisualisation) this.solverVisu)
                                                    .getClausesEvaluationTrace())));
                }
                if (this.visuPreferences.isDisplayClausesSize()) {
                    listeners
                            .add(new LearnedClausesSizeTracing(
                                    new ChartBasedVisualizationTool(
                                            ((JChartBasedSolverVisualisation) this.solverVisu)
                                                    .getLearnedClausesSizeTrace()),
                                    new ChartBasedVisualizationTool(
                                            ((JChartBasedSolverVisualisation) this.solverVisu)
                                                    .getLearnedClausesSizeRestartTrace()),
                                    new ChartBasedVisualizationTool(
                                            ((JChartBasedSolverVisualisation) this.solverVisu)
                                                    .getLearnedClausesSizeCleanTrace())));
                }
                if (this.visuPreferences.isDisplayConflictsDecision()) {
                    listeners
                            .add(new ConflictLevelTracing(
                                    new ChartBasedVisualizationTool(
                                            ((JChartBasedSolverVisualisation) this.solverVisu)
                                                    .getConflictLevelTrace()),
                                    new ChartBasedVisualizationTool(
                                            ((JChartBasedSolverVisualisation) this.solverVisu)
                                                    .getConflictLevelRestartTrace()),
                                    new ChartBasedVisualizationTool(
                                            ((JChartBasedSolverVisualisation) this.solverVisu)
                                                    .getConflictLevelCleanTrace())));
                }
                if (this.visuPreferences.isDisplayConflictsTrail()) {
                    listeners
                            .add(new ConflictDepthTracing(
                                    new ChartBasedVisualizationTool(
                                            ((JChartBasedSolverVisualisation) this.solverVisu)
                                                    .getConflictDepthTrace()),
                                    new ChartBasedVisualizationTool(
                                            ((JChartBasedSolverVisualisation) this.solverVisu)
                                                    .getConflictDepthRestartTrace()),
                                    new ChartBasedVisualizationTool(
                                            ((JChartBasedSolverVisualisation) this.solverVisu)
                                                    .getConflictDepthCleanTrace())));
                }
                if (this.visuPreferences.isDisplayDecisionIndexes()) {
                    listeners
                            .add(new DecisionTracing(
                                    new ChartBasedVisualizationTool(
                                            ((JChartBasedSolverVisualisation) this.solverVisu)
                                                    .getPositiveDecisionTrace()),
                                    new ChartBasedVisualizationTool(
                                            ((JChartBasedSolverVisualisation) this.solverVisu)
                                                    .getNegativeDecisionTrace()),
                                    new ChartBasedVisualizationTool(
                                            new TraceComposite(
                                                    ((JChartBasedSolverVisualisation) this.solverVisu)
                                                            .getRestartPosDecisionTrace(),
                                                    ((JChartBasedSolverVisualisation) this.solverVisu)
                                                            .getRestartNegDecisionTrace())),
                                    new ChartBasedVisualizationTool(
                                            new TraceComposite(
                                                    ((JChartBasedSolverVisualisation) this.solverVisu)
                                                            .getCleanPosDecisionTrace(),
                                                    ((JChartBasedSolverVisualisation) this.solverVisu)
                                                            .getCleanNegDecisionTrace()))));
                }
                if (this.visuPreferences.isDisplaySpeed()) {
                    listeners
                            .add(new SpeedTracing(
                                    new ChartBasedVisualizationTool(
                                            ((JChartBasedSolverVisualisation) this.solverVisu)
                                                    .getSpeedTrace()),
                                    new ChartBasedVisualizationTool(
                                            ((JChartBasedSolverVisualisation) this.solverVisu)
                                                    .getSpeedCleanTrace()),
                                    new ChartBasedVisualizationTool(
                                            ((JChartBasedSolverVisualisation) this.solverVisu)
                                                    .getSpeedRestartTrace())));
                }
                if (this.visuPreferences.isDisplayVariablesEvaluation()) {
                    listeners
                            .add(new HeuristicsTracing(
                                    new ChartBasedVisualizationTool(
                                            ((JChartBasedSolverVisualisation) this.solverVisu)
                                                    .getHeuristicsTrace())));
                }
            }

        }
        listeners.add(this);

        this.solver.setSearchListener(new MultiTracing<ISolverService>(listeners));

    }
