public void launchSolverWithConfigs() {
        ICDCL<?> cdclSolver;
        ASolverFactory<?> factory;
        String[] partsSelectedSolver;
        IOrder order;
        double proba;

        String selectedSolver;

        switch (startConfig) {
        case SOLVER_LIST_PARAM_REMOTE:
            selectedSolver = (String) this.listeSolvers.getSelectedItem();
            partsSelectedSolver = selectedSolver.split("\\.");

            assert partsSelectedSolver.length == 2;
            assert partsSelectedSolver[0].equals(MINISAT_PREFIX)
                    || partsSelectedSolver[0].equals(PB_PREFIX)
                    || partsSelectedSolver[0].equals(MAXSAT_PREFIX);

            if (partsSelectedSolver[0].equals(MINISAT_PREFIX)) {
                factory = org.sat4j.minisat.SolverFactory.instance();
            } else if (partsSelectedSolver[0].equals(PB_PREFIX)) {
                factory = org.sat4j.pb.SolverFactory.instance();
            } else {
                factory = org.sat4j.maxsat.SolverFactory.instance();
            }
            this.solver = (ICDCL<?>) factory
                    .createSolverByName(partsSelectedSolver[1]);

            cdclSolver = (ICDCL<?>) this.solver.getSolvingEngine();

            this.telecomStrategy.setSolver(cdclSolver);

            cdclSolver.setRestartStrategy(this.telecomStrategy);
            cdclSolver.setOrder(this.randomWalk);
            cdclSolver.getOrder().setPhaseSelectionStrategy(
                    this.telecomStrategy);

            this.restartPanel.hasClickedOnRestart();
            this.rwPanel.hasClickedOnApplyRW();
            this.phasePanel.hasClickedOnApplyPhase();
            this.simplifierPanel.hasClickedOnApplySimplification();
            break;

        case SOLVER_LINE_PARAM_LINE:
            this.solver = Solvers.configureSolver(this.commandLines, this);

            cdclSolver = (ICDCL<?>) this.solver.getSolvingEngine();

            this.telecomStrategy.setSolver(cdclSolver);
            this.telecomStrategy.setRestartStrategy(cdclSolver
                    .getRestartStrategy());
            cdclSolver.setRestartStrategy(this.telecomStrategy);

            this.restartPanel.setCurrentRestart(this.telecomStrategy
                    .getRestartStrategy().getClass().getSimpleName());

            order = cdclSolver.getOrder();

            proba = 0;

            if (this.optimizationMode) {
                if (order instanceof RandomWalkDecoratorObjective) {
                    this.randomWalk = (RandomWalkDecorator) order;
                    proba = this.randomWalk.getProbability();
                } else if (order instanceof VarOrderHeapObjective) {
                    this.randomWalk = new RandomWalkDecoratorObjective(
                            (VarOrderHeapObjective) order, 0);
                }
            } else if (cdclSolver.getOrder() instanceof RandomWalkDecorator) {
                this.randomWalk = (RandomWalkDecorator) order;
                proba = this.randomWalk.getProbability();
            } else {
                this.randomWalk = new RandomWalkDecorator((VarOrderHeap) order,
                        0);
            }

            this.randomWalk.setProbability(proba);
            this.rwPanel.setProba(proba);
            cdclSolver.setOrder(this.randomWalk);
            this.telecomStrategy.setPhaseSelectionStrategy(cdclSolver
                    .getOrder().getPhaseSelectionStrategy());
            cdclSolver.getOrder().setPhaseSelectionStrategy(
                    this.telecomStrategy);
            this.phasePanel.setPhaseListSelectedItem(this.telecomStrategy
                    .getPhaseSelectionStrategy().getClass().getSimpleName());
            this.simplifierPanel.setSelectedSimplification(cdclSolver
                    .getSimplifier().toString());

            this.phasePanel.repaint();
            break;

        case SOLVER_LINE_PARAM_REMOTE:
            this.solver = Solvers.configureSolver(this.commandLines, this);

            cdclSolver = (ICDCL<?>) this.solver.getSolvingEngine();

            cdclSolver.setRestartStrategy(this.telecomStrategy);
            cdclSolver.setOrder(this.randomWalk);
            cdclSolver.getOrder().setPhaseSelectionStrategy(
                    this.telecomStrategy);

            this.restartPanel.hasClickedOnRestart();
            this.rwPanel.hasClickedOnApplyRW();
            this.phasePanel.hasClickedOnApplyPhase();
            this.simplifierPanel.hasClickedOnApplySimplification();
            break;

        default:
            selectedSolver = (String) this.listeSolvers.getSelectedItem();
            partsSelectedSolver = selectedSolver.split("\\.");

            assert partsSelectedSolver.length == 2;
            assert partsSelectedSolver[0].equals(MINISAT_PREFIX)
                    || partsSelectedSolver[0].equals(PB_PREFIX)
                    || partsSelectedSolver[0].equals(MAXSAT_PREFIX);

            if (partsSelectedSolver[0].equals(MINISAT_PREFIX)) {
                factory = org.sat4j.minisat.SolverFactory.instance();
            } else if (partsSelectedSolver[0].equals(PB_PREFIX)) {
                factory = org.sat4j.pb.SolverFactory.instance();
            } else {
                factory = org.sat4j.maxsat.SolverFactory.instance();
            }

            this.solver = factory.createSolverByName(partsSelectedSolver[1]);

            cdclSolver = (ICDCL<?>) this.solver.getSolvingEngine();

            this.telecomStrategy.setSolver(cdclSolver);
            this.telecomStrategy.setRestartStrategy(cdclSolver
                    .getRestartStrategy());
            cdclSolver.setRestartStrategy(this.telecomStrategy);

            this.restartPanel.setCurrentRestart(this.telecomStrategy
                    .getRestartStrategy().getClass().getSimpleName());

            order = cdclSolver.getOrder();

            proba = 0;

            if (this.optimizationMode) {
                if (order instanceof RandomWalkDecoratorObjective) {
                    this.randomWalk = (RandomWalkDecorator) order;
                    proba = this.randomWalk.getProbability();
                } else if (order instanceof VarOrderHeapObjective) {
                    this.randomWalk = new RandomWalkDecoratorObjective(
                            (VarOrderHeapObjective) order, 0);
                }
            } else if (cdclSolver.getOrder() instanceof RandomWalkDecorator) {
                this.randomWalk = (RandomWalkDecorator) order;
                proba = this.randomWalk.getProbability();
            } else {
                this.randomWalk = new RandomWalkDecorator((VarOrderHeap) order,
                        0);
            }

            this.randomWalk.setProbability(proba);
            this.rwPanel.setProba(proba);

            cdclSolver.setOrder(this.randomWalk);

            this.telecomStrategy.setPhaseSelectionStrategy(cdclSolver
                    .getOrder().getPhaseSelectionStrategy());
            this.phasePanel.setPhaseListSelectedItem(this.telecomStrategy
                    .getPhaseSelectionStrategy().getClass().getSimpleName());
            cdclSolver.getOrder().setPhaseSelectionStrategy(
                    this.telecomStrategy);
            this.simplifierPanel.setSelectedSimplification(cdclSolver
                    .getSimplifier().toString());
            break;
        }

        this.whereToWriteFiles = this.instancePath;

        if (this.ramdisk.length() > 0) {
            String[] instancePathSplit = this.instancePath.split("/");
            this.whereToWriteFiles = this.ramdisk + "/"
                    + instancePathSplit[instancePathSplit.length - 1];
        }

        this.solver.setVerbose(true);
        initSearchListeners();
        cdclSolver.setLogger(this);

        try {
            switch (problemType) {
            case PB_OPT:
                this.solver = new ClausalConstraintsDecorator(
                        (IPBSolver) this.solver, this.encodingPolicy);
                if (lowerMode) {
                    this.solver = new ConstraintRelaxingPseudoOptDecorator(
                            (IPBSolver) solver);
                } else {
                    this.solver = new PseudoOptDecorator((IPBSolver) solver);
                }

                this.reader = createReader(this.solver, this.instancePath);
                this.problem = this.reader.parseInstance(this.instancePath);
                this.problem = new OptToPBSATAdapter(
                        (IOptimizationProblem) this.problem);
                break;
            case CNF_MAXSAT:
            case WCNF_MAXSAT:
                this.solver = new ClausalConstraintsDecorator(
                        (IPBSolver) this.solver, this.encodingPolicy);
                this.solver = new WeightedMaxSatDecorator(
                        (IPBSolver) this.solver, equivalenceMode);

                this.reader = createReader(this.solver, this.instancePath);
                this.problem = this.reader.parseInstance(this.instancePath);

                if (lowerMode) {
                    this.problem = new ConstraintRelaxingPseudoOptDecorator(
                            (WeightedMaxSatDecorator) this.problem);
                } else {
                    this.problem = new PseudoOptDecorator(
                            (WeightedMaxSatDecorator) this.problem, false,
                            false);
                }

                this.problem = new OptToPBSATAdapter(
                        (IOptimizationProblem) this.problem);
                break;
            case PB_SAT:
                this.solver = new ClausalConstraintsDecorator(
                        (IPBSolver) this.solver, this.encodingPolicy);
                this.reader = createReader(this.solver, this.instancePath);
                this.problem = this.reader.parseInstance(this.instancePath);
                break;
            case CNF_SAT:
            default:
                this.solver = new ClausalCardinalitiesDecorator<ISolver>(
                        this.solver, this.encodingPolicy);
                this.reader = createReader(this.solver, this.instancePath);
                this.problem = this.reader.parseInstance(this.instancePath);
                break;
            }

        } catch (FileNotFoundException e) {
            log(e.getMessage());
        } catch (ParseFormatException e) {
            log(e.getMessage());
        } catch (IOException e) {
            log(e.getMessage());
        } catch (ContradictionException e) {
            log("Unsatisfiable (trivial)!");
            return;
        }

        log("# Started solver "
                + this.solver.getSolvingEngine().getClass().getSimpleName());
        log("# on instance " + this.instancePath);
        log("# Optimisation = " + this.optimizationMode);
        log("# Restart strategy = "
                + this.telecomStrategy.getRestartStrategy().getClass()
                        .getSimpleName());
        log("# Random walk probability = " + this.randomWalk.getProbability());
        log("# variables : " + this.solver.nVars());

        Thread solveurThread = new Thread() {
            @Override
            public void run() {

                try {
                    DetailedCommandPanel.this.stringWriter = new StringWriter();
                    if (DetailedCommandPanel.this.problem.isSatisfiable()) {
                        log("Satisfiable !");

                        if (DetailedCommandPanel.this.problem instanceof OptToPBSATAdapter) {
                            log(((OptToPBSATAdapter) DetailedCommandPanel.this.problem)
                                    .getCurrentObjectiveValue() + "");
                            DetailedCommandPanel.this.reader
                                    .decode(((OptToPBSATAdapter) DetailedCommandPanel.this.problem)
                                            .model(new PrintWriter(
                                                    DetailedCommandPanel.this.stringWriter)),
                                            new PrintWriter(
                                                    DetailedCommandPanel.this.stringWriter));
                        } else {
                            DetailedCommandPanel.this.reader
                                    .decode(DetailedCommandPanel.this.problem
                                            .model(),
                                            new PrintWriter(
                                                    DetailedCommandPanel.this.stringWriter));
                        }
                        log(DetailedCommandPanel.this.stringWriter.toString());
                    } else {
                        log("Unsatisfiable !");
                    }
                } catch (TimeoutException e) {
                    log("Timeout, sorry!");
                }
            }
        };
        solveurThread.start();

        if (this.isPlotActivated) {
            this.solverVisu.setnVar(this.solver.nVars());
            startVisu();
        }
    }
