protected static ICDCL configureFromString(String solverconfig,
            ICDCL theSolver, ILogAble logger) {
        assert theSolver != null;
        // AFAIK, there is no easy way to solve parameterized problems
        // when building the solver at runtime.
        StringTokenizer stk = new StringTokenizer(solverconfig, ",");
        Properties pf = new Properties();
        String token;
        String[] couple;
        while (stk.hasMoreElements()) {
            token = stk.nextToken();
            couple = token.split("=");
            pf.setProperty(couple[0], couple[1]);
        }

        Solver aSolver = (Solver) theSolver;
        DataStructureFactory dsf = setupObject("DSF", pf, logger);
        if (dsf != null) {
            theSolver.setDataStructureFactory(dsf);
        }
        LearningStrategy learning = setupObject(LEARNING, pf, logger);
        if (learning != null) {
            theSolver.setLearningStrategy(learning);
            learning.setSolver(aSolver);
        }
        IOrder order = setupObject(ORDERS, pf, logger);
        if (order != null) {
            theSolver.setOrder(order);
        }
        IPhaseSelectionStrategy pss = setupObject(PHASE, pf, logger);
        if (pss != null) {
            theSolver.getOrder().setPhaseSelectionStrategy(pss);
        }
        RestartStrategy restarter = setupObject(RESTARTS, pf, logger);
        if (restarter != null) {
            theSolver.setRestartStrategy(restarter);
        }
        String simp = pf.getProperty(SIMP);
        if (simp != null) {
            logger.log("read " + simp);
            logger.log("configuring " + SIMP);
            theSolver.setSimplifier(SimplificationType.valueOf(simp));
        }
        SearchParams params = setupObject(PARAMS, pf, logger);
        if (params != null) {
            theSolver.setSearchParams(params);
        }
        String memory = pf.getProperty(CLEANING);
        if (memory != null) {
            try {
                logger.log("configuring "+CLEANING);
                LearnedConstraintsEvaluationType memoryType = LearnedConstraintsEvaluationType
                        .valueOf(memory);
                theSolver.setLearnedConstraintsDeletionStrategy(memoryType);
            } catch (IllegalArgumentException iae) {
                logger.log("wrong memory management setting: " + memory);
                showAvailableConstraintsCleaningStrategies(logger);
            }
        }
        return theSolver;
    }
