private static <T> T setupObject(String component, Properties pf,
            ILogAble logger) {
        try {
            String configline = pf.getProperty(component);
            String qualification = QUALIF.get(component);

            if (configline == null) {
                return null;
            }
            if (qualification != null) {
                logger.log("read " + qualification + "." + configline);
                if (configline.contains("Objective")
                        && qualification.contains(MINISAT)) {
                    qualification = qualification.replaceFirst(MINISAT, PB);
                }
                configline = qualification + "." + configline;
            }

            logger.log("configuring " + component);
            String[] config = configline.split("/");
            T comp = (T) Class.forName(config[0]).newInstance();
            for (int i = 1; i < config.length; i++) {
                String[] param = config[i].split(":"); //$NON-NLS-1$
                assert param.length == 2;
                try {
                    // Check first that the property really exists
                    BeanUtils.getProperty(comp, param[0]);
                    BeanUtils.setProperty(comp, param[0], param[1]);
                } catch (Exception e) {
                    logger.log(PROBLEM_WITH_COMPONENT + config[0] + " " + e);
                }
            }
            return comp;
        } catch (InstantiationException e) {
            logger.log(PROBLEM_WITH_COMPONENT + component + " " + e);
        } catch (IllegalAccessException e) {
            logger.log(PROBLEM_WITH_COMPONENT + component + " " + e);
        } catch (ClassNotFoundException e) {
            logger.log(PROBLEM_WITH_COMPONENT + component + " " + e);
        }
        return null;
    }
