public int print(Graphics graphics, PageFormat pageFormat, int pageIndex) {
        if (pageIndex == 0) {
            int cellSize = 60;
            int leftx = (int) pageFormat.getImageableX() + 5;
            int topy = (int) pageFormat.getImageableY() + 5;
            int minSide = (int) pageFormat.getImageableWidth() - 10;

            // To improve print quality, the resolution will be increased by
            // a factor of 1.0/theScaleFactor

            double theScaleFactor = 0.5;

            //
            // Print the grid
            //

            // Check whether a cellSize of 60 is permissible and make it smaller
            // if the page is not big enough

            if (minSide > (int) pageFormat.getImageableHeight() - 10) {
                minSide = (int) pageFormat.getImageableHeight() - 10;
            }

            if (theScaleFactor * cellSize * sdSize.getLargeSide() > minSide) {
                cellSize = (int) (minSide / (theScaleFactor * sdSize
                        .getLargeSide()));
            }

            Graphics2D the2DGraphics = (Graphics2D) graphics;

            the2DGraphics.scale(theScaleFactor, theScaleFactor);
            leftx /= theScaleFactor;
            topy /= theScaleFactor;

            the2DGraphics.setColor(Color.BLACK);

            Stroke basicStroke = new BasicStroke();
            Stroke heavyStroke = new BasicStroke(3.0f);
            Stroke veryHeavyStroke = new BasicStroke(5.0f);

            for (int r = 0; r <= sdSize.getLargeSide(); r++) {
                if (r % sdSize.getSmallRows() == 0) {
                    the2DGraphics.setStroke(heavyStroke);
                } else {
                    the2DGraphics.setStroke(basicStroke);
                }

                the2DGraphics
                        .drawLine(leftx, topy + r * cellSize, leftx
                                + sdSize.getLargeSide() * cellSize, topy + r
                                * cellSize);
            }

            for (int c = 0; c <= sdSize.getLargeSide(); c++) {
                if (c % sdSize.getSmallCols() == 0) {
                    the2DGraphics.setStroke(heavyStroke);
                } else {
                    the2DGraphics.setStroke(basicStroke);
                }

                the2DGraphics.drawLine(leftx + c * cellSize, topy, leftx + c
                        * cellSize, topy + sdSize.getLargeSide() * cellSize);
            }

            the2DGraphics.setStroke(basicStroke);

            // Choose a font size which is appropriate for the size of cell
            Font theFont = the2DGraphics.getFont().deriveFont(
                    (float) (cellSize / 2.0));
            the2DGraphics.setFont(theFont);
            FontMetrics fontMetrics = the2DGraphics.getFontMetrics();
            int maxDescent = fontMetrics.getMaxDescent();

            for (int r = 0; r < sdSize.getLargeSide(); r++) {
                for (int c = 0; c < sdSize.getLargeSide(); c++) {
                    String v = cells[r][c].getaText();
                    if (!"".equals(v)) {
                        // The size of the text is needed to ensure that it is
                        // centred in the cell
                        //
                        Rectangle2D rect = theFont.getStringBounds(v,
                                the2DGraphics.getFontRenderContext());
                        the2DGraphics.setColor(cells[r][c].getForeground());
                        the2DGraphics.drawString(v,
                                (int) (leftx + c * cellSize + (cellSize - rect
                                        .getWidth()) / 2.0), (int) (topy + r
                                        * cellSize + (cellSize + rect
                                        .getHeight()) / 2.0)
                                        - maxDescent);
                    }
                }
            }

            the2DGraphics.setColor(Color.BLACK);

            if (guiInput.getUseXSudoku()) {
                the2DGraphics.setStroke(veryHeavyStroke);
                for (int r = 0; r < sdSize.getLargeSide(); r++) {
                    drawCell(the2DGraphics, leftx, topy, cellSize, r, r);
                    drawCell(the2DGraphics, leftx, topy, cellSize, r, sdSize
                            .getLargeSide()
                            - (r + 1));
                }
                the2DGraphics.setStroke(basicStroke);
            }

            //
            // Print the footer
            //

            int fontSize = 18;
            Font smallFont = theFont.deriveFont((float) fontSize);
            the2DGraphics.setFont(smallFont);
            StringBuilder footer = new StringBuilder();

            if (guiInput.getUseExtra()) {
                footer.append("Complete ");
            }

            if (guiInput.getUseXSudoku()) {
                footer.append("X-SuDoku ");
            } else {
                footer.append("SuDoku ");
            }

            int newy = topy + (sdSize.getLargeSide() + 1) * cellSize;

            String footerProperty = guiInput.getSuDoku().getSuDokuResources()
                    .getParsedProperty("printout.footer");
            if ((footerProperty == null) || (footerProperty.length() == 0)) {
                // footer.append();
                // the2DGraphics.drawString(footer.toString(), leftx, newy);
                // newy += fontSize;
                footerProperty = guiInput.getSuDoku().getSuDokuResources()
                        .getStringFromKey("DEFAULT_PRINTER_FOOTER");
            }
            String allFooters[] = footerProperty.split("\n");
            if (allFooters.length >= 1) {
                footer.append(allFooters[0]);
                the2DGraphics.drawString(footer.toString(), leftx, newy);
            }
            for (int row = 1; row < allFooters.length; row++) {
                the2DGraphics.drawString(allFooters[row], leftx, newy + row
                        * fontSize);
            }

            newy += fontSize * allFooters.length;

            //
            // Print the icons
            //

            ImageIcon sat4jIcon, ecitIcon, crilIcon, objectWebIcon, scienceFestIcon;
            SuDokuResources suDokuResources = guiInput.getSuDoku()
                    .getSuDokuResources();
            sat4jIcon = suDokuResources.getSat4jIcon();
            ecitIcon = suDokuResources.getECITIcon();
            crilIcon = suDokuResources.getCRILIcon();
            objectWebIcon = suDokuResources.getObjectWebIcon();
            scienceFestIcon = suDokuResources.getEventIcon();

            // Display all icons with the same width, find the height to
            // preserve the aspect ration

            int icony = topy;
            int iconx;
            int iconWidth;

            int iconHeight;

            if (sdSize.getLargeSide() <= 9) // icons to right of grid
            {
                iconWidth = 250;
                iconx = leftx + (sdSize.getLargeSide() + 1) * cellSize;
                iconHeight = scaleWidthToHeight(iconWidth, sat4jIcon);
                the2DGraphics.drawImage(sat4jIcon.getImage(), iconx, icony,
                        iconWidth, iconHeight, sat4jIcon.getImageObserver());
                icony += iconHeight + 20;

                iconHeight = scaleWidthToHeight(iconWidth, ecitIcon);
                the2DGraphics.drawImage(ecitIcon.getImage(), iconx, icony,
                        iconWidth, iconHeight, ecitIcon.getImageObserver());
                icony += iconHeight + 20;

                iconHeight = scaleWidthToHeight(iconWidth, crilIcon);
                the2DGraphics.drawImage(crilIcon.getImage(), iconx, icony,
                        iconWidth, iconHeight, crilIcon.getImageObserver());
                icony += iconHeight + 20;

                iconHeight = scaleWidthToHeight(iconWidth, objectWebIcon);
                the2DGraphics
                        .drawImage(objectWebIcon.getImage(), iconx, icony,
                                iconWidth, iconHeight, objectWebIcon
                                        .getImageObserver());
                icony += iconHeight + 20;

                iconHeight = scaleWidthToHeight(iconWidth, scienceFestIcon);
                the2DGraphics.drawImage(scienceFestIcon.getImage(), iconx + 10,
                        icony, iconWidth, iconHeight, scienceFestIcon
                                .getImageObserver());

            } else // smaller icons below grid and footer
            {
                iconx = leftx;
                icony = newy + 20;
                iconWidth = 200;
                iconx = leftx;
                iconHeight = scaleWidthToHeight(iconWidth, sat4jIcon);
                the2DGraphics.drawImage(sat4jIcon.getImage(), iconx, icony,
                        iconWidth, iconHeight, sat4jIcon.getImageObserver());
                iconx += iconWidth + 20;

                iconHeight = scaleWidthToHeight(iconWidth, ecitIcon);
                the2DGraphics.drawImage(ecitIcon.getImage(), iconx, icony,
                        iconWidth, iconHeight, ecitIcon.getImageObserver());
                iconx += iconWidth + 20;

                iconHeight = scaleWidthToHeight(iconWidth, crilIcon);
                the2DGraphics.drawImage(crilIcon.getImage(), iconx, icony,
                        iconWidth, iconHeight, crilIcon.getImageObserver());
                iconx += iconWidth + 20;

                iconHeight = scaleWidthToHeight(iconWidth, objectWebIcon);
                the2DGraphics
                        .drawImage(objectWebIcon.getImage(), iconx, icony,
                                iconWidth, iconHeight, objectWebIcon
                                        .getImageObserver());
                iconx += iconWidth + 15;

                iconHeight = scaleWidthToHeight(iconWidth, scienceFestIcon);
                the2DGraphics.drawImage(scienceFestIcon.getImage(), iconx,
                        icony - 75, iconWidth, iconHeight, scienceFestIcon
                                .getImageObserver());
            }

            return PAGE_EXISTS;
        }
        return NO_SUCH_PAGE;
    }
