public void createPuzzle(int filledCells, CellGrid cellGrid,
            boolean onlyCreateUnique) {
        System.gc();

        int v[][], testv[][];
        v = new int[sdSize.getLargeSide() + 1][sdSize.getLargeSide() + 1];
        testv = new int[sdSize.getLargeSide() + 1][sdSize.getLargeSide() + 1];

        cellGrid.clearAll();

        boolean success = false;

        fullCNF = true;

        ISolver csolver;
        ProgressMonitor progressbar = new ProgressMonitor(null, suDokuResources
                .getStringFromKey("MSG_PROGRESS_DIALOG"), "", 0, sdSize
                .getLargeSide()
                * sdSize.getLargeSide() / 2);
        progressbar.setProgress(0);
        while (!success) {
            csolver = SolverFactory.newDefault();
            Sat4jClauseHandler ch = new Sat4jClauseHandler(numOfVariables(),
                    csolver);

            addSuDokuRules(ch);

            CoordinateSet cs1 = new CoordinateSet(sdSize.getLargeSide(), sdSize
                    .getLargeSide());

            int toAdd = sdSize.getLargeSide();

            for (int v1 = 1; v1 <= toAdd; v1++) {
                Coordinate coord;
                coord = cs1.getCoordinate();
                vi.clear();
                vi.push(variable(coord.getRow(), coord.getColumn(), v1));
                ch.addClause(vi);
            }

            ch.finish();

            try {
                if (csolver.isSatisfiable()) {
                    // System.out.println("Sudoku generated!");
                    success = true;
                    int[] m = csolver.model();
                    for (int i = 0; i < m.length; i++) {
                        if ((m[i] > 0) && (m[i] % sdSize.getBase() != 0)) {
                            v[m[i] / sdSize.getBase2()][(m[i] % sdSize
                                    .getBase2())
                                    / sdSize.getBase()] = m[i]
                                    % sdSize.getBase();
                        }
                    }
                } else {
                }
            } catch (OutOfMemoryError e) {
                gui.setResult("Increased Java Heap size required");
            } catch (Exception ex) {
                ex.printStackTrace();
            }
        }

        CoordinateSet cs = new CoordinateSet(sdSize.getLargeSide(), sdSize
                .getLargeSide());

        RandomPermutation rp;

        if (gui.getUseExtra()) {
            rp = new RandomPermutation(sdSize.getSmallRows(), sdSize
                    .getSmallCols());
        } else {
            rp = new RandomPermutation(sdSize.getLargeSide());
        }

        for (int r = 1; r <= sdSize.getLargeSide(); r++) {
            for (int c = 1; c <= sdSize.getLargeSide(); c++) {
                v[r][c] = rp.permute(v[r][c]);
            }
        }

        int requiredCells = filledCells;

        if (onlyCreateUnique) {
            requiredCells = 0;

            try {

                ISolver solver = SolverFactory.newBackjumping();
                // SingleSolutionDetector problem = new
                // SingleSolutionDetector(SolverFactory.newMiniSAT());
                Sat4jClauseHandler chp = new Sat4jClauseHandler(
                        numOfVariables(), solver);

                addSuDokuRules(chp);

                vi.clear();
                for (int r = 1; r <= sdSize.getLargeSide(); r++) {
                    for (int c = 1; c <= sdSize.getLargeSide(); c++) {
                        vi.push(-variable(r, c, v[r][c]));
                    }
                }
                chp.addClause(vi);

                boolean finished = false;

                SortedCoordinateSet s = new SortedCoordinateSet(sdSize
                        .getLargeSide(), sdSize.getLargeSide(), sdSize
                        .getSmallRows(), sdSize.getSmallCols(), v);
                int addedCount = 0;
                while (!finished) {
                    if (solver.isSatisfiable()) {
                        if (progressbar.isCanceled()) {
                            break;
                        }
                        // System.out.println("Simplifying Sudoku "+addedCount);
                        progressbar.setProgress(addedCount + 1);
                        int[] m = solver.model();
                        for (int i = 0; i < m.length; i++) {
                            if (m[i] > 0) {
                                int r = m[i] / sdSize.getBase2();
                                int c = (m[i] % sdSize.getBase2())
                                        / sdSize.getBase();
                                int val = m[i] % sdSize.getBase();
                                testv[r][c] = val;
                            }
                        }

                        boolean differenceFound = false;
                        Coordinate[] ccs = s.getAll();
                        for (int i = 0; !differenceFound; i++) {
                            Coordinate cc = ccs[i];
                            int r = cc.getRow();
                            int c = cc.getColumn();
                            if (v[r][c] != testv[r][c]) {
                                s.note(cc);
                                cellGrid.setIntValue(r, c, v[r][c]);
                                requiredCells++;
                                differenceFound = true;
                                addedCount++;
                                vi.clear();
                                vi.push(variable(r, c, v[r][c]));
                                try {
                                    chp.addClauseUnTrapped(vi);
                                } catch (ContradictionException ce) {
                                    finished = true;
                                }
                            }
                        }
                    } else {
                        finished = true;
                    }
                }

            } catch (Exception e) {
                e.printStackTrace();
            }

        } else {
            for (int i = 0; i < requiredCells / 4; i++) {
                Coordinate coords[] = cs.getGroup();
                for (int j = 0; j < 4; j++) {
                    cellGrid.setIntValue(coords[j].getRow(), coords[j]
                            .getColumn(), v[coords[j].getRow()][coords[j]
                            .getColumn()]);
                }
            }
            for (int j = 0; j < requiredCells % 4; j++) {
                Coordinate c = cs.getCoordinate();
                cellGrid.setIntValue(c.getRow(), c.getColumn(), v[c.getRow()][c
                        .getColumn()]);
            }

        }
        if (progressbar.isCanceled()) {
            cellGrid.clearAll();
        } else {
            gui.setFillCount(requiredCells);
            gui.setProtection(true);
        }
        progressbar.close();
    }
