public void graphicalSolve(CellGrid cellGrid, boolean showModel)
            throws Exception {
        System.gc();
        fullCNF = true;
        StringBuilder model = new StringBuilder("s SATISFIABLE\n");
        clauses = 0;

        solver = SolverFactory.newDefault();

        Sat4jClauseHandler ch = new Sat4jClauseHandler(numOfVariables(), solver);

        addSuDokuRules(ch);

        readPuzzleSolver(cellGrid, ch);

        ch.finish();

        gui.setResult("");

        try {
            if (solver.isSatisfiable()) {
                int[] m = solver.model();
                for (int i = 0; i < m.length; i++) {
                    if (showModel) {
                        model.append("v " + m[i] + "\n");
                    }

                    if ((m[i] > 0) && (m[i] % sdSize.getBase() != 0)) {
                        gui.getCellGrid().solverSetIntValue(
                                m[i] / sdSize.getBase2(),
                                (m[i] % sdSize.getBase2()) / sdSize.getBase(),
                                m[i] % sdSize.getBase());
                    }
                }
                if (showModel) {
                    model.append("v 0\n");
                    gui.setCNFModel(model.toString());
                }
            } else {
                gui.setResult("Cannot be solved");
                if (showModel) {
                    gui.setCNFModel("s UNSATISFIABLE");
                }
            }
        } catch (OutOfMemoryError e) {
            System.gc();
            gui.setResult("Increased Java Heap size required");
        } catch (Exception ex) {
            ex.printStackTrace();
        }

    }
