/*
 * Copyright (c) 2002-2017, Mairie de Paris
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice
 *     and the following disclaimer.
 *
 *  2. Redistributions in binary form must reproduce the above copyright notice
 *     and the following disclaimer in the documentation and/or other materials
 *     provided with the distribution.
 *
 *  3. Neither the name of 'Mairie de Paris' nor 'Lutece' nor the names of its
 *     contributors may be used to endorse or promote products derived from
 *     this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * License 1.0
 */
package fr.paris.lutece.util.jpa;

import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * Interface IGenericLuteceHome
 * 
 * @param <K>
 *            key class
 * @param <E>
 *            entity class
 */
public interface IGenericHome<K, E>
{
    /**
     * Creates the entity
     * 
     * @param entity
     *            object
     */
    void create( E entity );

    /**
     * Merges the entity
     * 
     * @param entity
     *            object
     */
    void update( E entity );

    /**
     * Removes the entity if exists
     * 
     * @param key
     *            The entity key
     */
    void remove( K key );

    /**
     * Loads an entity by its key
     * 
     * @param pKey
     *            primary key
     * @return the found entity, <code>null</code> otherwise.
     */
    @Transactional( readOnly = true )
    E findByPrimaryKey( K pKey );

    /**
     * Finds all
     * 
     * @return the list
     */
    @Transactional( readOnly = true )
    List<E> findAll( );
}
