/*
 * JORAM: Java(TM) Open Reliable Asynchronous Messaging
 * Copyright (C) 2003 - 2020 ScalAgent Distributed Technologies
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA.
 *
 * Initial developer(s): Frederic Maistre (INRIA)
 * Contributor(s): ScalAgent Distributed Technologies
 */
package org.objectweb.joram.shared.admin;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;

import fr.dyade.aaa.common.stream.StreamUtil;

/**
 * A <code>Monitor_GetServersIdsRep</code> instance holds the list of the
 * platform's servers' identifiers.
 */
public class GetServersIdsReply extends AdminReply {
  private static final long serialVersionUID = 1L;

  /** Servers identifiers. */
  private int[] ids;

  private String[] names;

  private String[] hostnames;

  /**
   * Constructs a <code>Monitor_GetServersRep</code> instance.
   * 
   * @param ids List of the platform's servers' identifiers.
   * @param names List of the platform's servers' names.
   * @param hostnames List of the platform's servers' hostnames.
   */
  public GetServersIdsReply(int[] ids,
                                  String[] names,
                                  String[] hostnames) {
    super(true, null);
    this.ids = ids;
    this.names = names;
    this.hostnames = hostnames;
  }

  /**
   * Returns the servers' identifiers.
   * 
   * @return List of the platform's servers' identifiers.
   */
  public /*@ pure @*/ final int[] getIds() {
    return ids;
  }

  public /*@ pure @*/ final String[] getNames() {
    return names;
  }

  public final String[] getHostNames() {
    return hostnames;
  }
  
  public GetServersIdsReply() { }
  
  protected int getClassId() {
    return MONITOR_GET_SERVERS_IDS_REP;
  }
  
  public void readFrom(InputStream is) throws IOException {
    super.readFrom(is);
    ids = StreamUtil.readArrayOfIntFrom(is);
    names = StreamUtil.readArrayOfStringFrom(is);
    hostnames = StreamUtil.readArrayOfStringFrom(is);
  }

  public void writeTo(OutputStream os) throws IOException {
    super.writeTo(os);
    StreamUtil.writeArrayOfIntTo(ids, os);
    StreamUtil.writeArrayOfStringTo(names, os);
    StreamUtil.writeArrayOfStringTo(hostnames, os);
  }
}
