/*
 * JORAM: Java(TM) Open Reliable Asynchronous Messaging
 * Copyright (C) 2013 ScalAgent Distributed Technologies
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA.
 *
 * Initial developer(s): ScalAgent Distributed Technologies
 * Contributor(s): 
 */
package org.objectweb.joram.shared.client;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;

import fr.dyade.aaa.common.stream.StreamUtil;

/**
 * A <code>AddClientIDRequest</code> is sent by an setClientID on
 * <code>Connection</code>.
 */
public final class AddClientIDRequest extends AbstractJmsRequest {
  private static final long serialVersionUID = 1L;

  protected int getClassId() {
    return ADD_CLIENTID_REQUEST;
  }
  
  public String clientID = null;

  /**
   * Constructs a <code>AddClientIDRequest</code>.
   */
  public AddClientIDRequest() {
    super(null);
  }
  
  public AddClientIDRequest(String clientID) {
    super(null);
    this.clientID = clientID;
  }
  
  /* ***** ***** ***** ***** *****
   * Streamable interface
   * ***** ***** ***** ***** ***** */

  /**
   *  The object implements the writeTo method to write its contents to
   * the output stream.
   *
   * @param os the stream to write the object to
   */
  public void writeTo(OutputStream os) throws IOException {
    super.writeTo(os);
    StreamUtil.writeTo(clientID, os);
  }

  /**
   *  The object implements the readFrom method to restore its contents from
   * the input stream.
   *
   * @param is the stream to read data from in order to restore the object
   */
   /*@ modifies this.clientID; @*/
  public void readFrom(InputStream is) throws IOException {
    super.readFrom(is);
    clientID = StreamUtil.readStringFrom(is);
  }
}
